@@ -21,9 +21,12 @@ package org.apache.flink.client.cli;
 import org.apache.flink.client.program.PackagedProgram;
 import org.apache.flink.configuration.Configuration;
 import org.apache.flink.configuration.CoreOptions;
+import org.apache.flink.configuration.SecurityOptions;
+import org.apache.flink.runtime.security.SecurityConfiguration;
 import org.apache.flink.util.ChildFirstClassLoader;
 import org.apache.flink.util.FlinkUserCodeClassLoaders.ParentFirstClassLoader;
 
+import org.apache.commons.cli.CommandLine;
 import org.apache.commons.cli.Options;
 import org.junit.jupiter.api.AfterAll;
 import org.junit.jupiter.api.BeforeAll;
@@ -31,6 +34,7 @@ import org.junit.jupiter.api.BeforeEach;
 import org.junit.jupiter.api.Test;
 import org.junit.jupiter.api.io.TempDir;
 
+import java.io.File;
 import java.util.Collections;
 import java.util.HashMap;
 import java.util.Map;
@@ -167,6 +171,28 @@ class CliFrontendDynamicPropertiesTest {
                 configuration, args, cliUnderTest, expectedConfigValues);
     }
 
+    @Test
+    public void testSecurityConfigWithDynamicProperties(@TempDir File tempDir) throws Exception {
+        File keytabFile = new File(tempDir, "keytab.file");
+        keytabFile.createNewFile();
+        String[] args = {
+            "-e",
+            "test-executor",
+            "-D" + SecurityOptions.KERBEROS_LOGIN_KEYTAB.key() + "=" + keytabFile.getPath(),
+            "-D" + SecurityOptions.KERBEROS_LOGIN_PRINCIPAL.key() + "=principal",
+            getTestJarPath(),
+        };
+        TestingCliFrontendWithDynamicProperties testFrontend =
+                new TestingCliFrontendWithDynamicProperties(
+                        configuration, cliUnderTest, null, null);
+        CommandLine commandLine = testFrontend.getCommandLine(new Options(), args, true);
+        Configuration securityConfig = new Configuration(configuration);
+        DynamicPropertiesUtil.encodeDynamicProperties(commandLine, securityConfig);
+        SecurityConfiguration securityConfiguration = new SecurityConfiguration(securityConfig);
+        assertThat(securityConfiguration.getKeytab()).isEqualTo(keytabFile.getPath());
+        assertThat(securityConfiguration.getPrincipal()).isEqualTo("principal");
+    }
+
     // --------------------------------------------------------------------------------------------
 
     public static void verifyCliFrontendWithDynamicProperties(
