@@ -45,7 +45,6 @@ import org.apache.flink.runtime.jobgraph.JobGraph;
 import org.apache.flink.runtime.jobgraph.JobGraphTestUtils;
 import org.apache.flink.runtime.jobgraph.JobType;
 import org.apache.flink.runtime.jobgraph.JobVertexID;
-import org.apache.flink.runtime.jobgraph.OperatorID;
 import org.apache.flink.runtime.jobmaster.JobResult;
 import org.apache.flink.runtime.messages.Acknowledge;
 import org.apache.flink.runtime.messages.FlinkJobNotFoundException;
@@ -1184,7 +1183,7 @@ class RestClusterClientTest {
             TestCoordinationRequest<String> request = new TestCoordinationRequest<>(payload);
             try {
                 CompletableFuture<CoordinationResponse> future =
-                        restClusterClient.sendCoordinationRequest(jobId, new OperatorID(), request);
+                        restClusterClient.sendCoordinationRequest(jobId, "uid", request);
                 TestCoordinationResponse response = (TestCoordinationResponse) future.get();
 
                 assertThat(response.payload).isEqualTo(payload);
@@ -1207,8 +1206,7 @@ class RestClusterClientTest {
                 assertThatThrownBy(
                                 () ->
                                         restClusterClient
-                                                .sendCoordinationRequest(
-                                                        jobId, new OperatorID(), request)
+                                                .sendCoordinationRequest(jobId, "uid", request)
                                                 .get())
                         .matches(
                                 e ->
@@ -1279,7 +1277,9 @@ class RestClusterClientTest {
                         Collections.singletonMap(JobStatus.RUNNING, 1L),
                         jobVertexDetailsInfos,
                         Collections.singletonMap(ExecutionState.RUNNING, 1),
-                        new JobPlanInfo.RawJson("{\"id\":\"1234\"}"));
+                        new JobPlanInfo.RawJson("{\"id\":\"1234\"}"),
+                        new JobPlanInfo.RawJson("{\"id\":\"1234\"}"),
+                        0);
         final TestJobDetailsInfoHandler jobDetailsInfoHandler =
                 new TestJobDetailsInfoHandler(jobDetailsInfo);
 
