@@ -18,7 +18,6 @@
 package org.apache.flink.connector.base.source.reader;
 
 import org.apache.flink.api.common.functions.RichMapFunction;
-import org.apache.flink.api.common.restartstrategy.RestartStrategies;
 import org.apache.flink.api.common.state.CheckpointListener;
 import org.apache.flink.configuration.CheckpointingOptions;
 import org.apache.flink.configuration.Configuration;
@@ -29,14 +28,13 @@ import org.apache.flink.configuration.TaskManagerOptions;
 import org.apache.flink.runtime.testutils.MiniClusterResourceConfiguration;
 import org.apache.flink.streaming.api.datastream.DataStream;
 import org.apache.flink.streaming.api.environment.StreamExecutionEnvironment;
-import org.apache.flink.streaming.api.functions.sink.SinkFunction;
-import org.apache.flink.test.util.MiniClusterWithClientResource;
-import org.apache.flink.util.TestLogger;
+import org.apache.flink.streaming.api.functions.sink.legacy.SinkFunction;
+import org.apache.flink.streaming.util.RestartStrategyUtils;
+import org.apache.flink.test.junit5.MiniClusterExtension;
 
-import org.junit.ClassRule;
-import org.junit.Rule;
-import org.junit.Test;
-import org.junit.rules.TemporaryFolder;
+import org.junit.jupiter.api.Test;
+import org.junit.jupiter.api.extension.RegisterExtension;
+import org.junit.jupiter.api.io.TempDir;
 
 import javax.annotation.Nullable;
 
@@ -53,31 +51,29 @@ import static org.apache.flink.runtime.state.filesystem.AbstractFsCheckpointStor
 import static org.assertj.core.api.Assertions.assertThatThrownBy;
 
 /** Tests if the coordinator handles up and downscaling. */
-public class CoordinatedSourceRescaleITCase extends TestLogger {
+class CoordinatedSourceRescaleITCase {
 
     public static final String CREATED_CHECKPOINT = "successfully created checkpoint";
     public static final String RESTORED_CHECKPOINT = "successfully restored checkpoint";
 
-    @ClassRule
-    public static final MiniClusterWithClientResource MINI_CLUSTER =
-            new MiniClusterWithClientResource(
+    @RegisterExtension
+    private static final MiniClusterExtension miniClusterResource =
+            new MiniClusterExtension(
                     new MiniClusterResourceConfiguration.Builder()
                             .setNumberTaskManagers(1)
                             .setNumberSlotsPerTaskManager(7)
                             .build());
 
-    @Rule public final TemporaryFolder temp = new TemporaryFolder();
-
     @Test
-    public void testDownscaling() throws Exception {
-        final File checkpointDir = temp.newFolder();
+    void testDownscaling(@TempDir Path tempDir) throws Exception {
+        final File checkpointDir = tempDir.toFile();
         final File lastCheckpoint = generateCheckpoint(checkpointDir, 7);
         resumeCheckpoint(checkpointDir, lastCheckpoint, 3);
     }
 
     @Test
-    public void testUpscaling() throws Exception {
-        final File checkpointDir = temp.newFolder();
+    void testUpscaling(@TempDir Path temp) throws Exception {
+        final File checkpointDir = temp.toFile();
         final File lastCheckpoint = generateCheckpoint(checkpointDir, 3);
         resumeCheckpoint(checkpointDir, lastCheckpoint, 7);
     }
@@ -124,7 +120,7 @@ public class CoordinatedSourceRescaleITCase extends TestLogger {
         env.getCheckpointConfig()
                 .setExternalizedCheckpointRetention(
                         ExternalizedCheckpointRetention.RETAIN_ON_CANCELLATION);
-        env.setRestartStrategy(RestartStrategies.noRestart());
+        RestartStrategyUtils.configureNoRestartStrategy(env);
 
         DataStream<Long> stream = env.fromSequence(0, Long.MAX_VALUE);
         stream.map(new FailingMapFunction(restoreCheckpoint == null)).addSink(new SleepySink());
