@@ -19,7 +19,6 @@
 package org.apache.flink.connector.file.sink.compactor.operator;
 
 import org.apache.flink.annotation.Internal;
-import org.apache.flink.api.common.ExecutionConfig;
 import org.apache.flink.api.common.serialization.SerializerConfig;
 import org.apache.flink.api.common.typeinfo.TypeInformation;
 import org.apache.flink.api.common.typeutils.TypeSerializer;
@@ -82,11 +81,6 @@ public class CompactorRequestTypeInfo extends TypeInformation<CompactorRequest>
                 () -> new CompactorRequestSerializer(createCommittableSerializer()));
     }
 
-    @Override
-    public TypeSerializer<CompactorRequest> createSerializer(ExecutionConfig config) {
-        return createSerializer(config.getSerializerConfig());
-    }
-
     @Override
     public String toString() {
         return "CompactorRequestTypeInfo{" + "serializer=" + createCommittableSerializer() + '}';
