@@ -62,7 +62,7 @@ public class HiveOutputFormatFactory implements OutputFormatFactory<Row> {
         public void configure(Configuration parameters) {}
 
         @Override
-        public void open(int taskNumber, int numTasks) {}
+        public void open(InitializationContext context) {}
 
         @Override
         public void writeRecord(Row record) throws IOException {
