@@ -19,7 +19,6 @@
 package org.apache.flink.connectors.hive;
 
 import org.apache.flink.api.common.eventtime.WatermarkStrategy;
-import org.apache.flink.api.common.restartstrategy.RestartStrategies;
 import org.apache.flink.api.common.typeinfo.Types;
 import org.apache.flink.api.java.typeutils.RowTypeInfo;
 import org.apache.flink.connector.datagen.source.TestDataGenerators;
@@ -27,6 +26,7 @@ import org.apache.flink.connector.file.table.FileSystemConnectorOptions;
 import org.apache.flink.core.fs.Path;
 import org.apache.flink.streaming.api.datastream.DataStream;
 import org.apache.flink.streaming.api.environment.StreamExecutionEnvironment;
+import org.apache.flink.streaming.util.RestartStrategyUtils;
 import org.apache.flink.table.api.DataTypes;
 import org.apache.flink.table.api.ExplainDetail;
 import org.apache.flink.table.api.Expressions;
@@ -45,7 +45,7 @@ import org.apache.flink.util.CloseableIterator;
 import org.apache.flink.util.CollectionUtil;
 import org.apache.flink.util.TestLoggerExtension;
 
-import org.apache.flink.shaded.guava31.com.google.common.collect.Lists;
+import org.apache.flink.shaded.guava32.com.google.common.collect.Lists;
 
 import org.apache.hadoop.hive.conf.HiveConf;
 import org.junit.jupiter.api.AfterAll;
@@ -272,7 +272,7 @@ class HiveTableSinkITCase {
                                     + "'partition.time-extractor.timestamp-pattern'='$pt_day $pt_hour:00:00',"
                                     + "'streaming-source.enable'='true',"
                                     + "'streaming-source.monitor-interval'='1s',"
-                                    + "'streaming-source.consume-order'='partition-time'"
+                                    + "'streaming-source.partition-order'='partition-time'"
                                     + ")");
 
                     tEnv.executeSql(
@@ -292,7 +292,7 @@ class HiveTableSinkITCase {
                                     + " 'sink.partition-commit.success-file.name'='_MY_SUCCESS',"
                                     + " 'streaming-source.enable'='true',"
                                     + " 'streaming-source.monitor-interval'='1s',"
-                                    + " 'streaming-source.consume-order'='partition-time'"
+                                    + " 'streaming-source.partition-order'='partition-time'"
                                     + ")");
 
                     tEnv.getConfig().setSqlDialect(SqlDialect.DEFAULT);
@@ -774,7 +774,7 @@ class HiveTableSinkITCase {
         env.setParallelism(1);
         env.enableCheckpointing(100);
         // avoid the job to restart infinitely
-        env.setRestartStrategy(RestartStrategies.fixedDelayRestart(3, 1_000));
+        RestartStrategyUtils.configureFixedDelayRestartStrategy(env, 3, 1000L);
 
         StreamTableEnvironment tEnv = HiveTestUtils.createTableEnvInStreamingMode(env);
         tEnv.registerCatalog(hiveCatalog.getName(), hiveCatalog);
