@@ -535,7 +535,10 @@ public class HiveTableSourceITCase extends BatchAbstractTestBase {
         final String dbName = "source_db";
         final String tblName = "test_parallelism_limit_pushdown";
         TableEnvironment tEnv = createTableEnv();
-        tEnv.getConfig().set(HiveOptions.TABLE_EXEC_HIVE_INFER_SOURCE_PARALLELISM, false);
+        tEnv.getConfig()
+                .set(
+                        HiveOptions.TABLE_EXEC_HIVE_INFER_SOURCE_PARALLELISM_MODE,
+                        HiveOptions.InferMode.NONE);
         tEnv.getConfig().set(ExecutionConfigOptions.TABLE_EXEC_RESOURCE_DEFAULT_PARALLELISM, 2);
         tEnv.executeSql(
                 "CREATE TABLE source_db.test_parallelism_limit_pushdown "
@@ -571,7 +574,10 @@ public class HiveTableSourceITCase extends BatchAbstractTestBase {
         tEnv.getConfig().setSqlDialect(SqlDialect.HIVE);
         tEnv.registerCatalog("hive", hiveCatalog);
         tEnv.useCatalog("hive");
-        tEnv.getConfig().set(HiveOptions.TABLE_EXEC_HIVE_INFER_SOURCE_PARALLELISM, false);
+        tEnv.getConfig()
+                .set(
+                        HiveOptions.TABLE_EXEC_HIVE_INFER_SOURCE_PARALLELISM_MODE,
+                        HiveOptions.InferMode.NONE);
         tEnv.executeSql(
                 "CREATE TABLE source_db.test_parallelism_no_infer "
                         + "(`year` STRING, `value` INT) partitioned by (pt int)");
@@ -691,7 +697,7 @@ public class HiveTableSourceITCase extends BatchAbstractTestBase {
                         + " p1 string, p2 string, p3 string) TBLPROPERTIES("
                         + "'streaming-source.enable'='true',"
                         + "'streaming-source.partition-include'='all',"
-                        + "'streaming-source.consume-order'='create-time',"
+                        + "'streaming-source.partition-order'='create-time',"
                         + "'streaming-source.monitor-interval'='1s',"
                         + "'streaming-source.consume-start-offset'='2020-10-02 00:00:00'"
                         + ")");
@@ -747,7 +753,7 @@ public class HiveTableSourceITCase extends BatchAbstractTestBase {
                         + ") PARTITIONED BY (ts STRING) TBLPROPERTIES ("
                         + "'streaming-source.enable'='true',"
                         + "'streaming-source.monitor-interval'='1s',"
-                        + "'streaming-source.consume-order'='partition-time'"
+                        + "'streaming-source.partition-order'='partition-time'"
                         + ")");
 
         HiveTestUtils.createTextTableInserter(hiveCatalog, dbName, tblName)
@@ -872,8 +878,17 @@ public class HiveTableSourceITCase extends BatchAbstractTestBase {
 
         TableEnvironment tableEnv = HiveTestUtils.createTableEnvInBatchMode();
         tableEnv.getConfig().set(HiveOptions.TABLE_EXEC_HIVE_FALLBACK_MAPRED_READER, fallbackMR);
-        tableEnv.getConfig()
-                .set(HiveOptions.TABLE_EXEC_HIVE_INFER_SOURCE_PARALLELISM, inferParallelism);
+        if (inferParallelism) {
+            tableEnv.getConfig()
+                    .set(
+                            HiveOptions.TABLE_EXEC_HIVE_INFER_SOURCE_PARALLELISM_MODE,
+                            HiveOptions.InferMode.STATIC);
+        } else {
+            tableEnv.getConfig()
+                    .set(
+                            HiveOptions.TABLE_EXEC_HIVE_INFER_SOURCE_PARALLELISM_MODE,
+                            HiveOptions.InferMode.NONE);
+        }
         tableEnv.getConfig().set(ExecutionConfigOptions.TABLE_EXEC_RESOURCE_DEFAULT_PARALLELISM, 2);
         tableEnv.registerCatalog(catalogSpy.getName(), catalogSpy);
         tableEnv.useCatalog(catalogSpy.getName());
@@ -1035,19 +1050,7 @@ public class HiveTableSourceITCase extends BatchAbstractTestBase {
         sortedRows.addAll(rows);
         sortedRows.addAll(rows);
         sortedRows.sort(Comparator.comparingInt(o -> (Integer) o.getField(0)));
-
-        List<Row> expectedRows = new ArrayList<>();
-        for (int i = 0; i < sortedRows.size(); i++) {
-            Row rowExpect = Row.copy(sortedRows.get(i));
-            Row nestedRow = (Row) rowExpect.getField(2);
-            if (nestedRow.getField(0) == null
-                    && nestedRow.getField(1) == null
-                    && nestedRow.getField(2) == null) {
-                rowExpect.setField(2, null);
-            }
-            expectedRows.add(rowExpect);
-        }
-        return expectedRows;
+        return sortedRows;
     }
 
     private static CloseableIterator<Row> executeAndGetResult(StreamTableEnvironment tEnv)
