@@ -21,7 +21,6 @@ package org.apache.flink.connectors.hive;
 import org.apache.flink.table.api.SqlDialect;
 import org.apache.flink.table.catalog.hive.HiveCatalog;
 import org.apache.flink.table.catalog.hive.HiveTestUtils;
-import org.apache.flink.table.catalog.hive.client.HiveShimLoader;
 import org.apache.flink.table.plan.stats.ColumnStats;
 import org.apache.flink.table.plan.stats.TableStats;
 import org.apache.flink.table.planner.plan.stats.FlinkStatistic;
@@ -41,10 +40,7 @@ import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
 
-import static org.apache.flink.table.catalog.hive.client.HiveShimLoader.HIVE_VERSION_V2_3_9;
-import static org.apache.flink.table.catalog.hive.client.HiveShimLoader.HIVE_VERSION_V3_1_1;
 import static org.assertj.core.api.Assertions.assertThat;
-import static org.assertj.core.api.Assertions.fail;
 
 /** Test for statistics functionality in {@link HiveTableSource}. */
 public class HiveTableSourceStatisticsReportTest extends StatisticsReportTestBase {
@@ -99,11 +95,20 @@ public class HiveTableSourceStatisticsReportTest extends StatisticsReportTestBas
     }
 
     @Test
-    public void testMapRedCsvFormatHiveTableSourceStatisticsReport() {
+    public void testMapRedCsvFormatHiveTableSourceStatisticsReport() throws Exception {
+        final String tableName = "testTable";
+        tEnv.executeSql(
+                String.format(
+                        "create table %s.%s.%s ( f_int int )", catalogName, dbName, tableName));
+        tEnv.executeSql(
+                        String.format(
+                                "insert into %s.%s.%s select f_int from %s.%s.%s",
+                                catalogName, dbName, tableName, catalogName, dbName, sourceTable))
+                .await();
         FlinkStatistic statistic =
                 getStatisticsFromOptimizedPlan(
-                        String.format("select * from %s.%s.%s", catalogName, dbName, sourceTable));
-        assertThat(statistic.getTableStats()).isEqualTo(TableStats.UNKNOWN);
+                        String.format("select * from %s.%s.%s", catalogName, dbName, tableName));
+        assertThat(statistic.getTableStats()).isEqualTo(new TableStats(4));
     }
 
     @Test
@@ -187,12 +192,20 @@ public class HiveTableSourceStatisticsReportTest extends StatisticsReportTestBas
     }
 
     @Test
-    public void testHiveTableSourceWithLimitPushDown() {
+    public void testHiveTableSourceWithLimitPushDown() throws Exception {
+        final String tableName = "pushDownTable";
+        tEnv.executeSql(
+                String.format(
+                        "create table %s.%s.%s ( f_int int )", catalogName, dbName, tableName));
+        tEnv.executeSql(
+                        String.format(
+                                "insert into %s.%s.%s select f_int from %s.%s.%s",
+                                catalogName, dbName, tableName, catalogName, dbName, sourceTable))
+                .await();
         FlinkStatistic statistic =
                 getStatisticsFromOptimizedPlan(
                         String.format(
-                                "select * from %s.%s.%s limit 1",
-                                catalogName, dbName, sourceTable));
+                                "select * from %s.%s.%s limit 1", catalogName, dbName, tableName));
         assertThat(statistic.getTableStats()).isEqualTo(new TableStats(1));
     }
 
@@ -299,46 +312,20 @@ public class HiveTableSourceStatisticsReportTest extends StatisticsReportTestBas
         expectedColumnStatsMap.put(
                 "f_string",
                 new ColumnStats.Builder().setMax("def").setMin("abcd").setNullCount(0L).build());
-        switch (HiveShimLoader.getHiveVersion()) {
-            case HIVE_VERSION_V2_3_9:
-                expectedColumnStatsMap.put(
-                        "f_decimal5",
-                        new ColumnStats.Builder()
-                                .setMax(new BigDecimal("223.45"))
-                                .setMin(new BigDecimal("123.45"))
-                                .setNullCount(0L)
-                                .build());
-                expectedColumnStatsMap.put(
-                        "f_decimal14",
-                        new ColumnStats.Builder()
-                                .setMax(new BigDecimal("123333333355.33"))
-                                .setMin(new BigDecimal("123333333333.33"))
-                                .setNullCount(0L)
-                                .build());
-                break;
-            case HIVE_VERSION_V3_1_1:
-                // TODO For hive 3.x version, Orc format encounter decimal type columns (like
-                // decimal(5, 2), decimal(14, 2)) will write a wrong column stat 'min' or 'max' in
-                // orc metadata footer. This branch will remove after this error is fixed, following
-                // issue HIVE-26492
-                expectedColumnStatsMap.put(
-                        "f_decimal5",
-                        new ColumnStats.Builder()
-                                .setMax(new BigDecimal("223.45"))
-                                .setMin(new BigDecimal("0"))
-                                .setNullCount(0L)
-                                .build());
-                expectedColumnStatsMap.put(
-                        "f_decimal14",
-                        new ColumnStats.Builder()
-                                .setMax(new BigDecimal("123333333355.33"))
-                                .setMin(new BigDecimal("0"))
-                                .setNullCount(0L)
-                                .build());
-                break;
-            default:
-                fail("Unknown test version " + HiveShimLoader.getHiveVersion());
-        }
+        expectedColumnStatsMap.put(
+                "f_decimal5",
+                new ColumnStats.Builder()
+                        .setMax(new BigDecimal("223.45"))
+                        .setMin(new BigDecimal("123.45"))
+                        .setNullCount(0L)
+                        .build());
+        expectedColumnStatsMap.put(
+                "f_decimal14",
+                new ColumnStats.Builder()
+                        .setMax(new BigDecimal("123333333355.33"))
+                        .setMin(new BigDecimal("123333333333.33"))
+                        .setNullCount(0L)
+                        .build());
         expectedColumnStatsMap.put(
                 "f_decimal38",
                 new ColumnStats.Builder()
