@@ -19,15 +19,16 @@ package org.apache.flink.connectors.hive.read;
 
 import org.apache.flink.connectors.hive.HiveOptions;
 import org.apache.flink.connectors.hive.HiveTablePartition;
+import org.apache.flink.table.api.Schema;
 import org.apache.flink.table.api.SqlDialect;
 import org.apache.flink.table.api.TableEnvironment;
-import org.apache.flink.table.api.TableSchema;
 import org.apache.flink.table.catalog.ObjectPath;
 import org.apache.flink.table.catalog.hive.HiveCatalog;
 import org.apache.flink.table.catalog.hive.HiveTestUtils;
 import org.apache.flink.table.catalog.hive.client.HiveShimLoader;
 import org.apache.flink.table.catalog.hive.util.HiveReflectionUtils;
 import org.apache.flink.table.data.GenericRowData;
+import org.apache.flink.table.types.DataType;
 import org.apache.flink.util.CollectionUtil;
 
 import org.apache.hadoop.hive.metastore.api.Table;
@@ -58,7 +59,7 @@ public class HiveInputFormatPartitionReaderITCase {
             throws Exception {
         String tableName = prepareData(tableEnv, format);
         ObjectPath tablePath = new ObjectPath("default", tableName);
-        TableSchema tableSchema = hiveCatalog.getTable(tablePath).getSchema();
+        Schema schema = hiveCatalog.getTable(tablePath).getUnresolvedSchema();
         // create partition reader
         HiveInputFormatPartitionReader partitionReader =
                 new HiveInputFormatPartitionReader(
@@ -66,8 +67,12 @@ public class HiveInputFormatPartitionReaderITCase {
                         new JobConf(hiveCatalog.getHiveConf()),
                         hiveCatalog.getHiveVersion(),
                         tablePath,
-                        tableSchema.getFieldDataTypes(),
-                        tableSchema.getFieldNames(),
+                        schema.getColumns().stream()
+                                .map(HiveTestUtils::getType)
+                                .toArray(DataType[]::new),
+                        schema.getColumns().stream()
+                                .map(Schema.UnresolvedColumn::getName)
+                                .toArray(String[]::new),
                         Collections.emptyList(),
                         null,
                         false);
@@ -80,7 +85,7 @@ public class HiveInputFormatPartitionReaderITCase {
                                 HiveShimLoader.loadHiveShim(hiveCatalog.getHiveVersion()),
                                 hiveTable));
         partitionReader.open(Collections.singletonList(tablePartition));
-        GenericRowData reuse = new GenericRowData(tableSchema.getFieldCount());
+        GenericRowData reuse = new GenericRowData(schema.getColumns().size());
         int count = 0;
         // this follows the way the partition reader is used during lookup join
         while (partitionReader.read(reuse) != null) {
