@@ -526,6 +526,11 @@ class HiveCatalogGenericMetadataTest extends HiveCatalogMetadataTestBase {
         throw new UnsupportedOperationException();
     }
 
+    @Override
+    protected boolean supportsModels() {
+        return false;
+    }
+
     @Override
     protected CatalogFunction createFunction() {
         return new CatalogFunctionImpl(TestGenericUDF.class.getCanonicalName());
