@@ -19,13 +19,12 @@
 package org.apache.flink.api.common.serialization;
 
 import org.apache.flink.annotation.Internal;
-import org.apache.flink.api.common.ExecutionConfig;
+import org.apache.flink.api.common.SerializableSerializer;
 import org.apache.flink.api.common.functions.InvalidTypesException;
 import org.apache.flink.api.common.typeinfo.TypeInfoFactory;
 import org.apache.flink.api.java.typeutils.TypeExtractor;
 import org.apache.flink.configuration.Configuration;
 import org.apache.flink.configuration.ConfigurationUtils;
-import org.apache.flink.configuration.GlobalConfiguration;
 import org.apache.flink.configuration.PipelineOptions;
 import org.apache.flink.configuration.ReadableConfig;
 import org.apache.flink.util.Preconditions;
@@ -50,27 +49,20 @@ public final class SerializerConfigImpl implements SerializerConfig {
 
     private final Configuration configuration;
 
-    /**
-     * Note: This field is used only for compatibility while {@link
-     * org.apache.flink.api.common.typeinfo.TypeInformation#createSerializer(ExecutionConfig)} is
-     * deprecated; If it is removed, this field will also be removed.
-     */
-    private final ExecutionConfig executionConfig;
-
     // ------------------------------- User code values --------------------------------------------
 
     // Serializers and types registered with Kryo and the PojoSerializer
     // we store them in linked maps/sets to ensure they are registered in order in all kryo
     // instances.
 
-    private LinkedHashMap<Class<?>, ExecutionConfig.SerializableSerializer<?>>
-            registeredTypesWithKryoSerializers = new LinkedHashMap<>();
+    private LinkedHashMap<Class<?>, SerializableSerializer<?>> registeredTypesWithKryoSerializers =
+            new LinkedHashMap<>();
 
     private LinkedHashMap<Class<?>, Class<? extends Serializer<?>>>
             registeredTypesWithKryoSerializerClasses = new LinkedHashMap<>();
 
-    private LinkedHashMap<Class<?>, ExecutionConfig.SerializableSerializer<?>>
-            defaultKryoSerializers = new LinkedHashMap<>();
+    private LinkedHashMap<Class<?>, SerializableSerializer<?>> defaultKryoSerializers =
+            new LinkedHashMap<>();
 
     private LinkedHashMap<Class<?>, Class<? extends Serializer<?>>> defaultKryoSerializerClasses =
             new LinkedHashMap<>();
@@ -89,13 +81,11 @@ public final class SerializerConfigImpl implements SerializerConfig {
     public SerializerConfigImpl() {
         Configuration conf = new Configuration();
         this.configuration = conf;
-        this.executionConfig = new ExecutionConfig(conf);
     }
 
     @Internal
-    public SerializerConfigImpl(Configuration configuration, ExecutionConfig executionConfig) {
+    public SerializerConfigImpl(Configuration configuration) {
         this.configuration = configuration;
-        this.executionConfig = executionConfig;
     }
 
     /**
@@ -114,7 +104,7 @@ public final class SerializerConfigImpl implements SerializerConfig {
             throw new NullPointerException("Cannot register null class or serializer.");
         }
 
-        defaultKryoSerializers.put(type, new ExecutionConfig.SerializableSerializer<>(serializer));
+        defaultKryoSerializers.put(type, new SerializableSerializer<>(serializer));
     }
 
     /**
@@ -147,8 +137,7 @@ public final class SerializerConfigImpl implements SerializerConfig {
             throw new NullPointerException("Cannot register null class or serializer.");
         }
 
-        registeredTypesWithKryoSerializers.put(
-                type, new ExecutionConfig.SerializableSerializer<>(serializer));
+        registeredTypesWithKryoSerializers.put(type, new SerializableSerializer<>(serializer));
     }
 
     /**
@@ -202,7 +191,7 @@ public final class SerializerConfigImpl implements SerializerConfig {
     }
 
     /** Returns the registered types with Kryo Serializers. */
-    public LinkedHashMap<Class<?>, ExecutionConfig.SerializableSerializer<?>>
+    public LinkedHashMap<Class<?>, SerializableSerializer<?>>
             getRegisteredTypesWithKryoSerializers() {
         return registeredTypesWithKryoSerializers;
     }
@@ -214,8 +203,7 @@ public final class SerializerConfigImpl implements SerializerConfig {
     }
 
     /** Returns the registered default Kryo Serializers. */
-    public LinkedHashMap<Class<?>, ExecutionConfig.SerializableSerializer<?>>
-            getDefaultKryoSerializers() {
+    public LinkedHashMap<Class<?>, SerializableSerializer<?>> getDefaultKryoSerializers() {
         return defaultKryoSerializers;
     }
 
@@ -280,12 +268,10 @@ public final class SerializerConfigImpl implements SerializerConfig {
         configuration.set(PipelineOptions.FORCE_AVRO, forceAvro);
     }
 
-    @Override
     public void setForceKryoAvro(boolean forceKryoAvro) {
         configuration.set(PipelineOptions.FORCE_KRYO_AVRO, forceKryoAvro);
     }
 
-    @Override
     public TernaryBoolean isForceKryoAvroEnabled() {
         return configuration
                 .getOptional(PipelineOptions.FORCE_KRYO_AVRO)
@@ -368,80 +354,9 @@ public final class SerializerConfigImpl implements SerializerConfig {
         configuration
                 .getOptional(PipelineOptions.FORCE_KRYO_AVRO)
                 .ifPresent(this::setForceKryoAvro);
-
         configuration
-                .getOptional(PipelineOptions.KRYO_DEFAULT_SERIALIZERS)
-                .map(s -> parseKryoSerializersWithExceptionHandling(classLoader, s))
-                .ifPresent(s -> this.defaultKryoSerializerClasses = s);
-
-        configuration
-                .getOptional(PipelineOptions.POJO_REGISTERED_CLASSES)
-                .map(c -> loadClasses(c, classLoader, "Could not load pojo type to be registered."))
-                .ifPresent(c -> this.registeredPojoTypes = c);
-
-        configuration
-                .getOptional(PipelineOptions.KRYO_REGISTERED_CLASSES)
-                .map(c -> loadClasses(c, classLoader, "Could not load kryo type to be registered."))
-                .ifPresent(c -> this.registeredKryoTypes = c);
-
-        try {
-            configuration
-                    .getOptional(PipelineOptions.SERIALIZATION_CONFIG)
-                    .ifPresent(c -> parseSerializationConfigWithExceptionHandling(classLoader, c));
-        } catch (Exception e) {
-            if (!GlobalConfiguration.isStandardYaml()) {
-                throw new UnsupportedOperationException(
-                        String.format(
-                                "%s is only supported with the standard YAML config parser, please use \"config.yaml\" as the config file.",
-                                PipelineOptions.SERIALIZATION_CONFIG.key()));
-            }
-            throw e;
-        }
-    }
-
-    private LinkedHashSet<Class<?>> loadClasses(
-            List<String> classNames, ClassLoader classLoader, String errorMessage) {
-        return classNames.stream()
-                .map(name -> this.<Class<?>>loadClass(name, classLoader, errorMessage))
-                .collect(Collectors.toCollection(LinkedHashSet::new));
-    }
-
-    private LinkedHashMap<Class<?>, Class<? extends Serializer<?>>>
-            parseKryoSerializersWithExceptionHandling(
-                    ClassLoader classLoader, List<String> kryoSerializers) {
-        try {
-            return parseKryoSerializers(classLoader, kryoSerializers);
-        } catch (Exception e) {
-            throw new IllegalArgumentException(
-                    String.format(
-                            "Could not configure kryo serializers from %s. The expected format is:"
-                                    + "'class:<fully qualified class name>,serializer:<fully qualified serializer name>;...",
-                            kryoSerializers),
-                    e);
-        }
-    }
-
-    private LinkedHashMap<Class<?>, Class<? extends Serializer<?>>> parseKryoSerializers(
-            ClassLoader classLoader, List<String> kryoSerializers) {
-        return kryoSerializers.stream()
-                .map(ConfigurationUtils::parseStringToMap)
-                .collect(
-                        Collectors.toMap(
-                                m ->
-                                        loadClass(
-                                                m.get("class"),
-                                                classLoader,
-                                                "Could not load class for kryo serialization"),
-                                m ->
-                                        loadClass(
-                                                m.get("serializer"),
-                                                classLoader,
-                                                "Could not load serializer's class"),
-                                (m1, m2) -> {
-                                    throw new IllegalArgumentException(
-                                            "Duplicated serializer for class: " + m1);
-                                },
-                                LinkedHashMap::new));
+                .getOptional(PipelineOptions.SERIALIZATION_CONFIG)
+                .ifPresent(c -> parseSerializationConfigWithExceptionHandling(classLoader, c));
     }
 
     @SuppressWarnings("unchecked")
@@ -566,15 +481,6 @@ public final class SerializerConfigImpl implements SerializerConfig {
         registeredTypeInfoFactories.put(t, factory);
     }
 
-    /**
-     * Note: This method is used only for compatibility while {@link
-     * org.apache.flink.api.common.typeinfo.TypeInformation#createSerializer(ExecutionConfig)} is
-     * deprecated; If it is removed, this method will also be removed.
-     */
-    public ExecutionConfig getExecutionConfig() {
-        return executionConfig;
-    }
-
     @Override
     public SerializerConfigImpl copy() {
         final SerializerConfigImpl newSerializerConfig = new SerializerConfigImpl();
