@@ -112,11 +112,6 @@ public class SqlTimeTypeInfo<T> extends TypeInformation<T> implements AtomicType
         return serializer;
     }
 
-    @Override
-    public TypeSerializer<T> createSerializer(ExecutionConfig config) {
-        return createSerializer(config.getSerializerConfig());
-    }
-
     @Override
     public TypeComparator<T> createComparator(
             boolean sortOrderAscending, ExecutionConfig executionConfig) {
