@@ -30,6 +30,7 @@ import org.apache.flink.api.java.typeutils.ObjectArrayTypeInfo;
 import org.apache.flink.api.java.typeutils.PojoField;
 import org.apache.flink.api.java.typeutils.PojoTypeInfo;
 import org.apache.flink.api.java.typeutils.RowTypeInfo;
+import org.apache.flink.api.java.typeutils.SetTypeInfo;
 import org.apache.flink.api.java.typeutils.TupleTypeInfo;
 import org.apache.flink.api.java.typeutils.TypeExtractor;
 import org.apache.flink.api.java.typeutils.ValueTypeInfo;
@@ -49,8 +50,10 @@ import java.time.LocalDateTime;
 import java.time.LocalTime;
 import java.util.ArrayList;
 import java.util.HashMap;
+import java.util.HashSet;
 import java.util.List;
 import java.util.Map;
+import java.util.Set;
 
 /**
  * This class gives access to the type information of the most common types for which Flink has
@@ -443,6 +446,22 @@ public class Types {
         return new ListTypeInfo<>(elementType);
     }
 
+    /**
+     * Returns type information for a Java {@link java.util.Set}. A set must not be null. Null
+     * values in elements are not supported.
+     *
+     * <p>By default, sets are untyped and treated as a generic type in Flink; therefore, it is
+     * useful to pass type information whenever a set is used.
+     *
+     * <p><strong>Note:</strong> Flink does not preserve the concrete {@link Set} type. It converts
+     * a list into {@link HashSet} when copying or deserializing.
+     *
+     * @param elementType type information for the set's elements
+     */
+    public static <E> TypeInformation<Set<E>> SET(TypeInformation<E> elementType) {
+        return new SetTypeInfo<>(elementType);
+    }
+
     /**
      * Returns type information for Java enumerations. Null values are not supported.
      *
