@@ -19,13 +19,15 @@
 package org.apache.flink.api.java.typeutils.runtime;
 
 import org.apache.flink.annotation.Internal;
-import org.apache.flink.api.common.ExecutionConfig;
+import org.apache.flink.api.common.serialization.SerializerConfig;
 import org.apache.flink.api.common.typeutils.TypeSerializer;
 import org.apache.flink.api.java.typeutils.TypeExtractor;
 import org.apache.flink.core.memory.DataInputView;
 import org.apache.flink.core.memory.DataOutputView;
 import org.apache.flink.util.CollectionUtil;
 
+import javax.annotation.Nullable;
+
 import java.io.IOException;
 import java.io.ObjectInputStream;
 import java.io.ObjectOutputStream;
@@ -85,23 +87,25 @@ public final class PojoSerializer<T> extends TypeSerializer<T> {
     // --------------------------------------------------------------------------------------------
 
     /** Configuration of the current execution. */
-    private final ExecutionConfig executionConfig;
+    private final SerializerConfig serializerConfig;
 
     private transient ClassLoader cl;
 
+    @Nullable private transient JavaRecordBuilderFactory<T> recordFactory;
+
     /** Constructor to create a new {@link PojoSerializer}. */
     @SuppressWarnings("unchecked")
     public PojoSerializer(
             Class<T> clazz,
             TypeSerializer<?>[] fieldSerializers,
             Field[] fields,
-            ExecutionConfig executionConfig) {
+            SerializerConfig serializerConfig) {
 
         this.clazz = checkNotNull(clazz);
         this.fieldSerializers = (TypeSerializer<Object>[]) checkNotNull(fieldSerializers);
         this.fields = checkNotNull(fields);
         this.numFields = fieldSerializers.length;
-        this.executionConfig = checkNotNull(executionConfig);
+        this.serializerConfig = checkNotNull(serializerConfig);
 
         for (int i = 0; i < numFields; i++) {
             this.fields[i].setAccessible(true);
@@ -111,13 +115,16 @@ public final class PojoSerializer<T> extends TypeSerializer<T> {
 
         // We only want those classes that are not our own class and are actually sub-classes.
         LinkedHashSet<Class<?>> registeredSubclasses =
-                getRegisteredSubclassesFromExecutionConfig(clazz, executionConfig);
+                getRegisteredSubclassesFromSerializerConfig(clazz, serializerConfig);
 
         this.registeredClasses = createRegisteredSubclassTags(registeredSubclasses);
         this.registeredSerializers =
-                createRegisteredSubclassSerializers(registeredSubclasses, executionConfig);
+                createRegisteredSubclassSerializers(registeredSubclasses, serializerConfig);
 
         this.subclassSerializerCache = new HashMap<>();
+        if (TypeExtractor.isRecord(clazz)) {
+            this.recordFactory = JavaRecordBuilderFactory.create(clazz, fields);
+        }
     }
 
     /**
@@ -131,7 +138,7 @@ public final class PojoSerializer<T> extends TypeSerializer<T> {
             LinkedHashMap<Class<?>, Integer> registeredClasses,
             TypeSerializer<?>[] registeredSerializers,
             Map<Class<?>, TypeSerializer<?>> subclassSerializerCache,
-            ExecutionConfig executionConfig) {
+            SerializerConfig serializerConfig) {
 
         this.clazz = checkNotNull(clazz);
         this.fields = checkNotNull(fields);
@@ -140,8 +147,11 @@ public final class PojoSerializer<T> extends TypeSerializer<T> {
         this.registeredClasses = checkNotNull(registeredClasses);
         this.registeredSerializers = checkNotNull(registeredSerializers);
         this.subclassSerializerCache = checkNotNull(subclassSerializerCache);
-        this.executionConfig = checkNotNull(executionConfig);
+        this.serializerConfig = checkNotNull(serializerConfig);
         this.cl = Thread.currentThread().getContextClassLoader();
+        if (TypeExtractor.isRecord(clazz)) {
+            this.recordFactory = JavaRecordBuilderFactory.create(clazz, fields);
+        }
     }
 
     @Override
@@ -149,6 +159,10 @@ public final class PojoSerializer<T> extends TypeSerializer<T> {
         return false;
     }
 
+    private boolean isRecord() {
+        return this.recordFactory != null;
+    }
+
     @Override
     public PojoSerializer<T> duplicate() {
         TypeSerializer<Object>[] duplicateFieldSerializers = duplicateSerializers(fieldSerializers);
@@ -164,7 +178,7 @@ public final class PojoSerializer<T> extends TypeSerializer<T> {
                 subclassSerializerCache.entrySet().stream()
                         .collect(
                                 Collectors.toMap(Map.Entry::getKey, e -> e.getValue().duplicate())),
-                executionConfig);
+                serializerConfig);
     }
 
     @SuppressWarnings("unchecked")
@@ -189,7 +203,7 @@ public final class PojoSerializer<T> extends TypeSerializer<T> {
 
     @Override
     public T createInstance() {
-        if (clazz.isInterface() || Modifier.isAbstract(clazz.getModifiers())) {
+        if (clazz.isInterface() || Modifier.isAbstract(clazz.getModifiers()) || isRecord()) {
             return null;
         }
         try {
@@ -221,7 +235,20 @@ public final class PojoSerializer<T> extends TypeSerializer<T> {
         }
 
         Class<?> actualType = from.getClass();
-        if (actualType == clazz) {
+        if (isRecord()) {
+            try {
+                JavaRecordBuilderFactory<T>.JavaRecordBuilder builder = recordFactory.newBuilder();
+                for (int i = 0; i < numFields; i++) {
+                    if (fields[i] != null) {
+                        builder.setField(i, copyField(i, from));
+                    }
+                }
+                return builder.build();
+            } catch (IllegalAccessException e) {
+                throw new RuntimeException(
+                        "Error during POJO copy, this should not happen since we check the fields before.");
+            }
+        } else if (actualType == clazz) {
             T target;
             try {
                 target = (T) from.getClass().newInstance();
@@ -232,13 +259,7 @@ public final class PojoSerializer<T> extends TypeSerializer<T> {
             try {
                 for (int i = 0; i < numFields; i++) {
                     if (fields[i] != null) {
-                        Object value = fields[i].get(from);
-                        if (value != null) {
-                            Object copy = fieldSerializers[i].copy(value);
-                            fields[i].set(target, copy);
-                        } else {
-                            fields[i].set(target, null);
-                        }
+                        fields[i].set(target, copyField(i, from));
                     }
                 }
             } catch (IllegalAccessException e) {
@@ -266,23 +287,24 @@ public final class PojoSerializer<T> extends TypeSerializer<T> {
             return copy(from);
         }
 
-        if (actualType == clazz) {
+        if (isRecord()) {
+            try {
+                JavaRecordBuilderFactory<T>.JavaRecordBuilder builder = recordFactory.newBuilder();
+                for (int i = 0; i < numFields; i++) {
+                    if (fields[i] != null) {
+                        builder.setField(i, copyField(reuse, i, from));
+                    }
+                }
+                return builder.build();
+            } catch (IllegalAccessException e) {
+                throw new RuntimeException(
+                        "Error during POJO copy, this should not happen since we check the fields before.");
+            }
+        } else if (actualType == clazz) {
             try {
                 for (int i = 0; i < numFields; i++) {
                     if (fields[i] != null) {
-                        Object value = fields[i].get(from);
-                        if (value != null) {
-                            Object reuseValue = fields[i].get(reuse);
-                            Object copy;
-                            if (reuseValue != null) {
-                                copy = fieldSerializers[i].copy(value, reuseValue);
-                            } else {
-                                copy = fieldSerializers[i].copy(value);
-                            }
-                            fields[i].set(reuse, copy);
-                        } else {
-                            fields[i].set(reuse, null);
-                        }
+                        fields[i].set(reuse, copyField(reuse, i, from));
                     }
                 }
             } catch (IllegalAccessException e) {
@@ -298,6 +320,30 @@ public final class PojoSerializer<T> extends TypeSerializer<T> {
         return reuse;
     }
 
+    private Object copyField(int i, Object from) throws IllegalAccessException {
+        Object value = fields[i].get(from);
+        if (value != null) {
+            return fieldSerializers[i].copy(value);
+        } else {
+            return null;
+        }
+    }
+
+    private Object copyField(T reuse, int i, Object from) throws IllegalAccessException {
+        Object value = fields[i].get(from);
+        if (value != null) {
+            Object reuseValue = fields[i].get(reuse);
+
+            if (reuseValue != null) {
+                return fieldSerializers[i].copy(value, reuseValue);
+            } else {
+                return fieldSerializers[i].copy(value);
+            }
+        } else {
+            return null;
+        }
+    }
+
     @Override
     public int getLength() {
         return -1;
@@ -400,21 +446,23 @@ public final class PojoSerializer<T> extends TypeSerializer<T> {
             target = createInstance();
         }
 
-        if ((flags & NO_SUBCLASS) != 0) {
+        if (isRecord()) {
+            JavaRecordBuilderFactory<T>.JavaRecordBuilder builder = recordFactory.newBuilder();
+            for (int i = 0; i < numFields; i++) {
+                boolean isNull = source.readBoolean();
+                Object fieldValue = isNull ? null : fieldSerializers[i].deserialize(source);
+                if (fields[i] != null) {
+                    builder.setField(i, fieldValue);
+                }
+            }
+            target = builder.build();
+        } else if ((flags & NO_SUBCLASS) != 0) {
             try {
                 for (int i = 0; i < numFields; i++) {
                     boolean isNull = source.readBoolean();
-
+                    Object fieldValue = isNull ? null : fieldSerializers[i].deserialize(source);
                     if (fields[i] != null) {
-                        if (isNull) {
-                            fields[i].set(target, null);
-                        } else {
-                            Object field = fieldSerializers[i].deserialize(source);
-                            fields[i].set(target, field);
-                        }
-                    } else if (!isNull) {
-                        // read and dump a pre-existing field value
-                        fieldSerializers[i].deserialize(source);
+                        fields[i].set(target, fieldValue);
                     }
                 }
             } catch (IllegalAccessException e) {
@@ -473,7 +521,32 @@ public final class PojoSerializer<T> extends TypeSerializer<T> {
             }
         }
 
-        if ((flags & NO_SUBCLASS) != 0) {
+        if (isRecord()) {
+            try {
+                JavaRecordBuilderFactory<T>.JavaRecordBuilder builder = recordFactory.newBuilder();
+                for (int i = 0; i < numFields; i++) {
+                    boolean isNull = source.readBoolean();
+
+                    if (fields[i] != null) {
+                        if (isNull) {
+                            builder.setField(i, null);
+                        } else {
+                            Object reuseField = reuse == null ? null : fields[i].get(reuse);
+                            builder.setField(i, deserializeField(reuseField, i, source));
+                        }
+                    } else if (!isNull) {
+                        // read and dump a pre-existing field value
+                        fieldSerializers[i].deserialize(source);
+                    }
+                }
+
+                reuse = builder.build();
+            } catch (IllegalAccessException e) {
+                throw new RuntimeException(
+                        "Error during POJO copy, this should not happen since we check the fields before.",
+                        e);
+            }
+        } else if ((flags & NO_SUBCLASS) != 0) {
             try {
                 for (int i = 0; i < numFields; i++) {
                     boolean isNull = source.readBoolean();
@@ -482,16 +555,7 @@ public final class PojoSerializer<T> extends TypeSerializer<T> {
                         if (isNull) {
                             fields[i].set(reuse, null);
                         } else {
-                            Object field;
-
-                            Object reuseField = fields[i].get(reuse);
-                            if (reuseField != null) {
-                                field = fieldSerializers[i].deserialize(reuseField, source);
-                            } else {
-                                field = fieldSerializers[i].deserialize(source);
-                            }
-
-                            fields[i].set(reuse, field);
+                            fields[i].set(reuse, deserializeField(fields[i].get(reuse), i, source));
                         }
                     } else if (!isNull) {
                         // read and dump a pre-existing field value
@@ -512,6 +576,15 @@ public final class PojoSerializer<T> extends TypeSerializer<T> {
         return reuse;
     }
 
+    private Object deserializeField(Object reuseField, int i, DataInputView source)
+            throws IllegalAccessException, IOException {
+        if (reuseField != null) {
+            return fieldSerializers[i].deserialize(reuseField, source);
+        } else {
+            return fieldSerializers[i].deserialize(source);
+        }
+    }
+
     @Override
     public void copy(DataInputView source, DataOutputView target) throws IOException {
         // copy the flags
@@ -591,7 +664,8 @@ public final class PojoSerializer<T> extends TypeSerializer<T> {
                 registeredSerializers,
                 fields,
                 fieldSerializers,
-                subclassSerializerCache);
+                subclassSerializerCache,
+                serializerConfig);
     }
 
     // --------------------------------------------------------------------------------------------
@@ -617,6 +691,9 @@ public final class PojoSerializer<T> extends TypeSerializer<T> {
 
         cl = Thread.currentThread().getContextClassLoader();
         subclassSerializerCache = new HashMap<>();
+        if (TypeExtractor.isRecord(clazz)) {
+            this.recordFactory = JavaRecordBuilderFactory.create(clazz, fields);
+        }
     }
 
     // --------------------------------------------------------------------------------------------
@@ -643,8 +720,8 @@ public final class PojoSerializer<T> extends TypeSerializer<T> {
         return fieldSerializers[fieldIndex];
     }
 
-    ExecutionConfig getExecutionConfig() {
-        return executionConfig;
+    SerializerConfig getSerializerConfig() {
+        return serializerConfig;
     }
 
     LinkedHashMap<Class<?>, Integer> getRegisteredClasses() {
@@ -672,13 +749,13 @@ public final class PojoSerializer<T> extends TypeSerializer<T> {
     // --------------------------------------------------------------------------------------------
 
     /** Extracts the subclasses of the base POJO class registered in the execution config. */
-    private static LinkedHashSet<Class<?>> getRegisteredSubclassesFromExecutionConfig(
-            Class<?> basePojoClass, ExecutionConfig executionConfig) {
+    private static LinkedHashSet<Class<?>> getRegisteredSubclassesFromSerializerConfig(
+            Class<?> basePojoClass, SerializerConfig serializerConfig) {
 
         LinkedHashSet<Class<?>> subclassesInRegistrationOrder =
                 CollectionUtil.newLinkedHashSetWithExpectedSize(
-                        executionConfig.getRegisteredPojoTypes().size());
-        for (Class<?> registeredClass : executionConfig.getRegisteredPojoTypes()) {
+                        serializerConfig.getRegisteredPojoTypes().size());
+        for (Class<?> registeredClass : serializerConfig.getRegisteredPojoTypes()) {
             if (registeredClass.equals(basePojoClass)) {
                 continue;
             }
@@ -713,7 +790,7 @@ public final class PojoSerializer<T> extends TypeSerializer<T> {
      * serializers will correspond to order of provided subclasses.
      */
     private static TypeSerializer<?>[] createRegisteredSubclassSerializers(
-            LinkedHashSet<Class<?>> registeredSubclasses, ExecutionConfig executionConfig) {
+            LinkedHashSet<Class<?>> registeredSubclasses, SerializerConfig serializerConfig) {
 
         final TypeSerializer<?>[] subclassSerializers =
                 new TypeSerializer[registeredSubclasses.size()];
@@ -721,7 +798,8 @@ public final class PojoSerializer<T> extends TypeSerializer<T> {
         int i = 0;
         for (Class<?> registeredClass : registeredSubclasses) {
             subclassSerializers[i] =
-                    TypeExtractor.createTypeInfo(registeredClass).createSerializer(executionConfig);
+                    TypeExtractor.createTypeInfo(registeredClass)
+                            .createSerializer(serializerConfig);
             i++;
         }
 
@@ -745,7 +823,7 @@ public final class PojoSerializer<T> extends TypeSerializer<T> {
 
     private TypeSerializer<?> createSubclassSerializer(Class<?> subclass) {
         TypeSerializer<?> serializer =
-                TypeExtractor.createTypeInfo(subclass).createSerializer(executionConfig);
+                TypeExtractor.createTypeInfo(subclass).createSerializer(serializerConfig);
 
         if (serializer instanceof PojoSerializer) {
             PojoSerializer<?> subclassSerializer = (PojoSerializer<?>) serializer;
@@ -787,7 +865,8 @@ public final class PojoSerializer<T> extends TypeSerializer<T> {
             TypeSerializer<?>[] registeredSubclassSerializers,
             Field[] fields,
             TypeSerializer<?>[] fieldSerializers,
-            Map<Class<?>, TypeSerializer<?>> nonRegisteredSubclassSerializerCache) {
+            Map<Class<?>, TypeSerializer<?>> nonRegisteredSubclassSerializerCache,
+            SerializerConfig serializerConfig) {
 
         final LinkedHashMap<Class<?>, TypeSerializer<?>> subclassRegistry =
                 CollectionUtil.newLinkedHashMapWithExpectedSize(registeredSubclassesToTags.size());
@@ -801,6 +880,7 @@ public final class PojoSerializer<T> extends TypeSerializer<T> {
                 fields,
                 fieldSerializers,
                 subclassRegistry,
-                nonRegisteredSubclassSerializerCache);
+                nonRegisteredSubclassSerializerCache,
+                serializerConfig);
     }
 }
