@@ -119,22 +119,6 @@ public class SecurityOptions {
                                     + " (for example, `Client,KafkaClient` to use the credentials for ZooKeeper authentication and for"
                                     + " Kafka authentication)");
 
-    /** @deprecated Use {@link #DELEGATION_TOKENS_ENABLED}. */
-    @Deprecated
-    @Documentation.Section(Documentation.Sections.SECURITY_AUTH_KERBEROS)
-    public static final ConfigOption<Boolean> KERBEROS_FETCH_DELEGATION_TOKEN =
-            key("security.kerberos.fetch.delegation-token")
-                    .booleanType()
-                    .defaultValue(true)
-                    .withDescription(
-                            "Indicates whether to fetch the delegation tokens for external services the Flink job needs to contact. "
-                                    + "Only HDFS and HBase are supported. It is used in Yarn deployments. "
-                                    + "If true, Flink will fetch HDFS and HBase delegation tokens and inject them into Yarn AM containers. "
-                                    + "If false, Flink will assume that the delegation tokens are managed outside of Flink. "
-                                    + "As a consequence, it will not fetch delegation tokens for HDFS and HBase. "
-                                    + "You may need to disable this option, if you rely on submission mechanisms, e.g. Apache Oozie, "
-                                    + "to handle delegation tokens.");
-
     @Documentation.Section(Documentation.Sections.SECURITY_AUTH_KERBEROS)
     public static final ConfigOption<Duration> KERBEROS_RELOGIN_PERIOD =
             key("security.kerberos.relogin.period")
@@ -143,26 +127,6 @@ public class SecurityOptions {
                     .withDescription(
                             "The time period when keytab login happens automatically in order to always have a valid TGT.");
 
-    /** @deprecated Use {@link #DELEGATION_TOKENS_RENEWAL_RETRY_BACKOFF}. */
-    @Deprecated
-    @Documentation.Section(Documentation.Sections.SECURITY_AUTH_KERBEROS)
-    public static final ConfigOption<Duration> KERBEROS_TOKENS_RENEWAL_RETRY_BACKOFF =
-            key("security.kerberos.tokens.renewal.retry.backoff")
-                    .durationType()
-                    .defaultValue(Duration.ofHours(1))
-                    .withDescription(
-                            "The time period how long to wait before retrying to obtain new delegation tokens after a failure.");
-
-    /** @deprecated Use {@link #DELEGATION_TOKENS_RENEWAL_TIME_RATIO}. */
-    @Deprecated
-    @Documentation.Section(Documentation.Sections.SECURITY_AUTH_KERBEROS)
-    public static final ConfigOption<Double> KERBEROS_TOKENS_RENEWAL_TIME_RATIO =
-            key("security.kerberos.tokens.renewal.time-ratio")
-                    .doubleType()
-                    .defaultValue(0.75)
-                    .withDescription(
-                            "Ratio of the tokens's expiration time when new credentials should be re-obtained.");
-
     @Documentation.Section(Documentation.Sections.SECURITY_AUTH_KERBEROS)
     public static final ConfigOption<List<String>> KERBEROS_HADOOP_FILESYSTEMS_TO_ACCESS =
             key("security.kerberos.access.hadoopFileSystems")
@@ -184,7 +148,7 @@ public class SecurityOptions {
             key("security.delegation.tokens.enabled")
                     .booleanType()
                     .defaultValue(true)
-                    .withDeprecatedKeys(KERBEROS_FETCH_DELEGATION_TOKEN.key())
+                    .withDeprecatedKeys("security.kerberos.fetch.delegation-token")
                     .withDescription(
                             "Indicates whether to start delegation tokens system for external services.");
 
@@ -193,7 +157,7 @@ public class SecurityOptions {
             key("security.delegation.tokens.renewal.retry.backoff")
                     .durationType()
                     .defaultValue(Duration.ofHours(1))
-                    .withDeprecatedKeys(KERBEROS_TOKENS_RENEWAL_RETRY_BACKOFF.key())
+                    .withDeprecatedKeys("security.kerberos.tokens.renewal.retry.backoff")
                     .withDescription(
                             "The time period how long to wait before retrying to obtain new delegation tokens after a failure.");
 
@@ -202,7 +166,7 @@ public class SecurityOptions {
             key("security.delegation.tokens.renewal.time-ratio")
                     .doubleType()
                     .defaultValue(0.75)
-                    .withDeprecatedKeys(KERBEROS_TOKENS_RENEWAL_TIME_RATIO.key())
+                    .withDeprecatedKeys("security.kerberos.tokens.renewal.time-ratio")
                     .withDescription(
                             "Ratio of the tokens's expiration time when new credentials should be re-obtained.");
 
@@ -260,23 +224,6 @@ public class SecurityOptions {
     //  SSL Security Options
     // ------------------------------------------------------------------------
 
-    /**
-     * Enable SSL for internal (rpc, data transport, blob server) and external (HTTP/REST)
-     * communication.
-     *
-     * @deprecated Use {@link #SSL_INTERNAL_ENABLED} and {@link #SSL_REST_ENABLED} instead.
-     */
-    @Deprecated
-    public static final ConfigOption<Boolean> SSL_ENABLED =
-            key("security.ssl.enabled")
-                    .booleanType()
-                    .defaultValue(false)
-                    .withDescription(
-                            "Turns on SSL for internal and external network communication."
-                                    + "This can be overridden by 'security.ssl.internal.enabled', 'security.ssl.external.enabled'. "
-                                    + "Specific internal components (rpc, data transport, blob server) may optionally override "
-                                    + "this through their own settings.");
-
     /** Enable SSL for internal communication (pekko rpc, netty data transport, blob server). */
     @Documentation.Section(Documentation.Sections.SECURITY_SSL)
     public static final ConfigOption<Boolean> SSL_INTERNAL_ENABLED =
@@ -675,16 +622,12 @@ public class SecurityOptions {
      * Checks whether SSL for internal communication (rpc, data transport, blob server) is enabled.
      */
     public static boolean isInternalSSLEnabled(Configuration sslConfig) {
-        @SuppressWarnings("deprecation")
-        final boolean fallbackFlag = sslConfig.get(SSL_ENABLED);
-        return sslConfig.get(SSL_INTERNAL_ENABLED, fallbackFlag);
+        return sslConfig.get(SSL_INTERNAL_ENABLED);
     }
 
     /** Checks whether SSL for the external REST endpoint is enabled. */
     public static boolean isRestSSLEnabled(Configuration sslConfig) {
-        @SuppressWarnings("deprecation")
-        final boolean fallbackFlag = sslConfig.get(SSL_ENABLED);
-        return sslConfig.get(SSL_REST_ENABLED, fallbackFlag);
+        return sslConfig.get(SSL_REST_ENABLED);
     }
 
     /** Checks whether mutual SSL authentication for the external REST endpoint is enabled. */
