@@ -318,11 +318,6 @@ public class LimitedConnectionsFileSystem extends FileSystem {
     //  other delegating file system methods
     // ------------------------------------------------------------------------
 
-    @Override
-    public FileSystemKind getKind() {
-        return originalFs.getKind();
-    }
-
     @Override
     public boolean isDistributedFS() {
         return originalFs.isDistributedFS();
