@@ -18,24 +18,17 @@
 
 package org.apache.flink.api.common.eventtime;
 
-import org.junit.Test;
+import org.junit.jupiter.api.Test;
 
 import java.util.UUID;
 
-import static org.apache.flink.api.common.eventtime.WatermarkMatchers.watermark;
-import static org.hamcrest.CoreMatchers.equalTo;
-import static org.hamcrest.CoreMatchers.is;
-import static org.hamcrest.CoreMatchers.nullValue;
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertFalse;
-import static org.junit.Assert.assertThat;
-import static org.junit.Assert.assertTrue;
+import static org.assertj.core.api.Assertions.assertThat;
 
 /** Tests for the {@link WatermarkOutputMultiplexer}. */
-public class WatermarkOutputMultiplexerTest {
+class WatermarkOutputMultiplexerTest {
 
     @Test
-    public void singleImmediateWatermark() {
+    void singleImmediateWatermark() {
         TestingWatermarkOutput underlyingWatermarkOutput = createTestingWatermarkOutput();
         WatermarkOutputMultiplexer multiplexer =
                 new WatermarkOutputMultiplexer(underlyingWatermarkOutput);
@@ -44,12 +37,12 @@ public class WatermarkOutputMultiplexerTest {
 
         watermarkOutput.emitWatermark(new Watermark(0));
 
-        assertThat(underlyingWatermarkOutput.lastWatermark(), is(watermark(0)));
-        assertThat(underlyingWatermarkOutput.isIdle(), is(false));
+        assertThat(underlyingWatermarkOutput.lastWatermark()).isEqualTo(new Watermark(0));
+        assertThat(underlyingWatermarkOutput.isIdle()).isFalse();
     }
 
     @Test
-    public void singleImmediateIdleness() {
+    void singleImmediateIdleness() {
         TestingWatermarkOutput underlyingWatermarkOutput = createTestingWatermarkOutput();
         WatermarkOutputMultiplexer multiplexer =
                 new WatermarkOutputMultiplexer(underlyingWatermarkOutput);
@@ -58,12 +51,12 @@ public class WatermarkOutputMultiplexerTest {
 
         watermarkOutput.markIdle();
 
-        assertThat(underlyingWatermarkOutput.lastWatermark(), nullValue());
-        assertThat(underlyingWatermarkOutput.isIdle(), is(true));
+        assertThat(underlyingWatermarkOutput.lastWatermark()).isNull();
+        assertThat(underlyingWatermarkOutput.isIdle()).isTrue();
     }
 
     @Test
-    public void singleImmediateWatermarkAfterIdleness() {
+    void singleImmediateWatermarkAfterIdleness() {
         TestingWatermarkOutput underlyingWatermarkOutput = createTestingWatermarkOutput();
         WatermarkOutputMultiplexer multiplexer =
                 new WatermarkOutputMultiplexer(underlyingWatermarkOutput);
@@ -71,16 +64,16 @@ public class WatermarkOutputMultiplexerTest {
         WatermarkOutput watermarkOutput = createImmediateOutput(multiplexer);
 
         watermarkOutput.markIdle();
-        assertThat(underlyingWatermarkOutput.isIdle(), is(true));
+        assertThat(underlyingWatermarkOutput.isIdle()).isTrue();
 
         watermarkOutput.emitWatermark(new Watermark(0));
 
-        assertThat(underlyingWatermarkOutput.lastWatermark(), is(watermark(0)));
-        assertThat(underlyingWatermarkOutput.isIdle(), is(false));
+        assertThat(underlyingWatermarkOutput.lastWatermark()).isEqualTo(new Watermark(0));
+        assertThat(underlyingWatermarkOutput.isIdle()).isFalse();
     }
 
     @Test
-    public void multipleImmediateWatermark() {
+    void multipleImmediateWatermark() {
         TestingWatermarkOutput underlyingWatermarkOutput = createTestingWatermarkOutput();
         WatermarkOutputMultiplexer multiplexer =
                 new WatermarkOutputMultiplexer(underlyingWatermarkOutput);
@@ -93,12 +86,12 @@ public class WatermarkOutputMultiplexerTest {
         watermarkOutput2.emitWatermark(new Watermark(5));
         watermarkOutput3.markIdle();
 
-        assertThat(underlyingWatermarkOutput.lastWatermark(), is(watermark(2)));
-        assertThat(underlyingWatermarkOutput.isIdle(), is(false));
+        assertThat(underlyingWatermarkOutput.lastWatermark()).isEqualTo(new Watermark(2));
+        assertThat(underlyingWatermarkOutput.isIdle()).isFalse();
     }
 
     @Test
-    public void whenImmediateOutputBecomesIdleWatermarkAdvances() {
+    void whenImmediateOutputBecomesIdleWatermarkAdvances() {
         TestingWatermarkOutput underlyingWatermarkOutput = createTestingWatermarkOutput();
         WatermarkOutputMultiplexer multiplexer =
                 new WatermarkOutputMultiplexer(underlyingWatermarkOutput);
@@ -109,15 +102,15 @@ public class WatermarkOutputMultiplexerTest {
         watermarkOutput1.emitWatermark(new Watermark(2));
         watermarkOutput2.emitWatermark(new Watermark(5));
 
-        assertThat(underlyingWatermarkOutput.lastWatermark(), is(watermark(2)));
+        assertThat(underlyingWatermarkOutput.lastWatermark()).isEqualTo(new Watermark(2));
 
         watermarkOutput1.markIdle();
 
-        assertThat(underlyingWatermarkOutput.lastWatermark(), is(watermark(5)));
+        assertThat(underlyingWatermarkOutput.lastWatermark()).isEqualTo(new Watermark(5));
     }
 
     @Test
-    public void combinedWatermarkDoesNotRegressWhenIdleOutputRegresses() {
+    void combinedWatermarkDoesNotRegressWhenIdleOutputRegresses() {
         TestingWatermarkOutput underlyingWatermarkOutput = createTestingWatermarkOutput();
         WatermarkOutputMultiplexer multiplexer =
                 new WatermarkOutputMultiplexer(underlyingWatermarkOutput);
@@ -129,11 +122,11 @@ public class WatermarkOutputMultiplexerTest {
         watermarkOutput2.emitWatermark(new Watermark(5));
         watermarkOutput1.markIdle();
 
-        assertThat(underlyingWatermarkOutput.lastWatermark(), is(watermark(5)));
+        assertThat(underlyingWatermarkOutput.lastWatermark()).isEqualTo(new Watermark(5));
 
         watermarkOutput1.emitWatermark(new Watermark(3));
 
-        assertThat(underlyingWatermarkOutput.lastWatermark(), is(watermark(5)));
+        assertThat(underlyingWatermarkOutput.lastWatermark()).isEqualTo(new Watermark(5));
     }
 
     /**
@@ -145,19 +138,19 @@ public class WatermarkOutputMultiplexerTest {
      * when there are no splits assigned and the combined watermark is at its initial value.
      */
     @Test
-    public void noCombinedDeferredUpdateWhenWeHaveZeroOutputs() {
+    void noCombinedDeferredUpdateWhenWeHaveZeroOutputs() {
         TestingWatermarkOutput underlyingWatermarkOutput = createTestingWatermarkOutput();
         WatermarkOutputMultiplexer multiplexer =
                 new WatermarkOutputMultiplexer(underlyingWatermarkOutput);
 
         multiplexer.onPeriodicEmit();
 
-        assertThat(underlyingWatermarkOutput.lastWatermark(), is(nullValue()));
-        assertThat(underlyingWatermarkOutput.isIdle(), is(false));
+        assertThat(underlyingWatermarkOutput.lastWatermark()).isNull();
+        assertThat(underlyingWatermarkOutput.isIdle()).isFalse();
     }
 
     @Test
-    public void deferredOutputDoesNotImmediatelyAdvanceWatermark() {
+    void deferredOutputDoesNotImmediatelyAdvanceWatermark() {
         TestingWatermarkOutput underlyingWatermarkOutput = createTestingWatermarkOutput();
         WatermarkOutputMultiplexer multiplexer =
                 new WatermarkOutputMultiplexer(underlyingWatermarkOutput);
@@ -168,15 +161,15 @@ public class WatermarkOutputMultiplexerTest {
         watermarkOutput1.emitWatermark(new Watermark(0));
         watermarkOutput2.emitWatermark(new Watermark(1));
 
-        assertThat(underlyingWatermarkOutput.lastWatermark(), nullValue());
+        assertThat(underlyingWatermarkOutput.lastWatermark()).isNull();
 
         multiplexer.onPeriodicEmit();
 
-        assertThat(underlyingWatermarkOutput.lastWatermark(), is(watermark(0)));
+        assertThat(underlyingWatermarkOutput.lastWatermark()).isEqualTo(new Watermark(0));
     }
 
     @Test
-    public void singleDeferredWatermark() {
+    void singleDeferredWatermark() {
         TestingWatermarkOutput underlyingWatermarkOutput = createTestingWatermarkOutput();
         WatermarkOutputMultiplexer multiplexer =
                 new WatermarkOutputMultiplexer(underlyingWatermarkOutput);
@@ -186,12 +179,12 @@ public class WatermarkOutputMultiplexerTest {
         watermarkOutput.emitWatermark(new Watermark(0));
         multiplexer.onPeriodicEmit();
 
-        assertThat(underlyingWatermarkOutput.lastWatermark(), is(watermark(0)));
-        assertThat(underlyingWatermarkOutput.isIdle(), is(false));
+        assertThat(underlyingWatermarkOutput.lastWatermark()).isEqualTo(new Watermark(0));
+        assertThat(underlyingWatermarkOutput.isIdle()).isFalse();
     }
 
     @Test
-    public void singleDeferredIdleness() {
+    void singleDeferredIdleness() {
         TestingWatermarkOutput underlyingWatermarkOutput = createTestingWatermarkOutput();
         WatermarkOutputMultiplexer multiplexer =
                 new WatermarkOutputMultiplexer(underlyingWatermarkOutput);
@@ -201,12 +194,12 @@ public class WatermarkOutputMultiplexerTest {
         watermarkOutput.markIdle();
         multiplexer.onPeriodicEmit();
 
-        assertThat(underlyingWatermarkOutput.lastWatermark(), nullValue());
-        assertThat(underlyingWatermarkOutput.isIdle(), is(true));
+        assertThat(underlyingWatermarkOutput.lastWatermark()).isNull();
+        assertThat(underlyingWatermarkOutput.isIdle()).isTrue();
     }
 
     @Test
-    public void singleDeferredWatermarkAfterIdleness() {
+    void singleDeferredWatermarkAfterIdleness() {
         TestingWatermarkOutput underlyingWatermarkOutput = createTestingWatermarkOutput();
         WatermarkOutputMultiplexer multiplexer =
                 new WatermarkOutputMultiplexer(underlyingWatermarkOutput);
@@ -216,17 +209,17 @@ public class WatermarkOutputMultiplexerTest {
         watermarkOutput.markIdle();
         multiplexer.onPeriodicEmit();
 
-        assertThat(underlyingWatermarkOutput.isIdle(), is(true));
+        assertThat(underlyingWatermarkOutput.isIdle()).isTrue();
 
         watermarkOutput.emitWatermark(new Watermark(0));
         multiplexer.onPeriodicEmit();
 
-        assertThat(underlyingWatermarkOutput.lastWatermark(), is(watermark(0)));
-        assertThat(underlyingWatermarkOutput.isIdle(), is(false));
+        assertThat(underlyingWatermarkOutput.lastWatermark()).isEqualTo(new Watermark(0));
+        assertThat(underlyingWatermarkOutput.isIdle()).isFalse();
     }
 
     @Test
-    public void multipleDeferredWatermark() {
+    void multipleDeferredWatermark() {
         TestingWatermarkOutput underlyingWatermarkOutput = createTestingWatermarkOutput();
         WatermarkOutputMultiplexer multiplexer =
                 new WatermarkOutputMultiplexer(underlyingWatermarkOutput);
@@ -241,12 +234,12 @@ public class WatermarkOutputMultiplexerTest {
 
         multiplexer.onPeriodicEmit();
 
-        assertThat(underlyingWatermarkOutput.lastWatermark(), is(watermark(2)));
-        assertThat(underlyingWatermarkOutput.isIdle(), is(false));
+        assertThat(underlyingWatermarkOutput.lastWatermark()).isEqualTo(new Watermark(2));
+        assertThat(underlyingWatermarkOutput.isIdle()).isFalse();
     }
 
     @Test
-    public void immediateUpdatesTakeDeferredUpdatesIntoAccount() {
+    void immediateUpdatesTakeDeferredUpdatesIntoAccount() {
         TestingWatermarkOutput underlyingWatermarkOutput = createTestingWatermarkOutput();
         WatermarkOutputMultiplexer multiplexer =
                 new WatermarkOutputMultiplexer(underlyingWatermarkOutput);
@@ -256,15 +249,15 @@ public class WatermarkOutputMultiplexerTest {
 
         deferredOutput.emitWatermark(new Watermark(5));
 
-        assertThat(underlyingWatermarkOutput.lastWatermark(), is(nullValue()));
+        assertThat(underlyingWatermarkOutput.lastWatermark()).isNull();
 
         immediateOutput.emitWatermark(new Watermark(2));
 
-        assertThat(underlyingWatermarkOutput.lastWatermark(), is(watermark(2)));
+        assertThat(underlyingWatermarkOutput.lastWatermark()).isEqualTo(new Watermark(2));
     }
 
     @Test
-    public void immediateUpdateOnSameOutputAsDeferredUpdateDoesNotRegress() {
+    void immediateUpdateOnSameOutputAsDeferredUpdateDoesNotRegress() {
         TestingWatermarkOutput underlyingWatermarkOutput = createTestingWatermarkOutput();
         WatermarkOutputMultiplexer multiplexer =
                 new WatermarkOutputMultiplexer(underlyingWatermarkOutput);
@@ -277,18 +270,18 @@ public class WatermarkOutputMultiplexerTest {
         deferredOutput.emitWatermark(new Watermark(5));
         multiplexer.onPeriodicEmit();
 
-        assertThat(underlyingWatermarkOutput.lastWatermark(), is(watermark(5)));
+        assertThat(underlyingWatermarkOutput.lastWatermark()).isEqualTo(new Watermark(5));
 
         immediateOutput.emitWatermark(new Watermark(2));
 
-        assertThat(underlyingWatermarkOutput.lastWatermark(), is(watermark(5)));
+        assertThat(underlyingWatermarkOutput.lastWatermark()).isEqualTo(new Watermark(5));
 
         multiplexer.onPeriodicEmit();
-        assertThat(underlyingWatermarkOutput.lastWatermark(), is(watermark(5)));
+        assertThat(underlyingWatermarkOutput.lastWatermark()).isEqualTo(new Watermark(5));
     }
 
     @Test
-    public void lowerImmediateUpdateOnSameOutputDoesNotEmitCombinedUpdate() {
+    void lowerImmediateUpdateOnSameOutputDoesNotEmitCombinedUpdate() {
         TestingWatermarkOutput underlyingWatermarkOutput = createTestingWatermarkOutput();
         WatermarkOutputMultiplexer multiplexer =
                 new WatermarkOutputMultiplexer(underlyingWatermarkOutput);
@@ -301,11 +294,11 @@ public class WatermarkOutputMultiplexerTest {
         deferredOutput.emitWatermark(new Watermark(5));
         immediateOutput.emitWatermark(new Watermark(2));
 
-        assertThat(underlyingWatermarkOutput.lastWatermark(), is(nullValue()));
+        assertThat(underlyingWatermarkOutput.lastWatermark()).isNull();
     }
 
     @Test
-    public void testRemoveUnblocksWatermarks() {
+    void testRemoveUnblocksWatermarks() {
         final TestingWatermarkOutput underlyingWatermarkOutput = createTestingWatermarkOutput();
         final WatermarkOutputMultiplexer multiplexer =
                 new WatermarkOutputMultiplexer(underlyingWatermarkOutput);
@@ -319,11 +312,12 @@ public class WatermarkOutputMultiplexerTest {
         multiplexer.unregisterOutput("lower");
         multiplexer.getImmediateOutput("higher").emitWatermark(new Watermark(highTimestamp));
 
-        assertEquals(highTimestamp, underlyingWatermarkOutput.lastWatermark().getTimestamp());
+        assertThat(underlyingWatermarkOutput.lastWatermark().getTimestamp())
+                .isEqualTo(highTimestamp);
     }
 
     @Test
-    public void testRemoveOfLowestDoesNotImmediatelyAdvanceWatermark() {
+    void testRemoveOfLowestDoesNotImmediatelyAdvanceWatermark() {
         final TestingWatermarkOutput underlyingWatermarkOutput = createTestingWatermarkOutput();
         final WatermarkOutputMultiplexer multiplexer =
                 new WatermarkOutputMultiplexer(underlyingWatermarkOutput);
@@ -337,11 +331,12 @@ public class WatermarkOutputMultiplexerTest {
 
         multiplexer.unregisterOutput("lower");
 
-        assertEquals(lowTimestamp, underlyingWatermarkOutput.lastWatermark().getTimestamp());
+        assertThat(underlyingWatermarkOutput.lastWatermark().getTimestamp())
+                .isEqualTo(lowTimestamp);
     }
 
     @Test
-    public void testRemoveOfHighestDoesNotRetractWatermark() {
+    void testRemoveOfHighestDoesNotRetractWatermark() {
         final TestingWatermarkOutput underlyingWatermarkOutput = createTestingWatermarkOutput();
         final WatermarkOutputMultiplexer multiplexer =
                 new WatermarkOutputMultiplexer(underlyingWatermarkOutput);
@@ -355,11 +350,12 @@ public class WatermarkOutputMultiplexerTest {
         multiplexer.registerNewOutput("lower", watermark -> {});
         multiplexer.getImmediateOutput("lower").emitWatermark(new Watermark(lowTimestamp));
 
-        assertEquals(highTimestamp, underlyingWatermarkOutput.lastWatermark().getTimestamp());
+        assertThat(underlyingWatermarkOutput.lastWatermark().getTimestamp())
+                .isEqualTo(highTimestamp);
     }
 
     @Test
-    public void testRemoveRegisteredReturnValue() {
+    void testRemoveRegisteredReturnValue() {
         final TestingWatermarkOutput underlyingWatermarkOutput = createTestingWatermarkOutput();
         final WatermarkOutputMultiplexer multiplexer =
                 new WatermarkOutputMultiplexer(underlyingWatermarkOutput);
@@ -367,22 +363,22 @@ public class WatermarkOutputMultiplexerTest {
 
         final boolean unregistered = multiplexer.unregisterOutput("does-exist");
 
-        assertTrue(unregistered);
+        assertThat(unregistered).isTrue();
     }
 
     @Test
-    public void testRemoveNotRegisteredReturnValue() {
+    void testRemoveNotRegisteredReturnValue() {
         final TestingWatermarkOutput underlyingWatermarkOutput = createTestingWatermarkOutput();
         final WatermarkOutputMultiplexer multiplexer =
                 new WatermarkOutputMultiplexer(underlyingWatermarkOutput);
 
         final boolean unregistered = multiplexer.unregisterOutput("does-not-exist");
 
-        assertFalse(unregistered);
+        assertThat(unregistered).isFalse();
     }
 
     @Test
-    public void testNotEmittingIdleAfterAllSplitsRemoved() {
+    void testNotEmittingIdleAfterAllSplitsRemoved() {
         final TestingWatermarkOutput underlyingWatermarkOutput = createTestingWatermarkOutput();
         final WatermarkOutputMultiplexer multiplexer =
                 new WatermarkOutputMultiplexer(underlyingWatermarkOutput);
@@ -395,8 +391,8 @@ public class WatermarkOutputMultiplexerTest {
         multiplexer.unregisterOutput(id);
 
         multiplexer.onPeriodicEmit();
-        assertThat(underlyingWatermarkOutput.lastWatermark(), equalTo(emittedWatermark));
-        assertThat(underlyingWatermarkOutput.isIdle(), equalTo(false));
+        assertThat(underlyingWatermarkOutput.lastWatermark()).isEqualTo(emittedWatermark);
+        assertThat(underlyingWatermarkOutput.isIdle()).isFalse();
     }
 
     /**
