@@ -45,7 +45,7 @@ class ByteValueSerializerTest extends SerializerTestBase<ByteValue> {
     @Override
     protected ByteValue[] getTestData() {
         Random rnd = new Random(874597969123412341L);
-        byte byteArray[] = new byte[1];
+        byte[] byteArray = new byte[1];
         rnd.nextBytes(byteArray);
 
         return new ByteValue[] {
