@@ -18,7 +18,6 @@
 
 package org.apache.flink.api.java.typeutils;
 
-import org.apache.flink.api.common.ExecutionConfig;
 import org.apache.flink.api.common.functions.InvalidTypesException;
 import org.apache.flink.api.common.functions.MapFunction;
 import org.apache.flink.api.common.serialization.SerializerConfig;
@@ -271,11 +270,6 @@ public class TypeInfoFactoryTest {
             return null;
         }
 
-        @Override
-        public TypeSerializer<MyFaulty> createSerializer(ExecutionConfig config) {
-            return createSerializer(config.getSerializerConfig());
-        }
-
         @Override
         public String toString() {
             return null;
@@ -375,11 +369,6 @@ public class TypeInfoFactoryTest {
             return null;
         }
 
-        @Override
-        public TypeSerializer<MyTuple<T0, T1>> createSerializer(ExecutionConfig config) {
-            return createSerializer(config.getSerializerConfig());
-        }
-
         @Override
         public String toString() {
             return null;
@@ -478,11 +467,6 @@ public class TypeInfoFactoryTest {
             return null;
         }
 
-        @Override
-        public TypeSerializer<MyOption<T>> createSerializer(ExecutionConfig config) {
-            return createSerializer(config.getSerializerConfig());
-        }
-
         @Override
         public String toString() {
             return null;
