@@ -20,17 +20,16 @@ package org.apache.flink.api.java.typeutils.runtime;
 
 import org.apache.flink.FlinkVersion;
 import org.apache.flink.api.common.typeutils.TypeSerializer;
-import org.apache.flink.api.common.typeutils.TypeSerializerMatchers;
+import org.apache.flink.api.common.typeutils.TypeSerializerConditions;
 import org.apache.flink.api.common.typeutils.TypeSerializerSchemaCompatibility;
 import org.apache.flink.api.common.typeutils.TypeSerializerUpgradeTestBase;
 import org.apache.flink.api.common.typeutils.base.LongSerializer;
 
-import org.hamcrest.Matcher;
+import org.assertj.core.api.Condition;
 
 import java.util.ArrayList;
 import java.util.Collection;
-
-import static org.hamcrest.CoreMatchers.is;
+import java.util.Objects;
 
 /** A {@link TypeSerializerUpgradeTestBase} for {@link NullableSerializer}. */
 class NullableSerializerUpgradeTest extends TypeSerializerUpgradeTestBase<Long, Long> {
@@ -88,14 +87,14 @@ class NullableSerializerUpgradeTest extends TypeSerializerUpgradeTestBase<Long,
         }
 
         @Override
-        public Matcher<Long> testDataMatcher() {
-            return is((Long) null);
+        public Condition<Long> testDataCondition() {
+            return new Condition<>(Objects::isNull, "value is null");
         }
 
         @Override
-        public Matcher<TypeSerializerSchemaCompatibility<Long>> schemaCompatibilityMatcher(
+        public Condition<TypeSerializerSchemaCompatibility<Long>> schemaCompatibilityCondition(
                 FlinkVersion version) {
-            return TypeSerializerMatchers.isCompatibleAsIs();
+            return TypeSerializerConditions.isCompatibleAsIs();
         }
     }
 
@@ -132,14 +131,14 @@ class NullableSerializerUpgradeTest extends TypeSerializerUpgradeTestBase<Long,
         }
 
         @Override
-        public Matcher<Long> testDataMatcher() {
-            return is((Long) null);
+        public Condition<Long> testDataCondition() {
+            return new Condition<>(Objects::isNull, "value is null");
         }
 
         @Override
-        public Matcher<TypeSerializerSchemaCompatibility<Long>> schemaCompatibilityMatcher(
+        public Condition<TypeSerializerSchemaCompatibility<Long>> schemaCompatibilityCondition(
                 FlinkVersion version) {
-            return TypeSerializerMatchers.isCompatibleAsIs();
+            return TypeSerializerConditions.isCompatibleAsIs();
         }
     }
 }
