@@ -19,6 +19,8 @@
 package org.apache.flink.datastream.api.context;
 
 import org.apache.flink.annotation.Experimental;
+import org.apache.flink.api.common.watermark.Watermark;
+import org.apache.flink.api.common.watermark.WatermarkManager;
 import org.apache.flink.datastream.api.function.ApplyPartitionFunction;
 
 /**
@@ -32,4 +34,10 @@ public interface NonPartitionedContext<OUT> extends RuntimeContext {
      * non-keyed stream, it will apply to single partition.
      */
     void applyToAllPartitions(ApplyPartitionFunction<OUT> applyPartitionFunction) throws Exception;
+
+    /**
+     * Get {@link WatermarkManager} instance, which allow emitting a {@link Watermark} from the
+     * process function.
+     */
+    WatermarkManager getWatermarkManager();
 }
