@@ -46,13 +46,10 @@ function build_image() {
     start_file_server
     local server_pid=$!
 
-    echo "Preparing Dockeriles"
-    retry_times_with_exponential_backoff 5 git clone https://github.com/apache/flink-docker.git --branch dev-1.20 --single-branch
+    echo "Preparing Dockerfiles"
+    retry_times_with_exponential_backoff 5 git clone https://github.com/apache/flink-docker.git --branch dev-2.0 --single-branch
 
-    local java_version=8
-    if [[ ${PROFILE} == *"jdk11"* ]]; then
-        java_version=11
-    fi
+    local java_version=17
     if [[ ${PROFILE} == *"jdk17"* ]]; then
         java_version=17
     fi
