@@ -45,7 +45,6 @@ import java.util.function.Consumer;
 import java.util.stream.Collectors;
 
 import static org.apache.flink.connector.testutils.formats.SchemaTestUtils.open;
-import static org.apache.flink.core.testutils.FlinkAssertions.anyCauseMatches;
 import static org.apache.flink.table.api.DataTypes.FIELD;
 import static org.apache.flink.table.api.DataTypes.FLOAT;
 import static org.apache.flink.table.api.DataTypes.INT;
@@ -114,34 +113,6 @@ class DebeziumJsonSerDeSchemaTest {
         assertThat(collector.list).isEmpty();
     }
 
-    @Test
-    void testIgnoreParseErrors() throws Exception {
-        List<String> lines = readLines("debezium-data-schema-exclude.txt");
-        DebeziumJsonDeserializationSchema deserializationSchema =
-                new DebeziumJsonDeserializationSchema(
-                        PHYSICAL_DATA_TYPE,
-                        Collections.emptyList(),
-                        InternalTypeInfo.of(PHYSICAL_DATA_TYPE.getLogicalType()),
-                        false,
-                        true,
-                        TimestampFormat.ISO_8601);
-        open(deserializationSchema);
-
-        ThrowingExceptionCollector collector = new ThrowingExceptionCollector();
-        assertThatThrownBy(
-                        () -> {
-                            for (String line : lines) {
-                                deserializationSchema.deserialize(
-                                        line.getBytes(StandardCharsets.UTF_8), collector);
-                            }
-                        })
-                .isInstanceOf(RuntimeException.class)
-                .satisfies(
-                        anyCauseMatches(
-                                RuntimeException.class,
-                                "An error occurred while collecting data."));
-    }
-
     @Test
     void testDeserializationWithMetadata() throws Exception {
         testDeserializationWithMetadata(
@@ -278,7 +249,8 @@ class DebeziumJsonSerDeSchemaTest {
                         TimestampFormat.SQL,
                         JsonFormatOptions.MapNullKeyMode.LITERAL,
                         "null",
-                        true);
+                        true,
+                        false);
 
         open(serializationSchema);
         actual = new ArrayList<>();
@@ -368,17 +340,4 @@ class DebeziumJsonSerDeSchemaTest {
             // do nothing
         }
     }
-
-    private static class ThrowingExceptionCollector implements Collector<RowData> {
-
-        @Override
-        public void collect(RowData record) {
-            throw new RuntimeException("An error occurred while collecting data.");
-        }
-
-        @Override
-        public void close() {
-            // do nothing
-        }
-    }
 }
