@@ -31,6 +31,7 @@ import org.apache.flink.formats.parquet.utils.SerializableConfiguration;
 import org.apache.flink.formats.parquet.vector.ColumnBatchFactory;
 import org.apache.flink.formats.parquet.vector.ParquetDecimalVector;
 import org.apache.flink.formats.parquet.vector.reader.ColumnReader;
+import org.apache.flink.formats.parquet.vector.type.ParquetField;
 import org.apache.flink.table.data.columnar.vector.ColumnVector;
 import org.apache.flink.table.data.columnar.vector.VectorizedColumnBatch;
 import org.apache.flink.table.data.columnar.vector.writable.WritableColumnVector;
@@ -46,6 +47,8 @@ import org.apache.parquet.column.page.PageReadStore;
 import org.apache.parquet.filter2.compat.FilterCompat;
 import org.apache.parquet.hadoop.ParquetFileReader;
 import org.apache.parquet.hadoop.metadata.BlockMetaData;
+import org.apache.parquet.io.ColumnIOFactory;
+import org.apache.parquet.io.MessageColumnIO;
 import org.apache.parquet.schema.GroupType;
 import org.apache.parquet.schema.MessageType;
 import org.apache.parquet.schema.Type;
@@ -65,6 +68,7 @@ import java.util.Locale;
 import java.util.Map;
 import java.util.Set;
 
+import static org.apache.flink.formats.parquet.vector.ParquetSplitReaderUtil.buildFieldsList;
 import static org.apache.flink.formats.parquet.vector.ParquetSplitReaderUtil.createColumnReader;
 import static org.apache.flink.formats.parquet.vector.ParquetSplitReaderUtil.createWritableColumnVector;
 import static org.apache.parquet.hadoop.ParquetInputFormat.getFilter;
@@ -136,16 +140,22 @@ public abstract class ParquetVectorizedInputFormat<T, SplitT extends FileSourceS
 
         checkSchema(fileSchema, requestedSchema);
 
-        final long totalRowCount = parquetFileReader.getFilteredRecordCount();
+        final long totalRowCount = parquetFileReader.getRecordCount();
         final Pool<ParquetReaderBatch<T>> poolOfBatches =
                 createPoolOfBatches(split, requestedSchema, numBatchesToCirculate(config));
 
+        RowType projectedType = RowType.of(projectedTypes, projectedFields);
+        MessageColumnIO columnIO = new ColumnIOFactory().getColumnIO(requestedSchema);
+        List<ParquetField> fields =
+                buildFieldsList(projectedType.getFields(), projectedType.getFieldNames(), columnIO);
+
         return new ParquetReader(
                 parquetFileReader,
                 requestedSchema,
                 unknownFieldsIndices,
                 totalRowCount,
-                poolOfBatches);
+                poolOfBatches,
+                fields);
     }
 
     protected int numBatchesToCirculate(Configuration config) {
@@ -342,12 +352,15 @@ public abstract class ParquetVectorizedInputFormat<T, SplitT extends FileSourceS
 
         private long recordsToSkip;
 
+        private final List<ParquetField> fields;
+
         private ParquetReader(
                 ParquetFileReader reader,
                 MessageType requestedSchema,
                 Set<Integer> unknownFieldsIndices,
                 long totalRowCount,
-                Pool<ParquetReaderBatch<T>> pool) {
+                Pool<ParquetReaderBatch<T>> pool,
+                List<ParquetField> fields) {
             this.reader = reader;
             this.requestedSchema = requestedSchema;
             this.unknownFieldsIndices = unknownFieldsIndices;
@@ -356,6 +369,7 @@ public abstract class ParquetVectorizedInputFormat<T, SplitT extends FileSourceS
             this.rowsReturned = 0;
             this.totalCountLoadedSoFar = 0;
             this.recordsToSkip = 0;
+            this.fields = fields;
         }
 
         @Nullable
@@ -425,6 +439,7 @@ public abstract class ParquetVectorizedInputFormat<T, SplitT extends FileSourceS
                                     types.get(i),
                                     requestedSchema.getColumns(),
                                     pages,
+                                    fields.get(i),
                                     0);
                 }
             }
