@@ -21,7 +21,6 @@ import org.apache.flink.table.data.TimestampData;
 import org.apache.flink.table.data.columnar.vector.writable.WritableIntVector;
 import org.apache.flink.table.data.columnar.vector.writable.WritableTimestampVector;
 
-import org.apache.parquet.Preconditions;
 import org.apache.parquet.column.ColumnDescriptor;
 import org.apache.parquet.column.page.PageReader;
 import org.apache.parquet.io.api.Binary;
@@ -34,6 +33,8 @@ import java.nio.ByteOrder;
 import java.sql.Timestamp;
 import java.util.concurrent.TimeUnit;
 
+import static org.apache.flink.util.Preconditions.checkArgument;
+
 /**
  * Timestamp {@link ColumnReader}. We support INT96 and INT64 now, julianDay(4) + nanosOfDay(8). See
  * https://github.com/apache/parquet-format/blob/master/LogicalTypes.md#timestamp TIMESTAMP_MILLIS
@@ -72,7 +73,7 @@ public class TimestampColumnReader extends AbstractColumnReader<WritableTimestam
     }
 
     private void checkTypeName() {
-        Preconditions.checkArgument(
+        checkArgument(
                 actualName == PrimitiveType.PrimitiveTypeName.INT96
                         || actualName == PrimitiveType.PrimitiveTypeName.INT64,
                 "Expected type name: %s or %s, actual type name: %s",
@@ -137,8 +138,7 @@ public class TimestampColumnReader extends AbstractColumnReader<WritableTimestam
     public static TimestampData decodeInt96ToTimestamp(
             boolean utcTimestamp, org.apache.parquet.column.Dictionary dictionary, int id) {
         Binary binary = dictionary.decodeToBinary(id);
-        Preconditions.checkArgument(
-                binary.length() == 12, "Timestamp with int96 should be 12 bytes.");
+        checkArgument(binary.length() == 12, "Timestamp with int96 should be 12 bytes.");
         ByteBuffer buffer = binary.toByteBuffer().order(ByteOrder.LITTLE_ENDIAN);
         return int96ToTimestamp(utcTimestamp, buffer.getLong(), buffer.getInt());
     }
@@ -159,8 +159,8 @@ public class TimestampColumnReader extends AbstractColumnReader<WritableTimestam
 
     public static TimestampData int64ToTimestamp(
             boolean utcTimestamp, long value, LogicalTypeAnnotation.TimeUnit timeUnit) {
-        long nanosOfMillisecond = 0L;
-        long milliseconds = 0L;
+        final long nanosOfMillisecond;
+        final long milliseconds;
 
         switch (timeUnit) {
             case MILLIS:
@@ -176,7 +176,7 @@ public class TimestampColumnReader extends AbstractColumnReader<WritableTimestam
                 nanosOfMillisecond = value % NANOS_PER_SECOND;
                 break;
             default:
-                break;
+                throw new IllegalArgumentException("Invalid time unit: " + timeUnit);
         }
 
         if (utcTimestamp) {
