@@ -20,7 +20,7 @@ package org.apache.flink.formats.protobuf.table;
 
 import org.apache.flink.api.common.functions.OpenContext;
 import org.apache.flink.api.common.serialization.DeserializationSchema;
-import org.apache.flink.streaming.api.functions.source.RichSourceFunction;
+import org.apache.flink.streaming.api.functions.source.legacy.RichSourceFunction;
 import org.apache.flink.table.data.RowData;
 
 /** Source Function for protobuf table factory test. */
