@@ -21,16 +21,16 @@ package org.apache.flink.cep.nfa;
 import org.apache.flink.cep.Event;
 import org.apache.flink.cep.pattern.Pattern;
 import org.apache.flink.cep.pattern.conditions.SimpleCondition;
-import org.apache.flink.streaming.api.windowing.time.Time;
 import org.apache.flink.streaming.runtime.streamrecord.StreamRecord;
 import org.apache.flink.util.TestLogger;
 
-import org.apache.flink.shaded.guava31.com.google.common.collect.Lists;
+import org.apache.flink.shaded.guava32.com.google.common.collect.Lists;
 
 import org.junit.Test;
 import org.junit.runner.RunWith;
 import org.junit.runners.Parameterized;
 
+import java.time.Duration;
 import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.Collection;
@@ -45,11 +45,11 @@ import static org.apache.flink.cep.utils.NFAUtils.compile;
 @RunWith(Parameterized.class)
 public class TimesRangeITCase extends TestLogger {
 
-    @Parameterized.Parameter public Time time;
+    @Parameterized.Parameter public Duration time;
 
     @Parameterized.Parameters(name = "Times Range Time: {0}")
-    public static Collection<Time> parameters() {
-        return Arrays.asList(null, Time.milliseconds(3));
+    public static Collection<Duration> parameters() {
+        return Arrays.asList(null, Duration.ofMillis(3));
     }
 
     @Test
