@@ -31,6 +31,7 @@ import org.apache.flink.state.api.functions.StateBootstrapFunction;
 import org.apache.flink.state.api.output.operators.BroadcastStateBootstrapOperator;
 import org.apache.flink.state.api.output.operators.StateBootstrapOperator;
 import org.apache.flink.streaming.api.datastream.DataStream;
+import org.apache.flink.streaming.api.operators.SimpleOperatorFactory;
 import org.apache.flink.streaming.util.keys.KeySelectorUtil;
 
 import java.util.OptionalInt;
@@ -48,19 +49,11 @@ public class OneInputStateTransformation<T> {
     /** The data stream containing the data to bootstrap the operator state with. */
     private final DataStream<T> stream;
 
-    /** Checkpoint ID. */
-    private final long checkpointId;
-
     /** Local max parallelism for the bootstrapped operator. */
     private OptionalInt operatorMaxParallelism = OptionalInt.empty();
 
     OneInputStateTransformation(DataStream<T> stream) {
-        this(stream, 0L);
-    }
-
-    OneInputStateTransformation(DataStream<T> stream, long checkpointId) {
         this.stream = stream;
-        this.checkpointId = checkpointId;
     }
 
     /**
@@ -90,8 +83,8 @@ public class OneInputStateTransformation<T> {
     public StateBootstrapTransformation<T> transform(StateBootstrapFunction<T> processFunction) {
         SavepointWriterOperatorFactory factory =
                 (timestamp, path) ->
-                        new StateBootstrapOperator<>(
-                                checkpointId, timestamp, path, processFunction);
+                        SimpleOperatorFactory.of(
+                                new StateBootstrapOperator<>(timestamp, path, processFunction));
 
         return transform(factory);
     }
@@ -110,8 +103,9 @@ public class OneInputStateTransformation<T> {
             BroadcastStateBootstrapFunction<T> processFunction) {
         SavepointWriterOperatorFactory factory =
                 (timestamp, path) ->
-                        new BroadcastStateBootstrapOperator<>(
-                                checkpointId, timestamp, path, processFunction);
+                        SimpleOperatorFactory.of(
+                                new BroadcastStateBootstrapOperator<>(
+                                        timestamp, path, processFunction));
 
         return transform(factory);
     }
@@ -139,8 +133,7 @@ public class OneInputStateTransformation<T> {
     public <K> KeyedStateTransformation<K, T> keyBy(KeySelector<T, K> keySelector) {
         TypeInformation<K> keyType =
                 TypeExtractor.getKeySelectorTypes(keySelector, stream.getType());
-        return new KeyedStateTransformation<>(
-                stream, checkpointId, operatorMaxParallelism, keySelector, keyType);
+        return new KeyedStateTransformation<>(stream, operatorMaxParallelism, keySelector, keyType);
     }
 
     /**
@@ -153,8 +146,7 @@ public class OneInputStateTransformation<T> {
      */
     public <K> KeyedStateTransformation<K, T> keyBy(
             KeySelector<T, K> keySelector, TypeInformation<K> keyType) {
-        return new KeyedStateTransformation<>(
-                stream, checkpointId, operatorMaxParallelism, keySelector, keyType);
+        return new KeyedStateTransformation<>(stream, operatorMaxParallelism, keySelector, keyType);
     }
 
     /**
@@ -194,7 +186,6 @@ public class OneInputStateTransformation<T> {
 
         TypeInformation<Tuple> keyType =
                 TypeExtractor.getKeySelectorTypes(keySelector, stream.getType());
-        return new KeyedStateTransformation<>(
-                stream, checkpointId, operatorMaxParallelism, keySelector, keyType);
+        return new KeyedStateTransformation<>(stream, operatorMaxParallelism, keySelector, keyType);
     }
 }
