@@ -26,7 +26,7 @@ import org.apache.flink.api.common.functions.RichFunction;
 import org.apache.flink.api.common.typeinfo.TypeInformation;
 import org.apache.flink.api.java.functions.KeySelector;
 import org.apache.flink.api.java.typeutils.TypeExtractor;
-import org.apache.flink.state.api.output.operators.StateBootstrapWrapperOperator;
+import org.apache.flink.state.api.output.operators.StateBootstrapWrapperOperatorFactory;
 import org.apache.flink.streaming.api.datastream.DataStream;
 import org.apache.flink.streaming.api.functions.windowing.PassThroughWindowFunction;
 import org.apache.flink.streaming.api.functions.windowing.ProcessWindowFunction;
@@ -57,8 +57,6 @@ public class WindowedStateTransformation<T, K, W extends Window> {
 
     private final WindowOperatorBuilder<T, K, W> builder;
 
-    private final long checkpointId;
-
     private final OptionalInt operatorMaxParallelism;
 
     private final KeySelector<T, K> keySelector;
@@ -67,13 +65,11 @@ public class WindowedStateTransformation<T, K, W extends Window> {
 
     WindowedStateTransformation(
             DataStream<T> input,
-            long checkpointId,
             OptionalInt operatorMaxParallelism,
             KeySelector<T, K> keySelector,
             TypeInformation<K> keyType,
             WindowAssigner<? super T, W> windowAssigner) {
         this.input = input;
-        this.checkpointId = checkpointId;
         this.operatorMaxParallelism = operatorMaxParallelism;
         this.keySelector = keySelector;
         this.keyType = keyType;
@@ -157,12 +153,12 @@ public class WindowedStateTransformation<T, K, W extends Window> {
         function = input.getExecutionEnvironment().clean(function);
         reduceFunction = input.getExecutionEnvironment().clean(reduceFunction);
 
-        WindowOperator<K, T, ?, R, W> operator = builder.reduce(reduceFunction, function);
+        WindowOperator<K, T, ?, R, W> operator =
+                (WindowOperator<K, T, ?, R, W>) builder.reduce(reduceFunction, function);
 
         SavepointWriterOperatorFactory factory =
                 (timestamp, path) ->
-                        new StateBootstrapWrapperOperator<>(
-                                checkpointId, timestamp, path, operator);
+                        new StateBootstrapWrapperOperatorFactory<>(timestamp, path, operator);
         return new StateBootstrapTransformation<>(
                 input, operatorMaxParallelism, factory, keySelector, keyType);
     }
@@ -185,12 +181,12 @@ public class WindowedStateTransformation<T, K, W extends Window> {
         function = input.getExecutionEnvironment().clean(function);
         reduceFunction = input.getExecutionEnvironment().clean(reduceFunction);
 
-        WindowOperator<K, T, ?, R, W> operator = builder.reduce(reduceFunction, function);
+        WindowOperator<K, T, ?, R, W> operator =
+                (WindowOperator<K, T, ?, R, W>) builder.reduce(reduceFunction, function);
 
         SavepointWriterOperatorFactory factory =
                 (timestamp, path) ->
-                        new StateBootstrapWrapperOperator<>(
-                                checkpointId, timestamp, path, operator);
+                        new StateBootstrapWrapperOperatorFactory<>(timestamp, path, operator);
         return new StateBootstrapTransformation<>(
                 input, operatorMaxParallelism, factory, keySelector, keyType);
     }
@@ -322,12 +318,12 @@ public class WindowedStateTransformation<T, K, W extends Window> {
         aggregateFunction = input.getExecutionEnvironment().clean(aggregateFunction);
 
         WindowOperator<K, T, ?, R, W> operator =
-                builder.aggregate(aggregateFunction, windowFunction, accumulatorType);
+                (WindowOperator<K, T, ?, R, W>)
+                        builder.aggregate(aggregateFunction, windowFunction, accumulatorType);
 
         SavepointWriterOperatorFactory factory =
                 (timestamp, path) ->
-                        new StateBootstrapWrapperOperator<>(
-                                checkpointId, timestamp, path, operator);
+                        new StateBootstrapWrapperOperatorFactory<>(timestamp, path, operator);
         return new StateBootstrapTransformation<>(
                 input, operatorMaxParallelism, factory, keySelector, keyType);
     }
@@ -401,12 +397,12 @@ public class WindowedStateTransformation<T, K, W extends Window> {
         aggregateFunction = input.getExecutionEnvironment().clean(aggregateFunction);
 
         WindowOperator<K, T, ?, R, W> operator =
-                builder.aggregate(aggregateFunction, windowFunction, accumulatorType);
+                (WindowOperator<K, T, ?, R, W>)
+                        builder.aggregate(aggregateFunction, windowFunction, accumulatorType);
 
         SavepointWriterOperatorFactory factory =
                 (timestamp, path) ->
-                        new StateBootstrapWrapperOperator<>(
-                                checkpointId, timestamp, path, operator);
+                        new StateBootstrapWrapperOperatorFactory<>(timestamp, path, operator);
         return new StateBootstrapTransformation<>(
                 input, operatorMaxParallelism, factory, keySelector, keyType);
     }
@@ -427,12 +423,12 @@ public class WindowedStateTransformation<T, K, W extends Window> {
      * @return The data stream that is the result of applying the window function to the window.
      */
     public <R> StateBootstrapTransformation<T> apply(WindowFunction<T, R, K, W> function) {
-        WindowOperator<K, T, ?, R, W> operator = builder.apply(function);
+        WindowOperator<K, T, ?, R, W> operator =
+                (WindowOperator<K, T, ?, R, W>) builder.apply(function);
 
         SavepointWriterOperatorFactory factory =
                 (timestamp, path) ->
-                        new StateBootstrapWrapperOperator<>(
-                                checkpointId, timestamp, path, operator);
+                        new StateBootstrapWrapperOperatorFactory<>(timestamp, path, operator);
         return new StateBootstrapTransformation<>(
                 input, operatorMaxParallelism, factory, keySelector, keyType);
     }
@@ -453,12 +449,12 @@ public class WindowedStateTransformation<T, K, W extends Window> {
             WindowFunction<T, R, K, W> function, TypeInformation<R> resultType) {
         function = input.getExecutionEnvironment().clean(function);
 
-        WindowOperator<K, T, ?, R, W> operator = builder.apply(function);
+        WindowOperator<K, T, ?, R, W> operator =
+                (WindowOperator<K, T, ?, R, W>) builder.apply(function);
 
         SavepointWriterOperatorFactory factory =
                 (timestamp, path) ->
-                        new StateBootstrapWrapperOperator<>(
-                                checkpointId, timestamp, path, operator);
+                        new StateBootstrapWrapperOperatorFactory<>(timestamp, path, operator);
         return new StateBootstrapTransformation<>(
                 input, operatorMaxParallelism, factory, keySelector, keyType);
     }
@@ -476,12 +472,12 @@ public class WindowedStateTransformation<T, K, W extends Window> {
      */
     @PublicEvolving
     public <R> StateBootstrapTransformation<T> process(ProcessWindowFunction<T, R, K, W> function) {
-        WindowOperator<K, T, ?, R, W> operator = builder.process(function);
+        WindowOperator<K, T, ?, R, W> operator =
+                (WindowOperator<K, T, ?, R, W>) builder.process(function);
 
         SavepointWriterOperatorFactory factory =
                 (timestamp, path) ->
-                        new StateBootstrapWrapperOperator<>(
-                                checkpointId, timestamp, path, operator);
+                        new StateBootstrapWrapperOperatorFactory<>(timestamp, path, operator);
         return new StateBootstrapTransformation<>(
                 input, operatorMaxParallelism, factory, keySelector, keyType);
     }
