@@ -22,6 +22,7 @@ import org.apache.flink.annotation.Internal;
 import org.apache.flink.core.fs.Path;
 import org.apache.flink.metrics.groups.OperatorMetricGroup;
 import org.apache.flink.runtime.checkpoint.CheckpointOptions;
+import org.apache.flink.runtime.event.WatermarkEvent;
 import org.apache.flink.runtime.jobgraph.OperatorID;
 import org.apache.flink.runtime.state.CheckpointStreamFactory;
 import org.apache.flink.state.api.output.SnapshotUtils;
@@ -30,13 +31,12 @@ import org.apache.flink.state.api.runtime.NeverFireProcessingTimeService;
 import org.apache.flink.streaming.api.graph.StreamConfig;
 import org.apache.flink.streaming.api.operators.AbstractStreamOperator;
 import org.apache.flink.streaming.api.operators.BoundedOneInput;
-import org.apache.flink.streaming.api.operators.ChainingStrategy;
 import org.apache.flink.streaming.api.operators.OneInputStreamOperator;
 import org.apache.flink.streaming.api.operators.OperatorSnapshotFutures;
 import org.apache.flink.streaming.api.operators.Output;
-import org.apache.flink.streaming.api.operators.SetupableStreamOperator;
 import org.apache.flink.streaming.api.operators.StreamTaskStateInitializer;
 import org.apache.flink.streaming.api.watermark.Watermark;
+import org.apache.flink.streaming.runtime.operators.windowing.WindowOperator;
 import org.apache.flink.streaming.runtime.streamrecord.LatencyMarker;
 import org.apache.flink.streaming.runtime.streamrecord.RecordAttributes;
 import org.apache.flink.streaming.runtime.streamrecord.StreamRecord;
@@ -49,36 +49,30 @@ import org.apache.flink.util.OutputTag;
 @SuppressWarnings({"unchecked", "deprecation", "rawtypes"})
 public final class StateBootstrapWrapperOperator<
                 IN, OUT, OP extends AbstractStreamOperator<OUT> & OneInputStreamOperator<IN, OUT>>
-        implements OneInputStreamOperator<IN, TaggedOperatorSubtaskState>,
-                SetupableStreamOperator<TaggedOperatorSubtaskState>,
-                BoundedOneInput {
+        implements OneInputStreamOperator<IN, TaggedOperatorSubtaskState>, BoundedOneInput {
 
     private static final long serialVersionUID = 1L;
 
-    private final long checkpointId;
-
     private final long timestamp;
 
     private final Path savepointPath;
 
     private Output<StreamRecord<TaggedOperatorSubtaskState>> output;
 
-    private final OP operator;
+    private final WindowOperator<?, IN, ?, ?, ?> operator;
 
     public StateBootstrapWrapperOperator(
-            long checkpointId, long timestamp, Path savepointPath, OP operator) {
-        this.checkpointId = checkpointId;
+            long timestamp, Path savepointPath, WindowOperator<?, IN, ?, ?, ?> operator) {
         this.timestamp = timestamp;
         this.savepointPath = savepointPath;
         this.operator = operator;
     }
 
-    @Override
     public void setup(
             StreamTask<?, ?> containingTask,
             StreamConfig config,
             Output<StreamRecord<TaggedOperatorSubtaskState>> output) {
-        ((SetupableStreamOperator) operator).setup(containingTask, config, new VoidOutput<>());
+        operator.setup(containingTask, config, new VoidOutput<>());
         operator.setProcessingTimeService(new NeverFireProcessingTimeService());
         this.output = output;
     }
@@ -149,16 +143,6 @@ public final class StateBootstrapWrapperOperator<
         operator.setKeyContextElement2(record);
     }
 
-    @Override
-    public ChainingStrategy getChainingStrategy() {
-        return operator.getChainingStrategy();
-    }
-
-    @Override
-    public void setChainingStrategy(ChainingStrategy strategy) {
-        operator.setChainingStrategy(strategy);
-    }
-
     @Override
     public OperatorMetricGroup getMetricGroup() {
         return operator.getMetricGroup();
@@ -188,7 +172,6 @@ public final class StateBootstrapWrapperOperator<
     public void endInput() throws Exception {
         TaggedOperatorSubtaskState state =
                 SnapshotUtils.snapshot(
-                        checkpointId,
                         this,
                         operator.getContainingTask()
                                 .getEnvironment()
@@ -224,6 +207,9 @@ public final class StateBootstrapWrapperOperator<
         @Override
         public void emitRecordAttributes(RecordAttributes recordAttributes) {}
 
+        @Override
+        public void emitWatermark(WatermarkEvent watermark) {}
+
         @Override
         public void collect(T record) {}
 
