@@ -41,8 +41,6 @@ import static org.apache.flink.runtime.state.KeyGroupRangeAssignment.UPPER_BOUND
 @Internal
 public class SavepointMetadataV2 {
 
-    private final long checkpointId;
-
     private final int maxParallelism;
 
     private final Collection<MasterState> masterStates;
@@ -50,7 +48,6 @@ public class SavepointMetadataV2 {
     private final Map<OperatorID, OperatorStateSpecV2> operatorStateIndex;
 
     public SavepointMetadataV2(
-            long checkpointId,
             int maxParallelism,
             Collection<MasterState> masterStates,
             Collection<OperatorState> initialStates) {
@@ -62,7 +59,6 @@ public class SavepointMetadataV2 {
                         + maxParallelism);
         Preconditions.checkNotNull(masterStates);
 
-        this.checkpointId = checkpointId;
         this.maxParallelism = maxParallelism;
         this.masterStates = new ArrayList<>(masterStates);
         this.operatorStateIndex = CollectionUtil.newHashMapWithExpectedSize(initialStates.size());
@@ -74,10 +70,6 @@ public class SavepointMetadataV2 {
                                 OperatorStateSpecV2.existing(existingState)));
     }
 
-    public long getCheckpointId() {
-        return checkpointId;
-    }
-
     public int getMaxParallelism() {
         return maxParallelism;
     }
@@ -127,10 +119,12 @@ public class SavepointMetadataV2 {
         operatorStateIndex.put(
                 id,
                 OperatorStateSpecV2.newWithTransformation(
-                        new StateBootstrapTransformationWithID<>(id, transformation)));
+                        new StateBootstrapTransformationWithID<>(identifier, transformation)));
     }
 
-    /** @return List of {@link OperatorState} that already exists within the savepoint. */
+    /**
+     * @return List of {@link OperatorState} that already exists within the savepoint.
+     */
     public List<OperatorState> getExistingOperators() {
         return operatorStateIndex.values().stream()
                 .filter(OperatorStateSpecV2::isExistingState)
