@@ -26,11 +26,12 @@ import org.apache.flink.api.common.state.ValueStateDescriptor;
 import org.apache.flink.api.common.typeinfo.Types;
 import org.apache.flink.api.common.typeutils.base.VoidSerializer;
 import org.apache.flink.configuration.Configuration;
+import org.apache.flink.runtime.asyncprocessing.operators.AsyncStreamFlatMap;
 import org.apache.flink.runtime.checkpoint.OperatorState;
 import org.apache.flink.runtime.checkpoint.OperatorSubtaskState;
 import org.apache.flink.runtime.jobgraph.OperatorID;
 import org.apache.flink.runtime.state.VoidNamespace;
-import org.apache.flink.runtime.state.memory.MemoryStateBackend;
+import org.apache.flink.runtime.state.hashmap.HashMapStateBackend;
 import org.apache.flink.state.api.functions.KeyedStateReaderFunction;
 import org.apache.flink.state.api.input.operator.KeyedStateReaderOperator;
 import org.apache.flink.state.api.input.splits.KeyGroupRangeInputSplit;
@@ -39,12 +40,18 @@ import org.apache.flink.streaming.api.functions.KeyedProcessFunction;
 import org.apache.flink.streaming.api.operators.KeyedProcessOperator;
 import org.apache.flink.streaming.api.operators.OneInputStreamOperator;
 import org.apache.flink.streaming.api.operators.StreamFlatMap;
+import org.apache.flink.streaming.api.operators.StreamingRuntimeContext;
 import org.apache.flink.streaming.util.KeyedOneInputStreamOperatorTestHarness;
 import org.apache.flink.streaming.util.MockStreamingRuntimeContext;
+import org.apache.flink.streaming.util.asyncprocessing.AsyncKeyedOneInputStreamOperatorTestHarness;
 import org.apache.flink.util.Collector;
 
 import org.junit.Assert;
-import org.junit.Test;
+import org.junit.jupiter.api.Test;
+import org.junit.jupiter.params.ParameterizedTest;
+import org.junit.jupiter.params.provider.ValueSource;
+import org.junit.runner.RunWith;
+import org.junit.runners.Parameterized;
 
 import javax.annotation.Nonnull;
 
@@ -55,24 +62,28 @@ import java.util.Comparator;
 import java.util.List;
 import java.util.Set;
 
+import static org.assertj.core.api.Assertions.assertThatThrownBy;
+
 /** Tests for keyed state input format. */
-public class KeyedStateInputFormatTest {
+@RunWith(Parameterized.class)
+class KeyedStateInputFormatTest {
     private static ValueStateDescriptor<Integer> stateDescriptor =
             new ValueStateDescriptor<>("state", Types.INT);
 
-    @Test
-    public void testCreatePartitionedInputSplits() throws Exception {
+    @ParameterizedTest(name = "Enable async state = {0}")
+    @ValueSource(booleans = {false, true})
+    void testCreatePartitionedInputSplits(boolean asyncState) throws Exception {
         OperatorID operatorID = OperatorIDGenerator.fromUid("uid");
 
         OperatorSubtaskState state =
-                createOperatorSubtaskState(new StreamFlatMap<>(new StatefulFunction()));
-        OperatorState operatorState = new OperatorState(operatorID, 1, 128);
+                createOperatorSubtaskState(createFlatMap(asyncState), asyncState);
+        OperatorState operatorState = new OperatorState(null, null, operatorID, 1, 128);
         operatorState.putState(0, state);
 
         KeyedStateInputFormat<?, ?, ?> format =
                 new KeyedStateInputFormat<>(
                         operatorState,
-                        new MemoryStateBackend(),
+                        new HashMapStateBackend(),
                         new Configuration(),
                         new KeyedStateReaderOperator<>(new ReaderFunction(), Types.INT),
                         new ExecutionConfig());
@@ -81,19 +92,20 @@ public class KeyedStateInputFormatTest {
                 "Failed to properly partition operator state into input splits", 4, splits.length);
     }
 
-    @Test
-    public void testMaxParallelismRespected() throws Exception {
+    @ParameterizedTest(name = "Enable async state = {0}")
+    @ValueSource(booleans = {false, true})
+    void testMaxParallelismRespected(boolean asyncState) throws Exception {
         OperatorID operatorID = OperatorIDGenerator.fromUid("uid");
 
         OperatorSubtaskState state =
-                createOperatorSubtaskState(new StreamFlatMap<>(new StatefulFunction()));
-        OperatorState operatorState = new OperatorState(operatorID, 1, 128);
+                createOperatorSubtaskState(createFlatMap(asyncState), asyncState);
+        OperatorState operatorState = new OperatorState(null, null, operatorID, 1, 128);
         operatorState.putState(0, state);
 
         KeyedStateInputFormat<?, ?, ?> format =
                 new KeyedStateInputFormat<>(
                         operatorState,
-                        new MemoryStateBackend(),
+                        new HashMapStateBackend(),
                         new Configuration(),
                         new KeyedStateReaderOperator<>(new ReaderFunction(), Types.INT),
                         new ExecutionConfig());
@@ -104,19 +116,20 @@ public class KeyedStateInputFormatTest {
                 splits.length);
     }
 
-    @Test
-    public void testReadState() throws Exception {
+    @ParameterizedTest(name = "Enable async state = {0}")
+    @ValueSource(booleans = {false, true})
+    void testReadState(boolean asyncState) throws Exception {
         OperatorID operatorID = OperatorIDGenerator.fromUid("uid");
 
         OperatorSubtaskState state =
-                createOperatorSubtaskState(new StreamFlatMap<>(new StatefulFunction()));
-        OperatorState operatorState = new OperatorState(operatorID, 1, 128);
+                createOperatorSubtaskState(createFlatMap(asyncState), asyncState);
+        OperatorState operatorState = new OperatorState(null, null, operatorID, 1, 128);
         operatorState.putState(0, state);
 
         KeyedStateInputFormat<?, ?, ?> format =
                 new KeyedStateInputFormat<>(
                         operatorState,
-                        new MemoryStateBackend(),
+                        new HashMapStateBackend(),
                         new Configuration(),
                         new KeyedStateReaderOperator<>(new ReaderFunction(), Types.INT),
                         new ExecutionConfig());
@@ -129,19 +142,20 @@ public class KeyedStateInputFormatTest {
         Assert.assertEquals("Incorrect data read from input split", Arrays.asList(1, 2, 3), data);
     }
 
-    @Test
-    public void testReadMultipleOutputPerKey() throws Exception {
+    @ParameterizedTest(name = "Enable async state = {0}")
+    @ValueSource(booleans = {false, true})
+    void testReadMultipleOutputPerKey(boolean asyncState) throws Exception {
         OperatorID operatorID = OperatorIDGenerator.fromUid("uid");
 
         OperatorSubtaskState state =
-                createOperatorSubtaskState(new StreamFlatMap<>(new StatefulFunction()));
-        OperatorState operatorState = new OperatorState(operatorID, 1, 128);
+                createOperatorSubtaskState(createFlatMap(asyncState), asyncState);
+        OperatorState operatorState = new OperatorState(null, null, operatorID, 1, 128);
         operatorState.putState(0, state);
 
         KeyedStateInputFormat<?, ?, ?> format =
                 new KeyedStateInputFormat<>(
                         operatorState,
-                        new MemoryStateBackend(),
+                        new HashMapStateBackend(),
                         new Configuration(),
                         new KeyedStateReaderOperator<>(new ReaderFunction(), Types.INT),
                         new ExecutionConfig());
@@ -155,19 +169,20 @@ public class KeyedStateInputFormatTest {
                 "Incorrect data read from input split", Arrays.asList(1, 1, 2, 2, 3, 3), data);
     }
 
-    @Test(expected = IOException.class)
-    public void testInvalidProcessReaderFunctionFails() throws Exception {
+    @ParameterizedTest(name = "Enable async state = {0}")
+    @ValueSource(booleans = {false, true})
+    void testInvalidProcessReaderFunctionFails(boolean asyncState) throws Exception {
         OperatorID operatorID = OperatorIDGenerator.fromUid("uid");
 
         OperatorSubtaskState state =
-                createOperatorSubtaskState(new StreamFlatMap<>(new StatefulFunction()));
-        OperatorState operatorState = new OperatorState(operatorID, 1, 128);
+                createOperatorSubtaskState(createFlatMap(asyncState), asyncState);
+        OperatorState operatorState = new OperatorState(null, null, operatorID, 1, 128);
         operatorState.putState(0, state);
 
         KeyedStateInputFormat<?, ?, ?> format =
                 new KeyedStateInputFormat<>(
                         operatorState,
-                        new MemoryStateBackend(),
+                        new HashMapStateBackend(),
                         new Configuration(),
                         new KeyedStateReaderOperator<>(new ReaderFunction(), Types.INT),
                         new ExecutionConfig());
@@ -175,25 +190,24 @@ public class KeyedStateInputFormatTest {
 
         KeyedStateReaderFunction<Integer, Integer> userFunction = new InvalidReaderFunction();
 
-        readInputSplit(split, userFunction);
-
-        Assert.fail("KeyedStateReaderFunction did not fail on invalid RuntimeContext use");
+        assertThatThrownBy(() -> readInputSplit(split, userFunction))
+                .isInstanceOf(IOException.class);
     }
 
     @Test
-    public void testReadTime() throws Exception {
+    void testReadTime() throws Exception {
         OperatorID operatorID = OperatorIDGenerator.fromUid("uid");
 
         OperatorSubtaskState state =
                 createOperatorSubtaskState(
-                        new KeyedProcessOperator<>(new StatefulFunctionWithTime()));
-        OperatorState operatorState = new OperatorState(operatorID, 1, 128);
+                        new KeyedProcessOperator<>(new StatefulFunctionWithTime()), false);
+        OperatorState operatorState = new OperatorState(null, null, operatorID, 1, 128);
         operatorState.putState(0, state);
 
         KeyedStateInputFormat<?, ?, ?> format =
                 new KeyedStateInputFormat<>(
                         operatorState,
-                        new MemoryStateBackend(),
+                        new HashMapStateBackend(),
                         new Configuration(),
                         new KeyedStateReaderOperator<>(new TimerReaderFunction(), Types.INT),
                         new ExecutionConfig());
@@ -213,8 +227,8 @@ public class KeyedStateInputFormatTest {
             throws IOException {
         KeyedStateInputFormat<Integer, VoidNamespace, Integer> format =
                 new KeyedStateInputFormat<>(
-                        new OperatorState(OperatorIDGenerator.fromUid("uid"), 1, 4),
-                        new MemoryStateBackend(),
+                        new OperatorState(null, null, OperatorIDGenerator.fromUid("uid"), 1, 4),
+                        new HashMapStateBackend(),
                         new Configuration(),
                         new KeyedStateReaderOperator<>(userFunction, Types.INT),
                         new ExecutionConfig());
@@ -237,11 +251,20 @@ public class KeyedStateInputFormatTest {
         return data;
     }
 
+    private OneInputStreamOperator<Integer, Void> createFlatMap(boolean asyncState) {
+        return asyncState
+                ? new AsyncStreamFlatMap<>(new AsyncStatefulFunction())
+                : new StreamFlatMap<>(new StatefulFunction());
+    }
+
     private OperatorSubtaskState createOperatorSubtaskState(
-            OneInputStreamOperator<Integer, Void> operator) throws Exception {
+            OneInputStreamOperator<Integer, Void> operator, boolean async) throws Exception {
         try (KeyedOneInputStreamOperatorTestHarness<Integer, Integer, Void> testHarness =
-                new KeyedOneInputStreamOperatorTestHarness<>(
-                        operator, id -> id, Types.INT, 128, 1, 0)) {
+                async
+                        ? AsyncKeyedOneInputStreamOperatorTestHarness.create(
+                                operator, id -> id, Types.INT, 128, 1, 0)
+                        : new KeyedOneInputStreamOperatorTestHarness<>(
+                                operator, id -> id, Types.INT, 128, 1, 0)) {
 
             testHarness.setup(VoidSerializer.INSTANCE);
             testHarness.open();
@@ -262,12 +285,6 @@ public class KeyedStateInputFormatTest {
             state = getRuntimeContext().getState(stateDescriptor);
         }
 
-        @Override
-        public void open(Configuration parameters) throws Exception {
-            throw new UnsupportedOperationException(
-                    "This method is deprecated and shouldn't be invoked. Please use open(OpenContext) instead.");
-        }
-
         @Override
         public void readKey(
                 Integer key, KeyedStateReaderFunction.Context ctx, Collector<Integer> out)
@@ -284,12 +301,6 @@ public class KeyedStateInputFormatTest {
             state = getRuntimeContext().getState(stateDescriptor);
         }
 
-        @Override
-        public void open(Configuration parameters) throws Exception {
-            throw new UnsupportedOperationException(
-                    "This method is deprecated and shouldn't be invoked. Please use open(OpenContext) instead.");
-        }
-
         @Override
         public void readKey(
                 Integer key, KeyedStateReaderFunction.Context ctx, Collector<Integer> out)
@@ -306,12 +317,6 @@ public class KeyedStateInputFormatTest {
             getRuntimeContext().getState(stateDescriptor);
         }
 
-        @Override
-        public void open(Configuration parameters) throws Exception {
-            throw new UnsupportedOperationException(
-                    "This method is deprecated and shouldn't be invoked. Please use open(OpenContext) instead.");
-        }
-
         @Override
         public void readKey(
                 Integer key, KeyedStateReaderFunction.Context ctx, Collector<Integer> out)
@@ -335,6 +340,26 @@ public class KeyedStateInputFormatTest {
         }
     }
 
+    static class AsyncStatefulFunction extends RichFlatMapFunction<Integer, Void> {
+        org.apache.flink.api.common.state.v2.ValueState<Integer> state;
+        org.apache.flink.api.common.state.v2.ValueStateDescriptor<Integer> asyncStateDescriptor;
+
+        @Override
+        public void open(OpenContext openContext) {
+            asyncStateDescriptor =
+                    new org.apache.flink.api.common.state.v2.ValueStateDescriptor<>(
+                            "state", Types.INT);
+            state =
+                    ((StreamingRuntimeContext) getRuntimeContext())
+                            .getValueState(asyncStateDescriptor);
+        }
+
+        @Override
+        public void flatMap(Integer value, Collector<Void> out) throws Exception {
+            state.asyncUpdate(value);
+        }
+    }
+
     static class StatefulFunctionWithTime extends KeyedProcessFunction<Integer, Integer, Void> {
         ValueState<Integer> state;
 
@@ -360,12 +385,6 @@ public class KeyedStateInputFormatTest {
             state = getRuntimeContext().getState(stateDescriptor);
         }
 
-        @Override
-        public void open(Configuration parameters) throws Exception {
-            throw new UnsupportedOperationException(
-                    "This method is deprecated and shouldn't be invoked. Please use open(OpenContext) instead.");
-        }
-
         @Override
         public void readKey(
                 Integer key, KeyedStateReaderFunction.Context ctx, Collector<Integer> out)
