@@ -15,7 +15,7 @@
 #  See the License for the specific language governing permissions and
 # limitations under the License.
 ################################################################################
-from pyflink.common.serialization import SimpleStringSchema
+from pyflink.common.serialization import SimpleStringSchema, ByteArraySchema
 from pyflink.testing.test_case_utils import PyFlinkTestCase
 
 
@@ -29,3 +29,13 @@ class SimpleStringSchemaTests(PyFlinkTestCase):
 
         self.assertEqual(expected_string, simple_string_schema._j_deserialization_schema
                          .deserialize(expected_string.encode(encoding='utf-8')))
+
+
+class SimpleByteSchemaTests(PyFlinkTestCase):
+    def test_simple_byte_schema(self):
+        expected_bytes = "test bytes".encode(encoding='utf-8')
+        simple_byte_schema = ByteArraySchema()
+        self.assertEqual(expected_bytes,
+                         simple_byte_schema._j_serialization_schema.serialize(expected_bytes))
+        self.assertEqual(expected_bytes, simple_byte_schema._j_deserialization_schema
+                         .deserialize(expected_bytes))
