@@ -23,12 +23,12 @@ import shutil
 import tempfile
 import time
 import uuid
+import unittest
 
-from pyflink.common import Configuration, ExecutionConfig, RestartStrategies
+from pyflink.common import Configuration, ExecutionConfig
 from pyflink.common.typeinfo import Types
 from pyflink.datastream import (StreamExecutionEnvironment, CheckpointConfig,
-                                CheckpointingMode, MemoryStateBackend, TimeCharacteristic,
-                                SlotSharingGroup)
+                                CheckpointingMode, SlotSharingGroup)
 from pyflink.datastream.connectors.kafka import FlinkKafkaConsumer
 from pyflink.datastream.execution_mode import RuntimeExecutionMode
 from pyflink.datastream.formats.json import JsonRowDeserializationSchema
@@ -77,45 +77,6 @@ class StreamExecutionEnvironmentTests(PyFlinkTestCase):
 
         self.assertEqual(parallelism, 8)
 
-    def test_set_get_restart_strategy(self):
-        self.env.set_restart_strategy(RestartStrategies.no_restart())
-
-        restart_strategy = self.env.get_restart_strategy()
-
-        self.assertEqual(restart_strategy, RestartStrategies.no_restart())
-
-    def test_add_default_kryo_serializer(self):
-        self.env.add_default_kryo_serializer(
-            "org.apache.flink.runtime.state.StateBackendTestBase$TestPojo",
-            "org.apache.flink.runtime.state.StateBackendTestBase$CustomKryoTestSerializer")
-
-        class_dict = self.env.get_config().get_default_kryo_serializer_classes()
-
-        self.assertEqual(class_dict,
-                         {'org.apache.flink.runtime.state.StateBackendTestBase$TestPojo':
-                          'org.apache.flink.runtime.state'
-                          '.StateBackendTestBase$CustomKryoTestSerializer'})
-
-    def test_register_type_with_kryo_serializer(self):
-        self.env.register_type_with_kryo_serializer(
-            "org.apache.flink.runtime.state.StateBackendTestBase$TestPojo",
-            "org.apache.flink.runtime.state.StateBackendTestBase$CustomKryoTestSerializer")
-
-        class_dict = self.env.get_config().get_registered_types_with_kryo_serializer_classes()
-
-        self.assertEqual(class_dict,
-                         {'org.apache.flink.runtime.state.StateBackendTestBase$TestPojo':
-                          'org.apache.flink.runtime.state'
-                          '.StateBackendTestBase$CustomKryoTestSerializer'})
-
-    def test_register_type(self):
-        self.env.register_type("org.apache.flink.runtime.state.StateBackendTestBase$TestPojo")
-
-        type_list = self.env.get_config().get_registered_pojo_types()
-
-        self.assertEqual(type_list,
-                         ['org.apache.flink.runtime.state.StateBackendTestBase$TestPojo'])
-
     def test_get_set_max_parallelism(self):
         self.env.set_max_parallelism(12)
 
@@ -161,21 +122,6 @@ class StreamExecutionEnvironmentTests(PyFlinkTestCase):
 
         self.assertEqual(mode, CheckpointingMode.AT_LEAST_ONCE)
 
-    def test_get_state_backend(self):
-        state_backend = self.env.get_state_backend()
-
-        self.assertIsNone(state_backend)
-
-    def test_set_state_backend(self):
-        input_backend = MemoryStateBackend()
-
-        self.env.set_state_backend(input_backend)
-
-        output_backend = self.env.get_state_backend()
-
-        self.assertEqual(output_backend._j_memory_state_backend,
-                         input_backend._j_memory_state_backend)
-
     def test_is_changelog_state_backend_enabled(self):
         self.assertIsNone(self.env.is_changelog_state_backend_enabled())
 
@@ -189,30 +135,15 @@ class StreamExecutionEnvironmentTests(PyFlinkTestCase):
 
         self.assertFalse(self.env.is_changelog_state_backend_enabled())
 
-    def test_get_set_stream_time_characteristic(self):
-        default_time_characteristic = self.env.get_stream_time_characteristic()
-
-        self.assertEqual(default_time_characteristic, TimeCharacteristic.EventTime)
-
-        self.env.set_stream_time_characteristic(TimeCharacteristic.ProcessingTime)
-
-        time_characteristic = self.env.get_stream_time_characteristic()
-
-        self.assertEqual(time_characteristic, TimeCharacteristic.ProcessingTime)
-
     def test_configure(self):
         configuration = Configuration()
         configuration.set_string('pipeline.operator-chaining', 'false')
-        configuration.set_string('pipeline.time-characteristic', 'IngestionTime')
         configuration.set_string('execution.buffer-timeout', '1 min')
         configuration.set_string('execution.checkpointing.timeout', '12000')
         self.env.configure(configuration)
         self.assertEqual(self.env.is_chaining_enabled(), False)
-        self.assertEqual(self.env.get_stream_time_characteristic(),
-                         TimeCharacteristic.IngestionTime)
         self.assertEqual(self.env.get_buffer_timeout(), 60000)
         self.assertEqual(self.env.get_checkpoint_config().get_checkpoint_timeout(), 12000)
-        self.assertTrue(self.env.get_state_backend() is None)
 
     def test_execute(self):
         tmp_dir = tempfile.gettempdir()
@@ -318,22 +249,6 @@ class StreamExecutionEnvironmentTests(PyFlinkTestCase):
         expected.sort()
         self.assertEqual(expected, results)
 
-    def test_read_text_file(self):
-        texts = ["Mike", "Marry", "Ted", "Jack", "Bob", "Henry"]
-        text_file_path = self.tempdir + '/text_file'
-        with open(text_file_path, 'a') as f:
-            for text in texts:
-                f.write(text)
-                f.write('\n')
-
-        ds = self.env.read_text_file(text_file_path)
-        ds.add_sink(self.test_sink)
-        self.env.execute("test read text file")
-        results = self.test_sink.get_results()
-        results.sort()
-        texts.sort()
-        self.assertEqual(texts, results)
-
     def test_execute_async(self):
         ds = self.env.from_collection([(1, 'Hi', 'Hello'), (2, 'Hello', 'Hi')],
                                       type_info=Types.ROW(
@@ -554,69 +469,41 @@ class StreamExecutionEnvironmentTests(PyFlinkTestCase):
         expected.sort()
         self.assertEqual(expected, result)
 
-    def test_add_jars_basic_non_standard_yaml(self):
-        self._test_add_jars_basic(False)
-
-    def test_add_jars_basic_standard_yaml(self):
-        self._test_add_jars_basic(True)
-
-    def _test_add_jars_basic(self, standard_yaml):
+    def test_add_jars_basic(self):
         jvm = get_gateway().jvm
         jars_key = jvm.org.apache.flink.configuration.PipelineOptions.JARS.key()
         env_config = jvm.org.apache.flink.python.util.PythonConfigUtil \
             .getEnvironmentConfig(self.env._j_stream_execution_environment)
 
-        jvm.org.apache.flink.configuration.GlobalConfiguration.setStandardYaml(standard_yaml)
-
         old_jars = env_config.getString(jars_key, None)
         self.assertIsNone(old_jars)
 
         self.env.add_jars('file://1.jar')
         new_jars = env_config.getString(jars_key, None)
-        if standard_yaml:
-            self.assertEqual(new_jars, '[\'file://1.jar\']')
-        else:
-            self.assertEqual(new_jars, 'file://1.jar')
+        self.assertEqual(new_jars, '[\'file://1.jar\']')
 
         self.env.add_jars('file://2.jar', 'file://3.jar')
         new_jars = env_config.getString(jars_key, None)
-        if standard_yaml:
-            self.assertEqual(new_jars, '[\'file://1.jar\', \'file://2.jar\', \'file://3.jar\']')
-        else:
-            self.assertEqual(new_jars, 'file://1.jar;file://2.jar;file://3.jar')
+        self.assertEqual(new_jars, '[\'file://1.jar\', \'file://2.jar\', \'file://3.jar\']')
 
-    def test_add_classpaths_basic_non_standard_yaml(self):
-        self._test_add_classpaths_basic(False)
-
-    def test_add_classpaths_basic_standard_yaml(self):
-        self._test_add_classpaths_basic(True)
-
-    def _test_add_classpaths_basic(self, standard_yaml):
+    def test_add_classpaths_basic(self):
         jvm = get_gateway().jvm
         classpaths_key = jvm.org.apache.flink.configuration.PipelineOptions.CLASSPATHS.key()
         env_config = jvm.org.apache.flink.python.util.PythonConfigUtil \
             .getEnvironmentConfig(self.env._j_stream_execution_environment)
 
-        jvm.org.apache.flink.configuration.GlobalConfiguration.setStandardYaml(standard_yaml)
-
         old_classpaths = env_config.getString(classpaths_key, None)
         self.assertIsNone(old_classpaths)
 
         self.env.add_classpaths('file://1.jar')
         new_classpaths = env_config.getString(classpaths_key, None)
-        if standard_yaml:
-            self.assertEqual(new_classpaths, '[\'file://1.jar\']')
-        else:
-            self.assertEqual(new_classpaths, 'file://1.jar')
+        self.assertEqual(new_classpaths, '[\'file://1.jar\']')
 
         self.env.add_classpaths('file://2.jar', 'file://3.jar')
         new_classpaths = env_config.getString(classpaths_key, None)
-        if standard_yaml:
-            self.assertEqual(
-                new_classpaths, '[\'file://1.jar\', \'file://2.jar\', \'file://3.jar\']')
-        else:
-            self.assertEqual(new_classpaths, 'file://1.jar;file://2.jar;file://3.jar')
+        self.assertEqual(new_classpaths, '[\'file://1.jar\', \'file://2.jar\', \'file://3.jar\']')
 
+    @unittest.skip("Disable due to Kafka connector need to release a new version 2.0")
     def test_add_jars(self):
         # find kafka connector jars
         flink_source_root = _find_flink_source_root()
@@ -638,6 +525,7 @@ class StreamExecutionEnvironmentTests(PyFlinkTestCase):
         self.env.add_source(kafka_consumer).print()
         self.env.get_execution_plan()
 
+    @unittest.skip("Disable due to Kafka connector need to release a new version 2.0")
     def test_add_classpaths(self):
         # find kafka connector jars
         flink_source_root = _find_flink_source_root()
