@@ -44,8 +44,9 @@ class EnvironmentAPICompletenessTests(PythonAPICompletenessTestCase, PyFlinkTest
             'compilePlanSql',
             'executePlan',
             'explainPlan',
-            # See FLINK-32647
-            'createCatalog'}
+            'registerFunction',
+            'scan',
+            'registerTable'}
 
     @classmethod
     def java_method_name(cls, python_method_name):
