@@ -33,8 +33,8 @@ from pyflink.datastream.tests.test_util import DataStreamTestSinkFunction
 from pyflink.datastream.window import TimeWindowSerializer
 from pyflink.java_gateway import get_gateway
 from pyflink.table import (DataTypes, StreamTableEnvironment, EnvironmentSettings, Module,
-                           ResultKind, ModuleEntry)
-from pyflink.table.catalog import ObjectPath, CatalogBaseTable
+                           ResultKind, ModuleEntry, Schema)
+from pyflink.table.catalog import ObjectPath, CatalogBaseTable, CatalogDescriptor
 from pyflink.table.explain_detail import ExplainDetail
 from pyflink.table.expressions import col, source_watermark
 from pyflink.table.table_descriptor import TableDescriptor
@@ -188,54 +188,70 @@ class TableEnvironmentTest(PyFlinkUTTestCase):
         self.assert_equals(t_env.list_user_defined_functions(), [])
 
     def test_create_temporary_table_from_descriptor(self):
-        from pyflink.table.schema import Schema
-
-        t_env = self.t_env
-        catalog = t_env.get_current_catalog()
-        database = t_env.get_current_database()
         schema = Schema.new_builder().column("f0", DataTypes.INT()).build()
-        t_env.create_temporary_table(
+
+        self.assert_created_temporary_table_from_descriptor(schema)
+
+    def test_create_temporary_table_if_not_exists_from_descriptor(self):
+        schema = Schema.new_builder().column("f0", DataTypes.INT()).build()
+
+        self.assert_created_temporary_table_from_descriptor(schema)
+
+        # This should be a no-op and throw no exception
+        self.t_env.create_temporary_table(
             "T",
             TableDescriptor.for_connector("fake")
-             .schema(schema)
-             .option("a", "Test")
-             .build())
+            .schema(schema)
+            .option("a", "Test")
+            .build(),
+            True)
 
-        self.assertFalse(t_env.get_catalog(catalog).table_exists(ObjectPath(database, "T")))
-        gateway = get_gateway()
+        with self.assertRaises(Exception) as error_context:
+            self.t_env.create_temporary_table(
+                "T",
+                TableDescriptor.for_connector("fake")
+                .schema(schema)
+                .option("a", "Test")
+                .build(),
+                False)
 
-        catalog_table = CatalogBaseTable(
-            t_env._j_tenv.getCatalogManager()
-                 .getTable(gateway.jvm.ObjectIdentifier.of(catalog, database, "T"))
-                 .get()
-                 .getTable())
-        self.assertEqual(schema, catalog_table.get_unresolved_schema())
-        self.assertEqual("fake", catalog_table.get_options().get("connector"))
-        self.assertEqual("Test", catalog_table.get_options().get("a"))
+        error_msg = str(error_context.exception)
+        self.assertIn("Temporary table '`default_catalog`.`default_database`.`T`' already exists",
+                      error_msg)
 
     def test_create_table_from_descriptor(self):
-        from pyflink.table.schema import Schema
-
-        catalog = self.t_env.get_current_catalog()
-        database = self.t_env.get_current_database()
         schema = Schema.new_builder().column("f0", DataTypes.INT()).build()
+
+        self.assert_created_table_from_descriptor(schema)
+
+    def test_create_table_ignore_if_exists_from_descriptor(self):
+        schema = Schema.new_builder().column("f0", DataTypes.INT()).build()
+        self.assert_created_table_from_descriptor(schema)
+
+        # This should be a no-op and throw no exception
         self.t_env.create_table(
             "T",
             TableDescriptor.for_connector("fake")
-                  .schema(schema)
-                  .option("a", "Test")
-                  .build())
-        object_path = ObjectPath(database, "T")
-        self.assertTrue(self.t_env.get_catalog(catalog).table_exists(object_path))
+            .schema(schema)
+            .option("a", "Test")
+            .build(),
+            True)
 
-        catalog_table = self.t_env.get_catalog(catalog).get_table(object_path)
-        self.assertEqual(schema, catalog_table.get_unresolved_schema())
-        self.assertEqual("fake", catalog_table.get_options().get("connector"))
-        self.assertEqual("Test", catalog_table.get_options().get("a"))
+        with self.assertRaises(Exception) as error_context:
+            self.t_env.create_table(
+                "T",
+                TableDescriptor.for_connector("fake")
+                .schema(schema)
+                .option("a", "Test")
+                .build(),
+                False)
+
+        error_msg = str(error_context.exception)
+        self.assertIn(
+            "Could not execute CreateTable in path `default_catalog`.`default_database`.`T`",
+            error_msg)
 
     def test_table_from_descriptor(self):
-        from pyflink.table.schema import Schema
-
         schema = Schema.new_builder().column("f0", DataTypes.INT()).build()
         descriptor = TableDescriptor.for_connector("fake").schema(schema).build()
 
@@ -326,6 +342,48 @@ class TableEnvironmentTest(PyFlinkUTTestCase):
             Py4JJavaError, "No module with name 'dummy' exists",
             self.t_env.use_modules, 'core', 'dummy')
 
+    def assert_created_table_from_descriptor(self, schema: Schema):
+        catalog = self.t_env.get_current_catalog()
+        database = self.t_env.get_current_database()
+
+        self.t_env.create_table(
+            "T",
+            TableDescriptor.for_connector("fake")
+            .schema(schema)
+            .option("a", "Test")
+            .build())
+
+        object_path = ObjectPath(database, "T")
+        self.assertTrue(self.t_env.get_catalog(catalog).table_exists(object_path))
+
+        catalog_table = self.t_env.get_catalog(catalog).get_table(object_path)
+        self.assertEqual(schema, catalog_table.get_unresolved_schema())
+        self.assertEqual("fake", catalog_table.get_options().get("connector"))
+        self.assertEqual("Test", catalog_table.get_options().get("a"))
+
+    def assert_created_temporary_table_from_descriptor(self, schema: Schema):
+        catalog = self.t_env.get_current_catalog()
+        database = self.t_env.get_current_database()
+
+        self.t_env.create_temporary_table(
+            "T",
+            TableDescriptor.for_connector("fake")
+            .schema(schema)
+            .option("a", "Test")
+            .build())
+
+        self.assertFalse(self.t_env.get_catalog(catalog).table_exists(ObjectPath(database, "T")))
+        gateway = get_gateway()
+
+        catalog_table = CatalogBaseTable(
+            self.t_env._j_tenv.getCatalogManager()
+            .getTable(gateway.jvm.ObjectIdentifier.of(catalog, database, "T"))
+            .get()
+            .getTable())
+        self.assertEqual(schema, catalog_table.get_unresolved_schema())
+        self.assertEqual("fake", catalog_table.get_options().get("connector"))
+        self.assertEqual("Test", catalog_table.get_options().get("a"))
+
 
 class DataStreamConversionTestCases(PyFlinkUTTestCase):
 
@@ -415,8 +473,6 @@ class DataStreamConversionTestCases(PyFlinkUTTestCase):
         self.assert_equals(result, expected)
 
     def test_from_data_stream_with_schema(self):
-        from pyflink.table import Schema
-
         ds = self.env.from_collection([(1, 'Hi', 'Hello'), (2, 'Hello', 'Hi')],
                                       type_info=Types.ROW_NAMED(
                                           ["a", "b", "c"],
@@ -601,6 +657,14 @@ class DataStreamConversionTestCases(PyFlinkUTTestCase):
         result.sort()
         self.assertEqual(expected, result)
 
+    def test_create_catalog(self):
+        config = Configuration()
+        config.set_string("type", "generic_in_memory")
+        catalog_desc = CatalogDescriptor.of("mycat", config, None)
+        self.t_env.create_catalog("mycat", catalog_desc)
+        mycat = self.t_env.get_catalog("mycat")
+        self.assertIsNotNone(mycat)
+
 
 class StreamTableEnvironmentTests(PyFlinkStreamTableTestCase):
 
