@@ -18,7 +18,6 @@
 package org.apache.flink.streaming.api.typeinfo.python;
 
 import org.apache.flink.annotation.Internal;
-import org.apache.flink.api.common.ExecutionConfig;
 import org.apache.flink.api.common.serialization.SerializerConfig;
 import org.apache.flink.api.common.typeinfo.TypeInformation;
 import org.apache.flink.api.common.typeutils.TypeSerializer;
@@ -73,11 +72,6 @@ public class PickledByteArrayTypeInfo extends TypeInformation<byte[]> {
         return BytePrimitiveArraySerializer.INSTANCE;
     }
 
-    @Override
-    public TypeSerializer<byte[]> createSerializer(ExecutionConfig config) {
-        return createSerializer(config.getSerializerConfig());
-    }
-
     @Override
     public String toString() {
         return "PickledByteArrayTypeInfo";
