@@ -24,12 +24,16 @@ import org.apache.flink.api.dag.Pipeline;
 import org.apache.flink.api.dag.Transformation;
 import org.apache.flink.configuration.ReadableConfig;
 import org.apache.flink.core.execution.JobClient;
+import org.apache.flink.core.execution.JobStatusHook;
 import org.apache.flink.python.PythonOptions;
 import org.apache.flink.python.chain.PythonOperatorChainingOptimizer;
 import org.apache.flink.python.util.PythonConfigUtil;
 import org.apache.flink.table.delegation.Executor;
 import org.apache.flink.util.Preconditions;
 
+import javax.annotation.Nullable;
+
+import java.util.Collections;
 import java.util.List;
 
 /** {@link Executor} which will perform chaining optimization before generating the StreamGraph. */
@@ -52,6 +56,16 @@ public class ChainingOptimizingExecutor implements Executor {
             List<Transformation<?>> transformations,
             ReadableConfig configuration,
             String defaultJobName) {
+        return createPipeline(
+                transformations, configuration, defaultJobName, Collections.emptyList());
+    }
+
+    @Override
+    public Pipeline createPipeline(
+            List<Transformation<?>> transformations,
+            ReadableConfig configuration,
+            @Nullable String defaultJobName,
+            List<JobStatusHook> jobStatusHookList) {
         List<Transformation<?>> chainedTransformations = transformations;
         if (configuration
                 .getOptional(PythonOptions.PYTHON_OPERATOR_CHAINING_ENABLED)
@@ -60,7 +74,8 @@ public class ChainingOptimizingExecutor implements Executor {
         }
 
         PythonConfigUtil.setPartitionCustomOperatorNumPartitions(chainedTransformations);
-        return executor.createPipeline(chainedTransformations, configuration, defaultJobName);
+        return executor.createPipeline(
+                chainedTransformations, configuration, defaultJobName, jobStatusHookList);
     }
 
     @Override
