@@ -260,10 +260,12 @@ public class PekkoRpcService implements RpcService {
     }
 
     @Override
-    public <C extends RpcEndpoint & RpcGateway> RpcServer startServer(C rpcEndpoint) {
+    public <C extends RpcEndpoint & RpcGateway> RpcServer startServer(
+            C rpcEndpoint, Map<String, String> loggingContext) {
         checkNotNull(rpcEndpoint, "rpc endpoint");
 
-        final SupervisorActor.ActorRegistration actorRegistration = registerRpcActor(rpcEndpoint);
+        final SupervisorActor.ActorRegistration actorRegistration =
+                registerRpcActor(rpcEndpoint, loggingContext);
         final ActorRef actorRef = actorRegistration.getActorRef();
         final CompletableFuture<Void> actorTerminationFuture =
                 actorRegistration.getTerminationFuture();
@@ -336,7 +338,7 @@ public class PekkoRpcService implements RpcService {
     }
 
     private <C extends RpcEndpoint & RpcGateway> SupervisorActor.ActorRegistration registerRpcActor(
-            C rpcEndpoint) {
+            C rpcEndpoint, Map<String, String> loggingContext) {
         final Class<? extends AbstractActor> rpcActorType;
 
         if (rpcEndpoint instanceof FencedRpcEndpoint) {
@@ -359,7 +361,8 @@ public class PekkoRpcService implements RpcService {
                                             getVersion(),
                                             configuration.getMaximumFramesize(),
                                             configuration.isForceRpcInvocationSerialization(),
-                                            flinkClassLoader),
+                                            flinkClassLoader,
+                                            loggingContext),
                             rpcEndpoint.getEndpointId());
 
             final SupervisorActor.ActorRegistration actorRegistration =
