@@ -18,7 +18,6 @@
 
 package org.apache.flink.runtime.webmonitor;
 
-import org.apache.flink.api.common.time.Time;
 import org.apache.flink.configuration.Configuration;
 import org.apache.flink.configuration.JobManagerOptions;
 import org.apache.flink.runtime.webmonitor.handlers.JarUploadHandler;
@@ -27,6 +26,7 @@ import org.apache.flink.util.concurrent.Executors;
 import org.junit.jupiter.api.Test;
 
 import java.nio.file.Paths;
+import java.time.Duration;
 import java.util.Collections;
 import java.util.concurrent.CompletableFuture;
 
@@ -43,7 +43,7 @@ class WebMonitorUtilsTest {
         final WebMonitorExtension webMonitorExtension =
                 WebMonitorUtils.loadWebSubmissionExtension(
                         CompletableFuture::new,
-                        Time.seconds(10),
+                        Duration.ofSeconds(10),
                         Collections.emptyMap(),
                         CompletableFuture.completedFuture("localhost:12345"),
                         Paths.get("/tmp"),
