@@ -19,7 +19,7 @@
 import { ChangeDetectorRef, Component, OnInit, ChangeDetectionStrategy, OnDestroy, Inject } from '@angular/core';
 import { ConfigService, JobManagerService } from '@flink-runtime-web/services';
 import { EditorOptions } from 'ng-zorro-antd/code-editor/typings';
-import { flinkEditorOptions } from '@flink-runtime-web/share/common/editor/editor-config';
+import { flinkEditorOptions } from '@flink-runtime-web/components/editor/editor-config';
 import {of, Subject} from 'rxjs';
 import {catchError, takeUntil} from 'rxjs/operators';
 import {
@@ -27,12 +27,20 @@ import {
   JOB_MANAGER_MODULE_DEFAULT_CONFIG,
   JobManagerModuleConfig
 } from '@flink-runtime-web/pages/job-manager/job-manager.config';
+import {NzCodeEditorModule} from "ng-zorro-antd/code-editor";
+import {AutoResizeDirective} from "@flink-runtime-web/components/editor/auto-resize.directive";
+import {FormsModule} from "@angular/forms";
+import {
+  AddonCompactComponent
+} from "@flink-runtime-web/components/addon-compact/addon-compact.component";
 
 @Component({
   selector: 'flink-job-manager-logs',
   templateUrl: './job-manager-logs.component.html',
   styleUrls: ['./job-manager-logs.component.less'],
-  changeDetection: ChangeDetectionStrategy.OnPush
+  changeDetection: ChangeDetectionStrategy.OnPush,
+  imports: [NzCodeEditorModule, AutoResizeDirective, FormsModule, AddonCompactComponent],
+  standalone: true
 })
 export class JobManagerLogsComponent implements OnInit, OnDestroy {
   public readonly downloadName = `jobmanager_log`;
@@ -69,7 +77,8 @@ export class JobManagerLogsComponent implements OnInit, OnDestroy {
       .loadLogs()
       .pipe(
         catchError(() => of('')),
-        takeUntil(this.destroy$))
+        takeUntil(this.destroy$)
+      )
       .subscribe(data => {
         this.loading = false;
         this.logs = data;
