@@ -16,5 +16,4 @@
  * limitations under the License.
  */
 
-export * from './deepFind';
-export * from './isNil';
+export * from './is-nil';
