@@ -21,7 +21,6 @@ package org.apache.flink.runtime.dispatcher;
 import org.apache.flink.annotation.VisibleForTesting;
 import org.apache.flink.api.common.JobID;
 import org.apache.flink.api.common.JobStatus;
-import org.apache.flink.api.common.time.Time;
 import org.apache.flink.runtime.executiongraph.ArchivedExecutionGraph;
 import org.apache.flink.runtime.messages.webmonitor.JobDetails;
 import org.apache.flink.runtime.messages.webmonitor.JobsOverview;
@@ -29,15 +28,14 @@ import org.apache.flink.runtime.scheduler.ExecutionGraphInfo;
 import org.apache.flink.util.FileUtils;
 import org.apache.flink.util.InstantiationUtil;
 import org.apache.flink.util.Preconditions;
-import org.apache.flink.util.ShutdownHookUtil;
 import org.apache.flink.util.concurrent.ScheduledExecutor;
 
-import org.apache.flink.shaded.guava31.com.google.common.base.Ticker;
-import org.apache.flink.shaded.guava31.com.google.common.cache.Cache;
-import org.apache.flink.shaded.guava31.com.google.common.cache.CacheBuilder;
-import org.apache.flink.shaded.guava31.com.google.common.cache.CacheLoader;
-import org.apache.flink.shaded.guava31.com.google.common.cache.LoadingCache;
-import org.apache.flink.shaded.guava31.com.google.common.cache.RemovalListener;
+import org.apache.flink.shaded.guava32.com.google.common.base.Ticker;
+import org.apache.flink.shaded.guava32.com.google.common.cache.Cache;
+import org.apache.flink.shaded.guava32.com.google.common.cache.CacheBuilder;
+import org.apache.flink.shaded.guava32.com.google.common.cache.CacheLoader;
+import org.apache.flink.shaded.guava32.com.google.common.cache.LoadingCache;
+import org.apache.flink.shaded.guava32.com.google.common.cache.RemovalListener;
 
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
@@ -49,6 +47,7 @@ import java.io.FileInputStream;
 import java.io.FileNotFoundException;
 import java.io.FileOutputStream;
 import java.io.IOException;
+import java.time.Duration;
 import java.util.Collection;
 import java.util.UUID;
 import java.util.concurrent.ExecutionException;
@@ -72,8 +71,6 @@ public class FileExecutionGraphInfoStore implements ExecutionGraphInfoStore {
 
     private final ScheduledFuture<?> cleanupFuture;
 
-    private final Thread shutdownHook;
-
     private int numFinishedJobs;
 
     private int numFailedJobs;
@@ -82,7 +79,7 @@ public class FileExecutionGraphInfoStore implements ExecutionGraphInfoStore {
 
     public FileExecutionGraphInfoStore(
             File rootDir,
-            Time expirationTime,
+            Duration expirationTime,
             int maximumCapacity,
             long maximumCacheSizeBytes,
             ScheduledExecutor scheduledExecutor,
@@ -95,7 +92,7 @@ public class FileExecutionGraphInfoStore implements ExecutionGraphInfoStore {
                 "Initializing {}: Storage directory {}, expiration time {}, maximum cache size {} bytes.",
                 FileExecutionGraphInfoStore.class.getSimpleName(),
                 storageDirectory,
-                expirationTime.toMilliseconds(),
+                expirationTime.toMillis(),
                 maximumCacheSizeBytes);
 
         this.storageDir = Preconditions.checkNotNull(storageDirectory);
@@ -104,7 +101,7 @@ public class FileExecutionGraphInfoStore implements ExecutionGraphInfoStore {
                 "The storage directory must exist and be a directory.");
         this.jobDetailsCache =
                 CacheBuilder.newBuilder()
-                        .expireAfterWrite(expirationTime.toMilliseconds(), TimeUnit.MILLISECONDS)
+                        .expireAfterWrite(expirationTime.toMillis(), TimeUnit.MILLISECONDS)
                         .maximumSize(maximumCapacity)
                         .removalListener(
                                 (RemovalListener<JobID, JobDetails>)
@@ -128,12 +125,10 @@ public class FileExecutionGraphInfoStore implements ExecutionGraphInfoStore {
         this.cleanupFuture =
                 scheduledExecutor.scheduleWithFixedDelay(
                         jobDetailsCache::cleanUp,
-                        expirationTime.toMilliseconds(),
-                        expirationTime.toMilliseconds(),
+                        expirationTime.toMillis(),
+                        expirationTime.toMillis(),
                         TimeUnit.MILLISECONDS);
 
-        this.shutdownHook = ShutdownHookUtil.addShutdownHook(this, getClass().getSimpleName(), LOG);
-
         this.numFinishedJobs = 0;
         this.numFailedJobs = 0;
         this.numCanceledJobs = 0;
@@ -232,9 +227,6 @@ public class FileExecutionGraphInfoStore implements ExecutionGraphInfoStore {
 
         // clean up the storage directory
         FileUtils.deleteFileOrDirectory(storageDir);
-
-        // Remove shutdown hook to prevent resource leaks
-        ShutdownHookUtil.removeShutdownHook(shutdownHook, getClass().getSimpleName(), LOG);
     }
 
     // --------------------------------------------------------------
