@@ -26,6 +26,7 @@ import org.apache.flink.configuration.MemorySize;
 import org.apache.flink.runtime.accumulators.StringifiedAccumulatorResult;
 import org.apache.flink.runtime.checkpoint.CheckpointStatsSnapshot;
 import org.apache.flink.runtime.clusterframework.types.ResourceProfile;
+import org.apache.flink.runtime.jobgraph.JobType;
 import org.apache.flink.runtime.jobgraph.JobVertex;
 import org.apache.flink.runtime.jobgraph.JobVertexID;
 import org.apache.flink.runtime.jobgraph.tasks.CheckpointCoordinatorConfiguration;
@@ -53,6 +54,7 @@ import java.util.Optional;
 public class ArchivedExecutionGraph implements AccessExecutionGraph, Serializable {
 
     private static final long serialVersionUID = 7231383912742578428L;
+
     // --------------------------------------------------------------------------------------------
 
     /** The ID of the job this graph has been built for. */
@@ -83,6 +85,9 @@ public class ArchivedExecutionGraph implements AccessExecutionGraph, Serializabl
     /** Current status of the job execution. */
     private final JobStatus state;
 
+    /** The job type of the job execution. */
+    @Nullable private final JobType jobType;
+
     /**
      * The exception that caused the job to fail. This is set to the first root exception that was
      * not recoverable and triggered job failure
@@ -108,6 +113,10 @@ public class ArchivedExecutionGraph implements AccessExecutionGraph, Serializabl
 
     @Nullable private final String changelogStorageName;
 
+    @Nullable private final String streamGraphJson;
+
+    private final int pendingOperatorCount;
+
     public ArchivedExecutionGraph(
             JobID jobID,
             String jobName,
@@ -115,6 +124,7 @@ public class ArchivedExecutionGraph implements AccessExecutionGraph, Serializabl
             List<ArchivedExecutionJobVertex> verticesInCreationOrder,
             long[] stateTimestamps,
             JobStatus state,
+            @Nullable JobType jobType,
             @Nullable ErrorInfo failureCause,
             String jsonPlan,
             StringifiedAccumulatorResult[] archivedUserAccumulators,
@@ -126,7 +136,9 @@ public class ArchivedExecutionGraph implements AccessExecutionGraph, Serializabl
             @Nullable String stateBackendName,
             @Nullable String checkpointStorageName,
             @Nullable TernaryBoolean stateChangelogEnabled,
-            @Nullable String changelogStorageName) {
+            @Nullable String changelogStorageName,
+            @Nullable String streamGraphJson,
+            int pendingOperatorCount) {
 
         this.jobID = Preconditions.checkNotNull(jobID);
         this.jobName = Preconditions.checkNotNull(jobName);
@@ -134,6 +146,7 @@ public class ArchivedExecutionGraph implements AccessExecutionGraph, Serializabl
         this.verticesInCreationOrder = Preconditions.checkNotNull(verticesInCreationOrder);
         this.stateTimestamps = Preconditions.checkNotNull(stateTimestamps);
         this.state = Preconditions.checkNotNull(state);
+        this.jobType = jobType;
         this.failureCause = failureCause;
         this.jsonPlan = Preconditions.checkNotNull(jsonPlan);
         this.archivedUserAccumulators = Preconditions.checkNotNull(archivedUserAccumulators);
@@ -146,6 +159,8 @@ public class ArchivedExecutionGraph implements AccessExecutionGraph, Serializabl
         this.checkpointStorageName = checkpointStorageName;
         this.stateChangelogEnabled = stateChangelogEnabled;
         this.changelogStorageName = changelogStorageName;
+        this.streamGraphJson = streamGraphJson;
+        this.pendingOperatorCount = pendingOperatorCount;
     }
 
     // --------------------------------------------------------------------------------------------
@@ -155,6 +170,11 @@ public class ArchivedExecutionGraph implements AccessExecutionGraph, Serializabl
         return jsonPlan;
     }
 
+    @Override
+    public String getStreamGraphJson() {
+        return streamGraphJson;
+    }
+
     @Override
     public JobID getJobID() {
         return jobID;
@@ -170,6 +190,11 @@ public class ArchivedExecutionGraph implements AccessExecutionGraph, Serializabl
         return state;
     }
 
+    @Override
+    public JobType getJobType() {
+        return jobType;
+    }
+
     @Nullable
     @Override
     public ErrorInfo getFailureInfo() {
@@ -286,6 +311,11 @@ public class ArchivedExecutionGraph implements AccessExecutionGraph, Serializabl
         return Optional.ofNullable(changelogStorageName);
     }
 
+    @Override
+    public int getPendingOperatorCount() {
+        return pendingOperatorCount;
+    }
+
     /**
      * Create a {@link ArchivedExecutionGraph} from the given {@link ExecutionGraph}.
      *
@@ -342,6 +372,7 @@ public class ArchivedExecutionGraph implements AccessExecutionGraph, Serializabl
                 archivedVerticesInCreationOrder,
                 timestamps,
                 statusOverride == null ? executionGraph.getState() : statusOverride,
+                executionGraph.getJobType(),
                 executionGraph.getFailureInfo(),
                 executionGraph.getJsonPlan(),
                 executionGraph.getAccumulatorResultsStringified(),
@@ -353,7 +384,9 @@ public class ArchivedExecutionGraph implements AccessExecutionGraph, Serializabl
                 executionGraph.getStateBackendName().orElse(null),
                 executionGraph.getCheckpointStorageName().orElse(null),
                 executionGraph.isChangelogStateBackendEnabled(),
-                executionGraph.getChangelogStorageName().orElse(null));
+                executionGraph.getChangelogStorageName().orElse(null),
+                executionGraph.getStreamGraphJson(),
+                executionGraph.getPendingOperatorCount());
     }
 
     /**
@@ -364,6 +397,7 @@ public class ArchivedExecutionGraph implements AccessExecutionGraph, Serializabl
             JobID jobId,
             String jobName,
             JobStatus jobStatus,
+            @Nullable JobType jobType,
             @Nullable Throwable throwable,
             @Nullable JobCheckpointingSettings checkpointingSettings,
             long initializationTimestamp) {
@@ -371,6 +405,7 @@ public class ArchivedExecutionGraph implements AccessExecutionGraph, Serializabl
                 jobId,
                 jobName,
                 jobStatus,
+                jobType,
                 Collections.emptyMap(),
                 Collections.emptyList(),
                 throwable,
@@ -382,6 +417,7 @@ public class ArchivedExecutionGraph implements AccessExecutionGraph, Serializabl
             JobID jobId,
             String jobName,
             JobStatus jobStatus,
+            JobType jobType,
             @Nullable Throwable throwable,
             @Nullable JobCheckpointingSettings checkpointingSettings,
             long initializationTimestamp,
@@ -400,6 +436,7 @@ public class ArchivedExecutionGraph implements AccessExecutionGraph, Serializabl
                             jobVertex.getName(),
                             parallelismInfo.getParallelism(),
                             parallelismInfo.getMaxParallelism(),
+                            jobVertex.getSlotSharingGroup(),
                             ResourceProfile.fromResourceSpec(
                                     jobVertex.getMinResources(), MemorySize.ZERO),
                             new StringifiedAccumulatorResult[0]);
@@ -410,6 +447,7 @@ public class ArchivedExecutionGraph implements AccessExecutionGraph, Serializabl
                 jobId,
                 jobName,
                 jobStatus,
+                jobType,
                 archivedJobVertices,
                 archivedVerticesInCreationOrder,
                 throwable,
@@ -421,6 +459,7 @@ public class ArchivedExecutionGraph implements AccessExecutionGraph, Serializabl
             JobID jobId,
             String jobName,
             JobStatus jobStatus,
+            JobType jobType,
             Map<JobVertexID, ArchivedExecutionJobVertex> archivedTasks,
             List<ArchivedExecutionJobVertex> archivedVerticesInCreationOrder,
             @Nullable Throwable throwable,
@@ -452,6 +491,7 @@ public class ArchivedExecutionGraph implements AccessExecutionGraph, Serializabl
                 archivedVerticesInCreationOrder,
                 timestamps,
                 jobStatus,
+                jobType,
                 failureInfo,
                 jsonPlan,
                 archivedUserAccumulators,
@@ -467,6 +507,8 @@ public class ArchivedExecutionGraph implements AccessExecutionGraph, Serializabl
                 checkpointingSettings == null
                         ? TernaryBoolean.UNDEFINED
                         : checkpointingSettings.isChangelogStateBackendEnabled(),
-                checkpointingSettings == null ? null : "Unknown");
+                checkpointingSettings == null ? null : "Unknown",
+                null,
+                0);
     }
 }
