@@ -28,6 +28,7 @@ import org.apache.flink.runtime.checkpoint.CheckpointType;
 import org.apache.flink.runtime.checkpoint.SavepointType;
 import org.apache.flink.runtime.checkpoint.SnapshotType;
 import org.apache.flink.runtime.event.AbstractEvent;
+import org.apache.flink.runtime.event.WatermarkEvent;
 import org.apache.flink.runtime.io.network.api.CancelCheckpointMarker;
 import org.apache.flink.runtime.io.network.api.CheckpointBarrier;
 import org.apache.flink.runtime.io.network.api.EndOfData;
@@ -81,6 +82,8 @@ public class EventSerializer {
 
     private static final int RECOVERY_METADATA = 10;
 
+    private static final int GENERALIZED_WATERMARK_EVENT = 11;
+
     private static final byte CHECKPOINT_TYPE_CHECKPOINT = 0;
 
     private static final byte CHECKPOINT_TYPE_SAVEPOINT = 1;
@@ -154,6 +157,15 @@ public class EventSerializer {
             buf.putInt(0, RECOVERY_METADATA);
             buf.putInt(4, recoveryMetadata.getFinalBufferSubpartitionId());
             return buf;
+        } else if (eventClass == WatermarkEvent.class) {
+            try {
+                final DataOutputSerializer serializer = new DataOutputSerializer(128);
+                serializer.writeInt(GENERALIZED_WATERMARK_EVENT);
+                event.write(serializer);
+                return serializer.wrapAsByteBuffer();
+            } catch (IOException e) {
+                throw new IOException("Error while serializing event.", e);
+            }
         } else {
             try {
                 final DataOutputSerializer serializer = new DataOutputSerializer(128);
@@ -203,6 +215,11 @@ public class EventSerializer {
             } else if (type == RECOVERY_METADATA) {
                 int subpartitionId = buffer.getInt();
                 return new RecoveryMetadata(subpartitionId);
+            } else if (type == GENERALIZED_WATERMARK_EVENT) {
+                final DataInputDeserializer deserializer = new DataInputDeserializer(buffer);
+                WatermarkEvent watermarkEvent = new WatermarkEvent();
+                watermarkEvent.read(deserializer);
+                return watermarkEvent;
             } else if (type == OTHER_EVENT) {
                 try {
                     final DataInputDeserializer deserializer = new DataInputDeserializer(buffer);
