@@ -22,6 +22,7 @@ import org.apache.flink.api.common.ExecutionConfig;
 import org.apache.flink.api.common.InvalidProgramException;
 import org.apache.flink.api.common.JobID;
 import org.apache.flink.api.common.cache.DistributedCache;
+import org.apache.flink.api.common.operators.ResourceSpec;
 import org.apache.flink.configuration.Configuration;
 import org.apache.flink.core.execution.JobStatusHook;
 import org.apache.flink.core.fs.Path;
@@ -29,6 +30,7 @@ import org.apache.flink.runtime.blob.PermanentBlobKey;
 import org.apache.flink.runtime.jobgraph.tasks.JobCheckpointingSettings;
 import org.apache.flink.runtime.jobmanager.scheduler.CoLocationGroup;
 import org.apache.flink.runtime.jobmanager.scheduler.SlotSharingGroup;
+import org.apache.flink.streaming.api.graph.ExecutionPlan;
 import org.apache.flink.util.InstantiationUtil;
 import org.apache.flink.util.IterableUtils;
 import org.apache.flink.util.SerializedValue;
@@ -36,7 +38,6 @@ import org.apache.flink.util.SerializedValue;
 import javax.annotation.Nullable;
 
 import java.io.IOException;
-import java.io.Serializable;
 import java.net.URISyntaxException;
 import java.net.URL;
 import java.util.ArrayList;
@@ -64,14 +65,14 @@ import static org.apache.flink.util.Preconditions.checkNotNull;
  * <p>The JobGraph defines the job-wide configuration settings, while each vertex and intermediate
  * result define the characteristics of the concrete operation and intermediate data.
  */
-public class JobGraph implements Serializable {
+public class JobGraph implements ExecutionPlan {
 
     private static final long serialVersionUID = 1L;
 
-    private static final String INITIAL_CLIENT_HEARTBEAT_TIMEOUT = "initialClientHeartbeatTimeout";
-
     // --- job and configuration ---
 
+    private long initialClientHeartbeatTimeout;
+
     /** List of task vertices included in this job graph. */
     private final Map<JobVertexID, JobVertex> taskVertices =
             new LinkedHashMap<JobVertexID, JobVertex>();
@@ -180,6 +181,7 @@ public class JobGraph implements Serializable {
      *
      * @return the ID of the job
      */
+    @Override
     public JobID getJobID() {
         return this.jobID;
     }
@@ -194,10 +196,36 @@ public class JobGraph implements Serializable {
      *
      * @return the name assigned to the job graph
      */
+    @Override
     public String getName() {
         return this.jobName;
     }
 
+    @Override
+    public boolean isPartialResourceConfigured() {
+        boolean hasVerticesWithUnknownResource = false;
+        boolean hasVerticesWithConfiguredResource = false;
+
+        for (JobVertex jobVertex : getVertices()) {
+            if (jobVertex.getMinResources() == ResourceSpec.UNKNOWN) {
+                hasVerticesWithUnknownResource = true;
+            } else {
+                hasVerticesWithConfiguredResource = true;
+            }
+
+            if (hasVerticesWithUnknownResource && hasVerticesWithConfiguredResource) {
+                return true;
+            }
+        }
+
+        return false;
+    }
+
+    @Override
+    public boolean isEmpty() {
+        return getNumberOfVertices() == 0;
+    }
+
     public void setJobConfiguration(Configuration jobConfiguration) {
         this.jobConfiguration = jobConfiguration;
     }
@@ -208,6 +236,7 @@ public class JobGraph implements Serializable {
      *
      * @return The configuration object for this job.
      */
+    @Override
     public Configuration getJobConfiguration() {
         return this.jobConfiguration;
     }
@@ -217,6 +246,7 @@ public class JobGraph implements Serializable {
      *
      * @return ExecutionConfig
      */
+    @Override
     public SerializedValue<ExecutionConfig> getSerializedExecutionConfig() {
         return serializedExecutionConfig;
     }
@@ -225,6 +255,7 @@ public class JobGraph implements Serializable {
         this.jobType = type;
     }
 
+    @Override
     public JobType getJobType() {
         return jobType;
     }
@@ -233,6 +264,7 @@ public class JobGraph implements Serializable {
         this.dynamic = dynamic;
     }
 
+    @Override
     public boolean isDynamic() {
         return dynamic;
     }
@@ -250,6 +282,7 @@ public class JobGraph implements Serializable {
      *
      * @param settings The savepoint restore settings.
      */
+    @Override
     public void setSavepointRestoreSettings(SavepointRestoreSettings settings) {
         this.savepointRestoreSettings = checkNotNull(settings, "Savepoint restore settings");
     }
@@ -259,6 +292,7 @@ public class JobGraph implements Serializable {
      *
      * @return The configured savepoint restore settings.
      */
+    @Override
     public SavepointRestoreSettings getSavepointRestoreSettings() {
         return savepointRestoreSettings;
     }
@@ -276,7 +310,8 @@ public class JobGraph implements Serializable {
         setSerializedExecutionConfig(new SerializedValue<>(executionConfig));
     }
 
-    void setSerializedExecutionConfig(SerializedValue<ExecutionConfig> serializedExecutionConfig) {
+    public void setSerializedExecutionConfig(
+            SerializedValue<ExecutionConfig> serializedExecutionConfig) {
         this.serializedExecutionConfig =
                 checkNotNull(
                         serializedExecutionConfig,
@@ -366,24 +401,11 @@ public class JobGraph implements Serializable {
      *
      * @return The snapshot settings
      */
+    @Override
     public JobCheckpointingSettings getCheckpointingSettings() {
         return snapshotSettings;
     }
 
-    /**
-     * Checks if the checkpointing was enabled for this job graph.
-     *
-     * @return true if checkpointing enabled
-     */
-    public boolean isCheckpointingEnabled() {
-
-        if (snapshotSettings == null) {
-            return false;
-        }
-
-        return snapshotSettings.getCheckpointCoordinatorConfiguration().isCheckpointingEnabled();
-    }
-
     /**
      * Searches for a vertex with a matching ID and returns it.
      *
@@ -404,6 +426,7 @@ public class JobGraph implements Serializable {
         classpaths = paths;
     }
 
+    @Override
     public List<URL> getClasspaths() {
         return classpaths;
     }
@@ -413,6 +436,7 @@ public class JobGraph implements Serializable {
      *
      * @return The maximum parallelism of this job graph
      */
+    @Override
     public int getMaximumParallelism() {
         int maxParallelism = -1;
         for (JobVertex vertex : taskVertices.values()) {
@@ -546,6 +570,7 @@ public class JobGraph implements Serializable {
      *
      * @return The list of assigned user jar paths
      */
+    @Override
     public List<Path> getUserJars() {
         return userJars;
     }
@@ -570,6 +595,7 @@ public class JobGraph implements Serializable {
      *
      * @return The list of assigned user jar paths
      */
+    @Override
     public Map<String, DistributedCache.DistributedCacheEntry> getUserArtifacts() {
         return userArtifacts;
     }
@@ -579,6 +605,7 @@ public class JobGraph implements Serializable {
      *
      * @param key path of the JAR file required to run the job on a task manager
      */
+    @Override
     public void addUserJarBlobKey(PermanentBlobKey key) {
         if (key == null) {
             throw new IllegalArgumentException();
@@ -603,6 +630,7 @@ public class JobGraph implements Serializable {
      *
      * @return set of BLOB keys referring to the JAR files required to run this job
      */
+    @Override
     public List<PermanentBlobKey> getUserJarBlobKeys() {
         return this.userJarBlobKeys;
     }
@@ -612,6 +640,7 @@ public class JobGraph implements Serializable {
         return "JobGraph(jobId: " + jobID + ")";
     }
 
+    @Override
     public void setUserArtifactBlobKey(String entryName, PermanentBlobKey blobKey)
             throws IOException {
         byte[] serializedBlobKey;
@@ -638,6 +667,7 @@ public class JobGraph implements Serializable {
                                 originalEntry.isZipped));
     }
 
+    @Override
     public void writeUserArtifactEntriesToConfiguration() {
         for (Map.Entry<String, DistributedCache.DistributedCacheEntry> userArtifact :
                 userArtifacts.entrySet()) {
@@ -656,10 +686,11 @@ public class JobGraph implements Serializable {
     }
 
     public void setInitialClientHeartbeatTimeout(long initialClientHeartbeatTimeout) {
-        jobConfiguration.setLong(INITIAL_CLIENT_HEARTBEAT_TIMEOUT, initialClientHeartbeatTimeout);
+        this.initialClientHeartbeatTimeout = initialClientHeartbeatTimeout;
     }
 
+    @Override
     public long getInitialClientHeartbeatTimeout() {
-        return jobConfiguration.getLong(INITIAL_CLIENT_HEARTBEAT_TIMEOUT, Long.MIN_VALUE);
+        return initialClientHeartbeatTimeout;
     }
 }
