@@ -19,16 +19,12 @@
 package org.apache.flink.runtime.jobmanager;
 
 import org.apache.flink.annotation.VisibleForTesting;
-import org.apache.flink.configuration.ConfigOption;
 import org.apache.flink.configuration.Configuration;
 import org.apache.flink.configuration.ConfigurationUtils;
-import org.apache.flink.configuration.IllegalConfigurationException;
 import org.apache.flink.configuration.JobManagerOptions;
 import org.apache.flink.configuration.MemorySize;
 import org.apache.flink.runtime.util.config.memory.CommonProcessMemorySpec;
 import org.apache.flink.runtime.util.config.memory.JvmMetaspaceAndOverheadOptions;
-import org.apache.flink.runtime.util.config.memory.LegacyMemoryOptions;
-import org.apache.flink.runtime.util.config.memory.MemoryBackwardsCompatibilityUtils;
 import org.apache.flink.runtime.util.config.memory.ProcessMemoryOptions;
 import org.apache.flink.runtime.util.config.memory.ProcessMemoryUtils;
 import org.apache.flink.runtime.util.config.memory.jobmanager.JobManagerFlinkMemory;
@@ -52,34 +48,12 @@ public class JobManagerProcessUtils {
                             JobManagerOptions.JVM_OVERHEAD_MAX,
                             JobManagerOptions.JVM_OVERHEAD_FRACTION));
 
-    @SuppressWarnings("deprecation")
-    static final LegacyMemoryOptions JM_LEGACY_HEAP_OPTIONS =
-            new LegacyMemoryOptions(
-                    "FLINK_JM_HEAP",
-                    JobManagerOptions.JOB_MANAGER_HEAP_MEMORY,
-                    JobManagerOptions.JOB_MANAGER_HEAP_MEMORY_MB);
-
     private static final ProcessMemoryUtils<JobManagerFlinkMemory> PROCESS_MEMORY_UTILS =
             new ProcessMemoryUtils<>(JM_PROCESS_MEMORY_OPTIONS, new JobManagerFlinkMemoryUtils());
 
-    private static final MemoryBackwardsCompatibilityUtils LEGACY_MEMORY_UTILS =
-            new MemoryBackwardsCompatibilityUtils(JM_LEGACY_HEAP_OPTIONS);
-
     private JobManagerProcessUtils() {}
 
-    public static JobManagerProcessSpec processSpecFromConfigWithNewOptionToInterpretLegacyHeap(
-            Configuration config, ConfigOption<MemorySize> newOptionToInterpretLegacyHeap) {
-        try {
-            return processSpecFromConfig(
-                    getConfigurationWithLegacyHeapSizeMappedToNewConfigOption(
-                            config, newOptionToInterpretLegacyHeap));
-        } catch (IllegalConfigurationException e) {
-            throw new IllegalConfigurationException(
-                    "JobManager memory configuration failed: " + e.getMessage(), e);
-        }
-    }
-
-    static JobManagerProcessSpec processSpecFromConfig(Configuration config) {
+    public static JobManagerProcessSpec processSpecFromConfig(Configuration config) {
         return createMemoryProcessSpec(PROCESS_MEMORY_UTILS.memoryProcessSpecFromConfig(config));
     }
 
@@ -89,12 +63,6 @@ public class JobManagerProcessUtils {
                 processMemory.getFlinkMemory(), processMemory.getJvmMetaspaceAndOverhead());
     }
 
-    static Configuration getConfigurationWithLegacyHeapSizeMappedToNewConfigOption(
-            Configuration configuration, ConfigOption<MemorySize> configOption) {
-        return LEGACY_MEMORY_UTILS.getConfWithLegacyHeapSizeMappedToNewConfigOption(
-                configuration, configOption);
-    }
-
     @VisibleForTesting
     public static JobManagerProcessSpec createDefaultJobManagerProcessSpec(
             int totalProcessMemoryMb) {
