@@ -33,7 +33,7 @@ import org.apache.flink.runtime.metrics.scope.ScopeFormat;
 import org.apache.flink.traces.reporter.TraceReporterFactory;
 import org.apache.flink.util.CollectionUtil;
 
-import org.apache.flink.shaded.guava31.com.google.common.collect.Iterators;
+import org.apache.flink.shaded.guava32.com.google.common.collect.Iterators;
 
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
@@ -79,8 +79,6 @@ public final class ReporterSetup {
                             // classes
                             "([\\S&&[^.]]*)\\."
                             + '('
-                            + Pattern.quote(MetricOptions.REPORTER_CLASS.key())
-                            + '|'
                             + Pattern.quote(MetricOptions.REPORTER_FACTORY_CLASS.key())
                             + ')');
 
@@ -345,7 +343,9 @@ public final class ReporterSetup {
 
                 // massage user variables keys into scope format for parity to variable exclusion
                 Map<String, String> additionalVariables =
-                        reporterConfig.get(MetricOptions.REPORTER_ADDITIONAL_VARIABLES).entrySet()
+                        reporterConfig
+                                .get(MetricOptions.REPORTER_ADDITIONAL_VARIABLES)
+                                .entrySet()
                                 .stream()
                                 .collect(
                                         Collectors.toMap(
@@ -381,7 +381,6 @@ public final class ReporterSetup {
             final Configuration reporterConfig,
             final Map<String, MetricReporterFactory> reporterFactories) {
 
-        final String reporterClassName = reporterConfig.get(MetricOptions.REPORTER_CLASS);
         final String factoryClassName = reporterConfig.get(MetricOptions.REPORTER_FACTORY_CLASS);
 
         if (factoryClassName != null) {
@@ -389,16 +388,6 @@ public final class ReporterSetup {
                     factoryClassName, reporterName, reporterConfig, reporterFactories);
         }
 
-        if (reporterClassName != null) {
-            LOG.warn(
-                    "The reporter configuration of '{}' configures the reporter class, which is no a no longer supported approach to configure reporters."
-                            + " Please configure a factory class instead: '{}{}.{}: <factoryClass>'.",
-                    reporterName,
-                    ConfigConstants.METRICS_REPORTER_PREFIX,
-                    reporterName,
-                    MetricOptions.REPORTER_FACTORY_CLASS.key());
-        }
-
         LOG.warn(
                 "No reporter factory set for reporter {}. Metrics might not be exposed/reported.",
                 reporterName);
