@@ -21,7 +21,6 @@ package org.apache.flink.runtime.resourcemanager;
 import org.apache.flink.annotation.VisibleForTesting;
 import org.apache.flink.api.common.JobID;
 import org.apache.flink.api.common.JobStatus;
-import org.apache.flink.api.common.time.Time;
 import org.apache.flink.api.java.tuple.Tuple2;
 import org.apache.flink.runtime.blob.TransientBlobKey;
 import org.apache.flink.runtime.blocklist.BlockedNode;
@@ -116,8 +115,8 @@ import static org.apache.flink.util.Preconditions.checkState;
  * <p>It offers the following methods as part of its rpc interface to interact with him remotely:
  *
  * <ul>
- *   <li>{@link #registerJobMaster(JobMasterId, ResourceID, String, JobID, Time)} registers a {@link
- *       JobMaster} at the resource manager
+ *   <li>{@link #registerJobMaster(JobMasterId, ResourceID, String, JobID, Duration)} registers a
+ *       {@link JobMaster} at the resource manager
  * </ul>
  */
 public abstract class ResourceManager<WorkerType extends ResourceIDRetrievable>
@@ -162,6 +161,7 @@ public abstract class ResourceManager<WorkerType extends ResourceIDRetrievable>
     protected final Executor ioExecutor;
 
     private final CompletableFuture<Void> startedFuture;
+
     /** The heartbeat manager with task managers. */
     private HeartbeatManager<TaskExecutorHeartbeatPayload, Void> taskManagerHeartbeatManager;
 
@@ -189,7 +189,7 @@ public abstract class ResourceManager<WorkerType extends ResourceIDRetrievable>
             ClusterInformation clusterInformation,
             FatalErrorHandler fatalErrorHandler,
             ResourceManagerMetricGroup resourceManagerMetricGroup,
-            Time rpcTimeout,
+            Duration rpcTimeout,
             Executor ioExecutor) {
 
         super(
@@ -366,7 +366,7 @@ public abstract class ResourceManager<WorkerType extends ResourceIDRetrievable>
             final ResourceID jobManagerResourceId,
             final String jobManagerAddress,
             final JobID jobId,
-            final Time timeout) {
+            final Duration timeout) {
 
         checkNotNull(jobMasterId);
         checkNotNull(jobManagerResourceId);
@@ -466,7 +466,7 @@ public abstract class ResourceManager<WorkerType extends ResourceIDRetrievable>
 
     @Override
     public CompletableFuture<RegistrationResponse> registerTaskExecutor(
-            final TaskExecutorRegistration taskExecutorRegistration, final Time timeout) {
+            final TaskExecutorRegistration taskExecutorRegistration, final Duration timeout) {
 
         CompletableFuture<TaskExecutorGateway> taskExecutorGatewayFuture =
                 getRpcService()
@@ -503,7 +503,7 @@ public abstract class ResourceManager<WorkerType extends ResourceIDRetrievable>
             ResourceID taskManagerResourceId,
             InstanceID taskManagerRegistrationId,
             SlotReport slotReport,
-            Time timeout) {
+            Duration timeout) {
         final WorkerRegistration<WorkerType> workerTypeWorkerRegistration =
                 taskExecutors.get(taskManagerResourceId);
 
@@ -572,7 +572,7 @@ public abstract class ResourceManager<WorkerType extends ResourceIDRetrievable>
 
     @Override
     public CompletableFuture<Acknowledge> declareRequiredResources(
-            JobMasterId jobMasterId, ResourceRequirements resourceRequirements, Time timeout) {
+            JobMasterId jobMasterId, ResourceRequirements resourceRequirements, Duration timeout) {
         final JobID jobId = resourceRequirements.getJobId();
         try (MdcCloseable ignored = MdcUtils.withContext(MdcUtils.asContextData(jobId))) {
             final JobManagerRegistration jobManagerRegistration =
@@ -660,7 +660,7 @@ public abstract class ResourceManager<WorkerType extends ResourceIDRetrievable>
     }
 
     @Override
-    public CompletableFuture<Collection<TaskManagerInfo>> requestTaskManagerInfo(Time timeout) {
+    public CompletableFuture<Collection<TaskManagerInfo>> requestTaskManagerInfo(Duration timeout) {
 
         final ArrayList<TaskManagerInfo> taskManagerInfos = new ArrayList<>(taskExecutors.size());
 
@@ -690,7 +690,7 @@ public abstract class ResourceManager<WorkerType extends ResourceIDRetrievable>
 
     @Override
     public CompletableFuture<TaskManagerInfoWithSlots> requestTaskManagerDetailsInfo(
-            ResourceID resourceId, Time timeout) {
+            ResourceID resourceId, Duration timeout) {
 
         final WorkerRegistration<WorkerType> taskExecutor = taskExecutors.get(resourceId);
 
@@ -721,7 +721,7 @@ public abstract class ResourceManager<WorkerType extends ResourceIDRetrievable>
     }
 
     @Override
-    public CompletableFuture<ResourceOverview> requestResourceOverview(Time timeout) {
+    public CompletableFuture<ResourceOverview> requestResourceOverview(Duration timeout) {
         final int numberSlots = slotManager.getNumberRegisteredSlots();
         final ResourceProfile totalResource = slotManager.getRegisteredResource();
 
@@ -757,7 +757,7 @@ public abstract class ResourceManager<WorkerType extends ResourceIDRetrievable>
 
     @Override
     public CompletableFuture<Collection<Tuple2<ResourceID, String>>>
-            requestTaskManagerMetricQueryServiceAddresses(Time timeout) {
+            requestTaskManagerMetricQueryServiceAddresses(Duration timeout) {
         final ArrayList<CompletableFuture<Optional<Tuple2<ResourceID, String>>>>
                 metricQueryServiceAddressFutures = new ArrayList<>(taskExecutors.size());
 
@@ -796,7 +796,7 @@ public abstract class ResourceManager<WorkerType extends ResourceIDRetrievable>
 
     @Override
     public CompletableFuture<TransientBlobKey> requestTaskManagerFileUploadByType(
-            ResourceID taskManagerId, FileType fileType, Time timeout) {
+            ResourceID taskManagerId, FileType fileType, Duration timeout) {
         log.debug(
                 "Request {} file upload from TaskExecutor {}.",
                 fileType,
@@ -844,7 +844,7 @@ public abstract class ResourceManager<WorkerType extends ResourceIDRetrievable>
 
     @Override
     public CompletableFuture<Collection<LogInfo>> requestTaskManagerLogList(
-            ResourceID taskManagerId, Time timeout) {
+            ResourceID taskManagerId, Duration timeout) {
         final WorkerRegistration<WorkerType> taskExecutor = taskExecutors.get(taskManagerId);
         if (taskExecutor == null) {
             log.debug(
@@ -885,7 +885,7 @@ public abstract class ResourceManager<WorkerType extends ResourceIDRetrievable>
 
     @Override
     public CompletableFuture<ThreadDumpInfo> requestThreadDump(
-            ResourceID taskManagerId, Time timeout) {
+            ResourceID taskManagerId, Duration timeout) {
         final WorkerRegistration<WorkerType> taskExecutor = taskExecutors.get(taskManagerId);
 
         if (taskExecutor == null) {
@@ -936,7 +936,7 @@ public abstract class ResourceManager<WorkerType extends ResourceIDRetrievable>
     @Override
     @Local // Bug; see FLINK-27954
     public CompletableFuture<TaskExecutorThreadInfoGateway> requestTaskExecutorThreadInfoGateway(
-            ResourceID taskManagerId, Time timeout) {
+            ResourceID taskManagerId, Duration timeout) {
 
         final WorkerRegistration<WorkerType> taskExecutor = taskExecutors.get(taskManagerId);
 
