@@ -37,12 +37,15 @@ import org.apache.flink.util.Preconditions;
 
 import org.apache.flink.shaded.jackson2.com.fasterxml.jackson.annotation.JsonCreator;
 import org.apache.flink.shaded.jackson2.com.fasterxml.jackson.annotation.JsonIgnore;
+import org.apache.flink.shaded.jackson2.com.fasterxml.jackson.annotation.JsonInclude;
 import org.apache.flink.shaded.jackson2.com.fasterxml.jackson.annotation.JsonProperty;
 import org.apache.flink.shaded.jackson2.com.fasterxml.jackson.databind.annotation.JsonDeserialize;
 import org.apache.flink.shaded.jackson2.com.fasterxml.jackson.databind.annotation.JsonSerialize;
 
 import io.swagger.v3.oas.annotations.media.Schema;
 
+import javax.annotation.Nullable;
+
 import java.util.Collection;
 import java.util.Map;
 import java.util.Objects;
@@ -79,6 +82,14 @@ public class JobDetailsInfo implements ResponseBody {
 
     public static final String FIELD_NAME_JSON_PLAN = "plan";
 
+    /**
+     * The {@link JobPlanInfo.RawJson} of the submitted stream graph, or null if the job is
+     * submitted with a JobGraph or if it's a streaming job.
+     */
+    public static final String FIELD_NAME_STREAM_GRAPH_JSON = "stream-graph";
+
+    public static final String FIELD_NAME_PENDING_OPERATORS = "pending-operators";
+
     @JsonProperty(FIELD_NAME_JOB_ID)
     @JsonSerialize(using = JobIDSerializer.class)
     private final JobID jobId;
@@ -122,6 +133,14 @@ public class JobDetailsInfo implements ResponseBody {
     @JsonProperty(FIELD_NAME_JSON_PLAN)
     private final JobPlanInfo.RawJson jsonPlan;
 
+    @JsonProperty(FIELD_NAME_STREAM_GRAPH_JSON)
+    @JsonInclude(JsonInclude.Include.NON_NULL)
+    @Nullable
+    private final JobPlanInfo.RawJson streamGraphJson;
+
+    @JsonProperty(FIELD_NAME_PENDING_OPERATORS)
+    private final int pendingOperators;
+
     @JsonCreator
     public JobDetailsInfo(
             @JsonDeserialize(using = JobIDDeserializer.class) @JsonProperty(FIELD_NAME_JOB_ID)
@@ -140,7 +159,10 @@ public class JobDetailsInfo implements ResponseBody {
                     Collection<JobVertexDetailsInfo> jobVertexInfos,
             @JsonProperty(FIELD_NAME_JOB_VERTICES_PER_STATE)
                     Map<ExecutionState, Integer> jobVerticesPerState,
-            @JsonProperty(FIELD_NAME_JSON_PLAN) JobPlanInfo.RawJson jsonPlan) {
+            @JsonProperty(FIELD_NAME_JSON_PLAN) JobPlanInfo.RawJson jsonPlan,
+            @JsonProperty(FIELD_NAME_STREAM_GRAPH_JSON) @Nullable
+                    JobPlanInfo.RawJson streamGraphJson,
+            @JsonProperty(FIELD_NAME_PENDING_OPERATORS) int pendingOperators) {
         this.jobId = Preconditions.checkNotNull(jobId);
         this.name = Preconditions.checkNotNull(name);
         this.isStoppable = isStoppable;
@@ -155,6 +177,8 @@ public class JobDetailsInfo implements ResponseBody {
         this.jobVertexInfos = Preconditions.checkNotNull(jobVertexInfos);
         this.jobVerticesPerState = Preconditions.checkNotNull(jobVerticesPerState);
         this.jsonPlan = Preconditions.checkNotNull(jsonPlan);
+        this.streamGraphJson = streamGraphJson;
+        this.pendingOperators = pendingOperators;
     }
 
     @Override
@@ -179,7 +203,9 @@ public class JobDetailsInfo implements ResponseBody {
                 && Objects.equals(timestamps, that.timestamps)
                 && Objects.equals(jobVertexInfos, that.jobVertexInfos)
                 && Objects.equals(jobVerticesPerState, that.jobVerticesPerState)
-                && Objects.equals(jsonPlan, that.jsonPlan);
+                && Objects.equals(jsonPlan, that.jsonPlan)
+                && Objects.equals(streamGraphJson, that.streamGraphJson)
+                && Objects.equals(pendingOperators, that.pendingOperators);
     }
 
     @Override
@@ -198,7 +224,9 @@ public class JobDetailsInfo implements ResponseBody {
                 timestamps,
                 jobVertexInfos,
                 jobVerticesPerState,
-                jsonPlan);
+                jsonPlan,
+                streamGraphJson,
+                pendingOperators);
     }
 
     @JsonIgnore
@@ -271,6 +299,20 @@ public class JobDetailsInfo implements ResponseBody {
         return jsonPlan.toString();
     }
 
+    @JsonIgnore
+    @Nullable
+    public String getStreamGraphJson() {
+        if (streamGraphJson != null) {
+            return streamGraphJson.toString();
+        }
+        return null;
+    }
+
+    @JsonIgnore
+    public int getPendingOperators() {
+        return pendingOperators;
+    }
+
     // ---------------------------------------------------
     // Static inner classes
     // ---------------------------------------------------
