@@ -18,6 +18,7 @@
 
 package org.apache.flink.runtime.scheduler.adaptivebatch;
 
+import org.apache.flink.api.common.JobID;
 import org.apache.flink.api.common.JobStatus;
 import org.apache.flink.api.java.tuple.Tuple2;
 import org.apache.flink.configuration.BatchExecutionOptions;
@@ -54,7 +55,7 @@ import org.apache.flink.runtime.shuffle.ShuffleMasterSnapshot;
 import org.apache.flink.util.clock.Clock;
 import org.apache.flink.util.clock.SystemClock;
 
-import org.apache.flink.shaded.guava31.com.google.common.collect.Sets;
+import org.apache.flink.shaded.guava32.com.google.common.collect.Sets;
 
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
@@ -85,6 +86,7 @@ public class DefaultBatchJobRecoveryHandler
     private final Logger log = LoggerFactory.getLogger(getClass());
 
     private final JobEventManager jobEventManager;
+    private final JobID jobId;
 
     private BatchJobRecoveryContext context;
 
@@ -116,8 +118,9 @@ public class DefaultBatchJobRecoveryHandler
     private final Duration previousWorkerRecoveryTimeout;
 
     public DefaultBatchJobRecoveryHandler(
-            JobEventManager jobEventManager, Configuration jobMasterConfiguration) {
+            JobEventManager jobEventManager, Configuration jobMasterConfiguration, JobID jobId) {
         this.jobEventManager = jobEventManager;
+        this.jobId = checkNotNull(jobId);
 
         this.previousWorkerRecoveryTimeout =
                 jobMasterConfiguration.get(
@@ -201,7 +204,7 @@ public class DefaultBatchJobRecoveryHandler
 
     private void restoreShuffleMaster(List<ShuffleMasterSnapshot> snapshots) {
         checkState(context.getShuffleMaster().supportsBatchSnapshot());
-        context.getShuffleMaster().restoreState(snapshots);
+        context.getShuffleMaster().restoreState(snapshots, jobId);
     }
 
     private void startRecoveringInternal() {
@@ -435,7 +438,9 @@ public class DefaultBatchJobRecoveryHandler
                 new CompletableFuture<>();
         context.getShuffleMaster()
                 .snapshotState(
-                        shuffleMasterSnapshotFuture, new DefaultShuffleMasterSnapshotContext());
+                        shuffleMasterSnapshotFuture,
+                        new DefaultShuffleMasterSnapshotContext(),
+                        jobId);
         return shuffleMasterSnapshotFuture;
     }
 
