@@ -19,11 +19,14 @@
 package org.apache.flink.runtime.shuffle;
 
 import org.apache.flink.api.common.JobID;
+import org.apache.flink.configuration.BatchExecutionOptions;
 import org.apache.flink.configuration.Configuration;
 import org.apache.flink.configuration.MemorySize;
 import org.apache.flink.configuration.NettyShuffleEnvironmentOptions;
 import org.apache.flink.runtime.io.network.partition.ResultPartitionID;
+import org.apache.flink.runtime.io.network.partition.hybrid.tiered.shuffle.AllTieredShuffleMasterSnapshots;
 import org.apache.flink.runtime.io.network.partition.hybrid.tiered.shuffle.TieredInternalShuffleMaster;
+import org.apache.flink.runtime.io.network.partition.hybrid.tiered.shuffle.TieredInternalShuffleMasterSnapshot;
 import org.apache.flink.runtime.io.network.partition.hybrid.tiered.tier.TierShuffleDescriptor;
 import org.apache.flink.runtime.shuffle.NettyShuffleDescriptor.LocalExecutionPartitionConnectionInfo;
 import org.apache.flink.runtime.shuffle.NettyShuffleDescriptor.NetworkPartitionConnectionInfo;
@@ -40,13 +43,14 @@ import java.util.Map;
 import java.util.Optional;
 import java.util.Set;
 import java.util.concurrent.CompletableFuture;
+import java.util.stream.Collectors;
 
 import static org.apache.flink.api.common.BatchShuffleMode.ALL_EXCHANGES_HYBRID_FULL;
 import static org.apache.flink.api.common.BatchShuffleMode.ALL_EXCHANGES_HYBRID_SELECTIVE;
 import static org.apache.flink.configuration.ExecutionOptions.BATCH_SHUFFLE_MODE;
-import static org.apache.flink.configuration.NettyShuffleEnvironmentOptions.NETWORK_HYBRID_SHUFFLE_ENABLE_NEW_MODE;
 import static org.apache.flink.util.Preconditions.checkArgument;
 import static org.apache.flink.util.Preconditions.checkNotNull;
+import static org.apache.flink.util.Preconditions.checkState;
 
 /** Default {@link ShuffleMaster} for netty and local file based shuffle implementation. */
 public class NettyShuffleMaster implements ShuffleMaster<NettyShuffleDescriptor> {
@@ -63,43 +67,45 @@ public class NettyShuffleMaster implements ShuffleMaster<NettyShuffleDescriptor>
 
     private final int networkBufferSize;
 
+    private final boolean enableJobMasterFailover;
+
     @Nullable private final TieredInternalShuffleMaster tieredInternalShuffleMaster;
 
     private final Map<JobID, JobShuffleContext> jobShuffleContexts = new HashMap<>();
 
+    private final Map<JobID, Map<ResultPartitionID, ShuffleDescriptor>> jobShuffleDescriptors =
+            new HashMap<>();
+
     public NettyShuffleMaster(ShuffleMasterContext shuffleMasterContext) {
         Configuration conf = shuffleMasterContext.getConfiguration();
         checkNotNull(conf);
-        buffersPerInputChannel =
-                conf.get(NettyShuffleEnvironmentOptions.NETWORK_BUFFERS_PER_CHANNEL);
-        floatingBuffersPerGate =
-                conf.get(NettyShuffleEnvironmentOptions.NETWORK_EXTRA_BUFFERS_PER_GATE);
+        buffersPerInputChannel = 2;
+        floatingBuffersPerGate = 8;
         maxRequiredBuffersPerGate =
                 conf.getOptional(
                         NettyShuffleEnvironmentOptions.NETWORK_READ_MAX_REQUIRED_BUFFERS_PER_GATE);
-        sortShuffleMinParallelism =
-                conf.get(NettyShuffleEnvironmentOptions.NETWORK_SORT_SHUFFLE_MIN_PARALLELISM);
+        sortShuffleMinParallelism = 1;
         sortShuffleMinBuffers =
                 conf.get(NettyShuffleEnvironmentOptions.NETWORK_SORT_SHUFFLE_MIN_BUFFERS);
         networkBufferSize = ConfigurationParserUtils.getPageSize(conf);
 
-        if (isHybridShuffleNewModeEnabled(conf)) {
-            tieredInternalShuffleMaster = new TieredInternalShuffleMaster(shuffleMasterContext);
+        if (isHybridShuffleEnabled(conf)) {
+            tieredInternalShuffleMaster =
+                    new TieredInternalShuffleMaster(
+                            shuffleMasterContext, this::getShuffleDescriptor);
         } else {
             tieredInternalShuffleMaster = null;
         }
 
+        enableJobMasterFailover =
+                conf.get(BatchExecutionOptions.JOB_RECOVERY_ENABLED) && supportsBatchSnapshot();
+
         checkArgument(
                 !maxRequiredBuffersPerGate.isPresent() || maxRequiredBuffersPerGate.get() >= 1,
                 String.format(
                         "At least one buffer is required for each gate, please increase the value of %s.",
                         NettyShuffleEnvironmentOptions.NETWORK_READ_MAX_REQUIRED_BUFFERS_PER_GATE
                                 .key()));
-        checkArgument(
-                floatingBuffersPerGate >= 1,
-                String.format(
-                        "The configured floating buffer should be at least 1, please increase the value of %s.",
-                        NettyShuffleEnvironmentOptions.NETWORK_EXTRA_BUFFERS_PER_GATE.key()));
     }
 
     @Override
@@ -117,7 +123,9 @@ public class NettyShuffleMaster implements ShuffleMaster<NettyShuffleDescriptor>
         if (tieredInternalShuffleMaster != null) {
             tierShuffleDescriptors =
                     tieredInternalShuffleMaster.addPartitionAndGetShuffleDescriptor(
-                            jobID, resultPartitionID);
+                            jobID,
+                            partitionDescriptor.getNumberOfSubpartitions(),
+                            resultPartitionID);
         }
 
         NettyShuffleDescriptor shuffleDeploymentDescriptor =
@@ -127,6 +135,11 @@ public class NettyShuffleMaster implements ShuffleMaster<NettyShuffleDescriptor>
                                 producerDescriptor, partitionDescriptor.getConnectionIndex()),
                         resultPartitionID,
                         tierShuffleDescriptors);
+        if (enableJobMasterFailover) {
+            Map<ResultPartitionID, ShuffleDescriptor> shuffleDescriptorMap =
+                    jobShuffleDescriptors.computeIfAbsent(jobID, k -> new HashMap<>());
+            shuffleDescriptorMap.put(resultPartitionID, shuffleDeploymentDescriptor);
+        }
         return CompletableFuture.completedFuture(shuffleDeploymentDescriptor);
     }
 
@@ -137,6 +150,12 @@ public class NettyShuffleMaster implements ShuffleMaster<NettyShuffleDescriptor>
         }
     }
 
+    public Optional<ShuffleDescriptor> getShuffleDescriptor(
+            JobID jobID, ResultPartitionID resultPartitionID) {
+        return Optional.ofNullable(jobShuffleDescriptors.get(jobID))
+                .map(descriptorMap -> descriptorMap.get(resultPartitionID));
+    }
+
     private static PartitionConnectionInfo createConnectionInfo(
             ProducerDescriptor producerDescriptor, int connectionIndex) {
         return producerDescriptor.getDataPort() >= 0
@@ -148,11 +167,9 @@ public class NettyShuffleMaster implements ShuffleMaster<NettyShuffleDescriptor>
     /**
      * JM announces network memory requirement from the calculating result of this method. Please
      * note that the calculating algorithm depends on both I/O details of a vertex and network
-     * configuration, e.g. {@link NettyShuffleEnvironmentOptions#NETWORK_BUFFERS_PER_CHANNEL} and
-     * {@link NettyShuffleEnvironmentOptions#NETWORK_EXTRA_BUFFERS_PER_GATE}, which means we should
-     * always keep the consistency of configurations between JM, RM and TM in fine-grained resource
-     * management, thus to guarantee that the processes of memory announcing and allocating respect
-     * each other.
+     * configuration, which means we should always keep the consistency of configurations between
+     * JM, RM and TM in fine-grained resource management, thus to guarantee that the processes of
+     * memory announcing and allocating respect each other.
      */
     @Override
     public MemorySize computeShuffleMemorySizeForTask(TaskInputsOutputsDescriptor desc) {
@@ -174,15 +191,19 @@ public class NettyShuffleMaster implements ShuffleMaster<NettyShuffleDescriptor>
         return new MemorySize((long) networkBufferSize * numRequiredNetworkBuffers);
     }
 
-    private boolean isHybridShuffleNewModeEnabled(Configuration conf) {
+    private boolean isHybridShuffleEnabled(Configuration conf) {
         return (conf.get(BATCH_SHUFFLE_MODE) == ALL_EXCHANGES_HYBRID_FULL
-                        || conf.get(BATCH_SHUFFLE_MODE) == ALL_EXCHANGES_HYBRID_SELECTIVE)
-                && conf.get(NETWORK_HYBRID_SHUFFLE_ENABLE_NEW_MODE);
+                || conf.get(BATCH_SHUFFLE_MODE) == ALL_EXCHANGES_HYBRID_SELECTIVE);
     }
 
     @Override
     public CompletableFuture<Collection<PartitionWithMetrics>> getPartitionWithMetrics(
             JobID jobId, Duration timeout, Set<ResultPartitionID> expectedPartitions) {
+        if (tieredInternalShuffleMaster != null) {
+            return tieredInternalShuffleMaster.getPartitionWithMetrics(
+                    jobShuffleContexts.get(jobId), timeout, expectedPartitions);
+        }
+
         return checkNotNull(jobShuffleContexts.get(jobId))
                 .getPartitionWithMetrics(timeout, expectedPartitions);
     }
@@ -199,22 +220,96 @@ public class NettyShuffleMaster implements ShuffleMaster<NettyShuffleDescriptor>
     public void unregisterJob(JobID jobId) {
         jobShuffleContexts.remove(jobId);
         if (tieredInternalShuffleMaster != null) {
+            if (enableJobMasterFailover) {
+                jobShuffleDescriptors.remove(jobId);
+            }
             tieredInternalShuffleMaster.unregisterJob(jobId);
         }
     }
 
     @Override
     public boolean supportsBatchSnapshot() {
+        if (tieredInternalShuffleMaster != null) {
+            return tieredInternalShuffleMaster.supportsBatchSnapshot();
+        }
+
         return true;
     }
 
     @Override
     public void snapshotState(
             CompletableFuture<ShuffleMasterSnapshot> snapshotFuture,
-            ShuffleMasterSnapshotContext context) {
+            ShuffleMasterSnapshotContext context,
+            JobID jobId) {
+        if (tieredInternalShuffleMaster != null) {
+            Map<ResultPartitionID, ShuffleDescriptor> shuffleDescriptorMap =
+                    jobShuffleDescriptors.remove(jobId);
+            CompletableFuture<AllTieredShuffleMasterSnapshots> allSnapshotFuture =
+                    new CompletableFuture<>();
+            tieredInternalShuffleMaster.snapshotState(allSnapshotFuture, context, jobId);
+            allSnapshotFuture.thenAccept(
+                    allSnap ->
+                            snapshotFuture.complete(
+                                    new TieredInternalShuffleMasterSnapshot(
+                                            shuffleDescriptorMap, allSnap)));
+            return;
+        }
+
         snapshotFuture.complete(EmptyShuffleMasterSnapshot.getInstance());
     }
 
+    @Override
+    public void snapshotState(CompletableFuture<ShuffleMasterSnapshot> snapshotFuture) {
+        if (tieredInternalShuffleMaster != null) {
+            CompletableFuture<AllTieredShuffleMasterSnapshots> allSnapshotFuture =
+                    new CompletableFuture<>();
+            tieredInternalShuffleMaster.snapshotState(allSnapshotFuture);
+            allSnapshotFuture.thenAccept(
+                    allSnap ->
+                            snapshotFuture.complete(
+                                    new TieredInternalShuffleMasterSnapshot(null, allSnap)));
+            return;
+        }
+
+        snapshotFuture.complete(EmptyShuffleMasterSnapshot.getInstance());
+    }
+
+    @Override
+    public void restoreState(ShuffleMasterSnapshot snapshot) {
+        if (tieredInternalShuffleMaster != null) {
+            checkState(snapshot instanceof TieredInternalShuffleMasterSnapshot);
+            tieredInternalShuffleMaster.restoreState(
+                    (TieredInternalShuffleMasterSnapshot) snapshot);
+        }
+    }
+
+    @Override
+    public void restoreState(List<ShuffleMasterSnapshot> snapshots, JobID jobId) {
+        if (tieredInternalShuffleMaster != null) {
+            List<TieredInternalShuffleMasterSnapshot> snapshotList =
+                    snapshots.stream()
+                            .map(
+                                    snap -> {
+                                        checkState(
+                                                snap
+                                                        instanceof
+                                                        TieredInternalShuffleMasterSnapshot);
+                                        Map<ResultPartitionID, ShuffleDescriptor>
+                                                shuffleDescriptors =
+                                                        ((TieredInternalShuffleMasterSnapshot) snap)
+                                                                .getShuffleDescriptors();
+                                        if (shuffleDescriptors != null) {
+                                            jobShuffleDescriptors
+                                                    .computeIfAbsent(jobId, k -> new HashMap<>())
+                                                    .putAll(shuffleDescriptors);
+                                        }
+                                        return (TieredInternalShuffleMasterSnapshot) snap;
+                                    })
+                            .collect(Collectors.toList());
+            tieredInternalShuffleMaster.restoreState(snapshotList, jobId);
+        }
+    }
+
     @Override
     public void notifyPartitionRecoveryStarted(JobID jobId) {
         checkNotNull(jobShuffleContexts.get(jobId)).notifyPartitionRecoveryStarted();
