@@ -19,7 +19,6 @@
 package org.apache.flink.runtime.taskexecutor;
 
 import org.apache.flink.api.common.JobID;
-import org.apache.flink.api.common.time.Time;
 import org.apache.flink.runtime.blob.BlobServer;
 import org.apache.flink.runtime.blob.TransientBlobKey;
 import org.apache.flink.runtime.checkpoint.CheckpointOptions;
@@ -77,7 +76,7 @@ public interface TaskExecutorGateway
             ResourceProfile resourceProfile,
             String targetAddress,
             ResourceManagerId resourceManagerId,
-            @RpcTimeout Time timeout);
+            @RpcTimeout Duration timeout);
 
     /**
      * Submit a {@link Task} to the {@link TaskExecutor}.
@@ -88,7 +87,7 @@ public interface TaskExecutorGateway
      * @return Future acknowledge of the successful operation
      */
     CompletableFuture<Acknowledge> submitTask(
-            TaskDeploymentDescriptor tdd, JobMasterId jobMasterId, @RpcTimeout Time timeout);
+            TaskDeploymentDescriptor tdd, JobMasterId jobMasterId, @RpcTimeout Duration timeout);
 
     /**
      * Update the task where the given partitions can be found.
@@ -101,7 +100,7 @@ public interface TaskExecutorGateway
     CompletableFuture<Acknowledge> updatePartitions(
             ExecutionAttemptID executionAttemptID,
             Iterable<PartitionInfo> partitionInfos,
-            @RpcTimeout Time timeout);
+            @RpcTimeout Duration timeout);
 
     /**
      * Batch release intermediate result partitions.
@@ -129,7 +128,7 @@ public interface TaskExecutorGateway
      * @return Future acknowledge that the request was received
      */
     CompletableFuture<Acknowledge> releaseClusterPartitions(
-            Collection<IntermediateDataSetID> dataSetsToRelease, @RpcTimeout Time timeout);
+            Collection<IntermediateDataSetID> dataSetsToRelease, @RpcTimeout Duration timeout);
 
     /**
      * Trigger the checkpoint for the given task. The checkpoint is identified by the checkpoint ID
@@ -187,7 +186,7 @@ public interface TaskExecutorGateway
      * @return Future acknowledge if the task is successfully canceled
      */
     CompletableFuture<Acknowledge> cancelTask(
-            ExecutionAttemptID executionAttemptID, @RpcTimeout Time timeout);
+            ExecutionAttemptID executionAttemptID, @RpcTimeout Duration timeout);
 
     /**
      * Heartbeat request from the job manager.
@@ -230,7 +229,9 @@ public interface TaskExecutorGateway
      * @return Future acknowledge which is returned once the slot has been freed
      */
     CompletableFuture<Acknowledge> freeSlot(
-            final AllocationID allocationId, final Throwable cause, @RpcTimeout final Time timeout);
+            final AllocationID allocationId,
+            final Throwable cause,
+            @RpcTimeout final Duration timeout);
 
     /**
      * Frees all currently inactive slot allocated for the given job.
@@ -238,7 +239,7 @@ public interface TaskExecutorGateway
      * @param jobId job for which all inactive slots should be released
      * @param timeout for the operation
      */
-    void freeInactiveSlots(JobID jobId, @RpcTimeout Time timeout);
+    void freeInactiveSlots(JobID jobId, @RpcTimeout Duration timeout);
 
     /**
      * Requests the file upload of the specified type to the cluster's {@link BlobServer}.
@@ -248,7 +249,7 @@ public interface TaskExecutorGateway
      * @return Future which is completed with the {@link TransientBlobKey} of the uploaded file.
      */
     CompletableFuture<TransientBlobKey> requestFileUploadByType(
-            FileType fileType, @RpcTimeout Time timeout);
+            FileType fileType, @RpcTimeout Duration timeout);
 
     /**
      * Requests the file upload of the specified name to the cluster's {@link BlobServer}.
@@ -278,7 +279,7 @@ public interface TaskExecutorGateway
      * @return Future gateway of Metric Query Service on the TaskManager.
      */
     CompletableFuture<SerializableOptional<String>> requestMetricQueryServiceAddress(
-            @RpcTimeout Time timeout);
+            @RpcTimeout Duration timeout);
 
     /**
      * Checks whether the task executor can be released. It cannot be released if there're
@@ -293,7 +294,7 @@ public interface TaskExecutorGateway
      *
      * @return A Tuple2 Array with all log file names with its length.
      */
-    CompletableFuture<Collection<LogInfo>> requestLogList(@RpcTimeout Time timeout);
+    CompletableFuture<Collection<LogInfo>> requestLogList(@RpcTimeout Duration timeout);
 
     @Override
     CompletableFuture<Acknowledge> sendOperatorEventToTask(
@@ -305,7 +306,7 @@ public interface TaskExecutorGateway
      * @param timeout timeout for the asynchronous operation
      * @return the {@link ThreadDumpInfo} for this TaskManager.
      */
-    CompletableFuture<ThreadDumpInfo> requestThreadDump(@RpcTimeout Time timeout);
+    CompletableFuture<ThreadDumpInfo> requestThreadDump(@RpcTimeout Duration timeout);
 
     /**
      * Sends new delegation tokens to this TaskManager.
