@@ -20,20 +20,27 @@ package org.apache.flink.runtime.asyncprocessing;
 
 import org.apache.flink.api.common.operators.MailboxExecutor;
 import org.apache.flink.api.common.state.v2.State;
+import org.apache.flink.api.common.state.v2.ValueStateDescriptor;
 import org.apache.flink.api.common.typeinfo.BasicTypeInfo;
 import org.apache.flink.api.common.typeutils.base.IntSerializer;
+import org.apache.flink.api.java.tuple.Tuple2;
 import org.apache.flink.core.fs.CloseableRegistry;
+import org.apache.flink.core.state.InternalStateFuture;
 import org.apache.flink.core.state.StateFutureImpl.AsyncFrameworkExceptionHandler;
 import org.apache.flink.core.state.StateFutureUtils;
+import org.apache.flink.metrics.Gauge;
+import org.apache.flink.metrics.MetricGroup;
+import org.apache.flink.metrics.groups.UnregisteredMetricsGroup;
 import org.apache.flink.runtime.asyncprocessing.EpochManager.Epoch;
 import org.apache.flink.runtime.asyncprocessing.EpochManager.ParallelMode;
-import org.apache.flink.runtime.concurrent.ManuallyTriggeredScheduledExecutorService;
+import org.apache.flink.runtime.asyncprocessing.declare.DeclarationManager;
 import org.apache.flink.runtime.mailbox.SyncMailboxExecutor;
 import org.apache.flink.runtime.state.AsyncKeyedStateBackend;
 import org.apache.flink.runtime.state.StateBackend;
 import org.apache.flink.runtime.state.StateBackendTestUtils;
-import org.apache.flink.runtime.state.v2.InternalValueState;
-import org.apache.flink.runtime.state.v2.ValueStateDescriptor;
+import org.apache.flink.runtime.state.VoidNamespace;
+import org.apache.flink.runtime.state.VoidNamespaceSerializer;
+import org.apache.flink.runtime.state.v2.AbstractValueState;
 import org.apache.flink.util.FlinkRuntimeException;
 import org.apache.flink.util.Preconditions;
 import org.apache.flink.util.function.ThrowingRunnable;
@@ -42,16 +49,17 @@ import org.junit.jupiter.api.Test;
 
 import java.io.IOException;
 import java.util.HashMap;
+import java.util.Map;
 import java.util.concurrent.CompletableFuture;
-import java.util.concurrent.ScheduledFuture;
 import java.util.concurrent.atomic.AtomicInteger;
+import java.util.function.Consumer;
 import java.util.function.Supplier;
 
 import static org.assertj.core.api.AssertionsForClassTypes.assertThat;
 
 /** Test for {@link AsyncExecutionController}. */
 class AsyncExecutionControllerTest {
-    AsyncExecutionController aec;
+    AsyncExecutionController<String> aec;
     AtomicInteger output;
     TestValueState valueState;
 
@@ -69,6 +77,7 @@ class AsyncExecutionControllerTest {
                                 })
                         .thenAccept(val -> output.set(val));
             };
+    final Map<String, Gauge> registeredGauges = new HashMap<>();
 
     void setup(
             int batchSize,
@@ -86,7 +95,7 @@ class AsyncExecutionControllerTest {
         StateBackend testAsyncStateBackend =
                 StateBackendTestUtils.buildAsyncStateBackend(stateSupplier, stateExecutor);
         assertThat(testAsyncStateBackend.supportsAsyncKeyedStateBackend()).isTrue();
-        AsyncKeyedStateBackend asyncKeyedStateBackend;
+        AsyncKeyedStateBackend<String> asyncKeyedStateBackend;
         try {
             asyncKeyedStateBackend = testAsyncStateBackend.createAsyncKeyedStateBackend(null);
         } catch (Exception e) {
@@ -94,19 +103,43 @@ class AsyncExecutionControllerTest {
         }
         closeableRegistry.registerCloseable(asyncKeyedStateBackend);
         closeableRegistry.registerCloseable(asyncKeyedStateBackend::dispose);
+
+        UnregisteredMetricsGroup metricsGroup =
+                new UnregisteredMetricsGroup() {
+                    String prefix = "";
+
+                    @Override
+                    public <T, G extends Gauge<T>> G gauge(String name, G gauge) {
+                        registeredGauges.put(prefix + "." + name, gauge);
+                        return gauge;
+                    }
+
+                    @Override
+                    public MetricGroup addGroup(String name) {
+                        prefix = name;
+                        return this;
+                    }
+                };
         aec =
                 new AsyncExecutionController<>(
                         mailboxExecutor,
                         exceptionHandler,
                         stateExecutor,
+                        new DeclarationManager(),
                         128,
                         batchSize,
                         timeout,
-                        maxInFlight);
+                        maxInFlight,
+                        null,
+                        metricsGroup.addGroup("asyncStateProcessing"));
         asyncKeyedStateBackend.setup(aec);
 
         try {
-            valueState = asyncKeyedStateBackend.createState(stateDescriptor);
+            valueState =
+                    asyncKeyedStateBackend.getOrCreateKeyedState(
+                            VoidNamespace.INSTANCE,
+                            VoidNamespaceSerializer.INSTANCE,
+                            stateDescriptor);
         } catch (Exception e) {
             throw new RuntimeException(e);
         }
@@ -139,6 +172,15 @@ class AsyncExecutionControllerTest {
         assertThat(aec.stateRequestsBuffer.activeQueueSize()).isEqualTo(1);
         assertThat(aec.keyAccountingUnit.occupiedCount()).isEqualTo(1);
         assertThat(aec.inFlightRecordNum.get()).isEqualTo(1);
+        assertThat(registeredGauges.get("asyncStateProcessing.numInFlightRecords").getValue())
+                .isEqualTo(1);
+        assertThat(registeredGauges.get("asyncStateProcessing.activeBufferSize").getValue())
+                .isEqualTo(1);
+        assertThat(registeredGauges.get("asyncStateProcessing.blockingBufferSize").getValue())
+                .isEqualTo(0);
+        assertThat(registeredGauges.get("asyncStateProcessing.numBlockingKeys").getValue())
+                .isEqualTo(0);
+
         aec.triggerIfNeeded(true);
         // After running, the value update is in active buffer.
         assertThat(aec.stateRequestsBuffer.activeQueueSize()).isEqualTo(1);
@@ -179,6 +221,14 @@ class AsyncExecutionControllerTest {
         assertThat(aec.stateRequestsBuffer.blockingQueueSize()).isEqualTo(1);
         assertThat(aec.keyAccountingUnit.occupiedCount()).isEqualTo(1);
         assertThat(aec.inFlightRecordNum.get()).isEqualTo(2);
+        assertThat(registeredGauges.get("asyncStateProcessing.numInFlightRecords").getValue())
+                .isEqualTo(2);
+        assertThat(registeredGauges.get("asyncStateProcessing.activeBufferSize").getValue())
+                .isEqualTo(1);
+        assertThat(registeredGauges.get("asyncStateProcessing.blockingBufferSize").getValue())
+                .isEqualTo(1);
+        assertThat(registeredGauges.get("asyncStateProcessing.numBlockingKeys").getValue())
+                .isEqualTo(1);
         aec.triggerIfNeeded(true);
         // Value update for record2 finishes. The value get for record3 is migrated from blocking
         // buffer to active buffer actively.
@@ -232,6 +282,115 @@ class AsyncExecutionControllerTest {
         resourceRegistry.close();
     }
 
+    @Test
+    void testNamespace() throws IOException {
+        final Consumer<String> userCode =
+                (r) -> {
+                    valueState.setCurrentNamespace(r);
+                    valueState
+                            .asyncValue()
+                            .thenCompose(
+                                    val -> {
+                                        int updated = (val == null ? 1 : (val + 1));
+                                        return valueState
+                                                .asyncUpdate(updated)
+                                                .thenCompose(
+                                                        o ->
+                                                                StateFutureUtils.completedFuture(
+                                                                        updated));
+                                    })
+                            .thenAccept(val -> output.set(val));
+                };
+        CloseableRegistry resourceRegistry = new CloseableRegistry();
+        setup(
+                100,
+                10000L,
+                1000,
+                new SyncMailboxExecutor(),
+                new TestAsyncFrameworkExceptionHandler(),
+                resourceRegistry);
+        // ============================ element1 ============================
+        String record1 = "key1-r1";
+        String key1 = "key1";
+        // Simulate the wrapping in {@link RecordProcessorUtils#getRecordProcessor()}, wrapping the
+        // record and key with RecordContext.
+        RecordContext<String> recordContext1 = aec.buildContext(record1, key1);
+        aec.setCurrentContext(recordContext1);
+        // execute user code
+        userCode.accept(record1);
+
+        // Single-step run.
+        // Firstly, the user code generates value get in active buffer.
+        assertThat(aec.stateRequestsBuffer.activeQueueSize()).isEqualTo(1);
+        assertThat(aec.keyAccountingUnit.occupiedCount()).isEqualTo(1);
+        assertThat(aec.inFlightRecordNum.get()).isEqualTo(1);
+        aec.triggerIfNeeded(true);
+        // After running, the value update is in active buffer.
+        assertThat(aec.stateRequestsBuffer.activeQueueSize()).isEqualTo(1);
+        assertThat(aec.keyAccountingUnit.occupiedCount()).isEqualTo(1);
+        aec.triggerIfNeeded(true);
+        // Value update finishes.
+        assertThat(aec.stateRequestsBuffer.activeQueueSize()).isEqualTo(0);
+        assertThat(aec.keyAccountingUnit.occupiedCount()).isEqualTo(0);
+        assertThat(output.get()).isEqualTo(1);
+        assertThat(recordContext1.getReferenceCount()).isEqualTo(0);
+        assertThat(aec.inFlightRecordNum.get()).isEqualTo(0);
+
+        // ============================ element 2 & 3(1) ============================
+        String record2 = "key1-r2";
+        String key2 = "key1";
+        RecordContext<String> recordContext2 = aec.buildContext(record2, key2);
+        aec.setCurrentContext(recordContext2);
+        // execute user code
+        userCode.accept(record2);
+
+        String record3 = "key1-r1";
+        String key3 = "key1";
+        RecordContext<String> recordContext3 = aec.buildContext(record3, key3);
+        aec.setCurrentContext(recordContext3);
+        // execute user code
+        userCode.accept(record3);
+
+        // Single-step run.
+        // Firstly, the user code for record2 generates value get in active buffer,
+        // while user code for record3 generates value get in blocking buffer.
+        assertThat(aec.stateRequestsBuffer.activeQueueSize()).isEqualTo(1);
+        assertThat(aec.stateRequestsBuffer.blockingQueueSize()).isEqualTo(1);
+        assertThat(aec.keyAccountingUnit.occupiedCount()).isEqualTo(1);
+        assertThat(aec.inFlightRecordNum.get()).isEqualTo(2);
+        aec.triggerIfNeeded(true);
+        // After running, the value update for record2 is in active buffer.
+        assertThat(aec.stateRequestsBuffer.activeQueueSize()).isEqualTo(1);
+        assertThat(aec.stateRequestsBuffer.blockingQueueSize()).isEqualTo(1);
+        assertThat(aec.keyAccountingUnit.occupiedCount()).isEqualTo(1);
+        assertThat(aec.inFlightRecordNum.get()).isEqualTo(2);
+        aec.triggerIfNeeded(true);
+        // Value update for record2 finishes. The value get for record3 is migrated from blocking
+        // buffer to active buffer actively.
+        assertThat(aec.stateRequestsBuffer.activeQueueSize()).isEqualTo(1);
+        assertThat(aec.keyAccountingUnit.occupiedCount()).isEqualTo(1);
+        assertThat(aec.inFlightRecordNum.get()).isEqualTo(1);
+        assertThat(output.get()).isEqualTo(1);
+        assertThat(recordContext2.getReferenceCount()).isEqualTo(0);
+        assertThat(aec.stateRequestsBuffer.blockingQueueSize()).isEqualTo(0);
+
+        // Let value get for record3 to run.
+        aec.triggerIfNeeded(true);
+        // After running, the value update for record3 is in active buffer.
+        assertThat(aec.stateRequestsBuffer.activeQueueSize()).isEqualTo(1);
+        assertThat(aec.keyAccountingUnit.occupiedCount()).isEqualTo(1);
+        assertThat(aec.inFlightRecordNum.get()).isEqualTo(1);
+        aec.triggerIfNeeded(true);
+        // Value update for record3 finishes.
+        assertThat(aec.stateRequestsBuffer.activeQueueSize()).isEqualTo(0);
+        assertThat(aec.keyAccountingUnit.occupiedCount()).isEqualTo(0);
+        assertThat(aec.inFlightRecordNum.get()).isEqualTo(0);
+        assertThat(output.get()).isEqualTo(2);
+        assertThat(recordContext3.getReferenceCount()).isEqualTo(0);
+
+        resourceRegistry.close();
+    }
+
     @Test
     void testRecordsRunInOrder() throws IOException {
         CloseableRegistry resourceRegistry = new CloseableRegistry();
@@ -370,7 +529,7 @@ class AsyncExecutionControllerTest {
         RecordContext<String> recordContext = aec.buildContext("record", "key");
         aec.setCurrentContext(recordContext);
         recordContext.retain();
-        aec.syncPointRequestWithCallback(counter::incrementAndGet);
+        aec.syncPointRequestWithCallback(counter::incrementAndGet, false);
         assertThat(counter.get()).isEqualTo(1);
         assertThat(recordContext.getReferenceCount()).isEqualTo(1);
         assertThat(aec.stateRequestsBuffer.activeQueueSize()).isEqualTo(0);
@@ -387,7 +546,7 @@ class AsyncExecutionControllerTest {
 
         RecordContext<String> recordContext2 = aec.buildContext("record2", "occupied");
         aec.setCurrentContext(recordContext2);
-        aec.syncPointRequestWithCallback(counter::incrementAndGet);
+        aec.syncPointRequestWithCallback(counter::incrementAndGet, false);
         recordContext2.retain();
         assertThat(counter.get()).isEqualTo(0);
         assertThat(recordContext2.getReferenceCount()).isGreaterThan(1);
@@ -409,7 +568,44 @@ class AsyncExecutionControllerTest {
     }
 
     @Test
-    void testBufferTimeout() throws IOException {
+    public void testSyncPointWithOverdraft() throws IOException {
+        CloseableRegistry resourceRegistry = new CloseableRegistry();
+        setup(
+                1,
+                10000L,
+                1,
+                new SyncMailboxExecutor(),
+                new TestAsyncFrameworkExceptionHandler(),
+                resourceRegistry);
+        AtomicInteger counter = new AtomicInteger(0);
+
+        // Test the sync point processing with a key occupied.
+        RecordContext<String> recordContext1 = aec.buildContext("record1", "occupied");
+        aec.setCurrentContext(recordContext1);
+        // retain this to avoid the recordContext1 being released before the sync point
+        recordContext1.retain();
+        userCode.run();
+
+        RecordContext<String> recordContext2 = aec.buildContext("record2", "occupied");
+        aec.setCurrentContext(recordContext2);
+        aec.syncPointRequestWithCallback(counter::incrementAndGet, true);
+        recordContext2.retain();
+        assertThat(counter.get()).isEqualTo(0);
+        assertThat(recordContext2.getReferenceCount()).isGreaterThan(1);
+        assertThat(aec.stateRequestsBuffer.activeQueueSize()).isEqualTo(0);
+        assertThat(aec.stateRequestsBuffer.blockingQueueSize()).isEqualTo(1);
+        recordContext1.release();
+        assertThat(counter.get()).isEqualTo(1);
+        assertThat(recordContext2.getReferenceCount()).isEqualTo(1);
+        assertThat(aec.stateRequestsBuffer.activeQueueSize()).isEqualTo(0);
+        assertThat(aec.stateRequestsBuffer.blockingQueueSize()).isEqualTo(0);
+        recordContext2.release();
+
+        resourceRegistry.close();
+    }
+
+    @Test
+    void testBufferTimeout() throws Exception {
         int batchSize = 5;
         int timeout = 1000;
         CloseableRegistry resourceRegistry = new CloseableRegistry();
@@ -420,11 +616,11 @@ class AsyncExecutionControllerTest {
                 new SyncMailboxExecutor(),
                 new TestAsyncFrameworkExceptionHandler(),
                 resourceRegistry);
-        ManuallyTriggeredScheduledExecutorService scheduledExecutor =
-                new ManuallyTriggeredScheduledExecutorService();
-        aec.stateRequestsBuffer.scheduledExecutor = scheduledExecutor;
+
         Runnable userCode = () -> valueState.asyncValue();
 
+        assertThat(aec.stateRequestsBuffer.currentSeq.get()).isEqualTo(0L);
+        assertThat(aec.stateRequestsBuffer.seqAndTimeout).isNull();
         // ------------ basic timeout -------------------
         for (int i = 0; i < batchSize - 1; i++) {
             String record = String.format("key%d-r%d", i, i);
@@ -433,127 +629,47 @@ class AsyncExecutionControllerTest {
             aec.setCurrentContext(recordContext);
             userCode.run();
         }
-        assertThat(aec.stateRequestsBuffer.currentSeq.get()).isEqualTo(0);
-        assertThat(aec.stateRequestsBuffer.scheduledSeq.get()).isEqualTo(0);
+        assertThat(aec.stateRequestsBuffer.currentSeq.get()).isEqualTo(0L);
+        assertThat(aec.stateRequestsBuffer.seqAndTimeout.f0).isEqualTo(0L);
         assertThat(aec.stateRequestsBuffer.currentScheduledFuture.isDone()).isFalse();
         assertThat(aec.inFlightRecordNum.get()).isEqualTo(batchSize - 1);
         assertThat(aec.stateRequestsBuffer.activeQueueSize()).isEqualTo(batchSize - 1);
         assertThat(aec.stateRequestsBuffer.blockingQueueSize()).isEqualTo(0);
 
         // buffer timeout, trigger
-        scheduledExecutor.triggerNonPeriodicScheduledTasks();
+        Thread.sleep(2000);
         assertThat(aec.stateRequestsBuffer.activeQueueSize()).isEqualTo(0);
-        assertThat(aec.stateRequestsBuffer.currentScheduledFuture.isDone()).isTrue();
-        assertThat(aec.inFlightRecordNum.get()).isEqualTo(0);
-        assertThat(aec.stateRequestsBuffer.currentSeq.get()).isEqualTo(1);
-        assertThat(aec.stateRequestsBuffer.scheduledSeq.get()).isEqualTo(0);
-
-        // ----------------- oldest state request timeout ------------------
-        // r5 and r6 should be triggered due to r5 exceeding timeout
-        String record5 = "key5-r5";
-        String key5 = "key5";
-        RecordContext<String> recordContext5 = aec.buildContext(record5, key5);
-        aec.setCurrentContext(recordContext5);
-        // execute user code
-        userCode.run();
-        assertThat(aec.inFlightRecordNum.get()).isEqualTo(1);
-        assertThat(aec.stateRequestsBuffer.activeQueueSize()).isEqualTo(1);
         assertThat(aec.stateRequestsBuffer.currentScheduledFuture.isDone()).isFalse();
-        ScheduledFuture<Void> scheduledFuture = aec.stateRequestsBuffer.currentScheduledFuture;
-        String record6 = "key6-r6";
-        String key6 = "key6";
-        RecordContext<String> recordContext6 = aec.buildContext(record6, key6);
-        aec.setCurrentContext(recordContext6);
-        // execute user code
-        userCode.run();
-        assertThat(aec.inFlightRecordNum.get()).isEqualTo(2);
-        assertThat(aec.stateRequestsBuffer.activeQueueSize()).isEqualTo(2);
-
-        assertThat(scheduledExecutor.getActiveNonPeriodicScheduledTask().size()).isEqualTo(1);
-        assertThat(scheduledExecutor.getAllNonPeriodicScheduledTask().size()).isEqualTo(1);
-        assertThat(aec.stateRequestsBuffer.currentSeq.get()).isEqualTo(1);
-        assertThat(aec.stateRequestsBuffer.scheduledSeq.get()).isEqualTo(1);
-        scheduledExecutor.triggerNonPeriodicScheduledTasks();
-
         assertThat(aec.inFlightRecordNum.get()).isEqualTo(0);
-        assertThat(aec.stateRequestsBuffer.activeQueueSize()).isEqualTo(0);
-        assertThat(scheduledFuture).isEqualTo(aec.stateRequestsBuffer.currentScheduledFuture);
-        assertThat(scheduledFuture.isDone()).isTrue();
-        assertThat(aec.stateRequestsBuffer.currentSeq.get()).isEqualTo(2);
-        assertThat(aec.stateRequestsBuffer.scheduledSeq.get()).isEqualTo(1);
+        assertThat(aec.stateRequestsBuffer.currentSeq.get()).isEqualTo(1L);
+        assertThat(aec.stateRequestsBuffer.seqAndTimeout).isNull();
 
-        resourceRegistry.close();
-    }
-
-    @Test
-    void testBufferTimeoutSkip() throws IOException {
-        int batchSize = 3;
-        int timeout = 1000;
-        CloseableRegistry resourceRegistry = new CloseableRegistry();
-        setup(
-                batchSize,
-                timeout,
-                1000,
-                new SyncMailboxExecutor(),
-                new TestAsyncFrameworkExceptionHandler(),
-                resourceRegistry);
-        ManuallyTriggeredScheduledExecutorService scheduledExecutor =
-                new ManuallyTriggeredScheduledExecutorService();
-        aec.stateRequestsBuffer.scheduledExecutor = scheduledExecutor;
-        Runnable userCode = () -> valueState.asyncValue();
-
-        assertThat(aec.stateRequestsBuffer.currentSeq.get()).isEqualTo(0);
-        assertThat(aec.stateRequestsBuffer.scheduledSeq.get()).isEqualTo(-1);
-        // register r1 timeout
-        RecordContext<String> recordContext = aec.buildContext("record1", "key1");
-        aec.setCurrentContext(recordContext);
-        userCode.run();
-        assertThat(aec.stateRequestsBuffer.activeQueueSize()).isEqualTo(1);
-        assertThat(aec.inFlightRecordNum.get()).isEqualTo(1);
-        assertThat(aec.stateRequestsBuffer.currentSeq.get()).isEqualTo(0);
-        assertThat(aec.stateRequestsBuffer.scheduledSeq.get()).isEqualTo(0);
-
-        // before r1 timeout execute, the active buffer size reach batch size.
-        RecordContext<String> recordContext2 = aec.buildContext("record2", "key2");
-        aec.setCurrentContext(recordContext2);
-        userCode.run();
-        assertThat(aec.stateRequestsBuffer.currentSeq.get()).isEqualTo(0);
-        assertThat(aec.stateRequestsBuffer.scheduledSeq.get()).isEqualTo(0);
-        RecordContext<String> recordContext3 = aec.buildContext("record3", "key3");
-        aec.setCurrentContext(recordContext3);
-        userCode.run();
-        assertThat(aec.stateRequestsBuffer.activeQueueSize()).isEqualTo(0);
-        assertThat(aec.stateRequestsBuffer.currentSeq.get()).isEqualTo(1);
-        assertThat(aec.stateRequestsBuffer.scheduledSeq.get()).isEqualTo(0);
-
-        // r1 timeout executes, but r1 is already triggered in [r1,r2,r3], so r1 timeout should skip
-        assertThat(scheduledExecutor.getActiveNonPeriodicScheduledTask().size()).isEqualTo(1);
-        assertThat(scheduledExecutor.getAllNonPeriodicScheduledTask().size()).isEqualTo(1);
-        scheduledExecutor.triggerNonPeriodicScheduledTask();
-        assertThat(aec.stateRequestsBuffer.currentScheduledFuture.isDone()).isTrue();
-        assertThat(aec.stateRequestsBuffer.currentSeq.get()).isEqualTo(1);
-        assertThat(aec.stateRequestsBuffer.scheduledSeq.get()).isEqualTo(0);
-
-        RecordContext<String> recordContext4 = aec.buildContext("record4", "key4");
-        aec.setCurrentContext(recordContext4);
-        userCode.run();
-
-        // register r4 timeout, set new currentScheduledFuture
-        assertThat(scheduledExecutor.getActiveNonPeriodicScheduledTask().size()).isEqualTo(1);
-        assertThat(aec.stateRequestsBuffer.activeQueueSize()).isEqualTo(1);
-        assertThat(aec.inFlightRecordNum.get()).isEqualTo(1);
+        // ---------- buffer full before timeout ------------------
+        for (int i = 0; i < batchSize - 1; i++) {
+            String record = String.format("key%d-r%d", i, i);
+            String key = String.format("key%d", batchSize + i);
+            RecordContext<String> recordContext = aec.buildContext(record, key);
+            aec.setCurrentContext(recordContext);
+            userCode.run();
+        }
+        assertThat(aec.stateRequestsBuffer.currentSeq.get()).isEqualTo(1L);
+        assertThat(aec.stateRequestsBuffer.seqAndTimeout.f0).isEqualTo(1L);
         assertThat(aec.stateRequestsBuffer.currentScheduledFuture.isDone()).isFalse();
-        assertThat(aec.stateRequestsBuffer.currentScheduledFuture.isCancelled()).isFalse();
-        assertThat(aec.stateRequestsBuffer.currentSeq.get()).isEqualTo(1);
-        assertThat(aec.stateRequestsBuffer.scheduledSeq.get()).isEqualTo(1);
-
-        // r4 timeout
-        scheduledExecutor.triggerNonPeriodicScheduledTask();
+        assertThat(aec.inFlightRecordNum.get()).isEqualTo(batchSize - 1);
+        assertThat(aec.stateRequestsBuffer.activeQueueSize()).isEqualTo(batchSize - 1);
+        assertThat(aec.stateRequestsBuffer.blockingQueueSize()).isEqualTo(0);
+        for (int i = batchSize - 1; i < batchSize; i++) {
+            String record = String.format("key%d-r%d", i, i);
+            String key = String.format("key%d", batchSize + i);
+            RecordContext<String> recordContext = aec.buildContext(record, key);
+            aec.setCurrentContext(recordContext);
+            userCode.run();
+        }
         assertThat(aec.stateRequestsBuffer.activeQueueSize()).isEqualTo(0);
+        assertThat(aec.stateRequestsBuffer.currentScheduledFuture.isDone()).isFalse();
         assertThat(aec.inFlightRecordNum.get()).isEqualTo(0);
-        assertThat(aec.stateRequestsBuffer.currentSeq.get()).isEqualTo(2);
-        assertThat(aec.stateRequestsBuffer.scheduledSeq.get()).isEqualTo(1);
-        assertThat(aec.stateRequestsBuffer.currentScheduledFuture.isDone()).isTrue();
+        assertThat(aec.stateRequestsBuffer.currentSeq.get()).isEqualTo(2L);
+        assertThat(aec.stateRequestsBuffer.seqAndTimeout).isNull();
 
         resourceRegistry.close();
     }
@@ -655,7 +771,7 @@ class AsyncExecutionControllerTest {
 
         assertThat(epoch1).isEqualTo(epoch2);
         assertThat(epoch1.ongoingRecordCount).isEqualTo(2);
-        aec.processNonRecord(() -> output.incrementAndGet());
+        aec.processNonRecord(null, () -> output.incrementAndGet());
 
         assertThat(output.get()).isEqualTo(3);
         // SERIAL_BETWEEN_EPOCH mode would drain in-flight records on non-record arriving.
@@ -688,7 +804,7 @@ class AsyncExecutionControllerTest {
         userCode.run();
 
         aec.epochManager.onNonRecord(
-                () -> output.incrementAndGet(), ParallelMode.PARALLEL_BETWEEN_EPOCH);
+                null, () -> output.incrementAndGet(), ParallelMode.PARALLEL_BETWEEN_EPOCH);
         assertThat(epoch1.ongoingRecordCount).isEqualTo(1);
 
         String record2 = "key2-r2";
@@ -700,7 +816,7 @@ class AsyncExecutionControllerTest {
         assertThat(epoch1.ongoingRecordCount).isEqualTo(1);
         assertThat(epoch2.ongoingRecordCount).isEqualTo(1);
         aec.epochManager.onNonRecord(
-                () -> output.incrementAndGet(), ParallelMode.PARALLEL_BETWEEN_EPOCH);
+                null, () -> output.incrementAndGet(), ParallelMode.PARALLEL_BETWEEN_EPOCH);
         assertThat(epoch1.ongoingRecordCount).isEqualTo(1);
         assertThat(epoch2.ongoingRecordCount).isEqualTo(1);
         assertThat(output.get()).isEqualTo(0);
@@ -715,7 +831,7 @@ class AsyncExecutionControllerTest {
         assertThat(epoch2.ongoingRecordCount).isEqualTo(1);
         assertThat(epoch3.ongoingRecordCount).isEqualTo(1);
         aec.epochManager.onNonRecord(
-                () -> output.incrementAndGet(), ParallelMode.SERIAL_BETWEEN_EPOCH);
+                null, () -> output.incrementAndGet(), ParallelMode.SERIAL_BETWEEN_EPOCH);
         assertThat(epoch1.ongoingRecordCount).isEqualTo(0);
         assertThat(epoch2.ongoingRecordCount).isEqualTo(0);
         assertThat(epoch3.ongoingRecordCount).isEqualTo(0);
@@ -727,22 +843,22 @@ class AsyncExecutionControllerTest {
     /** Simulate the underlying state that is actually used to execute the request. */
     static class TestUnderlyingState {
 
-        private final HashMap<String, Integer> hashMap;
+        private final HashMap<Tuple2<String, String>, Integer> hashMap;
 
         public TestUnderlyingState() {
             this.hashMap = new HashMap<>();
         }
 
-        public Integer get(String key) {
-            return hashMap.get(key);
+        public Integer get(String key, String namespace) {
+            return hashMap.get(Tuple2.of(key, namespace));
         }
 
-        public void update(String key, Integer val) {
-            hashMap.put(key, val);
+        public void update(String key, String namespace, Integer val) {
+            hashMap.put(Tuple2.of(key, namespace), val);
         }
     }
 
-    static class TestValueState extends InternalValueState<String, Integer> {
+    static class TestValueState extends AbstractValueState<String, String, Integer> {
 
         private final TestUnderlyingState underlyingState;
 
@@ -772,23 +888,7 @@ class AsyncExecutionControllerTest {
             CompletableFuture<Void> future = new CompletableFuture<>();
             for (StateRequest request :
                     ((MockStateRequestContainer) stateRequestContainer).getStateRequestList()) {
-                if (request.getRequestType() == StateRequestType.VALUE_GET) {
-                    Preconditions.checkState(request.getState() != null);
-                    TestValueState state = (TestValueState) request.getState();
-                    Integer val =
-                            state.underlyingState.get((String) request.getRecordContext().getKey());
-                    request.getFuture().complete(val);
-                } else if (request.getRequestType() == StateRequestType.VALUE_UPDATE) {
-                    Preconditions.checkState(request.getState() != null);
-                    TestValueState state = (TestValueState) request.getState();
-
-                    state.underlyingState.update(
-                            (String) request.getRecordContext().getKey(),
-                            (Integer) request.getPayload());
-                    request.getFuture().complete(null);
-                } else {
-                    throw new UnsupportedOperationException("Unsupported request type");
-                }
+                executeRequestSync(request);
             }
             future.complete(null);
             return future;
@@ -799,6 +899,35 @@ class AsyncExecutionControllerTest {
             return new MockStateRequestContainer();
         }
 
+        @Override
+        public void executeRequestSync(StateRequest<?, ?, ?, ?> request) {
+            if (request.getRequestType() == StateRequestType.VALUE_GET) {
+                Preconditions.checkState(request.getState() != null);
+                TestValueState state = (TestValueState) request.getState();
+                Integer val =
+                        state.underlyingState.get(
+                                (String) request.getRecordContext().getKey(),
+                                (String) request.getRecordContext().getNamespace(state));
+                ((InternalStateFuture<Integer>) request.getFuture()).complete(val);
+            } else if (request.getRequestType() == StateRequestType.VALUE_UPDATE) {
+                Preconditions.checkState(request.getState() != null);
+                TestValueState state = (TestValueState) request.getState();
+
+                state.underlyingState.update(
+                        (String) request.getRecordContext().getKey(),
+                        (String) request.getRecordContext().getNamespace(state),
+                        (Integer) request.getPayload());
+                request.getFuture().complete(null);
+            } else {
+                throw new UnsupportedOperationException("Unsupported request type");
+            }
+        }
+
+        @Override
+        public boolean fullyLoaded() {
+            return false;
+        }
+
         @Override
         public void shutdown() {}
     }
