@@ -22,12 +22,12 @@ import org.apache.flink.configuration.Configuration;
 import org.apache.flink.core.failure.FailureEnricher;
 import org.apache.flink.runtime.heartbeat.HeartbeatServices;
 import org.apache.flink.runtime.highavailability.HighAvailabilityServices;
-import org.apache.flink.runtime.jobgraph.JobGraph;
 import org.apache.flink.runtime.jobmaster.JobManagerSharedServices;
 import org.apache.flink.runtime.jobmaster.TestingJobManagerRunner;
 import org.apache.flink.runtime.jobmaster.factories.JobManagerJobMetricGroupFactory;
 import org.apache.flink.runtime.rpc.FatalErrorHandler;
 import org.apache.flink.runtime.rpc.RpcService;
+import org.apache.flink.streaming.api.graph.ExecutionPlan;
 
 import java.util.Collection;
 
@@ -49,7 +49,7 @@ public class TestingJobMasterServiceLeadershipRunnerFactory extends TestingJobMa
 
     @Override
     public TestingJobManagerRunner createJobManagerRunner(
-            JobGraph jobGraph,
+            ExecutionPlan executionPlan,
             Configuration configuration,
             RpcService rpcService,
             HighAvailabilityServices highAvailabilityServices,
@@ -60,6 +60,6 @@ public class TestingJobMasterServiceLeadershipRunnerFactory extends TestingJobMa
             Collection<FailureEnricher> failureEnrichers,
             long initializationTimestamp)
             throws Exception {
-        return offerTestingJobManagerRunner(jobGraph.getJobID());
+        return offerTestingJobManagerRunner(executionPlan.getJobID());
     }
 }
