@@ -20,64 +20,65 @@ package org.apache.flink.runtime.io.network.netty;
 
 import org.apache.flink.runtime.event.task.IntegerTaskEvent;
 import org.apache.flink.runtime.io.network.partition.ResultPartitionID;
+import org.apache.flink.runtime.io.network.partition.ResultSubpartitionIndexSet;
 import org.apache.flink.runtime.io.network.partition.consumer.InputChannelID;
-import org.apache.flink.util.TestLogger;
 
 import org.apache.flink.shaded.netty4.io.netty.channel.embedded.EmbeddedChannel;
 
-import org.junit.After;
-import org.junit.Before;
-import org.junit.Test;
+import org.junit.jupiter.api.AfterEach;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Test;
 
 import java.util.Random;
 
 import static org.apache.flink.runtime.io.network.netty.NettyTestUtil.encodeAndDecode;
-import static org.junit.Assert.assertEquals;
+import static org.assertj.core.api.Assertions.assertThat;
 
 /**
  * Tests for the serialization and deserialization of the various {@link NettyMessage} sub-classes
  * sent from client side to server side.
  */
-public class NettyMessageServerSideSerializationTest extends TestLogger {
+class NettyMessageServerSideSerializationTest {
 
     private final Random random = new Random();
 
     private EmbeddedChannel channel;
 
-    @Before
-    public void setup() {
+    @BeforeEach
+    void setup() {
         channel =
                 new EmbeddedChannel(
                         new NettyMessage.NettyMessageEncoder(), // For outbound messages
                         new NettyMessage.NettyMessageDecoder()); // For inbound messages
     }
 
-    @After
-    public void tearDown() {
+    @AfterEach
+    void tearDown() {
         if (channel != null) {
             channel.close();
         }
     }
 
     @Test
-    public void testPartitionRequest() {
+    void testPartitionRequest() {
+        int queueIndex = random.nextInt(Integer.MAX_VALUE);
         NettyMessage.PartitionRequest expected =
                 new NettyMessage.PartitionRequest(
                         new ResultPartitionID(),
-                        random.nextInt(),
+                        new ResultSubpartitionIndexSet(queueIndex),
                         new InputChannelID(),
                         random.nextInt());
 
         NettyMessage.PartitionRequest actual = encodeAndDecode(expected, channel);
 
-        assertEquals(expected.partitionId, actual.partitionId);
-        assertEquals(expected.queueIndex, actual.queueIndex);
-        assertEquals(expected.receiverId, actual.receiverId);
-        assertEquals(expected.credit, actual.credit);
+        assertThat(actual.partitionId).isEqualTo(expected.partitionId);
+        assertThat(actual.queueIndexSet).isEqualTo(expected.queueIndexSet);
+        assertThat(actual.receiverId).isEqualTo(expected.receiverId);
+        assertThat(actual.credit).isEqualTo(expected.credit);
     }
 
     @Test
-    public void testTaskEventRequest() {
+    void testTaskEventRequest() {
         NettyMessage.TaskEventRequest expected =
                 new NettyMessage.TaskEventRequest(
                         new IntegerTaskEvent(random.nextInt()),
@@ -85,65 +86,65 @@ public class NettyMessageServerSideSerializationTest extends TestLogger {
                         new InputChannelID());
         NettyMessage.TaskEventRequest actual = encodeAndDecode(expected, channel);
 
-        assertEquals(expected.event, actual.event);
-        assertEquals(expected.partitionId, actual.partitionId);
-        assertEquals(expected.receiverId, actual.receiverId);
+        assertThat(actual.event).isEqualTo(expected.event);
+        assertThat(actual.partitionId).isEqualTo(expected.partitionId);
+        assertThat(actual.receiverId).isEqualTo(expected.receiverId);
     }
 
     @Test
-    public void testCancelPartitionRequest() {
+    void testCancelPartitionRequest() {
         NettyMessage.CancelPartitionRequest expected =
                 new NettyMessage.CancelPartitionRequest(new InputChannelID());
         NettyMessage.CancelPartitionRequest actual = encodeAndDecode(expected, channel);
 
-        assertEquals(expected.receiverId, actual.receiverId);
+        assertThat(actual.receiverId).isEqualTo(expected.receiverId);
     }
 
     @Test
-    public void testCloseRequest() {
+    void testCloseRequest() {
         NettyMessage.CloseRequest expected = new NettyMessage.CloseRequest();
         NettyMessage.CloseRequest actual = encodeAndDecode(expected, channel);
 
-        assertEquals(expected.getClass(), actual.getClass());
+        assertThat(actual).isExactlyInstanceOf(expected.getClass());
     }
 
     @Test
-    public void testAddCredit() {
+    void testAddCredit() {
         NettyMessage.AddCredit expected =
                 new NettyMessage.AddCredit(
                         random.nextInt(Integer.MAX_VALUE) + 1, new InputChannelID());
         NettyMessage.AddCredit actual = encodeAndDecode(expected, channel);
 
-        assertEquals(expected.credit, actual.credit);
-        assertEquals(expected.receiverId, actual.receiverId);
+        assertThat(actual.credit).isEqualTo(expected.credit);
+        assertThat(actual.receiverId).isEqualTo(expected.receiverId);
     }
 
     @Test
-    public void testResumeConsumption() {
+    void testResumeConsumption() {
         NettyMessage.ResumeConsumption expected =
                 new NettyMessage.ResumeConsumption(new InputChannelID());
         NettyMessage.ResumeConsumption actual = encodeAndDecode(expected, channel);
 
-        assertEquals(expected.receiverId, actual.receiverId);
+        assertThat(actual.receiverId).isEqualTo(expected.receiverId);
     }
 
     @Test
-    public void testAckAllUserRecordsProcessed() {
+    void testAckAllUserRecordsProcessed() {
         NettyMessage.AckAllUserRecordsProcessed expected =
                 new NettyMessage.AckAllUserRecordsProcessed(new InputChannelID());
         NettyMessage.AckAllUserRecordsProcessed actual = encodeAndDecode(expected, channel);
 
-        assertEquals(expected.receiverId, actual.receiverId);
+        assertThat(actual.receiverId).isEqualTo(expected.receiverId);
     }
 
     @Test
-    public void testNewBufferSize() {
+    void testNewBufferSize() {
         NettyMessage.NewBufferSize expected =
                 new NettyMessage.NewBufferSize(
                         random.nextInt(Integer.MAX_VALUE), new InputChannelID());
         NettyMessage.NewBufferSize actual = encodeAndDecode(expected, channel);
 
-        assertEquals(expected.bufferSize, actual.bufferSize);
-        assertEquals(expected.receiverId, actual.receiverId);
+        assertThat(actual.bufferSize).isEqualTo(expected.bufferSize);
+        assertThat(actual.receiverId).isEqualTo(expected.receiverId);
     }
 }
