@@ -18,11 +18,11 @@
 package org.apache.flink.runtime.jobmaster.slotpool;
 
 import org.apache.flink.api.common.JobID;
-import org.apache.flink.api.common.time.Time;
 import org.apache.flink.runtime.blocklist.BlockedTaskManagerChecker;
 import org.apache.flink.runtime.clusterframework.types.AllocationID;
 import org.apache.flink.runtime.clusterframework.types.ResourceID;
 import org.apache.flink.runtime.clusterframework.types.ResourceProfile;
+import org.apache.flink.runtime.concurrent.ComponentMainThreadExecutor;
 import org.apache.flink.runtime.jobmaster.SlotInfo;
 import org.apache.flink.runtime.taskexecutor.TestingTaskExecutorGateway;
 import org.apache.flink.runtime.taskexecutor.TestingTaskExecutorGatewayBuilder;
@@ -30,9 +30,13 @@ import org.apache.flink.runtime.taskexecutor.slot.SlotOffer;
 import org.apache.flink.runtime.taskmanager.LocalTaskManagerLocation;
 import org.apache.flink.runtime.taskmanager.TaskManagerLocation;
 import org.apache.flink.runtime.util.ResourceCounter;
+import org.apache.flink.testutils.junit.extensions.parameterized.ParameterizedTestExtension;
 
 import org.junit.jupiter.api.Test;
+import org.junit.jupiter.api.TestTemplate;
+import org.junit.jupiter.api.extension.ExtendWith;
 
+import java.time.Duration;
 import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.Collection;
@@ -44,27 +48,29 @@ import java.util.Set;
 import java.util.function.Function;
 import java.util.stream.Collectors;
 
+import static org.apache.flink.runtime.concurrent.ComponentMainThreadExecutorServiceAdapter.forMainThread;
 import static org.apache.flink.runtime.jobmaster.slotpool.DefaultDeclarativeSlotPoolTest.FreeSlotConsumer;
 import static org.apache.flink.runtime.jobmaster.slotpool.DefaultDeclarativeSlotPoolTest.NewSlotsService;
 import static org.apache.flink.runtime.jobmaster.slotpool.DefaultDeclarativeSlotPoolTest.createResourceRequirements;
 import static org.apache.flink.runtime.jobmaster.slotpool.DefaultDeclarativeSlotPoolTest.drainNewSlotService;
 import static org.apache.flink.runtime.jobmaster.slotpool.DefaultDeclarativeSlotPoolTest.increaseRequirementsAndOfferSlotsToSlotPool;
 import static org.apache.flink.runtime.jobmaster.slotpool.SlotPoolTestUtils.createSlotOffersForResourceRequirements;
-import static org.apache.flink.shaded.guava31.com.google.common.collect.Iterables.getOnlyElement;
+import static org.apache.flink.shaded.guava32.com.google.common.collect.Iterables.getOnlyElement;
 import static org.assertj.core.api.Assertions.assertThat;
 
 /** Test for {@link BlocklistDeclarativeSlotPool}. */
-class BlocklistDeclarativeSlotPoolTest {
+@ExtendWith(ParameterizedTestExtension.class)
+class BlocklistDeclarativeSlotPoolTest extends DefaultDeclarativeSlotPoolTestBase {
 
     private static final ResourceProfile RESOURCE_PROFILE =
             ResourceProfile.newBuilder().setCpuCores(1.7).build();
 
-    @Test
+    @TestTemplate
     void testOfferSlotsFromBlockedTaskManager() throws Exception {
         testOfferSlots(true);
     }
 
-    @Test
+    @TestTemplate
     void testOfferSlotsFromUnblockedTaskManager() throws Exception {
         testOfferSlots(false);
     }
@@ -78,12 +84,16 @@ class BlocklistDeclarativeSlotPoolTest {
                 BlocklistDeclarativeSlotPoolBuilder.builder()
                         .setBlockedTaskManagerChecker(
                                 isBlocked ? taskManager.getResourceID()::equals : ignore -> false)
+                        .setSlotRequestMaxInterval(slotRequestMaxInterval)
+                        .setMainThreadExecutor(componentMainThreadExecutor)
                         .build();
         slotPool.registerNewSlotsListener(notifyNewSlots);
 
         final ResourceCounter resourceRequirements = createResourceRequirements();
         slotPool.increaseResourceRequirementsBy(resourceRequirements);
 
+        slotPool.tryWaitSlotRequestIsDone();
+
         // offer slots on the blocked task manager
         Collection<SlotOffer> slotOffers =
                 createSlotOffersForResourceRequirements(resourceRequirements);
@@ -107,7 +117,7 @@ class BlocklistDeclarativeSlotPoolTest {
         }
     }
 
-    @Test
+    @TestTemplate
     void testOfferDuplicateSlots() {
         final TaskManagerLocation taskManager = new LocalTaskManagerLocation();
         final List<ResourceID> blockedTaskManagers = new ArrayList<>();
@@ -115,12 +125,15 @@ class BlocklistDeclarativeSlotPoolTest {
         final BlocklistDeclarativeSlotPool slotPool =
                 BlocklistDeclarativeSlotPoolBuilder.builder()
                         .setBlockedTaskManagerChecker(blockedTaskManagers::contains)
+                        .setSlotRequestMaxInterval(slotRequestMaxInterval)
+                        .setMainThreadExecutor(componentMainThreadExecutor)
                         .build();
-
         final ResourceCounter resourceRequirements =
                 ResourceCounter.withResource(RESOURCE_PROFILE, 2);
         slotPool.increaseResourceRequirementsBy(resourceRequirements);
 
+        slotPool.tryWaitSlotRequestIsDone();
+
         SlotOffer slot1 = new SlotOffer(new AllocationID(), 1, RESOURCE_PROFILE);
         SlotOffer slot2 = new SlotOffer(new AllocationID(), 1, RESOURCE_PROFILE);
 
@@ -154,8 +167,9 @@ class BlocklistDeclarativeSlotPoolTest {
                 BlocklistDeclarativeSlotPoolBuilder.builder()
                         .setBlockedTaskManagerChecker(
                                 isBlocked ? taskManager.getResourceID()::equals : ignore -> false)
+                        .setSlotRequestMaxInterval(Duration.ZERO)
+                        .setMainThreadExecutor(componentMainThreadExecutor)
                         .build();
-
         final int numberSlots = 10;
         final Collection<SlotOffer> slotOffers =
                 createSlotOffersForResourceRequirements(
@@ -195,8 +209,9 @@ class BlocklistDeclarativeSlotPoolTest {
         final BlocklistDeclarativeSlotPool slotPool =
                 BlocklistDeclarativeSlotPoolBuilder.builder()
                         .setBlockedTaskManagerChecker(blockedTaskManagers::contains)
+                        .setSlotRequestMaxInterval(Duration.ZERO)
+                        .setMainThreadExecutor(componentMainThreadExecutor)
                         .build();
-
         SlotOffer slot1 = new SlotOffer(new AllocationID(), 1, RESOURCE_PROFILE);
         SlotOffer slot2 = new SlotOffer(new AllocationID(), 1, RESOURCE_PROFILE);
 
@@ -222,12 +237,12 @@ class BlocklistDeclarativeSlotPoolTest {
         assertThat(acceptedOffers).containsExactly(slot1);
     }
 
-    @Test
+    @TestTemplate
     void testFreeReservedSlotsOnBlockedTaskManager() throws Exception {
         testFreeReservedSlots(true);
     }
 
-    @Test
+    @TestTemplate
     void testFreeReservedSlotsOnUnblockedTaskManager() throws Exception {
         testFreeReservedSlots(false);
     }
@@ -244,6 +259,8 @@ class BlocklistDeclarativeSlotPoolTest {
         final BlocklistDeclarativeSlotPool slotPool =
                 BlocklistDeclarativeSlotPoolBuilder.builder()
                         .setBlockedTaskManagerChecker(blockedTaskManagers::contains)
+                        .setSlotRequestMaxInterval(slotRequestMaxInterval)
+                        .setMainThreadExecutor(componentMainThreadExecutor)
                         .build();
         slotPool.registerNewSlotsListener(notifyNewSlots);
 
@@ -292,6 +309,8 @@ class BlocklistDeclarativeSlotPoolTest {
 
     private static class BlocklistDeclarativeSlotPoolBuilder {
         private BlockedTaskManagerChecker blockedTaskManagerChecker = resourceID -> false;
+        private Duration slotRequestMaxInterval = Duration.ZERO;
+        private ComponentMainThreadExecutor mainThreadExecutor = forMainThread();
 
         public BlocklistDeclarativeSlotPoolBuilder setBlockedTaskManagerChecker(
                 BlockedTaskManagerChecker blockedTaskManagerChecker) {
@@ -299,14 +318,28 @@ class BlocklistDeclarativeSlotPoolTest {
             return this;
         }
 
+        public BlocklistDeclarativeSlotPoolBuilder setSlotRequestMaxInterval(
+                Duration slotRequestMaxInterval) {
+            this.slotRequestMaxInterval = slotRequestMaxInterval;
+            return this;
+        }
+
+        public BlocklistDeclarativeSlotPoolBuilder setMainThreadExecutor(
+                ComponentMainThreadExecutor mainThreadExecutor) {
+            this.mainThreadExecutor = mainThreadExecutor;
+            return this;
+        }
+
         public BlocklistDeclarativeSlotPool build() {
             return new BlocklistDeclarativeSlotPool(
                     new JobID(),
                     new DefaultAllocatedSlotPool(),
                     ignored -> {},
                     blockedTaskManagerChecker,
-                    Time.seconds(20),
-                    Time.seconds(20));
+                    Duration.ofSeconds(20),
+                    Duration.ofSeconds(20),
+                    slotRequestMaxInterval,
+                    mainThreadExecutor);
         }
 
         public static BlocklistDeclarativeSlotPoolBuilder builder() {
