@@ -18,7 +18,6 @@
 
 package org.apache.flink.runtime.jobmaster.slotpool;
 
-import org.apache.flink.api.common.time.Time;
 import org.apache.flink.runtime.clusterframework.types.AllocationID;
 import org.apache.flink.runtime.clusterframework.types.ResourceProfile;
 import org.apache.flink.runtime.jobmaster.SlotInfo;
@@ -31,16 +30,20 @@ import org.apache.flink.runtime.taskexecutor.slot.SlotOffer;
 import org.apache.flink.runtime.taskmanager.LocalTaskManagerLocation;
 import org.apache.flink.runtime.taskmanager.TaskManagerLocation;
 import org.apache.flink.runtime.util.ResourceCounter;
+import org.apache.flink.testutils.junit.extensions.parameterized.ParameterizedTestExtension;
 import org.apache.flink.util.FlinkException;
 import org.apache.flink.util.function.QuadConsumer;
 
-import org.apache.flink.shaded.guava31.com.google.common.collect.Iterables;
+import org.apache.flink.shaded.guava32.com.google.common.collect.Iterables;
 
 import org.junit.jupiter.api.Test;
+import org.junit.jupiter.api.TestTemplate;
+import org.junit.jupiter.api.extension.ExtendWith;
 
 import javax.annotation.Nonnull;
 import javax.annotation.Nullable;
 
+import java.time.Duration;
 import java.util.ArrayList;
 import java.util.Collection;
 import java.util.HashMap;
@@ -58,45 +61,66 @@ import static org.apache.flink.runtime.jobmaster.slotpool.SlotPoolTestUtils.crea
 import static org.assertj.core.api.Assertions.assertThat;
 
 /** Tests for the {@link DefaultDeclarativeSlotPool}. */
-class DefaultDeclarativeSlotPoolTest {
+@ExtendWith(ParameterizedTestExtension.class)
+class DefaultDeclarativeSlotPoolTest extends DefaultDeclarativeSlotPoolTestBase {
 
     private static final ResourceProfile RESOURCE_PROFILE_1 =
             ResourceProfile.newBuilder().setCpuCores(1.7).build();
     private static final ResourceProfile RESOURCE_PROFILE_2 =
             ResourceProfile.newBuilder().setManagedMemoryMB(100).build();
 
-    @Test
+    @TestTemplate
     void testIncreasingResourceRequirementsWillSendResourceRequirementNotification()
             throws InterruptedException {
         final NewResourceRequirementsService requirementsListener =
                 new NewResourceRequirementsService();
-        final DeclarativeSlotPool slotPool = createDefaultDeclarativeSlotPool(requirementsListener);
+        final DefaultDeclarativeSlotPool slotPool =
+                createDefaultDeclarativeSlotPool(requirementsListener, slotRequestMaxInterval);
 
         final ResourceCounter increment1 = ResourceCounter.withResource(RESOURCE_PROFILE_1, 1);
         final ResourceCounter increment2 = createResourceRequirements();
         slotPool.increaseResourceRequirementsBy(increment1);
         slotPool.increaseResourceRequirementsBy(increment2);
 
-        assertThat(requirementsListener.takeResourceRequirements())
-                .isEqualTo(toResourceRequirements(increment1));
+        slotPool.tryWaitSlotRequestIsDone();
 
-        final ResourceCounter totalResources = increment1.add(increment2);
         assertThat(requirementsListener.takeResourceRequirements())
-                .isEqualTo(toResourceRequirements(totalResources));
-        assertThat(requirementsListener.hasNextResourceRequirements()).isFalse();
+                .isEqualTo(
+                        toResourceRequirements(getExpectedResourceCounter(increment1, increment2)));
+
+        if (slotRequestMaxInterval.toMillis() <= 0L) {
+            final ResourceCounter totalResources = increment1.add(increment2);
+            assertThat(requirementsListener.takeResourceRequirements())
+                    .isEqualTo(toResourceRequirements(totalResources));
+            assertThat(requirementsListener.hasNextResourceRequirements()).isFalse();
+        }
     }
 
-    @Test
+    private ResourceCounter getExpectedResourceCounter(ResourceCounter... resourceCounters) {
+        ResourceCounter result = ResourceCounter.empty();
+        if (slotRequestMaxInterval.toMillis() > 0L) {
+            for (ResourceCounter resourceCounter : resourceCounters) {
+                result = result.add(resourceCounter);
+            }
+            return result;
+        } else {
+            return resourceCounters[0];
+        }
+    }
+
+    @TestTemplate
     void testDecreasingResourceRequirementsWillSendResourceRequirementNotification()
             throws InterruptedException {
         final NewResourceRequirementsService requirementsListener =
                 new NewResourceRequirementsService();
         final DefaultDeclarativeSlotPool slotPool =
-                createDefaultDeclarativeSlotPool(requirementsListener);
+                createDefaultDeclarativeSlotPool(requirementsListener, slotRequestMaxInterval);
 
         final ResourceCounter increment = ResourceCounter.withResource(RESOURCE_PROFILE_1, 3);
         slotPool.increaseResourceRequirementsBy(increment);
 
+        slotPool.tryWaitSlotRequestIsDone();
+
         requirementsListener.takeResourceRequirements();
 
         final ResourceCounter decrement = ResourceCounter.withResource(RESOURCE_PROFILE_1, 2);
@@ -108,10 +132,9 @@ class DefaultDeclarativeSlotPoolTest {
         assertThat(requirementsListener.hasNextResourceRequirements()).isFalse();
     }
 
-    @Test
+    @TestTemplate
     void testGetResourceRequirements() {
-        final DefaultDeclarativeSlotPool slotPool =
-                DefaultDeclarativeSlotPoolBuilder.builder().build();
+        final DefaultDeclarativeSlotPool slotPool = createDefaultDeclarativeSlotPool();
 
         assertThat(slotPool.getResourceRequirements()).isEmpty();
 
@@ -119,11 +142,13 @@ class DefaultDeclarativeSlotPoolTest {
 
         slotPool.increaseResourceRequirementsBy(resourceRequirements);
 
+        slotPool.tryWaitSlotRequestIsDone();
+
         assertThat(slotPool.getResourceRequirements())
                 .isEqualTo(toResourceRequirements(resourceRequirements));
     }
 
-    @Test
+    @TestTemplate
     void testOfferSlots() throws InterruptedException {
         final NewSlotsService notifyNewSlots = new NewSlotsService();
         final DefaultDeclarativeSlotPool slotPool =
@@ -133,6 +158,8 @@ class DefaultDeclarativeSlotPoolTest {
 
         slotPool.increaseResourceRequirementsBy(resourceRequirements);
 
+        slotPool.tryWaitSlotRequestIsDone();
+
         Collection<SlotOffer> slotOffers =
                 createSlotOffersForResourceRequirements(resourceRequirements);
 
@@ -177,7 +204,7 @@ class DefaultDeclarativeSlotPoolTest {
                         });
     }
 
-    @Test
+    @TestTemplate
     void testDuplicateSlotOfferings() throws InterruptedException {
         final NewSlotsService notifyNewSlots = new NewSlotsService();
         final DefaultDeclarativeSlotPool slotPool =
@@ -187,6 +214,8 @@ class DefaultDeclarativeSlotPoolTest {
 
         slotPool.increaseResourceRequirementsBy(resourceRequirements);
 
+        slotPool.tryWaitSlotRequestIsDone();
+
         final Collection<SlotOffer> slotOffers =
                 createSlotOffersForResourceRequirements(resourceRequirements);
 
@@ -202,7 +231,7 @@ class DefaultDeclarativeSlotPoolTest {
         assertThat(notifyNewSlots.hasNextNewSlots()).isFalse();
     }
 
-    @Test
+    @TestTemplate
     void testOfferingTooManySlotsWillRejectSuperfluousSlots() {
         final NewSlotsService notifyNewSlots = new NewSlotsService();
         final DefaultDeclarativeSlotPool slotPool =
@@ -212,6 +241,8 @@ class DefaultDeclarativeSlotPoolTest {
 
         slotPool.increaseResourceRequirementsBy(resourceRequirements);
 
+        slotPool.tryWaitSlotRequestIsDone();
+
         final ResourceCounter increasedRequirements =
                 resourceRequirements.add(RESOURCE_PROFILE_1, 2);
 
@@ -235,13 +266,13 @@ class DefaultDeclarativeSlotPoolTest {
                                         .isEqualTo((long) resourceCount.getValue()));
     }
 
-    @Test
+    @TestTemplate
     void testReleaseSlotsRemovesSlots() throws InterruptedException {
         final NewResourceRequirementsService notifyNewResourceRequirements =
                 new NewResourceRequirementsService();
         final DefaultDeclarativeSlotPool slotPool =
-                createDefaultDeclarativeSlotPool(notifyNewResourceRequirements);
-
+                createDefaultDeclarativeSlotPool(
+                        notifyNewResourceRequirements, slotRequestMaxInterval);
         final LocalTaskManagerLocation taskManagerLocation = new LocalTaskManagerLocation();
         increaseRequirementsAndOfferSlotsToSlotPool(
                 slotPool, createResourceRequirements(), taskManagerLocation);
@@ -253,11 +284,9 @@ class DefaultDeclarativeSlotPoolTest {
         assertThat(slotPool.getAllSlotsInformation()).isEmpty();
     }
 
-    @Test
+    @TestTemplate
     void testReleaseSlotsReturnsSlot() {
-        final DefaultDeclarativeSlotPool slotPool =
-                DefaultDeclarativeSlotPoolBuilder.builder().build();
-
+        final DefaultDeclarativeSlotPool slotPool = createDefaultDeclarativeSlotPool();
         final ResourceCounter resourceRequirements = createResourceRequirements();
 
         final LocalTaskManagerLocation taskManagerLocation = new LocalTaskManagerLocation();
@@ -286,7 +315,7 @@ class DefaultDeclarativeSlotPoolTest {
                                 .collect(Collectors.toList()));
     }
 
-    @Test
+    @TestTemplate
     void testReleaseSlotsOnlyReturnsFulfilledRequirementsOfReservedSlots() {
         withSlotPoolContainingOneTaskManagerWithTwoSlotsWithUniqueResourceProfiles(
                 (slotPool, freeSlot, slotToReserve, taskManagerLocation) -> {
@@ -311,7 +340,7 @@ class DefaultDeclarativeSlotPoolTest {
                 });
     }
 
-    @Test
+    @TestTemplate
     void testReleaseSlotOnlyReturnsFulfilledRequirementsOfReservedSlots() {
         withSlotPoolContainingOneTaskManagerWithTwoSlotsWithUniqueResourceProfiles(
                 (slotPool, freeSlot, slotToReserve, ignored) -> {
@@ -336,11 +365,10 @@ class DefaultDeclarativeSlotPoolTest {
                 });
     }
 
-    private static void withSlotPoolContainingOneTaskManagerWithTwoSlotsWithUniqueResourceProfiles(
+    private void withSlotPoolContainingOneTaskManagerWithTwoSlotsWithUniqueResourceProfiles(
             QuadConsumer<DefaultDeclarativeSlotPool, SlotOffer, SlotOffer, TaskManagerLocation>
                     test) {
-        final DefaultDeclarativeSlotPool slotPool =
-                DefaultDeclarativeSlotPoolBuilder.builder().build();
+        final DefaultDeclarativeSlotPool slotPool = createDefaultDeclarativeSlotPool();
 
         final ResourceCounter resourceRequirements =
                 ResourceCounter.withResource(RESOURCE_PROFILE_1, 1).add(RESOURCE_PROFILE_2, 1);
@@ -366,7 +394,7 @@ class DefaultDeclarativeSlotPoolTest {
         test.accept(slotPool, slot1, slot2, taskManagerLocation);
     }
 
-    @Test
+    @TestTemplate
     void testReleaseSlotDecreasesFulfilledResourceRequirements() throws InterruptedException {
         final NewSlotsService notifyNewSlots = new NewSlotsService();
         final DefaultDeclarativeSlotPool slotPool =
@@ -387,7 +415,7 @@ class DefaultDeclarativeSlotPoolTest {
                 .isEqualTo(finalResourceRequirements);
     }
 
-    @Test
+    @TestTemplate
     void testReleaseSlotReturnsSlot() throws InterruptedException {
         final NewSlotsService notifyNewSlots = new NewSlotsService();
         final DefaultDeclarativeSlotPool slotPool =
@@ -417,13 +445,14 @@ class DefaultDeclarativeSlotPoolTest {
         assertThat(freedSlot).isEqualTo(physicalSlot.getAllocationId());
     }
 
-    @Test
+    @TestTemplate
     void testReturnIdleSlotsAfterTimeout() {
-        final Time idleSlotTimeout = Time.seconds(10);
+        final Duration idleSlotTimeout = Duration.ofSeconds(10);
         final long offerTime = 0;
         final DefaultDeclarativeSlotPool slotPool =
                 DefaultDeclarativeSlotPoolBuilder.builder()
                         .setIdleSlotTimeout(idleSlotTimeout)
+                        .setComponentMainThreadExecutor(componentMainThreadExecutor)
                         .build();
 
         final ResourceCounter resourceRequirements = createResourceRequirements();
@@ -443,7 +472,7 @@ class DefaultDeclarativeSlotPoolTest {
         // decrease the resource requirements so that slots are no longer needed
         slotPool.decreaseResourceRequirementsBy(resourceRequirements);
 
-        slotPool.releaseIdleSlots(offerTime + idleSlotTimeout.toMilliseconds());
+        slotPool.releaseIdleSlots(offerTime + idleSlotTimeout.toMillis());
 
         final Collection<AllocationID> freedSlots = freeSlotConsumer.drainFreedSlots();
 
@@ -461,13 +490,14 @@ class DefaultDeclarativeSlotPoolTest {
         assertThat(slotPool.getAllSlotsInformation()).isEmpty();
     }
 
-    @Test
+    @TestTemplate
     void testOnlyReturnExcessIdleSlots() {
-        final Time idleSlotTimeout = Time.seconds(10);
+        final Duration idleSlotTimeout = Duration.ofSeconds(10);
         final long offerTime = 0;
         final DefaultDeclarativeSlotPool slotPool =
                 DefaultDeclarativeSlotPoolBuilder.builder()
                         .setIdleSlotTimeout(idleSlotTimeout)
+                        .setComponentMainThreadExecutor(componentMainThreadExecutor)
                         .build();
 
         final ResourceCounter resourceRequirements = createResourceRequirements();
@@ -475,6 +505,9 @@ class DefaultDeclarativeSlotPoolTest {
                 createSlotOffersForResourceRequirements(resourceRequirements);
 
         slotPool.increaseResourceRequirementsBy(resourceRequirements);
+
+        slotPool.tryWaitSlotRequestIsDone();
+
         final Collection<SlotOffer> acceptedSlots =
                 SlotPoolTestUtils.offerSlots(slotPool, slotOffers);
 
@@ -483,13 +516,13 @@ class DefaultDeclarativeSlotPoolTest {
         final ResourceCounter excessRequirements = resourceRequirements.subtract(requiredResources);
         slotPool.decreaseResourceRequirementsBy(excessRequirements);
 
-        slotPool.releaseIdleSlots(offerTime + idleSlotTimeout.toMilliseconds());
+        slotPool.releaseIdleSlots(offerTime + idleSlotTimeout.toMillis());
 
         assertThat(acceptedSlots).isNotEmpty();
         assertThat(slotPool.getFulfilledResourceRequirements()).isEqualTo(requiredResources);
     }
 
-    @Test
+    @TestTemplate
     void testFreedSlotWillBeUsedToFulfillOutstandingResourceRequirementsOfSameProfile()
             throws InterruptedException {
         final NewSlotsService notifyNewSlots = new NewSlotsService();
@@ -553,9 +586,9 @@ class DefaultDeclarativeSlotPoolTest {
                                         .isEqualTo(RESOURCE_PROFILE_1));
     }
 
-    @Test
+    @TestTemplate
     void testFreedSlotWillRemainAssignedToMatchedResourceProfile() {
-        final DefaultDeclarativeSlotPool slotPool = new DefaultDeclarativeSlotPoolBuilder().build();
+        final DefaultDeclarativeSlotPool slotPool = createDefaultDeclarativeSlotPool();
 
         final ResourceProfile largeResourceProfile =
                 ResourceProfile.newBuilder().setManagedMemoryMB(1024).build();
@@ -564,13 +597,16 @@ class DefaultDeclarativeSlotPoolTest {
 
         slotPool.increaseResourceRequirementsBy(
                 ResourceCounter.withResource(largeResourceProfile, 1));
+
+        slotPool.tryWaitSlotRequestIsDone();
+
         SlotPoolTestUtils.offerSlots(
                 slotPool,
                 createSlotOffersForResourceRequirements(
                         ResourceCounter.withResource(ResourceProfile.ANY, 1)));
 
-        final SlotInfo slot =
-                slotPool.getFreeSlotInfoTracker().getFreeSlotsInformation().iterator().next();
+        final PhysicalSlot slot =
+                slotPool.getFreeSlotTracker().getFreeSlotsInformation().iterator().next();
 
         slotPool.reserveFreeSlot(slot.getAllocationId(), largeResourceProfile);
         assertThat(
@@ -580,6 +616,9 @@ class DefaultDeclarativeSlotPoolTest {
 
         slotPool.increaseResourceRequirementsBy(
                 ResourceCounter.withResource(smallResourceProfile, 1));
+
+        slotPool.tryWaitSlotRequestIsDone();
+
         slotPool.decreaseResourceRequirementsBy(
                 ResourceCounter.withResource(largeResourceProfile, 1));
 
@@ -598,9 +637,9 @@ class DefaultDeclarativeSlotPoolTest {
                 .isEqualTo(0);
     }
 
-    @Test
+    @TestTemplate
     void testReserveFreeSlotForResourceUpdatesAvailableResourcesAndRequirements() {
-        final DefaultDeclarativeSlotPool slotPool = new DefaultDeclarativeSlotPoolBuilder().build();
+        final DefaultDeclarativeSlotPool slotPool = createDefaultDeclarativeSlotPool();
 
         final ResourceProfile largeResourceProfile =
                 ResourceProfile.newBuilder().setManagedMemoryMB(1024).build();
@@ -608,6 +647,9 @@ class DefaultDeclarativeSlotPoolTest {
 
         slotPool.increaseResourceRequirementsBy(
                 ResourceCounter.withResource(largeResourceProfile, 1));
+
+        slotPool.tryWaitSlotRequestIsDone();
+
         SlotPoolTestUtils.offerSlots(
                 slotPool,
                 createSlotOffersForResourceRequirements(
@@ -615,8 +657,10 @@ class DefaultDeclarativeSlotPoolTest {
         slotPool.increaseResourceRequirementsBy(
                 ResourceCounter.withResource(smallResourceProfile, 1));
 
-        final SlotInfo largeSlot =
-                slotPool.getFreeSlotInfoTracker().getFreeSlotsInformation().stream()
+        slotPool.tryWaitSlotRequestIsDone();
+
+        final PhysicalSlot largeSlot =
+                slotPool.getFreeSlotTracker().getFreeSlotsInformation().stream()
                         .filter(slot -> slot.getResourceProfile().equals(largeResourceProfile))
                         .findFirst()
                         .get();
@@ -638,7 +682,7 @@ class DefaultDeclarativeSlotPoolTest {
 
     @Test
     void testSetResourceRequirementsForInitialResourceRequirements() {
-        final DefaultDeclarativeSlotPool slotPool = new DefaultDeclarativeSlotPoolBuilder().build();
+        final DefaultDeclarativeSlotPool slotPool = createDefaultDeclarativeSlotPool();
 
         final ResourceCounter resourceRequirements =
                 ResourceCounter.withResource(RESOURCE_PROFILE_1, 2);
@@ -651,7 +695,7 @@ class DefaultDeclarativeSlotPoolTest {
 
     @Test
     void testSetResourceRequirementsOverwritesPreviousValue() {
-        final DefaultDeclarativeSlotPool slotPool = new DefaultDeclarativeSlotPoolBuilder().build();
+        final DefaultDeclarativeSlotPool slotPool = createDefaultDeclarativeSlotPool();
 
         slotPool.setResourceRequirements(ResourceCounter.withResource(RESOURCE_PROFILE_1, 1));
 
@@ -663,9 +707,9 @@ class DefaultDeclarativeSlotPoolTest {
                 .isEqualTo(toResourceRequirements(resourceRequirements));
     }
 
-    @Test
+    @TestTemplate
     void testRegisterSlotsDoesNotAffectRequirements() {
-        final DefaultDeclarativeSlotPool slotPool = new DefaultDeclarativeSlotPoolBuilder().build();
+        final DefaultDeclarativeSlotPool slotPool = createDefaultDeclarativeSlotPool();
 
         final ResourceProfile slotProfile = RESOURCE_PROFILE_1;
         final ResourceProfile requestedProfile = ResourceProfile.UNKNOWN;
@@ -678,11 +722,14 @@ class DefaultDeclarativeSlotPoolTest {
                 0L);
 
         final AllocationID allocationId =
-                slotPool.getFreeSlotInfoTracker().getAvailableSlots().iterator().next();
+                slotPool.getFreeSlotTracker().getAvailableSlots().iterator().next();
 
         assertThat(slotPool.getResourceRequirements()).isEmpty();
 
         slotPool.increaseResourceRequirementsBy(ResourceCounter.withResource(requestedProfile, 1));
+
+        slotPool.tryWaitSlotRequestIsDone();
+
         slotPool.reserveFreeSlot(allocationId, requestedProfile);
         slotPool.freeReservedSlot(allocationId, null, 1L);
         slotPool.decreaseResourceRequirementsBy(ResourceCounter.withResource(requestedProfile, 1));
@@ -711,15 +758,17 @@ class DefaultDeclarativeSlotPoolTest {
     }
 
     @Nonnull
-    private static DefaultDeclarativeSlotPool createDefaultDeclarativeSlotPool(
-            NewResourceRequirementsService requirementsListener) {
+    private DefaultDeclarativeSlotPool createDefaultDeclarativeSlotPool(
+            NewResourceRequirementsService requirementsListener, Duration slotRequestMaxInterval) {
         return DefaultDeclarativeSlotPoolBuilder.builder()
+                .setSlotRequestMaxInterval(slotRequestMaxInterval)
                 .setNotifyNewResourceRequirements(requirementsListener)
+                .setComponentMainThreadExecutor(componentMainThreadExecutor)
                 .build();
     }
 
     @Nonnull
-    private static DefaultDeclarativeSlotPool createDefaultDeclarativeSlotPoolWithNewSlotsListener(
+    private DefaultDeclarativeSlotPool createDefaultDeclarativeSlotPoolWithNewSlotsListener(
             DeclarativeSlotPool.NewSlotsListener newSlotsListener) {
         final DefaultDeclarativeSlotPool declarativeSlotPool = createDefaultDeclarativeSlotPool();
 
@@ -728,8 +777,10 @@ class DefaultDeclarativeSlotPoolTest {
     }
 
     @Nonnull
-    private static DefaultDeclarativeSlotPool createDefaultDeclarativeSlotPool() {
-        return DefaultDeclarativeSlotPoolBuilder.builder().build();
+    private DefaultDeclarativeSlotPool createDefaultDeclarativeSlotPool() {
+        return DefaultDeclarativeSlotPoolBuilder.builder()
+                .setComponentMainThreadExecutor(componentMainThreadExecutor)
+                .build();
     }
 
     @Nonnull
@@ -752,6 +803,8 @@ class DefaultDeclarativeSlotPoolTest {
 
         slotPool.increaseResourceRequirementsBy(resourceRequirements);
 
+        slotPool.tryWaitSlotRequestIsDone();
+
         return slotPool.offerSlots(
                 slotOffers,
                 taskManagerLocation == null ? new LocalTaskManagerLocation() : taskManagerLocation,
