@@ -19,7 +19,6 @@
 package org.apache.flink.runtime.rest;
 
 import org.apache.flink.api.common.JobID;
-import org.apache.flink.api.common.time.Time;
 import org.apache.flink.configuration.Configuration;
 import org.apache.flink.configuration.RestOptions;
 import org.apache.flink.configuration.SecurityOptions;
@@ -95,6 +94,7 @@ import java.net.URL;
 import java.nio.charset.StandardCharsets;
 import java.nio.file.Files;
 import java.nio.file.Path;
+import java.time.Duration;
 import java.util.Arrays;
 import java.util.Collection;
 import java.util.Collections;
@@ -121,7 +121,7 @@ public class RestServerEndpointITCase {
     private static final JobID PATH_JOB_ID = new JobID();
     private static final JobID QUERY_JOB_ID = new JobID();
     private static final String JOB_ID_KEY = "jobid";
-    private static final Time timeout = Time.seconds(10L);
+    private static final Duration timeout = Duration.ofSeconds(10L);
     private static final int TEST_REST_MAX_CONTENT_LENGTH = 4096;
 
     @RegisterExtension
@@ -262,7 +262,7 @@ public class RestServerEndpointITCase {
         }
 
         if (serverEndpoint != null) {
-            serverEndpoint.closeAsync().get(timeout.getSize(), timeout.getUnit());
+            serverEndpoint.closeAsync().get(timeout.toMillis(), TimeUnit.MILLISECONDS);
             serverEndpoint = null;
         }
     }
@@ -604,8 +604,8 @@ public class RestServerEndpointITCase {
         // Finish the in-flight request.
         sync.releaseBlocker();
 
-        request.get(timeout.getSize(), timeout.getUnit());
-        closeRestServerEndpointFuture.get(timeout.getSize(), timeout.getUnit());
+        request.get(timeout.toMillis(), TimeUnit.MILLISECONDS);
+        closeRestServerEndpointFuture.get(timeout.toMillis(), TimeUnit.MILLISECONDS);
     }
 
     /** Tests that new requests are ignored after a handler is shut down. */
@@ -629,7 +629,7 @@ public class RestServerEndpointITCase {
                 sendRequestToTestHandler(new TestRequest(1));
 
         try {
-            request.get(timeout.getSize(), timeout.getUnit());
+            request.get(timeout.toMillis(), TimeUnit.MILLISECONDS);
             fail("Expected a ConnectionClosedException");
         } catch (ExecutionException ee) {
             if (!ExceptionUtils.findThrowable(ee, ConnectionClosedException.class).isPresent()) {
@@ -781,7 +781,7 @@ public class RestServerEndpointITCase {
 
         private Function<Integer, CompletableFuture<TestResponse>> handlerBody;
 
-        TestHandler(GatewayRetriever<RestfulGateway> leaderRetriever, Time timeout) {
+        TestHandler(GatewayRetriever<RestfulGateway> leaderRetriever, Duration timeout) {
             super(leaderRetriever, timeout, Collections.emptyMap(), new TestHeaders());
         }
 
@@ -997,7 +997,7 @@ public class RestServerEndpointITCase {
 
         private TestUploadHandler(
                 final GatewayRetriever<? extends RestfulGateway> leaderRetriever,
-                final Time timeout) {
+                final Duration timeout) {
             super(leaderRetriever, timeout, Collections.emptyMap(), TestUploadHeaders.INSTANCE);
         }
 
@@ -1043,7 +1043,7 @@ public class RestServerEndpointITCase {
 
         TestVersionHandler(
                 final GatewayRetriever<? extends RestfulGateway> leaderRetriever,
-                final Time timeout) {
+                final Duration timeout) {
             super(leaderRetriever, timeout, Collections.emptyMap(), TestVersionHeaders.INSTANCE);
         }
 
