@@ -19,7 +19,6 @@
 package org.apache.flink.runtime.rest.handler.legacy;
 
 import org.apache.flink.api.common.JobID;
-import org.apache.flink.api.common.time.Time;
 import org.apache.flink.runtime.messages.FlinkJobNotFoundException;
 import org.apache.flink.runtime.rest.handler.legacy.utils.ArchivedExecutionGraphBuilder;
 import org.apache.flink.runtime.scheduler.ExecutionGraphInfo;
@@ -33,6 +32,7 @@ import org.apache.flink.util.concurrent.FutureUtils;
 import org.junit.jupiter.api.BeforeAll;
 import org.junit.jupiter.api.Test;
 
+import java.time.Duration;
 import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.Collection;
@@ -62,8 +62,8 @@ class DefaultExecutionGraphCacheTest {
     /** Tests that we can cache AccessExecutionGraphs over multiple accesses. */
     @Test
     void testExecutionGraphCaching() throws Exception {
-        final Time timeout = Time.milliseconds(100L);
-        final Time timeToLive = Time.hours(1L);
+        final Duration timeout = Duration.ofMillis(100L);
+        final Duration timeToLive = Duration.ofHours(1L);
 
         final CountingRestfulGateway restfulGateway =
                 createCountingRestfulGateway(
@@ -93,8 +93,8 @@ class DefaultExecutionGraphCacheTest {
     /** Tests that an AccessExecutionGraph is invalidated after its TTL expired. */
     @Test
     void testExecutionGraphEntryInvalidation() throws Exception {
-        final Time timeout = Time.milliseconds(100L);
-        final Time timeToLive = Time.milliseconds(1L);
+        final Duration timeout = Duration.ofMillis(100L);
+        final Duration timeToLive = Duration.ofMillis(1L);
 
         final CountingRestfulGateway restfulGateway =
                 createCountingRestfulGateway(
@@ -112,7 +112,7 @@ class DefaultExecutionGraphCacheTest {
                     .isEqualTo(expectedExecutionGraphInfo);
 
             // sleep for the TTL
-            Thread.sleep(timeToLive.toMilliseconds() * 5L);
+            Thread.sleep(timeToLive.toMillis() * 5L);
 
             CompletableFuture<ExecutionGraphInfo> executionGraphInfoFuture2 =
                     executionGraphCache.getExecutionGraphInfo(expectedJobId, restfulGateway);
@@ -131,8 +131,8 @@ class DefaultExecutionGraphCacheTest {
      */
     @Test
     void testImmediateCacheInvalidationAfterFailure() throws Exception {
-        final Time timeout = Time.milliseconds(100L);
-        final Time timeToLive = Time.hours(1L);
+        final Duration timeout = Duration.ofMillis(100L);
+        final Duration timeToLive = Duration.ofHours(1L);
 
         // let's first answer with a JobNotFoundException and then only with the correct result
         final CountingRestfulGateway restfulGateway =
@@ -165,8 +165,8 @@ class DefaultExecutionGraphCacheTest {
      */
     @Test
     void testCacheEntryCleanup() throws Exception {
-        final Time timeout = Time.milliseconds(100L);
-        final Time timeToLive = Time.milliseconds(1L);
+        final Duration timeout = Duration.ofMillis(100L);
+        final Duration timeToLive = Duration.ofMillis(1L);
         final JobID expectedJobId2 = new JobID();
         final ExecutionGraphInfo expectedExecutionGraphInfo2 =
                 new ExecutionGraphInfo(new ArchivedExecutionGraphBuilder().build());
@@ -208,7 +208,7 @@ class DefaultExecutionGraphCacheTest {
 
             assertThat(requestJobCalls.get()).isEqualTo(2);
 
-            Thread.sleep(timeToLive.toMilliseconds());
+            Thread.sleep(timeToLive.toMillis());
 
             executionGraphCache.cleanup();
 
@@ -219,8 +219,8 @@ class DefaultExecutionGraphCacheTest {
     /** Tests that concurrent accesses only trigger a single AccessExecutionGraph request. */
     @Test
     void testConcurrentAccess() throws Exception {
-        final Time timeout = Time.milliseconds(100L);
-        final Time timeToLive = Time.hours(1L);
+        final Duration timeout = Duration.ofMillis(100L);
+        final Duration timeToLive = Duration.ofHours(1L);
 
         final CountingRestfulGateway restfulGateway =
                 createCountingRestfulGateway(
@@ -273,7 +273,7 @@ class DefaultExecutionGraphCacheTest {
 
     /**
      * {@link RestfulGateway} implementation which counts the number of {@link #requestJob(JobID,
-     * Time)} calls.
+     * Duration)} calls.
      */
     private static class CountingRestfulGateway extends TestingRestfulGateway {
 
@@ -290,7 +290,7 @@ class DefaultExecutionGraphCacheTest {
 
         @Override
         public CompletableFuture<ExecutionGraphInfo> requestExecutionGraphInfo(
-                JobID jobId, Time timeout) {
+                JobID jobId, Duration timeout) {
             assertThat(jobId).isEqualTo(expectedJobId);
             numRequestJobCalls.incrementAndGet();
             return super.requestExecutionGraphInfo(jobId, timeout);
