@@ -57,6 +57,7 @@ import org.apache.flink.runtime.jobgraph.tasks.CheckpointCoordinatorConfiguratio
 import org.apache.flink.runtime.metrics.groups.JobManagerJobMetricGroup;
 import org.apache.flink.runtime.query.KvStateLocationRegistry;
 import org.apache.flink.runtime.scheduler.InternalFailuresListener;
+import org.apache.flink.runtime.scheduler.VertexParallelismStore;
 import org.apache.flink.runtime.scheduler.exceptionhistory.TestingAccessExecution;
 import org.apache.flink.runtime.scheduler.strategy.SchedulingTopology;
 import org.apache.flink.runtime.scheduler.strategy.TestingSchedulingTopology;
@@ -78,6 +79,8 @@ import java.util.List;
 import java.util.Map;
 import java.util.Optional;
 import java.util.concurrent.CompletableFuture;
+import java.util.stream.Collectors;
+import java.util.stream.StreamSupport;
 
 /**
  * Mocked ExecutionGraph which (partially) tracks the job status, and provides some basic mocks to
@@ -165,7 +168,8 @@ class StateTrackingMockExecutionGraph implements ExecutionGraph {
 
     @Override
     public Map<JobVertexID, ExecutionJobVertex> getAllVertices() {
-        return Collections.emptyMap();
+        return StreamSupport.stream(getVerticesTopologically().spliterator(), false)
+                .collect(Collectors.toMap(ExecutionJobVertex::getJobVertexId, v -> v));
     }
 
     @Override
@@ -183,6 +187,11 @@ class StateTrackingMockExecutionGraph implements ExecutionGraph {
         return "";
     }
 
+    @Override
+    public String getStreamGraphJson() {
+        return null;
+    }
+
     @Override
     public void setJsonPlan(String jsonPlan) {}
 
@@ -245,6 +254,11 @@ class StateTrackingMockExecutionGraph implements ExecutionGraph {
         return Optional.empty();
     }
 
+    @Override
+    public int getPendingOperatorCount() {
+        return 0;
+    }
+
     @Override
     public StringifiedAccumulatorResult[] getAccumulatorResultsStringified() {
         return new StringifiedAccumulatorResult[0];
@@ -294,12 +308,6 @@ class StateTrackingMockExecutionGraph implements ExecutionGraph {
         throw new UnsupportedOperationException();
     }
 
-    @Nullable
-    @Override
-    public CheckpointStatsTracker getCheckpointStatsTracker() {
-        throw new UnsupportedOperationException();
-    }
-
     @Override
     public KvStateLocationRegistry getKvStateLocationRegistry() {
         throw new UnsupportedOperationException();
@@ -407,6 +415,15 @@ class StateTrackingMockExecutionGraph implements ExecutionGraph {
         throw new UnsupportedOperationException();
     }
 
+    @Override
+    public void addNewJobVertices(
+            List<JobVertex> sortedJobVertices,
+            JobManagerJobMetricGroup jobManagerJobMetricGroup,
+            VertexParallelismStore newVerticesParallelismStore)
+            throws JobException {
+        throw new UnsupportedOperationException();
+    }
+
     public void registerExecution(TestingAccessExecution execution) {
         executions.put(execution.getAttemptId(), execution);
     }
