@@ -23,12 +23,14 @@ import org.apache.flink.core.memory.DataInputViewStreamWrapper;
 import org.apache.flink.core.memory.DataOutputView;
 import org.apache.flink.core.memory.DataOutputViewStreamWrapper;
 
-import org.junit.Assert;
-import org.junit.Test;
+import org.junit.jupiter.api.Test;
 
 import java.io.IOException;
 
-public class KeyedStateCheckpointOutputStreamTest {
+import static org.assertj.core.api.Assertions.assertThat;
+import static org.assertj.core.api.Assertions.assertThatThrownBy;
+
+class KeyedStateCheckpointOutputStreamTest {
 
     private static final int STREAM_CAPACITY = 128;
 
@@ -51,61 +53,57 @@ public class KeyedStateCheckpointOutputStreamTest {
     }
 
     @Test
-    public void testCloseNotPropagated() throws Exception {
+    void testCloseNotPropagated() throws Exception {
         KeyedStateCheckpointOutputStream stream = createStream(new KeyGroupRange(0, 0));
         TestMemoryCheckpointOutputStream innerStream =
                 (TestMemoryCheckpointOutputStream) stream.getDelegate();
         stream.close();
-        Assert.assertFalse(innerStream.isClosed());
+        assertThat(innerStream.isClosed()).isFalse();
     }
 
     @Test
-    public void testEmptyKeyedStream() throws Exception {
+    void testEmptyKeyedStream() throws Exception {
         final KeyGroupRange keyRange = new KeyGroupRange(0, 2);
         KeyedStateCheckpointOutputStream stream = createStream(keyRange);
         TestMemoryCheckpointOutputStream innerStream =
                 (TestMemoryCheckpointOutputStream) stream.getDelegate();
         KeyGroupsStateHandle emptyHandle = stream.closeAndGetHandle();
-        Assert.assertTrue(innerStream.isClosed());
-        Assert.assertEquals(null, emptyHandle);
+        assertThat(innerStream.isClosed()).isTrue();
+        assertThat(emptyHandle).isNull();
     }
 
     @Test
-    public void testWriteReadRoundtrip() throws Exception {
+    void testWriteReadRoundtrip() throws Exception {
         final KeyGroupRange keyRange = new KeyGroupRange(0, 2);
         KeyedStateCheckpointOutputStream stream = createStream(keyRange);
         KeyGroupsStateHandle fullHandle = writeAllTestKeyGroups(stream, keyRange);
-        Assert.assertNotNull(fullHandle);
+        assertThat(fullHandle).isNotNull();
 
         verifyRead(fullHandle, keyRange);
     }
 
     @Test
-    public void testWriteKeyGroupTracking() throws Exception {
+    void testWriteKeyGroupTracking() throws Exception {
         final KeyGroupRange keyRange = new KeyGroupRange(0, 2);
         KeyedStateCheckpointOutputStream stream = createStream(keyRange);
 
-        try {
-            stream.startNewKeyGroup(4711);
-            Assert.fail();
-        } catch (IllegalArgumentException expected) {
-            // good
-        }
+        assertThatThrownBy(() -> stream.startNewKeyGroup(4711))
+                .isInstanceOf(IllegalArgumentException.class);
 
-        Assert.assertEquals(-1, stream.getCurrentKeyGroup());
+        assertThat(stream.getCurrentKeyGroup()).isEqualTo(-1);
 
         DataOutputView dov = new DataOutputViewStreamWrapper(stream);
         int previous = -1;
         for (int kg : keyRange) {
-            Assert.assertFalse(stream.isKeyGroupAlreadyStarted(kg));
-            Assert.assertFalse(stream.isKeyGroupAlreadyFinished(kg));
+            assertThat(stream.isKeyGroupAlreadyStarted(kg)).isFalse();
+            assertThat(stream.isKeyGroupAlreadyFinished(kg)).isFalse();
             stream.startNewKeyGroup(kg);
             if (-1 != previous) {
-                Assert.assertTrue(stream.isKeyGroupAlreadyStarted(previous));
-                Assert.assertTrue(stream.isKeyGroupAlreadyFinished(previous));
+                assertThat(stream.isKeyGroupAlreadyStarted(previous)).isTrue();
+                assertThat(stream.isKeyGroupAlreadyFinished(previous)).isTrue();
             }
-            Assert.assertTrue(stream.isKeyGroupAlreadyStarted(kg));
-            Assert.assertFalse(stream.isKeyGroupAlreadyFinished(kg));
+            assertThat(stream.isKeyGroupAlreadyStarted(kg)).isTrue();
+            assertThat(stream.isKeyGroupAlreadyFinished(kg)).isFalse();
             dov.writeInt(kg);
             previous = kg;
         }
@@ -115,17 +113,12 @@ public class KeyedStateCheckpointOutputStreamTest {
         verifyRead(fullHandle, keyRange);
 
         for (int kg : keyRange) {
-            try {
-                stream.startNewKeyGroup(kg);
-                Assert.fail();
-            } catch (IOException ex) {
-                // required
-            }
+            assertThatThrownBy(() -> stream.startNewKeyGroup(kg)).isInstanceOf(IOException.class);
         }
     }
 
     @Test
-    public void testReadWriteMissingKeyGroups() throws Exception {
+    void testReadWriteMissingKeyGroups() throws Exception {
         final KeyGroupRange keyRange = new KeyGroupRange(0, 2);
         KeyedStateCheckpointOutputStream stream = createStream(keyRange);
 
@@ -142,13 +135,13 @@ public class KeyedStateCheckpointOutputStreamTest {
                 long off = fullHandle.getOffsetForKeyGroup(kg);
                 if (off >= 0) {
                     in.seek(off);
-                    Assert.assertEquals(1, div.readInt());
+                    assertThat(div.readInt()).isOne();
                     ++count;
                 }
             }
         }
 
-        Assert.assertEquals(1, count);
+        assertThat(count).isOne();
     }
 
     private static void verifyRead(KeyGroupsStateHandle fullHandle, KeyGroupRange keyRange)
@@ -159,11 +152,11 @@ public class KeyedStateCheckpointOutputStreamTest {
             for (int kg : fullHandle.getKeyGroupRange()) {
                 long off = fullHandle.getOffsetForKeyGroup(kg);
                 in.seek(off);
-                Assert.assertEquals(kg, div.readInt());
+                assertThat(div.readInt()).isEqualTo(kg);
                 ++count;
             }
         }
 
-        Assert.assertEquals(keyRange.getNumberOfKeyGroups(), count);
+        assertThat(count).isEqualTo(keyRange.getNumberOfKeyGroups());
     }
 }
