@@ -47,8 +47,8 @@ import org.apache.flink.runtime.execution.Environment;
 import org.apache.flink.runtime.state.filemerging.FileMergingOperatorStreamStateHandle;
 import org.apache.flink.runtime.state.filesystem.AbstractFsCheckpointStorageAccess;
 import org.apache.flink.runtime.state.filesystem.FsMergingCheckpointStorageLocation;
+import org.apache.flink.runtime.state.hashmap.HashMapStateBackend;
 import org.apache.flink.runtime.state.memory.MemCheckpointStreamFactory;
-import org.apache.flink.runtime.state.memory.MemoryStateBackend;
 import org.apache.flink.runtime.util.BlockerCheckpointStreamFactory;
 import org.apache.flink.runtime.util.BlockingCheckpointOutputStream;
 import org.apache.flink.runtime.util.TestingUserCodeClassLoader;
@@ -95,7 +95,7 @@ class OperatorStateBackendTest {
     @Test
     void testCreateOnAbstractStateBackend() throws Exception {
         // we use the memory state backend as a subclass of the AbstractStateBackend
-        final AbstractStateBackend abstractStateBackend = new MemoryStateBackend();
+        final AbstractStateBackend abstractStateBackend = new HashMapStateBackend();
         CloseableRegistry cancelStreamRegistry = new CloseableRegistry();
         Environment env = createMockEnvironment();
         final OperatorStateBackend operatorStateBackend =
@@ -124,7 +124,7 @@ class OperatorStateBackendTest {
                 .isFalse();
 
         final ExecutionConfig cfg = new ExecutionConfig();
-        cfg.getSerializerConfig()
+        ((SerializerConfigImpl) cfg.getSerializerConfig())
                 .registerTypeWithKryoSerializer(
                         registeredType, com.esotericsoftware.kryo.serializers.JavaSerializer.class);
 
@@ -256,7 +256,7 @@ class OperatorStateBackendTest {
     @Test
     void testCorrectClassLoaderUsedOnSnapshot() throws Exception {
 
-        AbstractStateBackend abstractStateBackend = new MemoryStateBackend(4096);
+        AbstractStateBackend abstractStateBackend = new HashMapStateBackend();
 
         final Environment env = createMockEnvironment();
         CloseableRegistry cancelStreamRegistry = new CloseableRegistry();
@@ -408,7 +408,7 @@ class OperatorStateBackendTest {
 
     @Test
     void testSnapshotEmpty() throws Exception {
-        final AbstractStateBackend abstractStateBackend = new MemoryStateBackend(4096);
+        final AbstractStateBackend abstractStateBackend = new HashMapStateBackend();
         CloseableRegistry cancelStreamRegistry = new CloseableRegistry();
 
         Environment env = createMockEnvironment();
@@ -434,7 +434,7 @@ class OperatorStateBackendTest {
 
     @Test
     void testFileMergingSnapshotEmpty(@TempDir File tmpFolder) throws Exception {
-        final AbstractStateBackend abstractStateBackend = new MemoryStateBackend(4096);
+        final AbstractStateBackend abstractStateBackend = new HashMapStateBackend();
         CloseableRegistry cancelStreamRegistry = new CloseableRegistry();
 
         Environment env = createMockEnvironment();
@@ -491,7 +491,7 @@ class OperatorStateBackendTest {
 
     @Test
     void testSnapshotBroadcastStateWithEmptyOperatorState() throws Exception {
-        final AbstractStateBackend abstractStateBackend = new MemoryStateBackend(4096);
+        final AbstractStateBackend abstractStateBackend = new HashMapStateBackend();
 
         Environment env = createMockEnvironment();
         CloseableRegistry cancelStreamRegistry = new CloseableRegistry();
@@ -613,7 +613,7 @@ class OperatorStateBackendTest {
 
     @Test
     void testSnapshotRestoreSync() throws Exception {
-        AbstractStateBackend abstractStateBackend = new MemoryStateBackend(2 * 4096);
+        AbstractStateBackend abstractStateBackend = new HashMapStateBackend();
 
         Environment env1 = createMockEnvironment();
         CloseableRegistry cancelStreamRegistry1 = new CloseableRegistry();
@@ -866,7 +866,7 @@ class OperatorStateBackendTest {
             operatorStateBackend.close();
             operatorStateBackend.dispose();
 
-            AbstractStateBackend abstractStateBackend = new MemoryStateBackend(4096);
+            AbstractStateBackend abstractStateBackend = new HashMapStateBackend();
             CloseableRegistry cancelStreamRegistry = new CloseableRegistry();
 
             Environment env = createMockEnvironment();
