@@ -37,6 +37,7 @@ import org.apache.flink.runtime.state.SharedStateRegistryImpl;
 import org.apache.flink.runtime.state.SnapshotResult;
 import org.apache.flink.runtime.state.StateBackend;
 import org.apache.flink.runtime.state.internal.InternalKvState;
+import org.apache.flink.runtime.state.storage.JobManagerCheckpointStorage;
 import org.apache.flink.util.Preconditions;
 
 import javax.annotation.Nonnull;
@@ -75,14 +76,7 @@ public abstract class StateBackendTestContext {
     protected abstract StateBackend createStateBackend();
 
     protected CheckpointStorage createCheckpointStorage() {
-        if (stateBackend instanceof CheckpointStorage) {
-            return (CheckpointStorage) stateBackend;
-        }
-
-        throw new IllegalStateException(
-                "The state backend under test does not implement CheckpointStorage."
-                        + "Please override 'createCheckpointStorage' and provide an appropriate"
-                        + "checkpoint storage instance");
+        return new JobManagerCheckpointStorage();
     }
 
     private CheckpointStreamFactory createCheckpointStreamFactory() {
@@ -95,11 +89,12 @@ public abstract class StateBackendTestContext {
         }
     }
 
-    void createAndRestoreKeyedStateBackend(KeyedStateHandle snapshot) {
+    void createAndRestoreKeyedStateBackend(KeyedStateHandle snapshot) throws IOException {
         createAndRestoreKeyedStateBackend(NUMBER_OF_KEY_GROUPS, snapshot);
     }
 
-    void createAndRestoreKeyedStateBackend(int numberOfKeyGroups, KeyedStateHandle snapshot) {
+    void createAndRestoreKeyedStateBackend(int numberOfKeyGroups, KeyedStateHandle snapshot)
+            throws IOException {
         Collection<KeyedStateHandle> stateHandles;
         if (snapshot == null) {
             stateHandles = Collections.emptyList();
@@ -108,6 +103,8 @@ public abstract class StateBackendTestContext {
             stateHandles.add(snapshot);
         }
         env = MockEnvironment.builder().build();
+        env.setCheckpointStorageAccess(
+                createCheckpointStorage().createCheckpointStorage(new JobID()));
         try {
             disposeKeyedStateBackend();
             keyedStateBackend =
