@@ -21,43 +21,28 @@ package org.apache.flink.runtime.util.bash;
 import org.apache.flink.api.common.cache.DistributedCache;
 import org.apache.flink.configuration.ConfigOption;
 import org.apache.flink.configuration.Configuration;
+import org.apache.flink.configuration.ConfigurationFileMigrationUtils;
 import org.apache.flink.configuration.ConfigurationUtils;
 import org.apache.flink.configuration.GlobalConfiguration;
 import org.apache.flink.configuration.PipelineOptions;
-import org.apache.flink.testutils.junit.extensions.parameterized.Parameter;
-import org.apache.flink.testutils.junit.extensions.parameterized.ParameterizedTestExtension;
-import org.apache.flink.testutils.junit.extensions.parameterized.Parameters;
 import org.apache.flink.testutils.junit.utils.TempDirUtils;
 
-import org.junit.jupiter.api.AfterAll;
 import org.junit.jupiter.api.BeforeEach;
 import org.junit.jupiter.api.Test;
-import org.junit.jupiter.api.TestTemplate;
-import org.junit.jupiter.api.extension.ExtendWith;
 import org.junit.jupiter.api.io.TempDir;
 
 import java.io.File;
 import java.io.FileWriter;
 import java.io.IOException;
-import java.util.Arrays;
-import java.util.Collection;
 import java.util.List;
-import java.util.stream.Collectors;
+import java.util.Map;
 
 import static org.apache.flink.configuration.ConfigOptions.key;
 import static org.assertj.core.api.Assertions.assertThat;
 
 /** Tests for {@link FlinkConfigLoader}. */
-@ExtendWith(ParameterizedTestExtension.class)
 public class FlinkConfigLoaderTest {
 
-    @Parameter public boolean standardYaml;
-
-    @Parameters(name = "standardYaml: {0}")
-    public static Collection<Boolean> parameters() {
-        return Arrays.asList(true, false);
-    }
-
     private static final String TEST_CONFIG_KEY = "test.key";
     private static final String TEST_CONFIG_VALUE = "test_value";
 
@@ -65,105 +50,71 @@ public class FlinkConfigLoaderTest {
 
     @BeforeEach
     void setUp() throws IOException {
-        File flinkConfFile;
-        if (standardYaml) {
-            flinkConfFile =
-                    TempDirUtils.newFile(
-                            confDir.toAbsolutePath(), GlobalConfiguration.FLINK_CONF_FILENAME);
-        } else {
-            flinkConfFile =
-                    TempDirUtils.newFile(
-                            confDir.toAbsolutePath(),
-                            GlobalConfiguration.LEGACY_FLINK_CONF_FILENAME);
-        }
+        File flinkConfFile =
+                TempDirUtils.newFile(
+                        confDir.toAbsolutePath(), GlobalConfiguration.FLINK_CONF_FILENAME);
         FileWriter fw = new FileWriter(flinkConfFile);
         fw.write(TEST_CONFIG_KEY + ": " + TEST_CONFIG_VALUE + "\n");
         fw.close();
     }
 
-    @AfterAll
-    static void after() {
-        // clean the standard yaml flag to avoid impact to other cases.
-        GlobalConfiguration.setStandardYaml(true);
-    }
-
-    @TestTemplate
+    @Test
     void testLoadConfigurationConfigDirLongOpt() throws Exception {
         String[] args = {"--configDir", confDir.toFile().getAbsolutePath()};
         Configuration configuration = FlinkConfigLoader.loadConfiguration(args);
         verifyConfiguration(configuration, TEST_CONFIG_KEY, TEST_CONFIG_VALUE);
     }
 
-    @TestTemplate
+    @Test
     void testloadAndModifyConfigurationConfigDirLongOpt() throws Exception {
         String[] args = {"--configDir", confDir.toFile().getAbsolutePath()};
         List<String> list = FlinkConfigLoader.loadAndModifyConfiguration(args);
-        if (standardYaml) {
-            assertThat(list).containsExactly("test:", "  key: " + TEST_CONFIG_VALUE);
-        } else {
-            assertThat(list).containsExactly(TEST_CONFIG_KEY + ": " + TEST_CONFIG_VALUE);
-        }
+        assertThat(list).containsExactly("test:", "  key: " + TEST_CONFIG_VALUE);
     }
 
-    @TestTemplate
+    @Test
     void testLoadConfigurationConfigDirShortOpt() throws Exception {
         String[] args = {"-c", confDir.toFile().getAbsolutePath()};
         Configuration configuration = FlinkConfigLoader.loadConfiguration(args);
         verifyConfiguration(configuration, TEST_CONFIG_KEY, TEST_CONFIG_VALUE);
     }
 
-    @TestTemplate
+    @Test
     void testloadAndModifyConfigurationConfigDirShortOpt() throws Exception {
         String[] args = {"-c", confDir.toFile().getAbsolutePath()};
         List<String> list = FlinkConfigLoader.loadAndModifyConfiguration(args);
-        if (standardYaml) {
-            assertThat(list).containsExactly("test:", "  key: " + TEST_CONFIG_VALUE);
-        } else {
-            assertThat(list).containsExactly(TEST_CONFIG_KEY + ": " + TEST_CONFIG_VALUE);
-        }
+        assertThat(list).containsExactly("test:", "  key: " + TEST_CONFIG_VALUE);
     }
 
-    @TestTemplate
+    @Test
     void testLoadConfigurationDynamicPropertyWithSpace() throws Exception {
         String[] args = {"--configDir", confDir.toFile().getAbsolutePath(), "-D", "key=value"};
         Configuration configuration = FlinkConfigLoader.loadConfiguration(args);
         verifyConfiguration(configuration, "key", "value");
     }
 
-    @TestTemplate
+    @Test
     void testloadAndModifyConfigurationDynamicPropertyWithSpace() throws Exception {
         String[] args = {"--configDir", confDir.toFile().getAbsolutePath(), "-D", "key=value"};
         List<String> list = FlinkConfigLoader.loadAndModifyConfiguration(args);
-        if (standardYaml) {
-            assertThat(list).containsExactly("test:", "  key: " + TEST_CONFIG_VALUE, "key: value");
-        } else {
-            assertThat(list)
-                    .containsExactlyInAnyOrder(
-                            TEST_CONFIG_KEY + ": " + TEST_CONFIG_VALUE, "key: value");
-        }
+        assertThat(list).containsExactly("test:", "  key: " + TEST_CONFIG_VALUE, "key: value");
     }
 
-    @TestTemplate
+    @Test
     void testLoadConfigurationDynamicPropertyWithoutSpace() throws Exception {
         String[] args = {"--configDir", confDir.toFile().getAbsolutePath(), "-Dkey=value"};
         Configuration configuration = FlinkConfigLoader.loadConfiguration(args);
         verifyConfiguration(configuration, "key", "value");
     }
 
-    @TestTemplate
+    @Test
     void testloadAndModifyConfigurationDynamicPropertyWithoutSpace() throws Exception {
         String[] args = {"--configDir", confDir.toFile().getAbsolutePath(), "-Dkey=value"};
         List<String> list = FlinkConfigLoader.loadAndModifyConfiguration(args);
-        if (standardYaml) {
-            assertThat(list).containsExactly("test:", "  key: " + TEST_CONFIG_VALUE, "key: value");
-        } else {
-            assertThat(list)
-                    .containsExactlyInAnyOrder(
-                            TEST_CONFIG_KEY + ": " + TEST_CONFIG_VALUE, "key: value");
-        }
+        assertThat(list).containsExactly("test:", "  key: " + TEST_CONFIG_VALUE, "key: value");
     }
 
-    @TestTemplate
+    @Test
     void testLoadConfigurationIgnoreUnknownToken() throws Exception {
         String[] args = {
             "unknown",
@@ -178,7 +129,7 @@ public class FlinkConfigLoaderTest {
         verifyConfiguration(configuration, "key", "value");
     }
 
-    @TestTemplate
+    @Test
     void testloadAndModifyConfigurationIgnoreUnknownToken() throws Exception {
         String[] args = {
             "unknown",
@@ -189,16 +140,10 @@ public class FlinkConfigLoaderTest {
             "-Dkey=value"
         };
         List<String> list = FlinkConfigLoader.loadAndModifyConfiguration(args);
-        if (standardYaml) {
-            assertThat(list).containsExactly("test:", "  key: " + TEST_CONFIG_VALUE, "key: value");
-        } else {
-            assertThat(list)
-                    .containsExactlyInAnyOrder(
-                            TEST_CONFIG_KEY + ": " + TEST_CONFIG_VALUE, "key: value");
-        }
+        assertThat(list).containsExactly("test:", "  key: " + TEST_CONFIG_VALUE, "key: value");
     }
 
-    @TestTemplate
+    @Test
     void testloadAndModifyConfigurationRemoveKeysMatched() throws Exception {
         String key = "key";
 
@@ -210,14 +155,10 @@ public class FlinkConfigLoaderTest {
             key
         };
         List<String> list = FlinkConfigLoader.loadAndModifyConfiguration(args);
-        if (standardYaml) {
-            assertThat(list).containsExactly("test:", "  key: " + TEST_CONFIG_VALUE);
-        } else {
-            assertThat(list).containsExactlyInAnyOrder(TEST_CONFIG_KEY + ": " + TEST_CONFIG_VALUE);
-        }
+        assertThat(list).containsExactly("test:", "  key: " + TEST_CONFIG_VALUE);
     }
 
-    @TestTemplate
+    @Test
     void testloadAndModifyConfigurationRemoveKeysNotMatched() throws Exception {
         String key = "key";
         String value = "value";
@@ -231,17 +172,11 @@ public class FlinkConfigLoaderTest {
             removeKey
         };
         List<String> list = FlinkConfigLoader.loadAndModifyConfiguration(args);
-        if (standardYaml) {
-            assertThat(list)
-                    .containsExactly("test:", "  key: " + TEST_CONFIG_VALUE, key + ": " + value);
-        } else {
-            assertThat(list)
-                    .containsExactlyInAnyOrder(
-                            TEST_CONFIG_KEY + ": " + TEST_CONFIG_VALUE, key + ": " + value);
-        }
+        assertThat(list)
+                .containsExactly("test:", "  key: " + TEST_CONFIG_VALUE, key + ": " + value);
     }
 
-    @TestTemplate
+    @Test
     void testloadAndModifyConfigurationRemoveKeyValuesMatched() throws Exception {
         String removeKey = "removeKey";
         String removeValue = "removeValue";
@@ -254,14 +189,10 @@ public class FlinkConfigLoaderTest {
             String.format("%s=%s", removeKey, removeValue)
         };
         List<String> list = FlinkConfigLoader.loadAndModifyConfiguration(args);
-        if (standardYaml) {
-            assertThat(list).containsExactly("test:", "  key: " + TEST_CONFIG_VALUE);
-        } else {
-            assertThat(list).containsExactlyInAnyOrder(TEST_CONFIG_KEY + ": " + TEST_CONFIG_VALUE);
-        }
+        assertThat(list).containsExactly("test:", "  key: " + TEST_CONFIG_VALUE);
     }
 
-    @TestTemplate
+    @Test
     void testloadAndModifyConfigurationRemoveKeyValuesNotMatched() throws Exception {
         String removeKey = "removeKey";
         String removeValue = "removeValue";
@@ -275,19 +206,12 @@ public class FlinkConfigLoaderTest {
             String.format("%s=%s", removeKey, nonExistentValue)
         };
         List<String> list = FlinkConfigLoader.loadAndModifyConfiguration(args);
-        if (standardYaml) {
-            assertThat(list)
-                    .containsExactlyInAnyOrder(
-                            "test:", "  key: " + TEST_CONFIG_VALUE, removeKey + ": " + removeValue);
-        } else {
-            assertThat(list)
-                    .containsExactlyInAnyOrder(
-                            TEST_CONFIG_KEY + ": " + TEST_CONFIG_VALUE,
-                            removeKey + ": " + removeValue);
-        }
+        assertThat(list)
+                .containsExactlyInAnyOrder(
+                        "test:", "  key: " + TEST_CONFIG_VALUE, removeKey + ": " + removeValue);
     }
 
-    @TestTemplate
+    @Test
     void testloadAndModifyConfigurationReplaceKeyValuesMatched() throws Exception {
         String newValue = "newValue";
 
@@ -298,14 +222,10 @@ public class FlinkConfigLoaderTest {
             String.format("%s,%s,%s", TEST_CONFIG_KEY, TEST_CONFIG_VALUE, newValue)
         };
         List<String> list = FlinkConfigLoader.loadAndModifyConfiguration(args);
-        if (standardYaml) {
-            assertThat(list).containsExactly("test:", "  key: " + newValue);
-        } else {
-            assertThat(list).containsExactlyInAnyOrder(TEST_CONFIG_KEY + ": " + newValue);
-        }
+        assertThat(list).containsExactly("test:", "  key: " + newValue);
     }
 
-    @TestTemplate
+    @Test
     void testloadAndModifyConfigurationReplaceKeyValuesNotMatched() throws Exception {
         String nonExistentValue = "nonExistentValue";
         String newValue = "newValue";
@@ -317,14 +237,10 @@ public class FlinkConfigLoaderTest {
             String.format("%s,%s,%s", TEST_CONFIG_KEY, nonExistentValue, newValue)
         };
         List<String> list = FlinkConfigLoader.loadAndModifyConfiguration(args);
-        if (standardYaml) {
-            assertThat(list).containsExactly("test:", "  key: " + TEST_CONFIG_VALUE);
-        } else {
-            assertThat(list).containsExactlyInAnyOrder(TEST_CONFIG_KEY + ": " + TEST_CONFIG_VALUE);
-        }
+        assertThat(list).containsExactly("test:", "  key: " + TEST_CONFIG_VALUE);
     }
 
-    @TestTemplate
+    @Test
     void testloadAndModifyConfigurationWithFlatten() throws Exception {
         String[] args = {"-c", confDir.toFile().getAbsolutePath(), "-flatten"};
         List<String> list = FlinkConfigLoader.loadAndModifyConfiguration(args);
@@ -333,25 +249,20 @@ public class FlinkConfigLoaderTest {
 
     @Test
     void testMigrateLegacyConfigToStandardYaml() throws Exception {
-        try (FileWriter fw =
-                new FileWriter(
-                        new File(
-                                confDir.toFile(),
-                                GlobalConfiguration.LEGACY_FLINK_CONF_FILENAME))) {
+        File file =
+                new File(
+                        confDir.toFile(),
+                        ConfigurationFileMigrationUtils.LEGACY_FLINK_CONF_FILENAME);
+        try (FileWriter fw = new FileWriter(file)) {
             fw.write(TEST_CONFIG_KEY + ": " + TEST_CONFIG_VALUE + "\n");
             fw.write(
                     "pipeline.cached-files"
                             + ": "
                             + "name:file1,path:'file:///tmp/file1';name:file2,path:'hdfs:///tmp/file2'"
                             + "\n");
-            fw.write(
-                    "pipeline.default-kryo-serializers"
-                            + ": "
-                            + "class:org.example.ExampleClass,serializer:org.example.ExampleSerializer1;"
-                            + " class:org.example.ExampleClass2,serializer:org.example.ExampleSerializer2"
-                            + "\n");
         }
-        Configuration configuration = GlobalConfiguration.loadConfiguration(confDir.toString());
+        Map<String, String> configuration =
+                ConfigurationFileMigrationUtils.loadLegacyYAMLResource(file);
 
         File newConfigFolder = TempDirUtils.newFolder(confDir);
         try (FileWriter fw =
@@ -367,21 +278,13 @@ public class FlinkConfigLoaderTest {
 
         Configuration standardYamlConfig =
                 GlobalConfiguration.loadConfiguration(newConfigFolder.toString());
-        assertThat(configuration.getString(TEST_CONFIG_KEY, null))
+        assertThat(configuration.getOrDefault(TEST_CONFIG_KEY, null))
                 .isEqualTo(standardYamlConfig.getString(TEST_CONFIG_KEY, null));
 
-        assertThat(
-                        configuration.get(PipelineOptions.KRYO_DEFAULT_SERIALIZERS).stream()
-                                .map(ConfigurationUtils::parseStringToMap)
-                                .collect(Collectors.toList()))
-                .isEqualTo(
-                        standardYamlConfig.get(PipelineOptions.KRYO_DEFAULT_SERIALIZERS).stream()
-                                .map(ConfigurationUtils::parseStringToMap)
-                                .collect(Collectors.toList()));
-
-        assertThat(
-                        DistributedCache.parseCachedFilesFromString(
-                                configuration.get(PipelineOptions.CACHED_FILES)))
+        List<String> cachedFiles =
+                ConfigurationUtils.convertToList(
+                        configuration.get(PipelineOptions.CACHED_FILES.key()), String.class);
+        assertThat(DistributedCache.parseCachedFilesFromString(cachedFiles))
                 .isEqualTo(
                         DistributedCache.parseCachedFilesFromString(
                                 standardYamlConfig.get(PipelineOptions.CACHED_FILES)));
