@@ -19,7 +19,6 @@
 package org.apache.flink.state.changelog;
 
 import org.apache.flink.api.common.state.StateTtlConfig;
-import org.apache.flink.api.common.time.Time;
 import org.apache.flink.api.common.typeutils.TypeSerializer;
 import org.apache.flink.configuration.Configuration;
 import org.apache.flink.configuration.StateLatencyTrackOptions;
@@ -39,6 +38,7 @@ import org.junit.jupiter.api.io.TempDir;
 
 import java.io.IOException;
 import java.nio.file.Path;
+import java.time.Duration;
 
 /** Tests for {@link ChangelogStateBackend} delegating {@link HashMapStateBackendTest}. */
 public class ChangelogDelegateHashMapTest extends HashMapStateBackendTest {
@@ -99,7 +99,7 @@ public class ChangelogDelegateHashMapTest extends HashMapStateBackendTest {
                         .configure(configuration, Thread.currentThread().getContextClassLoader());
         ChangelogStateBackendTestUtils.testMaterializedRestore(
                 stateBackend,
-                StateTtlConfig.newBuilder(Time.minutes(1)).build(),
+                StateTtlConfig.newBuilder(Duration.ofMinutes(1)).build(),
                 env,
                 streamFactory);
     }
@@ -116,5 +116,7 @@ public class ChangelogDelegateHashMapTest extends HashMapStateBackendTest {
     @Override
     @TestTemplate
     @Disabled("Currently, ChangelogStateBackend does not support null values for map state")
-    public void testMapStateWithNullValue() {}
+    public void testMapStateWithNullValue() throws Exception {
+        super.testMapStateWithNullValue();
+    }
 }
