@@ -60,6 +60,7 @@ import org.apache.flink.state.forst.snapshot.ForStSnapshotStrategyBase;
 import org.apache.flink.util.FlinkRuntimeException;
 import org.apache.flink.util.IOUtils;
 import org.apache.flink.util.Preconditions;
+import org.apache.flink.util.ResourceGuard;
 import org.apache.flink.util.StateMigrationException;
 
 import org.forstdb.ColumnFamilyHandle;
@@ -120,6 +121,12 @@ public class ForStKeyedStateBackend<K> implements AsyncKeyedStateBackend<K> {
     /** The container of ForSt options. */
     private final ForStResourceContainer optionsContainer;
 
+    /**
+     * Protects access to ForSt in other threads, like the checkpointing thread from parallel call
+     * that disposes the ForSt object.
+     */
+    private final ResourceGuard resourceGuard;
+
     /** Factory function to create column family options from state name. */
     private final Function<String, ColumnFamilyOptions> columnFamilyOptionsFactory;
 
@@ -183,6 +190,7 @@ public class ForStKeyedStateBackend<K> implements AsyncKeyedStateBackend<K> {
             UUID backendUID,
             ExecutionConfig executionConfig,
             ForStResourceContainer optionsContainer,
+            ResourceGuard resourceGuard,
             int keyGroupPrefixBytes,
             TypeSerializer<K> keySerializer,
             Supplier<SerializedCompositeKeyBuilder<K>> serializedKeyBuilder,
@@ -203,6 +211,7 @@ public class ForStKeyedStateBackend<K> implements AsyncKeyedStateBackend<K> {
         this.backendUID = backendUID;
         this.executionConfig = executionConfig;
         this.optionsContainer = Preconditions.checkNotNull(optionsContainer);
+        this.resourceGuard = resourceGuard;
         this.keyGroupPrefixBytes = keyGroupPrefixBytes;
         this.keyGroupRange = keyContext.getKeyGroupRange();
         this.keySerializer = keySerializer;
@@ -510,6 +519,14 @@ public class ForStKeyedStateBackend<K> implements AsyncKeyedStateBackend<K> {
             if (this.disposed) {
                 return;
             }
+            // This call will block until all clients that still acquire access to the ForSt
+            // instance
+            // have released it,
+            // so that we cannot release the native resources while clients are still working with
+            // it in
+            // parallel.
+            resourceGuard.close();
+
             for (StateExecutor executor : managedStateExecutors) {
                 executor.shutdown();
             }
@@ -530,18 +547,14 @@ public class ForStKeyedStateBackend<K> implements AsyncKeyedStateBackend<K> {
                 IOUtils.closeQuietly(db);
 
                 LOG.info(
-                        "Closed ForSt State Backend. Cleaning up ForSt local working directory {}, remote working directory {}.",
-                        optionsContainer.getLocalBasePath(),
-                        optionsContainer.getRemoteBasePath());
+                        "Closed ForSt State Backend. Cleaning up ForSt: {}.",
+                        optionsContainer.getPathContainer());
 
                 try {
                     optionsContainer.clearDirectories();
                 } catch (Exception ex) {
                     LOG.warn(
-                            "Could not delete ForSt local working directory {}, remote working directory {}.",
-                            optionsContainer.getLocalBasePath(),
-                            optionsContainer.getRemoteBasePath(),
-                            ex);
+                            "Could not delete ForSt: {}.", optionsContainer.getPathContainer(), ex);
                 }
 
                 IOUtils.closeQuietly(optionsContainer);
@@ -558,12 +571,12 @@ public class ForStKeyedStateBackend<K> implements AsyncKeyedStateBackend<K> {
 
     @VisibleForTesting
     Path getLocalBasePath() {
-        return optionsContainer.getLocalBasePath();
+        return optionsContainer.getPathContainer().getLocalBasePath();
     }
 
     @VisibleForTesting
     Path getRemoteBasePath() {
-        return optionsContainer.getRemoteBasePath();
+        return optionsContainer.getPathContainer().getRemoteBasePath();
     }
 
     @Override
