@@ -302,11 +302,7 @@ public class ForStKeyedStateBackendBuilder<K>
                 //       deletion in file mapping manager.
                 optionsContainer.forceClearRemoteDirectories();
             } catch (Exception ex) {
-                logger.warn(
-                        "Failed to delete ForSt local base path {}, remote base path {}.",
-                        optionsContainer.getLocalBasePath(),
-                        optionsContainer.getRemoteBasePath(),
-                        ex);
+                logger.warn("Failed to delete ForSt: {}.", optionsContainer.getPathContainer(), ex);
             }
             IOUtils.closeQuietly(optionsContainer);
             IOUtils.closeQuietly(snapshotStrategy);
@@ -322,13 +318,13 @@ public class ForStKeyedStateBackendBuilder<K>
         InternalKeyContext<K> keyContext =
                 new InternalKeyContextImpl<>(keyGroupRange, numberOfKeyGroups);
         logger.info(
-                "Finished building ForSt keyed state-backend at local base path: {}, remote base path: {}.",
-                optionsContainer.getLocalBasePath(),
-                optionsContainer.getRemoteBasePath());
+                "Finished building ForSt keyed state-backend at {}",
+                optionsContainer.getPathContainer());
         return new ForStKeyedStateBackend<>(
                 backendUID,
                 executionConfig,
                 this.optionsContainer,
+                forstResourceGuard,
                 keyGroupPrefixBytes,
                 this.keySerializerProvider.currentSchemaSerializer(),
                 serializedKeyBuilder,
@@ -358,10 +354,9 @@ public class ForStKeyedStateBackendBuilder<K>
         // env. We expect to directly use the dfs directory in flink env or local directory as
         // working dir. We will implement this in ForStDB later, but before that, we achieved this
         // by setting the dbPath to "/" when the dfs directory existed.
-        // TODO: use localForStPath as dbPath after ForSt Support mixing local-dir and remote-dir
         Path instanceForStPath =
-                optionsContainer.getRemoteForStPath() == null
-                        ? optionsContainer.getLocalForStPath()
+                optionsContainer.getPathContainer().getRemoteForStPath() == null
+                        ? optionsContainer.getPathContainer().getLocalForStPath()
                         : new Path("/db");
 
         if (CollectionUtil.isEmptyOrAllElementsNull(restoreStateHandles)) {
