@@ -188,8 +188,12 @@ public class ForStStateBackend extends AbstractManagedMemoryStateBackend
     /** The recovery claim mode. */
     private RecoveryClaimMode recoveryClaimMode = RecoveryClaimMode.DEFAULT;
 
+    /** Whether to share the ForSt remote directory with checkpoint directory. */
     private boolean remoteShareWithCheckpoint;
 
+    /** Whether to use local directory as primary directory in synchronous mode. */
+    private boolean forceSyncLocal;
+
     // ------------------------------------------------------------------------
 
     /** Creates a new {@code ForStStateBackend} for storing state. */
@@ -203,6 +207,7 @@ public class ForStStateBackend extends AbstractManagedMemoryStateBackend
         this.useIngestDbRestoreMode = TernaryBoolean.UNDEFINED;
         this.rescalingUseDeleteFilesInRange = TernaryBoolean.UNDEFINED;
         this.remoteShareWithCheckpoint = false;
+        this.forceSyncLocal = true;
     }
 
     /**
@@ -237,6 +242,7 @@ public class ForStStateBackend extends AbstractManagedMemoryStateBackend
                                 : new Path(remoteDirStr);
             }
         }
+        this.forceSyncLocal = config.get(ForStOptions.SYNC_ENFORCE_LOCAL);
 
         this.priorityQueueConfig =
                 ForStPriorityQueueConfig.fromOtherAndConfiguration(
@@ -409,31 +415,8 @@ public class ForStStateBackend extends AbstractManagedMemoryStateBackend
 
         lazyInitializeForJob(env, fileCompatibleIdentifier);
 
-        String opChildPath =
-                String.format(
-                        "op_%s_attempt_%s",
-                        fileCompatibleIdentifier, env.getTaskInfo().getAttemptNumber());
-
-        Path localBasePath =
-                new Path(
-                        new File(new File(getNextStoragePath(), jobId.toHexString()), opChildPath)
-                                .getAbsolutePath());
-        Path remoteBasePath = null;
-        if (remoteForStDirectory != null) {
-            remoteBasePath =
-                    new Path(new Path(remoteForStDirectory, jobId.toHexString()), opChildPath);
-        } else if (remoteShareWithCheckpoint) {
-            if (env.getCheckpointStorageAccess() instanceof FsCheckpointStorageAccess) {
-                Path sharedStateDirectory =
-                        ((FsCheckpointStorageAccess) env.getCheckpointStorageAccess())
-                                .getSharedStateDirectory();
-                remoteBasePath = new Path(sharedStateDirectory, opChildPath);
-                LOG.info("Set remote ForSt directory to checkpoint directory {}", remoteBasePath);
-            } else {
-                LOG.warn(
-                        "Remote ForSt directory can't be set, because checkpoint directory isn't on file system.");
-            }
-        }
+        ForStPathContainer pathContainer =
+                createForStPathContainer(fileCompatibleIdentifier, env, false);
 
         final OpaqueMemoryResource<ForStSharedResources> sharedResources =
                 ForStOperationUtils.allocateSharedCachesIfConfigured(
@@ -448,8 +431,7 @@ public class ForStStateBackend extends AbstractManagedMemoryStateBackend
         final ForStResourceContainer resourceContainer =
                 createOptionsAndResourceContainer(
                         sharedResources,
-                        localBasePath,
-                        remoteBasePath,
+                        pathContainer,
                         env.getCheckpointStorageAccess(),
                         parameters.getMetricGroup(),
                         nativeMetricOptions.isStatisticsEnabled());
@@ -505,17 +487,8 @@ public class ForStStateBackend extends AbstractManagedMemoryStateBackend
 
         lazyInitializeForJob(env, fileCompatibleIdentifier);
 
-        Path instanceBasePath =
-                new Path(
-                        new File(
-                                        getNextStoragePath(),
-                                        "job_"
-                                                + jobId
-                                                + "_op_"
-                                                + fileCompatibleIdentifier
-                                                + "_uuid_"
-                                                + UUID.randomUUID())
-                                .getAbsolutePath());
+        ForStPathContainer pathContainer =
+                createForStPathContainer(fileCompatibleIdentifier, env, forceSyncLocal);
 
         LocalRecoveryConfig localRecoveryConfig =
                 env.getTaskStateManager().createLocalRecoveryConfig();
@@ -533,10 +506,9 @@ public class ForStStateBackend extends AbstractManagedMemoryStateBackend
         final ForStResourceContainer resourceContainer =
                 createOptionsAndResourceContainer(
                         sharedResources,
-                        instanceBasePath,
-                        null,
+                        pathContainer,
                         env.getCheckpointStorageAccess(),
-                        null,
+                        parameters.getMetricGroup(),
                         nativeMetricOptions.isStatisticsEnabled());
 
         ExecutionConfig executionConfig = env.getExecutionConfig();
@@ -549,7 +521,6 @@ public class ForStStateBackend extends AbstractManagedMemoryStateBackend
                 new ForStSyncKeyedStateBackendBuilder<>(
                                 parameters.getOperatorIdentifier(),
                                 env.getUserCodeClassLoader().asClassLoader(),
-                                instanceBasePath,
                                 resourceContainer,
                                 stateName -> resourceContainer.getColumnOptions(),
                                 parameters.getKvStateRegistry(),
@@ -818,16 +789,53 @@ public class ForStStateBackend extends AbstractManagedMemoryStateBackend
         return configuration;
     }
 
+    ForStPathContainer createForStPathContainer(
+            String operatorIdentifier, Environment env, boolean forceLocal) {
+        String opChildPath =
+                String.format(
+                        "op_%s_attempt_%s",
+                        operatorIdentifier, env.getTaskInfo().getAttemptNumber());
+
+        File localJobFile = new File(getNextStoragePath(), jobId.toHexString());
+        Path localJobPath = new Path(localJobFile.getPath());
+        Path localBasePath = new Path(new File(localJobFile, opChildPath).getAbsolutePath());
+
+        if (forceLocal) {
+            return ForStPathContainer.ofLocal(localJobPath, localBasePath);
+        }
+
+        Path remoteJobPath = null;
+        Path remoteBasePath = null;
+        if (remoteForStDirectory != null) {
+            remoteJobPath = new Path(remoteForStDirectory, jobId.toHexString());
+            remoteBasePath = new Path(remoteJobPath, opChildPath);
+        } else if (remoteShareWithCheckpoint) {
+            if (env.getCheckpointStorageAccess() instanceof FsCheckpointStorageAccess) {
+                FsCheckpointStorageAccess fsCheckpointStorageAccess =
+                        (FsCheckpointStorageAccess) env.getCheckpointStorageAccess();
+                remoteJobPath = fsCheckpointStorageAccess.getCheckpointsDirectory();
+                Path sharedStateDirectory = fsCheckpointStorageAccess.getSharedStateDirectory();
+                remoteBasePath = new Path(sharedStateDirectory, opChildPath);
+                LOG.info("Set remote ForSt directory to checkpoint directory {}", remoteBasePath);
+            } else {
+                LOG.warn(
+                        "Remote ForSt directory can't be set, because checkpoint directory isn't on file system.");
+            }
+        }
+
+        return ForStPathContainer.of(localJobPath, localBasePath, remoteJobPath, remoteBasePath);
+    }
+
     @VisibleForTesting
     ForStResourceContainer createOptionsAndResourceContainer(@Nullable Path localBasePath) {
-        return createOptionsAndResourceContainer(null, localBasePath, null, null, null, false);
+        return createOptionsAndResourceContainer(
+                null, ForStPathContainer.ofLocal(null, localBasePath), null, null, false);
     }
 
     @VisibleForTesting
     private ForStResourceContainer createOptionsAndResourceContainer(
             @Nullable OpaqueMemoryResource<ForStSharedResources> sharedResources,
-            @Nullable Path localBasePath,
-            @Nullable Path remoteBasePath,
+            ForStPathContainer pathContainer,
             @Nullable CheckpointStorageAccess checkpointStorageAccess,
             @Nullable MetricGroup metricGroup,
             boolean enableStatistics) {
@@ -836,8 +844,7 @@ public class ForStStateBackend extends AbstractManagedMemoryStateBackend
                 configurableOptions != null ? configurableOptions : new Configuration(),
                 forStOptionsFactory,
                 sharedResources,
-                localBasePath,
-                remoteBasePath,
+                pathContainer,
                 recoveryClaimMode,
                 checkpointStorageAccess,
                 metricGroup,
