@@ -45,6 +45,7 @@ import org.apache.flink.state.forst.ForStDBWriteBatchWrapper;
 import org.apache.flink.state.forst.ForStIncrementalCheckpointUtils;
 import org.apache.flink.state.forst.ForStNativeMetricOptions;
 import org.apache.flink.state.forst.ForStOperationUtils;
+import org.apache.flink.state.forst.ForStPathContainer;
 import org.apache.flink.state.forst.ForStResourceContainer;
 import org.apache.flink.state.forst.StateHandleTransferSpec;
 import org.apache.flink.state.forst.datatransfer.ForStStateDataTransfer;
@@ -93,7 +94,6 @@ import static org.apache.flink.state.forst.ForStIncrementalCheckpointUtils.check
 import static org.apache.flink.state.forst.ForStIncrementalCheckpointUtils.clipDBWithKeyGroupRange;
 import static org.apache.flink.state.forst.ForStIncrementalCheckpointUtils.findTheBestStateHandleForInitial;
 import static org.apache.flink.state.forst.ForStOperationUtils.createColumnFamilyOptions;
-import static org.apache.flink.state.forst.ForStResourceContainer.DB_DIR_STRING;
 
 /** Encapsulates the process of restoring a ForSt instance from an incremental snapshot. */
 public class ForStIncrementalRestoreOperation<K> implements ForStRestoreOperation {
@@ -212,7 +212,7 @@ public class ForStIncrementalRestoreOperation<K> implements ForStRestoreOperatio
             toTransferSpecs.add(
                     new StateHandleTransferSpec(
                             restoreStateHandles.get(bestStateHandleForInit),
-                            new Path(forstBasePath, DB_DIR_STRING)));
+                            new Path(forstBasePath, ForStPathContainer.DB_DIR_STRING)));
         }
         for (int i = 0; i < restoreStateHandles.size(); i++) {
             if (i != bestStateHandleForInit) {
@@ -263,7 +263,10 @@ public class ForStIncrementalRestoreOperation<K> implements ForStRestoreOperatio
                         ForStStateDataTransfer.DEFAULT_THREAD_NUM,
                         optionsContainer.getFileSystem())) {
             transfer.transferAllStateDataToDirectory(
-                    specs, cancelStreamRegistry, recoveryClaimMode);
+                    optionsContainer.getPathContainer(),
+                    specs,
+                    cancelStreamRegistry,
+                    recoveryClaimMode);
         }
     }
 
@@ -692,7 +695,7 @@ public class ForStIncrementalRestoreOperation<K> implements ForStRestoreOperatio
                 StateHandleTransferSpec baseSpec =
                         new StateHandleTransferSpec(
                                 restoreStateHandles.get(bestStateHandleForInit),
-                                new Path(forstBasePath, DB_DIR_STRING));
+                                new Path(forstBasePath, ForStPathContainer.DB_DIR_STRING));
                 transferAllStateHandles(Collections.singletonList(baseSpec));
                 mergeStateHandlesWithCopyFromTemporaryInstance(
                         baseSpec,
@@ -746,7 +749,7 @@ public class ForStIncrementalRestoreOperation<K> implements ForStRestoreOperatio
                 String uuid = UUID.randomUUID().toString();
 
                 String subPathStr =
-                        optionsContainer.getRemoteBasePath() != null
+                        optionsContainer.getPathContainer().getRemoteBasePath() != null
                                 ? exportBasePath.getName() + "/" + uuid
                                 : exportBasePath.toString() + "/" + uuid;
                 ExportImportFilesMetaData exportedColumnFamilyMetaData =
@@ -948,7 +951,7 @@ public class ForStIncrementalRestoreOperation<K> implements ForStRestoreOperatio
                 new ArrayList<>(stateMetaInfoSnapshots.size() + 1);
 
         String dbName =
-                optionsContainer.getRemoteBasePath() != null
+                optionsContainer.getPathContainer().getRemoteBasePath() != null
                         ? "/" + stateHandleSpec.getTransferDestination().getName()
                         : stateHandleSpec.getTransferDestination().toString();
 
