@@ -104,12 +104,10 @@ import static org.apache.flink.util.Preconditions.checkArgument;
  */
 public class ForStSyncKeyedStateBackendBuilder<K> extends AbstractKeyedStateBackendBuilder<K> {
 
-    private static final String DB_INSTANCE_DIR_STRING = "db";
-
     /** String that identifies the operator that owns this backend. */
     private final String operatorIdentifier;
 
-    /** The configuration of rocksDB priorityQueue state. */
+    /** The configuration of ForSt priorityQueue state. */
     private final ForStPriorityQueueConfig priorityQueueConfig;
 
     /** The configuration of local recovery. */
@@ -118,22 +116,16 @@ public class ForStSyncKeyedStateBackendBuilder<K> extends AbstractKeyedStateBack
     /** Factory function to create column family options from state name. */
     private final Function<String, ColumnFamilyOptions> columnFamilyOptionsFactory;
 
-    /** The container of RocksDB option factory and predefined options. */
+    /** The container of ForSt option factory and predefined options. */
     private final ForStResourceContainer optionsContainer;
 
-    /** Path where this configured instance stores its data directory. */
-    private final Path instanceBasePath;
-
-    /** Path where this configured instance stores its RocksDB database. */
-    private final Path instanceForStDBPath;
-
     private final MetricGroup metricGroup;
     private final StateBackend.CustomInitializationMetrics customInitializationMetrics;
 
     /** True if incremental checkpointing is enabled. */
     private boolean enableIncrementalCheckpointing;
 
-    /** RocksDB property-based and statistics-based native metrics options. */
+    /** ForSt property-based and statistics-based native metrics options. */
     private ForStNativeMetricOptions nativeMetricOptions;
 
     private long writeBatchSize =
@@ -154,7 +146,6 @@ public class ForStSyncKeyedStateBackendBuilder<K> extends AbstractKeyedStateBack
     public ForStSyncKeyedStateBackendBuilder(
             String operatorIdentifier,
             ClassLoader userCodeClassLoader,
-            Path instanceBasePath,
             ForStResourceContainer optionsContainer,
             Function<String, ColumnFamilyOptions> columnFamilyOptionsFactory,
             TaskKvStateRegistry kvStateRegistry,
@@ -190,8 +181,6 @@ public class ForStSyncKeyedStateBackendBuilder<K> extends AbstractKeyedStateBack
         // ensure that we use the right merge operator, because other code relies on this
         this.columnFamilyOptionsFactory = Preconditions.checkNotNull(columnFamilyOptionsFactory);
         this.optionsContainer = optionsContainer;
-        this.instanceBasePath = instanceBasePath;
-        this.instanceForStDBPath = getInstanceRocksDBPath(instanceBasePath);
         this.metricGroup = metricGroup;
         this.customInitializationMetrics = customInitializationMetrics;
         this.enableIncrementalCheckpointing = false;
@@ -203,7 +192,6 @@ public class ForStSyncKeyedStateBackendBuilder<K> extends AbstractKeyedStateBack
     ForStSyncKeyedStateBackendBuilder(
             String operatorIdentifier,
             ClassLoader userCodeClassLoader,
-            Path instanceBasePath,
             ForStResourceContainer optionsContainer,
             Function<String, ColumnFamilyOptions> columnFamilyOptionsFactory,
             TaskKvStateRegistry kvStateRegistry,
@@ -212,7 +200,7 @@ public class ForStSyncKeyedStateBackendBuilder<K> extends AbstractKeyedStateBack
             KeyGroupRange keyGroupRange,
             ExecutionConfig executionConfig,
             LocalRecoveryConfig localRecoveryConfig,
-            ForStPriorityQueueConfig rocksDBPriorityQueueConfig,
+            ForStPriorityQueueConfig forStPriorityQueueConfig,
             TtlTimeProvider ttlTimeProvider,
             LatencyTrackingStateConfig latencyTrackingStateConfig,
             MetricGroup metricGroup,
@@ -224,7 +212,6 @@ public class ForStSyncKeyedStateBackendBuilder<K> extends AbstractKeyedStateBack
         this(
                 operatorIdentifier,
                 userCodeClassLoader,
-                instanceBasePath,
                 optionsContainer,
                 columnFamilyOptionsFactory,
                 kvStateRegistry,
@@ -233,7 +220,7 @@ public class ForStSyncKeyedStateBackendBuilder<K> extends AbstractKeyedStateBack
                 keyGroupRange,
                 executionConfig,
                 localRecoveryConfig,
-                rocksDBPriorityQueueConfig,
+                forStPriorityQueueConfig,
                 ttlTimeProvider,
                 latencyTrackingStateConfig,
                 metricGroup,
@@ -263,10 +250,6 @@ public class ForStSyncKeyedStateBackendBuilder<K> extends AbstractKeyedStateBack
         return this;
     }
 
-    public static Path getInstanceRocksDBPath(Path instanceBasePath) {
-        return new Path(instanceBasePath, DB_INSTANCE_DIR_STRING);
-    }
-
     private static void checkAndCreateDirectory(File directory) throws IOException {
         if (directory.exists()) {
             if (!directory.isDirectory()) {
@@ -274,7 +257,7 @@ public class ForStSyncKeyedStateBackendBuilder<K> extends AbstractKeyedStateBack
             }
         } else if (!directory.mkdirs()) {
             throw new IOException(
-                    String.format("Could not create RocksDB data directory at %s.", directory));
+                    String.format("Could not create ForSt data directory at %s.", directory));
         }
     }
 
@@ -300,7 +283,7 @@ public class ForStSyncKeyedStateBackendBuilder<K> extends AbstractKeyedStateBack
 
         ForStSnapshotStrategyBase<K, ?> checkpointStrategy = null;
 
-        ResourceGuard rocksDBResourceGuard = new ResourceGuard();
+        ResourceGuard forStResourceGuard = new ResourceGuard();
         PriorityQueueSetFactory priorityQueueFactory;
         SerializedCompositeKeyBuilder<K> sharedRocksKeyBuilder;
         // Number of bytes required to prefix the key groups.
@@ -316,7 +299,7 @@ public class ForStSyncKeyedStateBackendBuilder<K> extends AbstractKeyedStateBack
             UUID backendUID = UUID.randomUUID();
             SortedMap<Long, Collection<HandleAndLocalPath>> materializedSstFiles = new TreeMap<>();
             long lastCompletedCheckpointId = -1L;
-            prepareDirectories();
+            optionsContainer.prepareDirectories();
             restoreOperation =
                     getForStDBRestoreOperation(
                             keyGroupPrefixBytes,
@@ -346,7 +329,7 @@ public class ForStSyncKeyedStateBackendBuilder<K> extends AbstractKeyedStateBack
             checkpointStrategy =
                     initializeSnapshotStrategy(
                             db,
-                            rocksDBResourceGuard,
+                            forStResourceGuard,
                             keySerializerProvider.currentSchemaSerializer(),
                             kvStateInformation,
                             keyGroupRange,
@@ -369,7 +352,7 @@ public class ForStSyncKeyedStateBackendBuilder<K> extends AbstractKeyedStateBack
                     new ArrayList<>(kvStateInformation.values().size());
             IOUtils.closeQuietly(cancelRegistryForBackend);
             IOUtils.closeQuietly(writeBatchWrapper);
-            IOUtils.closeQuietly(rocksDBResourceGuard);
+            IOUtils.closeQuietly(forStResourceGuard);
             ForStOperationUtils.addColumnFamilyOptionsToCloseLater(
                     columnFamilyOptions, defaultColumnFamilyHandle);
             IOUtils.closeQuietly(defaultColumnFamilyHandle);
@@ -388,9 +371,11 @@ public class ForStSyncKeyedStateBackendBuilder<K> extends AbstractKeyedStateBack
             kvStateInformation.clear();
 
             try {
-                FileUtils.deleteDirectory(new File(instanceBasePath.getPath()));
+                FileUtils.deleteDirectory(new File(optionsContainer.getBasePath().getPath()));
             } catch (Exception ex) {
-                logger.warn("Failed to delete base path for RocksDB: " + instanceBasePath, ex);
+                logger.warn(
+                        "Failed to delete base path for ForSt: " + optionsContainer.getBasePath(),
+                        ex);
             }
             // Log and rethrow
             if (e instanceof BackendBuildingException) {
@@ -403,10 +388,11 @@ public class ForStSyncKeyedStateBackendBuilder<K> extends AbstractKeyedStateBack
         }
         InternalKeyContext<K> keyContext =
                 new InternalKeyContextImpl<>(keyGroupRange, numberOfKeyGroups);
-        logger.info("Finished building RocksDB keyed state-backend at {}.", instanceBasePath);
+        logger.info(
+                "Finished building ForSt keyed state-backend at {}.",
+                optionsContainer.getBasePath());
         return new ForStSyncKeyedStateBackend<>(
                 this.userCodeClassLoader,
-                this.instanceBasePath,
                 this.optionsContainer,
                 columnFamilyOptionsFactory,
                 this.kvStateRegistry,
@@ -420,7 +406,7 @@ public class ForStSyncKeyedStateBackendBuilder<K> extends AbstractKeyedStateBack
                 keyGroupPrefixBytes,
                 cancelRegistryForBackend,
                 this.keyGroupCompressionDecorator,
-                rocksDBResourceGuard,
+                forStResourceGuard,
                 checkpointStrategy,
                 writeBatchWrapper,
                 defaultColumnFamilyHandle,
@@ -513,11 +499,15 @@ public class ForStSyncKeyedStateBackendBuilder<K> extends AbstractKeyedStateBack
         // env. We expect to directly use the dfs directory in flink env or local directory as
         // working dir. We will implement this in ForStDB later, but before that, we achieved this
         // by setting the dbPath to "/" when the dfs directory existed.
+        Path instanceForStPath =
+                optionsContainer.getPathContainer().getRemoteForStPath() == null
+                        ? optionsContainer.getPathContainer().getLocalForStPath()
+                        : new Path("/db");
 
         if (CollectionUtil.isEmptyOrAllElementsNull(restoreStateHandles)) {
             return new ForStNoneRestoreOperation(
                     Collections.emptyMap(),
-                    instanceForStDBPath,
+                    instanceForStPath,
                     optionsContainer.getDbOptions(),
                     columnFamilyOptionsFactory,
                     nativeMetricOptions,
@@ -538,7 +528,7 @@ public class ForStSyncKeyedStateBackendBuilder<K> extends AbstractKeyedStateBack
                     keySerializerProvider,
                     optionsContainer,
                     optionsContainer.getBasePath(),
-                    instanceForStDBPath,
+                    instanceForStPath,
                     optionsContainer.getDbOptions(),
                     columnFamilyOptionsFactory,
                     nativeMetricOptions,
@@ -565,7 +555,7 @@ public class ForStSyncKeyedStateBackendBuilder<K> extends AbstractKeyedStateBack
                     registeredPQStates,
                     createHeapQueueFactory(),
                     keySerializerProvider,
-                    instanceForStDBPath,
+                    instanceForStPath,
                     optionsContainer.getDbOptions(),
                     columnFamilyOptionsFactory,
                     nativeMetricOptions,
@@ -605,7 +595,7 @@ public class ForStSyncKeyedStateBackendBuilder<K> extends AbstractKeyedStateBack
                                 nativeMetricMonitor,
                                 columnFamilyOptionsFactory,
                                 optionsContainer.getWriteBufferManagerCapacity(),
-                                priorityQueueConfig.getRocksDBPriorityQueueSetCacheSize());
+                                priorityQueueConfig.getForStDBPriorityQueueSetCacheSize());
                 break;
             default:
                 throw new IllegalArgumentException(
@@ -618,14 +608,4 @@ public class ForStSyncKeyedStateBackendBuilder<K> extends AbstractKeyedStateBack
     private HeapPriorityQueueSetFactory createHeapQueueFactory() {
         return new HeapPriorityQueueSetFactory(keyGroupRange, numberOfKeyGroups, 128);
     }
-
-    private void prepareDirectories() throws IOException {
-        File baseFile = new File(instanceBasePath.getPath());
-        checkAndCreateDirectory(baseFile);
-        if (new File(instanceForStDBPath.getPath()).exists()) {
-            // Clear the base directory when the backend is created
-            // in case something crashed and the backend never reached dispose()
-            FileUtils.deleteDirectory(baseFile);
-        }
-    }
 }
