@@ -34,8 +34,7 @@ import org.apache.flink.runtime.state.StateEntry;
 import org.apache.flink.runtime.state.StateSnapshotTransformer;
 import org.apache.flink.runtime.state.heap.space.Allocator;
 import org.apache.flink.runtime.state.internal.InternalKvState;
-
-import org.hamcrest.Matcher;
+import org.apache.flink.runtime.state.testutils.StateAssertions;
 
 import javax.annotation.Nonnull;
 
@@ -48,18 +47,11 @@ import java.util.Iterator;
 import java.util.List;
 import java.util.Map;
 import java.util.Set;
-import java.util.stream.Collectors;
 
 import static org.apache.flink.runtime.state.heap.CopyOnWriteSkipListStateMap.DEFAULT_LOGICAL_REMOVED_KEYS_RATIO;
 import static org.apache.flink.runtime.state.heap.CopyOnWriteSkipListStateMap.DEFAULT_MAX_KEYS_TO_DELETE_ONE_TIME;
 import static org.apache.flink.runtime.state.heap.SkipListUtils.NIL_NODE;
-import static org.apache.flink.runtime.state.testutils.StateEntryMatcher.entry;
-import static org.hamcrest.Matchers.containsInAnyOrder;
-import static org.hamcrest.Matchers.nullValue;
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertNull;
-import static org.junit.Assert.assertThat;
-import static org.junit.Assert.assertTrue;
+import static org.assertj.core.api.Assertions.assertThat;
 
 /** Utils for CopyOnWriteSkipListStateMap test. */
 class CopyOnWriteSkipListStateMapTestUtils {
@@ -99,8 +91,8 @@ class CopyOnWriteSkipListStateMapTestUtils {
             for (Map.Entry<K, S> keyEntry : entry.getValue().entrySet()) {
                 K key = keyEntry.getKey();
                 S state = keyEntry.getValue();
-                assertEquals(state, stateMap.get(key, namespace));
-                assertTrue(stateMap.containsKey(key, namespace));
+                assertThat(stateMap.get(key, namespace)).isEqualTo(state);
+                assertThat(stateMap.containsKey(key, namespace)).isTrue();
             }
         }
 
@@ -108,13 +100,13 @@ class CopyOnWriteSkipListStateMapTestUtils {
         for (Map.Entry<N, Map<K, S>> entry : referenceStates.entrySet()) {
             N namespace = entry.getKey();
             Set<K> expectedKeySet = new HashSet<>(entry.getValue().keySet());
-            assertEquals(expectedKeySet.size(), stateMap.sizeOfNamespace(namespace));
+            assertThat(stateMap.sizeOfNamespace(namespace)).isEqualTo(expectedKeySet.size());
             Iterator<K> keyIterator = stateMap.getKeys(namespace).iterator();
             while (keyIterator.hasNext()) {
                 K key = keyIterator.next();
-                assertTrue(expectedKeySet.remove(key));
+                assertThat(expectedKeySet.remove(key)).isTrue();
             }
-            assertTrue(expectedKeySet.isEmpty());
+            assertThat(expectedKeySet).isEmpty();
         }
 
         // validates iterator()
@@ -126,14 +118,14 @@ class CopyOnWriteSkipListStateMapTestUtils {
                     actualStates
                             .computeIfAbsent(entry.getNamespace(), (none) -> new HashMap<>())
                             .put(entry.getKey(), entry.getState());
-            assertNull(oldState);
+            assertThat(oldState).isNull();
         }
         referenceStates.forEach(
                 (ns, kvMap) -> {
                     if (kvMap.isEmpty()) {
-                        assertThat(actualStates.get(ns), nullValue());
+                        assertThat(actualStates.get(ns)).isNull();
                     } else {
-                        assertEquals(kvMap, actualStates.get(ns));
+                        assertThat(actualStates.get(ns)).isEqualTo(kvMap);
                     }
                 });
 
@@ -148,15 +140,15 @@ class CopyOnWriteSkipListStateMapTestUtils {
                         actualStates
                                 .computeIfAbsent(entry.getNamespace(), (none) -> new HashMap<>())
                                 .put(entry.getKey(), entry.getState());
-                assertNull(oldState);
+                assertThat(oldState).isNull();
             }
         }
         referenceStates.forEach(
                 (ns, kvMap) -> {
                     if (kvMap.isEmpty()) {
-                        assertThat(actualStates.get(ns), nullValue());
+                        assertThat(actualStates.get(ns)).isNull();
                     } else {
-                        assertEquals(kvMap, actualStates.get(ns));
+                        assertThat(actualStates.get(ns)).isEqualTo(kvMap);
                     }
                 });
     }
@@ -212,7 +204,7 @@ class CopyOnWriteSkipListStateMapTestUtils {
         if (verificationMode == SnapshotVerificationMode.ITERATOR) {
             Iterator<StateEntry<K, N, S>> iterator =
                     snapshot.getIterator(keySerializer, namespaceSerializer, stateSerializer, null);
-            assertThat(() -> iterator, containsInAnyOrder(toMatchers(referenceStates)));
+            StateAssertions.assertContainsExactly(iterator, referenceStates);
         } else {
             snapshot.writeState(
                     keySerializer, namespaceSerializer, stateSerializer, outputView, null);
@@ -223,20 +215,10 @@ class CopyOnWriteSkipListStateMapTestUtils {
                             keySerializer,
                             namespaceSerializer,
                             stateSerializer);
-            assertEquals(referenceStates, actualStates);
+            assertThat(actualStates).isEqualTo(referenceStates);
         }
     }
 
-    private static <K, N, S> List<Matcher<? super StateEntry<K, N, S>>> toMatchers(
-            Map<N, Map<K, S>> referenceStates) {
-        return referenceStates.entrySet().stream()
-                .flatMap(
-                        e ->
-                                e.getValue().entrySet().stream()
-                                        .map(ks -> entry(ks.getKey(), e.getKey(), ks.getValue())))
-                .collect(Collectors.toList());
-    }
-
     static <K, N, S> void verifySnapshotWithTransform(
             @Nonnull Map<N, Map<K, S>> referenceStates,
             @Nonnull CopyOnWriteSkipListStateMapSnapshot<K, N, S> snapshot,
@@ -288,11 +270,11 @@ class CopyOnWriteSkipListStateMapTestUtils {
                             keySerializer,
                             namespaceSerializer,
                             stateSerializer);
-            assertEquals(transformedStates, actualStates);
+            assertThat(actualStates).isEqualTo(transformedStates);
         } else {
             Iterator<StateEntry<K, N, S>> iterator =
                     snapshot.getIterator(keySerializer, namespaceSerializer, stateSerializer, null);
-            assertThat(() -> iterator, containsInAnyOrder(toMatchers(referenceStates)));
+            StateAssertions.assertContainsExactly(iterator, referenceStates);
         }
     }
 
