@@ -435,6 +435,7 @@ public class AsyncWaitOperator<IN, OUT>
 
         private final ResultHandler resultHandler;
         private final ProcessingTimeService processingTimeService;
+        private final long startTs;
 
         private ScheduledFuture<?> delayedRetryTimer;
 
@@ -454,6 +455,7 @@ public class AsyncWaitOperator<IN, OUT>
                 ProcessingTimeService processingTimeService) {
             this.resultHandler = new ResultHandler(inputRecord, resultFuture);
             this.processingTimeService = processingTimeService;
+            this.startTs = processingTimeService.getCurrentProcessingTime();
         }
 
         private void registerTimeout(long timeout) {
@@ -510,6 +512,10 @@ public class AsyncWaitOperator<IN, OUT>
                     () -> processRetry(results, error), "delayed retry or complete");
         }
 
+        private boolean isTimeout() {
+            return processingTimeService.getCurrentProcessingTime() - startTs > timeout;
+        }
+
         private void processRetry(Collection<OUT> results, Throwable error) {
             // ignore repeated call(s) and only called in main thread can be safe
             if (!retryAwaiting.compareAndSet(false, true)) {
@@ -520,7 +526,8 @@ public class AsyncWaitOperator<IN, OUT>
                     (null != results && retryResultPredicate.test(results))
                             || (null != error && retryExceptionPredicate.test(error));
 
-            if (satisfy
+            if (!isTimeout()
+                    && satisfy
                     && asyncRetryStrategy.canRetry(currentAttempts)
                     && !retryDisabledOnFinish.get()) {
                 long nextBackoffTimeMillis =
