@@ -20,7 +20,6 @@ package org.apache.flink.streaming.runtime.operators.sink;
 
 import org.apache.flink.api.common.eventtime.Watermark;
 import org.apache.flink.api.common.typeutils.base.IntSerializer;
-import org.apache.flink.api.common.typeutils.base.StringSerializer;
 import org.apache.flink.api.connector.sink2.Committer;
 import org.apache.flink.api.connector.sink2.CommitterInitContext;
 import org.apache.flink.api.connector.sink2.CommittingSinkWriter;
@@ -30,7 +29,6 @@ import org.apache.flink.api.connector.sink2.StatefulSinkWriter;
 import org.apache.flink.api.connector.sink2.SupportsCommitter;
 import org.apache.flink.api.connector.sink2.SupportsWriterState;
 import org.apache.flink.api.connector.sink2.WriterInitContext;
-import org.apache.flink.api.java.tuple.Tuple3;
 import org.apache.flink.core.io.SimpleVersionedSerializer;
 import org.apache.flink.core.io.SimpleVersionedSerializerAdapter;
 import org.apache.flink.streaming.api.connector.sink2.CommittableMessage;
@@ -41,12 +39,12 @@ import org.apache.flink.streaming.api.connector.sink2.StandardSinkTopologies;
 import org.apache.flink.streaming.api.connector.sink2.SupportsPostCommitTopology;
 import org.apache.flink.streaming.api.connector.sink2.SupportsPreCommitTopology;
 import org.apache.flink.streaming.api.datastream.DataStream;
-import org.apache.flink.util.Preconditions;
+import org.apache.flink.util.InstantiationUtil;
+import org.apache.flink.util.function.SerializableFunction;
+import org.apache.flink.util.function.SerializableSupplier;
 
 import org.apache.flink.shaded.guava32.com.google.common.collect.ImmutableSet;
 
-import javax.annotation.Nullable;
-
 import java.io.IOException;
 import java.io.Serializable;
 import java.util.ArrayList;
@@ -54,94 +52,93 @@ import java.util.Collection;
 import java.util.Collections;
 import java.util.LinkedHashSet;
 import java.util.List;
-import java.util.Queue;
+import java.util.Objects;
 import java.util.Set;
-import java.util.concurrent.ConcurrentLinkedQueue;
-import java.util.function.Supplier;
+import java.util.stream.Collectors;
 
 import static org.apache.flink.util.Preconditions.checkNotNull;
-import static org.assertj.core.api.Assertions.assertThat;
 
 /** A {@link Sink} for all the sink related tests. */
 public class TestSinkV2<InputT> implements Sink<InputT> {
-    public static final SimpleVersionedSerializerAdapter<String> COMMITTABLE_SERIALIZER =
-            new SimpleVersionedSerializerAdapter<>(StringSerializer.INSTANCE);
-    public static final SimpleVersionedSerializerAdapter<Integer> WRITER_SERIALIZER =
+    public static final SimpleVersionedSerializer<Integer> WRITER_SERIALIZER =
             new SimpleVersionedSerializerAdapter<>(IntSerializer.INSTANCE);
 
-    private final DefaultSinkWriter<InputT> writer;
+    private final SinkWriter<InputT> writer;
 
-    private TestSinkV2(DefaultSinkWriter<InputT> writer) {
+    private TestSinkV2(SinkWriter<InputT> writer) {
         this.writer = writer;
     }
 
     public SinkWriter<InputT> createWriter(WriterInitContext context) {
-        writer.init(context);
+        if (writer instanceof DefaultSinkWriter) {
+            ((DefaultSinkWriter<InputT>) writer).init(context);
+        }
         return writer;
     }
 
-    DefaultSinkWriter<InputT> getWriter() {
+    SinkWriter<InputT> getWriter() {
         return writer;
     }
 
-    public static <InputT> Builder<InputT> newBuilder() {
+    public static <InputT> Builder<InputT, Record<InputT>> newBuilder() {
         return new Builder<>();
     }
 
-    public static <InputT> Builder<InputT> newBuilder(DefaultSinkWriter<InputT> writer) {
-        return new Builder<InputT>().setWriter(writer);
-    }
-
-    public SupportsCommitter<String> asSupportsCommitter() {
-        throw new UnsupportedOperationException("No committter");
+    public static <InputT> Builder<InputT, Record<InputT>> newBuilder(
+            DefaultSinkWriter<InputT> writer) {
+        return new Builder<InputT, Record<InputT>>().setWriter(writer);
     }
 
     /** A builder class for {@link TestSinkV2}. */
-    public static class Builder<InputT> {
-        private DefaultSinkWriter<InputT> writer = null;
-        private DefaultCommitter committer;
+    public static class Builder<InputT, CommT> {
+        private SinkWriter<InputT> writer = null;
+        private Committer<CommT> committer;
         private boolean withPostCommitTopology = false;
-        private boolean withPreCommitTopology = false;
+        private SerializableFunction<CommT, CommT> preCommitTopology = null;
         private boolean withWriterState = false;
         private String compatibleStateNames;
+        private SerializableSupplier<SimpleVersionedSerializer<CommT>> commSerializerFactory;
 
-        public Builder<InputT> setWriter(DefaultSinkWriter<InputT> writer) {
-            this.writer = checkNotNull(writer);
-            return this;
+        @SuppressWarnings("unchecked")
+        public <NewInputT, NewCommT> Builder<NewInputT, NewCommT> setWriter(
+                CommittingSinkWriter<NewInputT, NewCommT> writer) {
+            Builder<NewInputT, NewCommT> self = (Builder<NewInputT, NewCommT>) this;
+            self.writer = checkNotNull(writer);
+            return self;
         }
 
-        public Builder<InputT> setCommitter(DefaultCommitter committer) {
+        @SuppressWarnings("unchecked")
+        public <NewInputT> Builder<NewInputT, CommT> setWriter(SinkWriter<NewInputT> writer) {
+            Builder<NewInputT, CommT> self = (Builder<NewInputT, CommT>) this;
+            self.writer = checkNotNull(writer);
+            return self;
+        }
+
+        public Builder<InputT, CommT> setCommitter(
+                Committer<CommT> committer,
+                SerializableSupplier<SimpleVersionedSerializer<CommT>> commSerializerFactory) {
             this.committer = committer;
+            this.commSerializerFactory = commSerializerFactory;
             return this;
         }
 
-        public Builder<InputT> setDefaultCommitter() {
-            this.committer = new DefaultCommitter();
-            return this;
-        }
-
-        public Builder<InputT> setDefaultCommitter(
-                Supplier<Queue<Committer.CommitRequest<String>>> queueSupplier) {
-            this.committer = new DefaultCommitter(queueSupplier);
-            return this;
-        }
-
-        public Builder<InputT> setWithPostCommitTopology(boolean withPostCommitTopology) {
+        public Builder<InputT, CommT> setWithPostCommitTopology(boolean withPostCommitTopology) {
             this.withPostCommitTopology = withPostCommitTopology;
             return this;
         }
 
-        public Builder<InputT> setWithPreCommitTopology(boolean withPreCommitTopology) {
-            this.withPreCommitTopology = withPreCommitTopology;
+        public Builder<InputT, CommT> setWithPreCommitTopology(
+                SerializableFunction<CommT, CommT> preCommitTopology) {
+            this.preCommitTopology = preCommitTopology;
             return this;
         }
 
-        public Builder<InputT> setWriterState(boolean withWriterState) {
+        public Builder<InputT, CommT> setWriterState(boolean withWriterState) {
             this.withWriterState = withWriterState;
             return this;
         }
 
-        public Builder<InputT> setCompatibleStateNames(String compatibleStateNames) {
+        public Builder<InputT, CommT> setCompatibleStateNames(String compatibleStateNames) {
             this.compatibleStateNames = compatibleStateNames;
             return this;
         }
@@ -158,139 +155,130 @@ public class TestSinkV2<InputT> implements Sink<InputT> {
                     writer = new DefaultCommittingSinkWriter<>();
                 }
                 if (!withPostCommitTopology) {
-                    if (!withPreCommitTopology) {
+                    if (preCommitTopology == null) {
                         // TwoPhaseCommittingSink with a stateless writer and a committer
                         return new TestSinkV2TwoPhaseCommittingSink<>(
-                                writer, COMMITTABLE_SERIALIZER, committer);
+                                writer, commSerializerFactory, committer);
                     } else {
                         // TwoPhaseCommittingSink with a stateless writer, pre commit topology,
                         // committer
-                        Preconditions.checkArgument(
-                                writer instanceof DefaultCommittingSinkWriter,
-                                "Please provide a DefaultCommittingSinkWriter instance");
                         return new TestSinkV2WithPreCommitTopology<>(
-                                writer, COMMITTABLE_SERIALIZER, committer);
+                                writer, commSerializerFactory, committer, preCommitTopology);
                     }
                 } else {
                     if (withWriterState) {
                         // TwoPhaseCommittingSink with a stateful writer and a committer and post
                         // commit topology
-                        Preconditions.checkArgument(
-                                writer instanceof DefaultStatefulSinkWriter,
-                                "Please provide a DefaultStatefulSinkWriter instance");
                         return new TestStatefulSinkV2<>(
-                                (DefaultStatefulSinkWriter<InputT>) writer,
-                                COMMITTABLE_SERIALIZER,
-                                committer,
-                                compatibleStateNames);
+                                writer, commSerializerFactory, committer, compatibleStateNames);
                     } else {
                         // TwoPhaseCommittingSink with a stateless writer and a committer and post
                         // commit topology
-                        Preconditions.checkArgument(
-                                writer instanceof DefaultCommittingSinkWriter,
-                                "Please provide a DefaultCommittingSinkWriter instance");
                         return new TestSinkV2WithPostCommitTopology<>(
-                                writer, COMMITTABLE_SERIALIZER, committer);
+                                writer, commSerializerFactory, committer);
                     }
                 }
             }
         }
     }
 
-    private static class TestSinkV2TwoPhaseCommittingSink<InputT> extends TestSinkV2<InputT>
-            implements SupportsCommitter<String> {
-        private final DefaultCommitter committer;
-        private final SimpleVersionedSerializer<String> committableSerializer;
+    private static class TestSinkV2TwoPhaseCommittingSink<InputT, CommT> extends TestSinkV2<InputT>
+            implements SupportsCommitter<CommT> {
+        private final Committer<CommT> committer;
+        protected final SerializableSupplier<SimpleVersionedSerializer<CommT>>
+                commSerializerFactory;
 
         public TestSinkV2TwoPhaseCommittingSink(
-                DefaultSinkWriter<InputT> writer,
-                SimpleVersionedSerializer<String> committableSerializer,
-                DefaultCommitter committer) {
+                SinkWriter<InputT> writer,
+                SerializableSupplier<SimpleVersionedSerializer<CommT>> commSerializerFactory,
+                Committer<CommT> committer) {
             super(writer);
             this.committer = committer;
-            this.committableSerializer = committableSerializer;
+            this.commSerializerFactory = commSerializerFactory;
         }
 
         @Override
-        public Committer<String> createCommitter(CommitterInitContext context) {
-            committer.init();
+        public Committer<CommT> createCommitter(CommitterInitContext context) {
+            if (committer instanceof DefaultCommitter) {
+                ((DefaultCommitter<CommT>) committer).init();
+            }
             return committer;
         }
 
         @Override
-        public SupportsCommitter<String> asSupportsCommitter() {
-            return this;
-        }
-
-        @Override
-        public SimpleVersionedSerializer<String> getCommittableSerializer() {
-            return committableSerializer;
+        public SimpleVersionedSerializer<CommT> getCommittableSerializer() {
+            return commSerializerFactory.get();
         }
     }
 
     // -------------------------------------- Sink With PostCommitTopology -------------------------
 
-    private static class TestSinkV2WithPostCommitTopology<InputT>
-            extends TestSinkV2TwoPhaseCommittingSink<InputT>
-            implements SupportsPostCommitTopology<String> {
+    private static class TestSinkV2WithPostCommitTopology<InputT, CommT>
+            extends TestSinkV2TwoPhaseCommittingSink<InputT, CommT>
+            implements SupportsPostCommitTopology<CommT> {
         public TestSinkV2WithPostCommitTopology(
-                DefaultSinkWriter<InputT> writer,
-                SimpleVersionedSerializer<String> committableSerializer,
-                DefaultCommitter committer) {
-            super(writer, committableSerializer, committer);
+                SinkWriter<InputT> writer,
+                SerializableSupplier<SimpleVersionedSerializer<CommT>> commSerializerFactory,
+                Committer<CommT> committer) {
+            super(writer, commSerializerFactory, committer);
         }
 
         @Override
-        public void addPostCommitTopology(DataStream<CommittableMessage<String>> committables) {
+        public void addPostCommitTopology(DataStream<CommittableMessage<CommT>> committables) {
             StandardSinkTopologies.addGlobalCommitter(
                     committables, this::createCommitter, this::getCommittableSerializer);
         }
     }
 
-    private static class TestSinkV2WithPreCommitTopology<InputT>
-            extends TestSinkV2TwoPhaseCommittingSink<InputT>
-            implements SupportsPreCommitTopology<String, String> {
+    private static class TestSinkV2WithPreCommitTopology<InputT, CommT>
+            extends TestSinkV2TwoPhaseCommittingSink<InputT, CommT>
+            implements SupportsPreCommitTopology<CommT, CommT> {
+        private final SerializableFunction<CommT, CommT> preCommitTopology;
+
         public TestSinkV2WithPreCommitTopology(
-                DefaultSinkWriter<InputT> writer,
-                SimpleVersionedSerializer<String> committableSerializer,
-                DefaultCommitter committer) {
-            super(writer, committableSerializer, committer);
+                SinkWriter<InputT> writer,
+                SerializableSupplier<SimpleVersionedSerializer<CommT>> commSerializerFactory,
+                Committer<CommT> committer,
+                SerializableFunction<CommT, CommT> preCommitTopology) {
+            super(writer, commSerializerFactory, committer);
+            this.preCommitTopology = preCommitTopology;
         }
 
         @Override
-        public DataStream<CommittableMessage<String>> addPreCommitTopology(
-                DataStream<CommittableMessage<String>> committables) {
+        public DataStream<CommittableMessage<CommT>> addPreCommitTopology(
+                DataStream<CommittableMessage<CommT>> committables) {
             return committables
                     .map(
                             m -> {
                                 if (m instanceof CommittableSummary) {
                                     return m;
                                 } else {
-                                    CommittableWithLineage<String> withLineage =
-                                            (CommittableWithLineage<String>) m;
-                                    return withLineage.map(old -> old + "Transformed");
+                                    CommittableWithLineage<CommT> withLineage =
+                                            (CommittableWithLineage<CommT>) m;
+                                    return withLineage.map(preCommitTopology);
                                 }
                             })
-                    .returns(CommittableMessageTypeInfo.of(() -> COMMITTABLE_SERIALIZER));
+                    .returns(CommittableMessageTypeInfo.of(commSerializerFactory));
         }
 
         @Override
-        public SimpleVersionedSerializer<String> getWriteResultSerializer() {
-            return new SimpleVersionedSerializerAdapter<>(StringSerializer.INSTANCE);
+        public SimpleVersionedSerializer<CommT> getWriteResultSerializer() {
+            return commSerializerFactory.get();
         }
     }
 
-    private static class TestStatefulSinkV2<InputT> extends TestSinkV2WithPostCommitTopology<InputT>
+    private static class TestStatefulSinkV2<InputT, CommT>
+            extends TestSinkV2WithPostCommitTopology<InputT, CommT>
             implements SupportsWriterState<InputT, Integer>,
                     SupportsWriterState.WithCompatibleState {
         private final String compatibleState;
 
         public TestStatefulSinkV2(
-                DefaultStatefulSinkWriter<InputT> writer,
-                SimpleVersionedSerializer<String> committableSerializer,
-                DefaultCommitter committer,
+                SinkWriter<InputT> writer,
+                SerializableSupplier<SimpleVersionedSerializer<CommT>> commSerializerFactory,
+                Committer<CommT> committer,
                 String compatibleState) {
-            super(writer, committableSerializer, committer);
+            super(writer, commSerializerFactory, committer);
             this.compatibleState = compatibleState;
         }
 
@@ -303,7 +291,7 @@ public class TestSinkV2<InputT> implements Sink<InputT> {
         public StatefulSinkWriter<InputT, Integer> restoreWriter(
                 WriterInitContext context, Collection<Integer> recoveredState) {
             DefaultStatefulSinkWriter<InputT> statefulWriter =
-                    (DefaultStatefulSinkWriter) getWriter();
+                    (DefaultStatefulSinkWriter<InputT>) getWriter();
 
             statefulWriter.restore(recoveredState);
             return statefulWriter;
@@ -322,10 +310,90 @@ public class TestSinkV2<InputT> implements Sink<InputT> {
 
     // -------------------------------------- Sink Writer ------------------------------------------
 
+    public static class Record<T> implements Serializable {
+        private final T value;
+        private final Long timestamp;
+        private final long watermark;
+
+        public Record(T value, Long timestamp, long watermark) {
+            this.value = value;
+            this.timestamp = timestamp;
+            this.watermark = watermark;
+        }
+
+        public T getValue() {
+            return value;
+        }
+
+        public Long getTimestamp() {
+            return timestamp;
+        }
+
+        public long getWatermark() {
+            return watermark;
+        }
+
+        @Override
+        public boolean equals(Object object) {
+            if (this == object) {
+                return true;
+            }
+            if (object == null || getClass() != object.getClass()) {
+                return false;
+            }
+            Record<?> record = (Record<?>) object;
+            return Objects.equals(timestamp, record.timestamp)
+                    && watermark == record.watermark
+                    && Objects.equals(value, record.value);
+        }
+
+        @Override
+        public int hashCode() {
+            return Objects.hash(value, timestamp, watermark);
+        }
+
+        @Override
+        public String toString() {
+            return "Record{"
+                    + "value="
+                    + value
+                    + ", timestamp="
+                    + timestamp
+                    + ", watermark="
+                    + watermark
+                    + '}';
+        }
+
+        public Record<T> withValue(T value) {
+            return new Record<>(value, timestamp, watermark);
+        }
+    }
+
+    public static class RecordSerializer<T> implements SimpleVersionedSerializer<Record<T>> {
+        @Override
+        public int getVersion() {
+            return 0;
+        }
+
+        @Override
+        public byte[] serialize(Record<T> record) throws IOException {
+            return InstantiationUtil.serializeObject(record);
+        }
+
+        @Override
+        public Record<T> deserialize(int version, byte[] serialized) throws IOException {
+            try {
+                return InstantiationUtil.deserializeObject(serialized, getClass().getClassLoader());
+            } catch (ClassNotFoundException e) {
+                throw new RuntimeException(e);
+            }
+        }
+    }
+
     /** Base class for out testing {@link SinkWriter}. */
     public static class DefaultSinkWriter<InputT> implements SinkWriter<InputT>, Serializable {
 
-        protected List<String> elements;
+        protected List<Record<InputT>> elements;
 
         protected List<Watermark> watermarks;
 
@@ -338,8 +406,7 @@ public class TestSinkV2<InputT> implements Sink<InputT> {
 
         @Override
         public void write(InputT element, Context context) {
-            elements.add(
-                    Tuple3.of(element, context.timestamp(), context.currentWatermark()).toString());
+            elements.add(new Record<>(element, context.timestamp(), context.currentWatermark()));
         }
 
         @Override
@@ -347,6 +414,18 @@ public class TestSinkV2<InputT> implements Sink<InputT> {
             elements = new ArrayList<>();
         }
 
+        public List<Record<InputT>> getRecordsOfCurrentCheckpoint() {
+            return elements;
+        }
+
+        public List<Watermark> getWatermarks() {
+            return watermarks;
+        }
+
+        public long getLastCheckpointId() {
+            return lastCheckpointId;
+        }
+
         @Override
         public void writeWatermark(Watermark watermark) {
             watermarks.add(watermark);
@@ -364,7 +443,7 @@ public class TestSinkV2<InputT> implements Sink<InputT> {
 
     /** Base class for out testing {@link CommittingSinkWriter}. */
     protected static class DefaultCommittingSinkWriter<InputT> extends DefaultSinkWriter<InputT>
-            implements CommittingSinkWriter<InputT, String>, Serializable {
+            implements CommittingSinkWriter<InputT, Record<InputT>>, Serializable {
 
         @Override
         public void flush(boolean endOfInput) throws IOException, InterruptedException {
@@ -372,8 +451,25 @@ public class TestSinkV2<InputT> implements Sink<InputT> {
         }
 
         @Override
-        public Collection<String> prepareCommit() {
-            List<String> result = elements;
+        public Collection<Record<InputT>> prepareCommit() {
+            List<Record<InputT>> result = elements;
+            elements = new ArrayList<>();
+            return result;
+        }
+    }
+
+    protected static class ForwardCommittingSinkWriter<InputT> extends DefaultSinkWriter<InputT>
+            implements CommittingSinkWriter<InputT, InputT>, Serializable {
+
+        @Override
+        public void flush(boolean endOfInput) throws IOException, InterruptedException {
+            // We empty the elements on prepareCommit
+        }
+
+        @Override
+        public Collection<InputT> prepareCommit() {
+            List<InputT> result =
+                    elements.stream().map(Record::getValue).collect(Collectors.toList());
             elements = new ArrayList<>();
             return result;
         }
@@ -412,42 +508,15 @@ public class TestSinkV2<InputT> implements Sink<InputT> {
     // -------------------------------------- Sink Committer ---------------------------------------
 
     /** Base class for testing {@link Committer}. */
-    public static class DefaultCommitter implements Committer<String>, Serializable {
-
-        @Nullable protected Queue<CommitRequest<String>> committedData;
-
+    public static class DefaultCommitter<CommT> implements Committer<CommT>, Serializable {
         private boolean isClosed;
 
-        @Nullable private final Supplier<Queue<CommitRequest<String>>> queueSupplier;
-
         public DefaultCommitter() {
-            this.committedData = new ConcurrentLinkedQueue<>();
             this.isClosed = false;
-            this.queueSupplier = null;
-        }
-
-        public DefaultCommitter(@Nullable Supplier<Queue<CommitRequest<String>>> queueSupplier) {
-            this.queueSupplier = queueSupplier;
-            this.isClosed = false;
-            this.committedData = null;
-        }
-
-        public List<CommitRequest<String>> getCommittedData() {
-            if (committedData != null) {
-                return new ArrayList<>(committedData);
-            } else {
-                return Collections.emptyList();
-            }
         }
 
         @Override
-        public void commit(Collection<CommitRequest<String>> committables) {
-            if (committedData == null) {
-                assertThat(queueSupplier).isNotNull();
-                committedData = queueSupplier.get();
-            }
-            committedData.addAll(committables);
-        }
+        public void commit(Collection<CommitRequest<CommT>> committables) {}
 
         public void close() throws Exception {
             isClosed = true;
@@ -463,18 +532,15 @@ public class TestSinkV2<InputT> implements Sink<InputT> {
     }
 
     /** A {@link Committer} that always re-commits the committables data it received. */
-    static class RetryOnceCommitter extends DefaultCommitter {
+    static class RetryOnceCommitter<CommT> extends DefaultCommitter<CommT> {
 
-        private final Set<String> seen = new LinkedHashSet<>();
+        private final Set<CommT> seen = new LinkedHashSet<>();
 
         @Override
-        public void commit(Collection<CommitRequest<String>> committables) {
+        public void commit(Collection<CommitRequest<CommT>> committables) {
             committables.forEach(
                     c -> {
-                        if (seen.remove(c.getCommittable())) {
-                            checkNotNull(committedData);
-                            committedData.add(c);
-                        } else {
+                        if (!seen.remove(c.getCommittable())) {
                             seen.add(c.getCommittable());
                             c.retryLater();
                         }
