@@ -72,6 +72,7 @@ import org.apache.flink.table.operations.BeginStatementSetOperation;
 import org.apache.flink.table.operations.CallProcedureOperation;
 import org.apache.flink.table.operations.CompileAndExecutePlanOperation;
 import org.apache.flink.table.operations.DeleteFromFilterOperation;
+import org.apache.flink.table.operations.DescribeFunctionOperation;
 import org.apache.flink.table.operations.EndStatementSetOperation;
 import org.apache.flink.table.operations.ExecutableOperation;
 import org.apache.flink.table.operations.LoadModuleOperation;
@@ -120,6 +121,7 @@ import java.util.Map;
 import java.util.Optional;
 import java.util.Set;
 import java.util.concurrent.TimeUnit;
+import java.util.function.BiFunction;
 import java.util.stream.Collectors;
 
 import static org.apache.flink.api.common.RuntimeExecutionMode.STREAMING;
@@ -145,12 +147,28 @@ public class OperationExecutor {
     private final Configuration executionConfig;
 
     private final ClusterClientServiceLoader clusterClientServiceLoader;
+    private final BiFunction<Configuration, ClassLoader, StreamExecutionEnvironment>
+            environmentBuilder;
 
     @VisibleForTesting
     public OperationExecutor(SessionContext context, Configuration executionConfig) {
         this.sessionContext = context;
         this.executionConfig = executionConfig;
         this.clusterClientServiceLoader = new DefaultClusterClientServiceLoader();
+        // We need not different StreamExecutionEnvironments to build and submit flink job,
+        // instead we just use StreamExecutionEnvironment#executeAsync(StreamGraph) method
+        // to execute existing StreamGraph.
+        // This requires StreamExecutionEnvironment to have a full flink configuration.
+        this.environmentBuilder = StreamExecutionEnvironment::new;
+    }
+
+    public OperationExecutor(
+            SessionContext sessionContext,
+            BiFunction<Configuration, ClassLoader, StreamExecutionEnvironment> environmentBuilder) {
+        this.sessionContext = sessionContext;
+        this.executionConfig = new Configuration();
+        this.clusterClientServiceLoader = new DefaultClusterClientServiceLoader();
+        this.environmentBuilder = environmentBuilder;
     }
 
     public ResultFetcher configureSession(OperationHandle handle, String statement) {
@@ -225,7 +243,8 @@ public class OperationExecutor {
             op = parsedOperations.get(0);
         }
 
-        if (op instanceof CallProcedureOperation) {
+        if (op instanceof CallProcedureOperation
+                && SqlGatewayStreamExecutionEnvironment.areExplicitEnvironmentsAllowed()) {
             // if the operation is CallProcedureOperation, we need to set the stream environment
             // context to it since the procedure will use the stream environment
             try {
@@ -299,8 +318,11 @@ public class OperationExecutor {
     }
 
     public Set<FunctionInfo> listUserDefinedFunctions(String catalogName, String databaseName) {
-        return sessionContext.getSessionState().functionCatalog
-                .getUserDefinedFunctions(catalogName, databaseName).stream()
+        return sessionContext
+                .getSessionState()
+                .functionCatalog
+                .getUserDefinedFunctions(catalogName, databaseName)
+                .stream()
                 // Load the CatalogFunction from the remote catalog is time wasted. Set the
                 // FunctionKind null.
                 .map(FunctionInfo::new)
@@ -374,13 +396,8 @@ public class OperationExecutor {
         final EnvironmentSettings settings =
                 EnvironmentSettings.newInstance().withConfiguration(operationConfig).build();
 
-        // We need not different StreamExecutionEnvironments to build and submit flink job,
-        // instead we just use StreamExecutionEnvironment#executeAsync(StreamGraph) method
-        // to execute existing StreamGraph.
-        // This requires StreamExecutionEnvironment to have a full flink configuration.
         StreamExecutionEnvironment streamExecEnv =
-                new StreamExecutionEnvironment(
-                        operationConfig, sessionContext.getUserClassloader());
+                environmentBuilder.apply(operationConfig, sessionContext.getUserClassloader());
 
         TableConfig tableConfig = TableConfig.getDefault();
         tableConfig.setRootConfiguration(sessionContext.getDefaultContext().getFlinkConfig());
@@ -399,6 +416,14 @@ public class OperationExecutor {
                 sessionContext.getSessionState().functionCatalog.copy(resourceManager));
     }
 
+    public <ClusterID> Optional<String> getSessionClusterId() {
+        ClusterClientFactory<ClusterID> clusterClientFactory =
+                clusterClientServiceLoader.getClusterClientFactory(sessionContext.getSessionConf());
+        ClusterID clusterID = clusterClientFactory.getClusterId(sessionContext.getSessionConf());
+
+        return Optional.ofNullable(clusterID).map(ClusterID::toString);
+    }
+
     private static Executor lookupExecutor(
             StreamExecutionEnvironment executionEnvironment, ClassLoader userClassLoader) {
         try {
@@ -510,7 +535,8 @@ public class OperationExecutor {
                 || op instanceof ShowJarsOperation
                 || op instanceof CreateTempSystemFunctionOperation
                 || op instanceof CreateCatalogFunctionOperation
-                || op instanceof ShowFunctionsOperation) {
+                || op instanceof ShowFunctionsOperation
+                || op instanceof DescribeFunctionOperation) {
             return callExecutableOperation(handle, (ExecutableOperation) op);
         } else if (op instanceof MaterializedTableOperation) {
             return sessionContext
@@ -722,7 +748,10 @@ public class OperationExecutor {
 
     private Set<TableInfo> listViews(String catalogName, String databaseName) {
         return Collections.unmodifiableSet(
-                sessionContext.getSessionState().catalogManager.listViews(catalogName, databaseName)
+                sessionContext
+                        .getSessionState()
+                        .catalogManager
+                        .listViews(catalogName, databaseName)
                         .stream()
                         .map(
                                 name ->
@@ -847,7 +876,8 @@ public class OperationExecutor {
                         clusterClient -> {
                             try {
                                 JobID expectedJobId = JobID.fromHexString(jobId);
-                                return clusterClient.listJobs()
+                                return clusterClient
+                                        .listJobs()
                                         .get(clientTimeout.toMillis(), TimeUnit.MILLISECONDS)
                                         .stream()
                                         .filter(job -> expectedJobId.equals(job.getJobId()))
