@@ -158,7 +158,10 @@ public class SqlReplaceTableAs extends SqlCreate implements ExtendedSqlNode {
 
     @Override
     public void validate() throws SqlValidateException {
-        SqlConstraintValidator.validateAndChangeColumnNullability(tableConstraints, columnList);
+        if (!isSchemaWithColumnsIdentifiersOnly()) {
+            SqlConstraintValidator.validateAndChangeColumnNullability(tableConstraints, columnList);
+        }
+
         // The following features are not currently supported by RTAS, but may be supported in the
         // future
         String errorMsg =
@@ -175,33 +178,6 @@ public class SqlReplaceTableAs extends SqlCreate implements ExtendedSqlNode {
                     getParserPosition(),
                     errorMsg + " syntax does not support temporary table yet.");
         }
-
-        if (getColumnList().size() > 0) {
-            throw new SqlValidateException(
-                    getParserPosition(),
-                    errorMsg + " syntax does not support to specify explicit columns yet.");
-        }
-
-        if (getWatermark().isPresent()) {
-            throw new SqlValidateException(
-                    getParserPosition(),
-                    errorMsg + " syntax does not support to specify explicit watermark yet.");
-        }
-        if (getDistribution() != null) {
-            throw new SqlValidateException(
-                    getParserPosition(),
-                    errorMsg + " syntax does not support creating distributed tables yet.");
-        }
-        if (getPartitionKeyList().size() > 0) {
-            throw new SqlValidateException(
-                    getParserPosition(),
-                    errorMsg + " syntax does not support to create partitioned table yet.");
-        }
-        if (getFullConstraints().stream().anyMatch(SqlTableConstraint::isPrimaryKey)) {
-            throw new SqlValidateException(
-                    getParserPosition(),
-                    errorMsg + " syntax does not support primary key constraints yet.");
-        }
     }
 
     public SqlNode getAsQuery() {
@@ -248,6 +224,13 @@ public class SqlReplaceTableAs extends SqlCreate implements ExtendedSqlNode {
         return isTemporary;
     }
 
+    public boolean isSchemaWithColumnsIdentifiersOnly() {
+        // REPLACE table supports passing only column identifiers in the column list. If
+        // the first column in the list is an identifier, then we assume the rest of the
+        // columns are identifiers as well.
+        return !columnList.isEmpty() && columnList.get(0) instanceof SqlIdentifier;
+    }
+
     /** Returns the column constraints plus the table constraints. */
     public List<SqlTableConstraint> getFullConstraints() {
         return SqlConstraintValidator.getFullConstraints(tableConstraints, columnList);
