@@ -24,7 +24,6 @@ import org.apache.flink.annotation.docs.Documentation;
 import org.apache.flink.configuration.ConfigOption;
 import org.apache.flink.configuration.ConfigOptions;
 import org.apache.flink.configuration.DescribedEnum;
-import org.apache.flink.configuration.ExecutionOptions;
 import org.apache.flink.configuration.MemorySize;
 import org.apache.flink.configuration.description.Description;
 import org.apache.flink.configuration.description.InlineElement;
@@ -32,7 +31,6 @@ import org.apache.flink.configuration.description.InlineElement;
 import java.time.Duration;
 
 import static org.apache.flink.configuration.ConfigOptions.key;
-import static org.apache.flink.configuration.description.TextElement.code;
 import static org.apache.flink.configuration.description.TextElement.text;
 
 /**
@@ -499,43 +497,6 @@ public class ExecutionConfigOptions {
                     .withDescription(
                             "If true, multiple physical operators will be compiled into a single operator by planner which can improve the performance.");
 
-    /** @deprecated Use {@link ExecutionOptions#BATCH_SHUFFLE_MODE} instead. */
-    @Deprecated
-    @Documentation.TableOption(execMode = Documentation.ExecMode.BATCH)
-    public static final ConfigOption<String> TABLE_EXEC_SHUFFLE_MODE =
-            key("table.exec.shuffle-mode")
-                    .stringType()
-                    .noDefaultValue()
-                    .withDescription(
-                            Description.builder()
-                                    .text("Sets exec shuffle mode.")
-                                    .linebreak()
-                                    .text("Accepted values are:")
-                                    .list(
-                                            text(
-                                                    "%s: All edges will use blocking shuffle.",
-                                                    code("ALL_EDGES_BLOCKING")),
-                                            text(
-                                                    "%s: Forward edges will use pipelined shuffle, others blocking.",
-                                                    code("FORWARD_EDGES_PIPELINED")),
-                                            text(
-                                                    "%s: Pointwise edges will use pipelined shuffle, others blocking. "
-                                                            + "Pointwise edges include forward and rescale edges.",
-                                                    code("POINTWISE_EDGES_PIPELINED")),
-                                            text(
-                                                    "%s: All edges will use pipelined shuffle.",
-                                                    code("ALL_EDGES_PIPELINED")),
-                                            text(
-                                                    "%s: the same as %s. Deprecated.",
-                                                    code("batch"), code("ALL_EDGES_BLOCKING")),
-                                            text(
-                                                    "%s: the same as %s. Deprecated.",
-                                                    code("pipelined"), code("ALL_EDGES_PIPELINED")))
-                                    .text(
-                                            "Note: Blocking shuffle means data will be fully produced before sent to consumer tasks. "
-                                                    + "Pipelined shuffle means data will be sent to consumer tasks once produced.")
-                                    .build());
-
     @Documentation.TableOption(execMode = Documentation.ExecMode.BATCH_STREAMING)
     public static final ConfigOption<LegacyCastBehaviour> TABLE_EXEC_LEGACY_CAST_BEHAVIOUR =
             key("table.exec.legacy-cast-behaviour")
@@ -550,7 +511,6 @@ public class ExecutionConfigOptions {
             ConfigOptions.key("table.exec.rank.topn-cache-size")
                     .longType()
                     .defaultValue(10000L)
-                    .withDeprecatedKeys("table.exec.topn-cache-size")
                     .withDescription(
                             "Rank operators have a cache which caches partial state contents "
                                     + "to reduce state access. Cache size is the number of records "
@@ -570,8 +530,6 @@ public class ExecutionConfigOptions {
                     key("table.exec.deduplicate.insert-update-after-sensitive-enabled")
                             .booleanType()
                             .defaultValue(true)
-                            .withDeprecatedKeys(
-                                    "table.exec.deduplicate.insert-and-updateafter-sensitive.enabled")
                             .withDescription(
                                     "Set whether the job (especially the sinks) is sensitive to "
                                             + "INSERT messages and UPDATE_AFTER messages. "
@@ -587,8 +545,6 @@ public class ExecutionConfigOptions {
                     ConfigOptions.key("table.exec.deduplicate.mini-batch.compact-changes-enabled")
                             .booleanType()
                             .defaultValue(false)
-                            .withDeprecatedKeys(
-                                    "table.exec.deduplicate.mini-batch.compact-changes.enabled")
                             .withDescription(
                                     "Set whether to compact the changes sent downstream in row-time "
                                             + "mini-batch. If true, Flink will compact changes and send "
@@ -598,19 +554,6 @@ public class ExecutionConfigOptions {
                                             + "all changes to downstream just like when the mini-batch is "
                                             + "not enabled.");
 
-    /** @deprecated Use {@link #TABLE_EXEC_UID_GENERATION} instead. */
-    @Documentation.TableOption(execMode = Documentation.ExecMode.STREAMING)
-    @Deprecated
-    public static final ConfigOption<Boolean> TABLE_EXEC_LEGACY_TRANSFORMATION_UIDS =
-            key("table.exec.legacy-transformation-uids")
-                    .booleanType()
-                    .defaultValue(false)
-                    .withDescription(
-                            "This flag has been replaced by table.exec.uid.generation. Use the enum "
-                                    + "value DISABLED to restore legacy behavior. However, the new "
-                                    + "default value should be sufficient for most use cases as "
-                                    + "only pipelines from compiled plans get UIDs assigned.");
-
     @Documentation.TableOption(execMode = Documentation.ExecMode.STREAMING)
     public static final ConfigOption<UidGeneration> TABLE_EXEC_UID_GENERATION =
             key("table.exec.uid.generation")
@@ -664,6 +607,15 @@ public class ExecutionConfigOptions {
                                     + "leading to possible discarding of these records by downstream watermark-dependent operators, such as window operators. "
                                     + "The default value is 0, which means it will clean up unmatched records immediately.");
 
+    @Documentation.TableOption(execMode = Documentation.ExecMode.STREAMING)
+    public static final ConfigOption<Boolean> TABLE_EXEC_ASYNC_STATE_ENABLED =
+            key("table.exec.async-state.enabled")
+                    .booleanType()
+                    .defaultValue(false)
+                    .withDescription(
+                            "Set whether to use the SQL/Table operators based on the asynchronous state api. "
+                                    + "Default value is false.");
+
     // ------------------------------------------------------------------------------------------
     // Enum option types
     // ------------------------------------------------------------------------------------------
