@@ -21,11 +21,14 @@ package org.apache.flink.table.api.config;
 import org.apache.flink.annotation.PublicEvolving;
 import org.apache.flink.annotation.docs.Documentation;
 import org.apache.flink.configuration.ConfigOption;
+import org.apache.flink.configuration.DescribedEnum;
 import org.apache.flink.configuration.MemorySize;
 import org.apache.flink.configuration.description.Description;
+import org.apache.flink.configuration.description.InlineElement;
 
 import static org.apache.flink.configuration.ConfigOptions.key;
 import static org.apache.flink.configuration.description.TextElement.code;
+import static org.apache.flink.configuration.description.TextElement.text;
 
 /**
  * This class holds configuration constants used by Flink's table planner module.
@@ -102,28 +105,6 @@ public class OptimizerConfigOptions {
                                     + TABLE_OPTIMIZER_REUSE_SUB_PLAN_ENABLED.key()
                                     + " is true.");
 
-    /** This configuration will be removed in Flink 2.0. */
-    @Deprecated
-    @Documentation.TableOption(execMode = Documentation.ExecMode.BATCH)
-    public static final ConfigOption<Boolean> TABLE_OPTIMIZER_SOURCE_AGGREGATE_PUSHDOWN_ENABLED =
-            key("table.optimizer.source.aggregate-pushdown-enabled")
-                    .booleanType()
-                    .defaultValue(true)
-                    .withDescription(
-                            "When it is true, the optimizer will push down the local aggregates into "
-                                    + "the TableSource which implements SupportsAggregatePushDown.");
-
-    /** This configuration will be removed in Flink 2.0. */
-    @Deprecated
-    @Documentation.TableOption(execMode = Documentation.ExecMode.BATCH_STREAMING)
-    public static final ConfigOption<Boolean> TABLE_OPTIMIZER_SOURCE_PREDICATE_PUSHDOWN_ENABLED =
-            key("table.optimizer.source.predicate-pushdown-enabled")
-                    .booleanType()
-                    .defaultValue(true)
-                    .withDescription(
-                            "When it is true, the optimizer will push down predicates into the FilterableTableSource. "
-                                    + "Default value is true.");
-
     @Documentation.TableOption(execMode = Documentation.ExecMode.BATCH_STREAMING)
     public static final ConfigOption<Boolean> TABLE_OPTIMIZER_SOURCE_REPORT_STATISTICS_ENABLED =
             key("table.optimizer.source.report-statistics-enabled")
@@ -180,6 +161,65 @@ public class OptimizerConfigOptions {
                             "A flag to enable or disable the runtime filter. "
                                     + "When it is true, the optimizer will try to inject a runtime filter for eligible join.");
 
+    @Documentation.TableOption(execMode = Documentation.ExecMode.BATCH)
+    public static final ConfigOption<AdaptiveBroadcastJoinStrategy>
+            TABLE_OPTIMIZER_ADAPTIVE_BROADCAST_JOIN_STRATEGY =
+                    key("table.optimizer.adaptive-broadcast-join.strategy")
+                            .enumType(AdaptiveBroadcastJoinStrategy.class)
+                            .defaultValue(AdaptiveBroadcastJoinStrategy.AUTO)
+                            .withDescription(
+                                    "Flink will perform broadcast hash join optimization when the runtime "
+                                            + "statistics on one side of a join operator is less than the "
+                                            + "threshold `table.optimizer.join.broadcast-threshold`. The "
+                                            + "value of this configuration option decides when Flink should "
+                                            + "perform this optimization. AUTO means Flink will automatically "
+                                            + "choose the timing for optimization, RUNTIME_ONLY means broadcast "
+                                            + "hash join optimization is only performed at runtime, and NONE "
+                                            + "means the optimization is only carried out at compile time.");
+
+    @Documentation.TableOption(execMode = Documentation.ExecMode.BATCH)
+    public static final ConfigOption<AdaptiveSkewedJoinOptimizationStrategy>
+            TABLE_OPTIMIZER_ADAPTIVE_SKEWED_JOIN_OPTIMIZATION_STRATEGY =
+                    key("table.optimizer.skewed-join-optimization.strategy")
+                            .enumType(AdaptiveSkewedJoinOptimizationStrategy.class)
+                            .defaultValue(AdaptiveSkewedJoinOptimizationStrategy.AUTO)
+                            .withDescription(
+                                    "Flink will handle skew in shuffled joins (sort-merge and hash) "
+                                            + "at runtime by splitting data according to the skewed join "
+                                            + "key. The value of this configuration determines how Flink performs "
+                                            + "this optimization. AUTO means Flink will automatically apply this "
+                                            + "optimization, FORCED means Flink will enforce this optimization even "
+                                            + "if it introduces extra hash shuffle, and NONE means this optimization "
+                                            + "will not be executed.");
+
+    @Documentation.TableOption(execMode = Documentation.ExecMode.BATCH)
+    public static final ConfigOption<Double>
+            TABLE_OPTIMIZER_ADAPTIVE_SKEWED_JOIN_OPTIMIZATION_SKEWED_FACTOR =
+                    key("table.optimizer.skewed-join-optimization.skewed-factor")
+                            .doubleType()
+                            .defaultValue(4.0)
+                            .withDescription(
+                                    "When a join operator instance encounters input data that exceeds N times the median "
+                                            + "size of other concurrent join operator instances, it is considered skewed "
+                                            + "(where N represents this skewed-factor). In such cases, Flink may automatically "
+                                            + "split the skewed data into multiple parts to ensure a more balanced data "
+                                            + "distribution, unless the data volume is below the skewed threshold(defined "
+                                            + "using table.optimizer.skewed-join-optimization.skewed-threshold).");
+
+    @Documentation.TableOption(execMode = Documentation.ExecMode.BATCH)
+    public static final ConfigOption<MemorySize>
+            TABLE_OPTIMIZER_ADAPTIVE_SKEWED_JOIN_OPTIMIZATION_SKEWED_THRESHOLD =
+                    key("table.optimizer.skewed-join-optimization.skewed-threshold")
+                            .memoryType()
+                            .defaultValue(MemorySize.ofMebiBytes(256))
+                            .withDescription(
+                                    "When a join operator instance encounters input data that exceeds N times the median "
+                                            + "size of other concurrent join operator instances, it is considered skewed "
+                                            + "(where N represents the table.optimizer.skewed-join-optimization.skewed-factor). "
+                                            + "In such cases, Flink may automatically split the skewed data into multiple "
+                                            + "parts to ensure a more balanced data distribution, unless the data volume "
+                                            + "is below this skewed threshold.");
+
     /**
      * The data volume of build side needs to be under this value. If the data volume of build side
      * is too large, the building overhead will be too large, which may lead to a negative impact on
@@ -267,7 +307,6 @@ public class OptimizerConfigOptions {
             key("table.optimizer.sql2rel.project-merge.enabled")
                     .booleanType()
                     .defaultValue(false)
-                    .withDeprecatedKeys("table.optimizer.sql-to-rel.project.merge.enabled")
                     .withDescription(
                             Description.builder()
                                     .text(
@@ -327,4 +366,63 @@ public class OptimizerConfigOptions {
          */
         IGNORE
     }
+
+    /** Strategies used for {@link #TABLE_OPTIMIZER_ADAPTIVE_BROADCAST_JOIN_STRATEGY}. */
+    @PublicEvolving
+    public enum AdaptiveBroadcastJoinStrategy implements DescribedEnum {
+        AUTO("auto", text("Flink will automatically choose the timing for optimization")),
+        RUNTIME_ONLY(
+                "runtime_only",
+                text("Broadcast hash join optimization is only performed at runtime.")),
+        NONE("none", text("Broadcast hash join optimization is only carried out at compile time."));
+
+        private final String value;
+
+        private final InlineElement description;
+
+        AdaptiveBroadcastJoinStrategy(String value, InlineElement description) {
+            this.value = value;
+            this.description = description;
+        }
+
+        @Override
+        public String toString() {
+            return value;
+        }
+
+        @Override
+        public InlineElement getDescription() {
+            return description;
+        }
+    }
+
+    /** Strategies used for {@link #TABLE_OPTIMIZER_ADAPTIVE_SKEWED_JOIN_OPTIMIZATION_STRATEGY}. */
+    @PublicEvolving
+    public enum AdaptiveSkewedJoinOptimizationStrategy implements DescribedEnum {
+        AUTO("auto", text(" Flink will automatically perform this optimization.")),
+        FORCED(
+                "forced",
+                text(
+                        "Flink will perform this optimization even if it introduces extra hash shuffling.")),
+        NONE("none", text("Skewed join optimization will not be performed."));
+
+        private final String value;
+
+        private final InlineElement description;
+
+        AdaptiveSkewedJoinOptimizationStrategy(String value, InlineElement description) {
+            this.value = value;
+            this.description = description;
+        }
+
+        @Override
+        public String toString() {
+            return value;
+        }
+
+        @Override
+        public InlineElement getDescription() {
+            return description;
+        }
+    }
 }
