@@ -39,12 +39,12 @@ import java.util.Objects;
 import java.util.Optional;
 import java.util.stream.Collectors;
 
-import static org.apache.flink.table.utils.EncodingUtils.escapeIdentifier;
-
 /** SHOW CREATE statement Util. */
 @Internal
 public class ShowCreateUtil {
 
+    private static final String PRINT_INDENT = "  ";
+
     private ShowCreateUtil() {}
 
     public static String buildShowCreateTableRow(
@@ -57,18 +57,16 @@ public class ShowCreateUtil {
                             "SHOW CREATE TABLE is only supported for tables, but %s is a view. Please use SHOW CREATE VIEW instead.",
                             tableIdentifier.asSerializableString()));
         }
-        final String printIndent = "  ";
         StringBuilder sb =
                 new StringBuilder()
                         .append(buildCreateFormattedPrefix("TABLE", isTemporary, tableIdentifier));
-        sb.append(extractFormattedColumns(table, printIndent));
-        extractFormattedWatermarkSpecs(table, printIndent)
+        sb.append(extractFormattedColumns(table, PRINT_INDENT));
+        extractFormattedWatermarkSpecs(table, PRINT_INDENT)
                 .ifPresent(watermarkSpecs -> sb.append(",\n").append(watermarkSpecs));
-        extractFormattedPrimaryKey(table, printIndent).ifPresent(pk -> sb.append(",\n").append(pk));
-        sb.append("\n) ");
-        extractFormattedComment(table)
-                .ifPresent(
-                        c -> sb.append(String.format("COMMENT '%s'%s", c, System.lineSeparator())));
+        extractFormattedPrimaryKey(table, PRINT_INDENT)
+                .ifPresent(pk -> sb.append(",\n").append(pk));
+        sb.append("\n)\n");
+        extractComment(table).ifPresent(c -> sb.append(formatComment(c)).append("\n"));
         extractFormattedDistributedInfo((ResolvedCatalogTable) table).ifPresent(sb::append);
         extractFormattedPartitionedInfo((ResolvedCatalogTable) table)
                 .ifPresent(
@@ -76,7 +74,7 @@ public class ShowCreateUtil {
                                 sb.append("PARTITIONED BY (")
                                         .append(partitionedInfoFormatted)
                                         .append(")\n"));
-        extractFormattedOptions(table.getOptions(), printIndent)
+        extractFormattedOptions(table.getOptions(), PRINT_INDENT)
                 .ifPresent(v -> sb.append("WITH (\n").append(v).append("\n)\n"));
         return sb.toString();
     }
@@ -92,45 +90,32 @@ public class ShowCreateUtil {
                             "SHOW CREATE VIEW is only supported for views, but %s is a table. Please use SHOW CREATE TABLE instead.",
                             viewIdentifier.asSerializableString()));
         }
-        final StringBuilder stringBuilder = new StringBuilder();
         final CatalogBaseTable origin = view.getOrigin();
         if (origin instanceof QueryOperationCatalogView
                 && !((QueryOperationCatalogView) origin).supportsShowCreateView()) {
             throw new TableException(
                     "SHOW CREATE VIEW is not supported for views registered by Table API.");
-        } else {
-            stringBuilder.append(
-                    String.format(
-                            "CREATE %sVIEW %s%s as%s%s",
-                            isTemporary ? "TEMPORARY " : "",
-                            viewIdentifier.asSerializableString(),
-                            String.format("(%s)", extractFormattedColumnNames(view)),
-                            System.lineSeparator(),
-                            ((CatalogView) view.getOrigin()).getExpandedQuery()));
         }
-        extractFormattedComment(view)
-                .ifPresent(
-                        c ->
-                                stringBuilder.append(
-                                        String.format(
-                                                " COMMENT '%s'%s", c, System.lineSeparator())));
-        return stringBuilder.toString();
+        StringBuilder sb =
+                new StringBuilder()
+                        .append(buildCreateFormattedPrefix("VIEW", isTemporary, viewIdentifier));
+        sb.append(extractFormattedColumnNames(view, PRINT_INDENT)).append("\n)\n");
+        extractComment(view).ifPresent(c -> sb.append(formatComment(c)).append("\n"));
+        sb.append("AS ").append(((CatalogView) origin).getExpandedQuery()).append("\n");
+
+        return sb.toString();
     }
 
     public static String buildShowCreateCatalogRow(CatalogDescriptor catalogDescriptor) {
-        final String printIndent = "  ";
-        final String comment = catalogDescriptor.getComment().orElse(null);
-        return String.format(
-                "CREATE CATALOG %s %sWITH (%s%s%s)%s",
-                escapeIdentifier(catalogDescriptor.getCatalogName()),
-                StringUtils.isNotEmpty(comment)
-                        ? String.format("COMMENT '%s' ", EncodingUtils.escapeSingleQuotes(comment))
-                        : "",
-                System.lineSeparator(),
-                extractFormattedOptions(catalogDescriptor.getConfiguration().toMap(), printIndent)
-                        .orElse(""),
-                System.lineSeparator(),
-                System.lineSeparator());
+        final Optional<String> comment = catalogDescriptor.getComment();
+        StringBuilder sb = new StringBuilder();
+        sb.append("CREATE CATALOG ")
+                .append(EncodingUtils.escapeIdentifier(catalogDescriptor.getCatalogName()))
+                .append("\n");
+        comment.ifPresent(c -> sb.append(formatComment(c)).append("\n"));
+        extractFormattedOptions(catalogDescriptor.getConfiguration().toMap(), PRINT_INDENT)
+                .ifPresent(o -> sb.append("WITH (\n").append(o).append("\n)\n"));
+        return sb.toString();
     }
 
     static String buildCreateFormattedPrefix(
@@ -178,10 +163,7 @@ public class ShowCreateUtil {
                         comment -> {
                             if (StringUtils.isNotEmpty(comment)) {
                                 sb.append(" ");
-                                sb.append(
-                                        String.format(
-                                                "COMMENT '%s'",
-                                                EncodingUtils.escapeSingleQuotes(comment)));
+                                sb.append(formatComment(comment));
                             }
                         });
         return sb.toString();
@@ -213,12 +195,14 @@ public class ShowCreateUtil {
                         .collect(Collectors.joining("\n")));
     }
 
-    static Optional<String> extractFormattedComment(ResolvedCatalogBaseTable<?> table) {
-        String comment = table.getComment();
-        if (StringUtils.isNotEmpty(comment)) {
-            return Optional.of(EncodingUtils.escapeSingleQuotes(comment));
-        }
-        return Optional.empty();
+    private static String formatComment(String comment) {
+        return String.format("COMMENT '%s'", EncodingUtils.escapeSingleQuotes(comment));
+    }
+
+    static Optional<String> extractComment(ResolvedCatalogBaseTable<?> table) {
+        return StringUtils.isEmpty(table.getComment())
+                ? Optional.empty()
+                : Optional.of(table.getComment());
     }
 
     static Optional<String> extractFormattedDistributedInfo(ResolvedCatalogTable catalogTable) {
@@ -248,13 +232,19 @@ public class ShowCreateUtil {
                                                 printIndent,
                                                 EncodingUtils.escapeSingleQuotes(entry.getKey()),
                                                 EncodingUtils.escapeSingleQuotes(entry.getValue())))
+                        .sorted()
                         .collect(Collectors.joining("," + System.lineSeparator())));
     }
 
-    static String extractFormattedColumnNames(ResolvedCatalogBaseTable<?> baseTable) {
+    static String extractFormattedColumnNames(
+            ResolvedCatalogBaseTable<?> baseTable, String printIndent) {
         return baseTable.getResolvedSchema().getColumns().stream()
-                .map(Column::getName)
-                .map(EncodingUtils::escapeIdentifier)
-                .collect(Collectors.joining(", "));
+                .map(
+                        column ->
+                                String.format(
+                                        "%s%s",
+                                        printIndent,
+                                        EncodingUtils.escapeIdentifier(column.getName())))
+                .collect(Collectors.joining(",\n"));
     }
 }
