@@ -52,7 +52,6 @@ import org.apache.flink.table.catalog.CatalogManager;
 import org.apache.flink.table.catalog.CatalogStore;
 import org.apache.flink.table.catalog.CatalogStoreHolder;
 import org.apache.flink.table.catalog.Column;
-import org.apache.flink.table.catalog.ConnectorCatalogTable;
 import org.apache.flink.table.catalog.ContextResolvedTable;
 import org.apache.flink.table.catalog.FunctionCatalog;
 import org.apache.flink.table.catalog.FunctionLanguage;
@@ -81,6 +80,8 @@ import org.apache.flink.table.factories.TableFactoryUtil;
 import org.apache.flink.table.functions.ScalarFunction;
 import org.apache.flink.table.functions.UserDefinedFunction;
 import org.apache.flink.table.functions.UserDefinedFunctionHelper;
+import org.apache.flink.table.legacy.sinks.TableSink;
+import org.apache.flink.table.legacy.sources.TableSource;
 import org.apache.flink.table.module.Module;
 import org.apache.flink.table.module.ModuleEntry;
 import org.apache.flink.table.module.ModuleManager;
@@ -108,9 +109,6 @@ import org.apache.flink.table.operations.utils.OperationTreeBuilder;
 import org.apache.flink.table.resource.ResourceManager;
 import org.apache.flink.table.resource.ResourceType;
 import org.apache.flink.table.resource.ResourceUri;
-import org.apache.flink.table.sinks.TableSink;
-import org.apache.flink.table.sources.TableSource;
-import org.apache.flink.table.sources.TableSourceValidation;
 import org.apache.flink.table.types.AbstractDataType;
 import org.apache.flink.table.types.DataType;
 import org.apache.flink.table.types.utils.DataTypeUtils;
@@ -485,22 +483,35 @@ public class TableEnvironmentImpl implements TableEnvironmentInternal {
 
     @Override
     public void createTemporaryTable(String path, TableDescriptor descriptor) {
+        this.createTemporaryTable(path, descriptor, false);
+    }
+
+    @Override
+    public void createTemporaryTable(
+            String path, TableDescriptor descriptor, boolean ignoreIfExists) {
         Preconditions.checkNotNull(path, "Path must not be null.");
         Preconditions.checkNotNull(descriptor, "Table descriptor must not be null.");
 
         final ObjectIdentifier tableIdentifier =
                 catalogManager.qualifyIdentifier(getParser().parseIdentifier(path));
-        catalogManager.createTemporaryTable(descriptor.toCatalogTable(), tableIdentifier, false);
+        catalogManager.createTemporaryTable(
+                descriptor.toCatalogTable(), tableIdentifier, ignoreIfExists);
     }
 
     @Override
     public void createTable(String path, TableDescriptor descriptor) {
+        this.createTable(path, descriptor, false);
+    }
+
+    @Override
+    public boolean createTable(String path, TableDescriptor descriptor, boolean ignoreIfExists) {
         Preconditions.checkNotNull(path, "Path must not be null.");
         Preconditions.checkNotNull(descriptor, "Table descriptor must not be null.");
 
         final ObjectIdentifier tableIdentifier =
                 catalogManager.qualifyIdentifier(getParser().parseIdentifier(path));
-        catalogManager.createTable(descriptor.toCatalogTable(), tableIdentifier, false);
+        return catalogManager.createTable(
+                descriptor.toCatalogTable(), tableIdentifier, ignoreIfExists);
     }
 
     @Override
@@ -531,6 +542,24 @@ public class TableEnvironmentImpl implements TableEnvironmentInternal {
         catalogManager.createTemporaryTable(tableTable, tableIdentifier, false);
     }
 
+    @Override
+    public void createView(String path, Table view) {
+        createView(path, view, false);
+    }
+
+    @Override
+    public boolean createView(String path, Table view, boolean ignoreIfExists) {
+        Preconditions.checkNotNull(path, "Path must not be null.");
+        Preconditions.checkNotNull(view, "Table view must not be null.");
+        UnresolvedIdentifier identifier = getParser().parseIdentifier(path);
+
+        ObjectIdentifier viewIdentifier = catalogManager.qualifyIdentifier(identifier);
+        QueryOperation queryOperation =
+                qualifyQueryOperation(viewIdentifier, view.getQueryOperation());
+        CatalogBaseTable tableTable = new QueryOperationCatalogView(queryOperation);
+        return catalogManager.createTable(tableTable, viewIdentifier, ignoreIfExists);
+    }
+
     @Override
     public Table scan(String... tablePath) {
         UnresolvedIdentifier unresolvedIdentifier = UnresolvedIdentifier.of(tablePath);
@@ -589,7 +618,10 @@ public class TableEnvironmentImpl implements TableEnvironmentInternal {
 
     @Override
     public String[] listDatabases() {
-        return catalogManager.getCatalog(catalogManager.getCurrentCatalog()).get().listDatabases()
+        return catalogManager
+                .getCatalog(catalogManager.getCurrentCatalog())
+                .get()
+                .listDatabases()
                 .stream()
                 .sorted()
                 .toArray(String[]::new);
@@ -634,6 +666,18 @@ public class TableEnvironmentImpl implements TableEnvironmentInternal {
         }
     }
 
+    @Override
+    public boolean dropTable(String path) {
+        return dropTable(path, true);
+    }
+
+    @Override
+    public boolean dropTable(String path, boolean ignoreIfNotExists) {
+        UnresolvedIdentifier unresolvedIdentifier = getParser().parseIdentifier(path);
+        ObjectIdentifier identifier = catalogManager.qualifyIdentifier(unresolvedIdentifier);
+        return catalogManager.dropTable(identifier, ignoreIfNotExists);
+    }
+
     @Override
     public boolean dropTemporaryView(String path) {
         UnresolvedIdentifier unresolvedIdentifier = getParser().parseIdentifier(path);
@@ -646,6 +690,18 @@ public class TableEnvironmentImpl implements TableEnvironmentInternal {
         }
     }
 
+    @Override
+    public boolean dropView(String path) {
+        return dropView(path, true);
+    }
+
+    @Override
+    public boolean dropView(String path, boolean ignoreIfNotExists) {
+        UnresolvedIdentifier unresolvedIdentifier = getParser().parseIdentifier(path);
+        ObjectIdentifier identifier = catalogManager.qualifyIdentifier(unresolvedIdentifier);
+        return catalogManager.dropView(identifier, ignoreIfNotExists);
+    }
+
     @Override
     public String[] listUserDefinedFunctions() {
         String[] functions = functionCatalog.getUserDefinedFunctions();
@@ -892,8 +948,7 @@ public class TableEnvironmentImpl implements TableEnvironmentInternal {
         }
         Catalog catalog =
                 catalogManager.getCatalogOrThrowException(tableIdentifier.getCatalogName());
-        ResolvedCatalogTable catalogTable =
-                catalogManager.resolveCatalogTable(createTableOperation.getCatalogTable());
+        ResolvedCatalogTable catalogTable = createTableOperation.getCatalogTable();
         Optional<DynamicTableSink> stagingDynamicTableSink =
                 getSupportsStagingDynamicTableSink(createTableOperation, catalog, catalogTable);
         if (stagingDynamicTableSink.isPresent()) {
@@ -927,8 +982,7 @@ public class TableEnvironmentImpl implements TableEnvironmentInternal {
         ObjectIdentifier tableIdentifier = createTableOperation.getTableIdentifier();
         Catalog catalog =
                 catalogManager.getCatalogOrThrowException(tableIdentifier.getCatalogName());
-        ResolvedCatalogTable catalogTable =
-                catalogManager.resolveCatalogTable(createTableOperation.getCatalogTable());
+        ResolvedCatalogTable catalogTable = createTableOperation.getCatalogTable();
         Optional<DynamicTableSink> stagingDynamicTableSink =
                 getSupportsStagingDynamicTableSink(createTableOperation, catalog, catalogTable);
         if (stagingDynamicTableSink.isPresent()) {
@@ -958,7 +1012,6 @@ public class TableEnvironmentImpl implements TableEnvironmentInternal {
             ResolvedCatalogTable catalogTable) {
         if (tableConfig.get(TableConfigOptions.TABLE_RTAS_CTAS_ATOMICITY_ENABLED)) {
             if (!TableFactoryUtil.isLegacyConnectorOptions(
-                    catalog,
                     tableConfig,
                     isStreamingMode,
                     createTableOperation.getTableIdentifier(),
@@ -1295,102 +1348,10 @@ public class TableEnvironmentImpl implements TableEnvironmentInternal {
         return queryOperation;
     }
 
-    /**
-     * Subclasses can override this method to add additional checks.
-     *
-     * @param tableSource tableSource to validate
-     */
-    protected void validateTableSource(TableSource<?> tableSource) {
-        TableSourceValidation.validateTableSource(tableSource, tableSource.getTableSchema());
-    }
-
     protected List<Transformation<?>> translate(List<ModifyOperation> modifyOperations) {
         return planner.translate(modifyOperations);
     }
 
-    @Override
-    public void registerTableSourceInternal(String name, TableSource<?> tableSource) {
-        validateTableSource(tableSource);
-        ObjectIdentifier objectIdentifier =
-                catalogManager.qualifyIdentifier(UnresolvedIdentifier.of(name));
-        Optional<CatalogBaseTable> table = getTemporaryTable(objectIdentifier);
-
-        if (table.isPresent()) {
-            if (table.get() instanceof ConnectorCatalogTable<?, ?>) {
-                ConnectorCatalogTable<?, ?> sourceSinkTable =
-                        (ConnectorCatalogTable<?, ?>) table.get();
-                if (sourceSinkTable.getTableSource().isPresent()) {
-                    throw new ValidationException(
-                            String.format(
-                                    "Table '%s' already exists. Please choose a different name.",
-                                    name));
-                } else {
-                    // wrapper contains only sink (not source)
-                    ConnectorCatalogTable sourceAndSink =
-                            ConnectorCatalogTable.sourceAndSink(
-                                    tableSource,
-                                    sourceSinkTable.getTableSink().get(),
-                                    !IS_STREAM_TABLE);
-                    catalogManager.dropTemporaryTable(objectIdentifier, false);
-                    catalogManager.createTemporaryTable(sourceAndSink, objectIdentifier, false);
-                }
-            } else {
-                throw new ValidationException(
-                        String.format(
-                                "Table '%s' already exists. Please choose a different name.",
-                                name));
-            }
-        } else {
-            ConnectorCatalogTable source =
-                    ConnectorCatalogTable.source(tableSource, !IS_STREAM_TABLE);
-            catalogManager.createTemporaryTable(source, objectIdentifier, false);
-        }
-    }
-
-    @Override
-    public void registerTableSinkInternal(String name, TableSink<?> tableSink) {
-        ObjectIdentifier objectIdentifier =
-                catalogManager.qualifyIdentifier(UnresolvedIdentifier.of(name));
-        Optional<CatalogBaseTable> table = getTemporaryTable(objectIdentifier);
-
-        if (table.isPresent()) {
-            if (table.get() instanceof ConnectorCatalogTable<?, ?>) {
-                ConnectorCatalogTable<?, ?> sourceSinkTable =
-                        (ConnectorCatalogTable<?, ?>) table.get();
-                if (sourceSinkTable.getTableSink().isPresent()) {
-                    throw new ValidationException(
-                            String.format(
-                                    "Table '%s' already exists. Please choose a different name.",
-                                    name));
-                } else {
-                    // wrapper contains only sink (not source)
-                    ConnectorCatalogTable sourceAndSink =
-                            ConnectorCatalogTable.sourceAndSink(
-                                    sourceSinkTable.getTableSource().get(),
-                                    tableSink,
-                                    !IS_STREAM_TABLE);
-                    catalogManager.dropTemporaryTable(objectIdentifier, false);
-                    catalogManager.createTemporaryTable(sourceAndSink, objectIdentifier, false);
-                }
-            } else {
-                throw new ValidationException(
-                        String.format(
-                                "Table '%s' already exists. Please choose a different name.",
-                                name));
-            }
-        } else {
-            ConnectorCatalogTable sink = ConnectorCatalogTable.sink(tableSink, !IS_STREAM_TABLE);
-            catalogManager.createTemporaryTable(sink, objectIdentifier, false);
-        }
-    }
-
-    private Optional<CatalogBaseTable> getTemporaryTable(ObjectIdentifier identifier) {
-        return catalogManager
-                .getTable(identifier)
-                .filter(ContextResolvedTable::isTemporary)
-                .map(ContextResolvedTable::getResolvedTable);
-    }
-
     @VisibleForTesting
     public TableImpl createTable(QueryOperation tableOperation) {
         return TableImpl.createTable(
