@@ -19,19 +19,14 @@
 package org.apache.flink.table.operations;
 
 import org.apache.flink.annotation.Internal;
-import org.apache.flink.table.api.TableException;
 import org.apache.flink.table.catalog.ContextResolvedTable;
 import org.apache.flink.table.catalog.ResolvedSchema;
 import org.apache.flink.table.connector.source.DynamicTableSource;
-import org.apache.flink.table.utils.EncodingUtils;
-
-import javax.annotation.Nullable;
 
 import java.util.Collections;
 import java.util.LinkedHashMap;
 import java.util.List;
 import java.util.Map;
-import java.util.stream.Collectors;
 
 /**
  * Describes a query operation from a {@link ContextResolvedTable}.
@@ -43,18 +38,11 @@ import java.util.stream.Collectors;
 @Internal
 public class SourceQueryOperation implements QueryOperation {
 
+    private static final String INPUT_ALIAS = "$$T_SOURCE";
     private final ContextResolvedTable contextResolvedTable;
-    private final @Nullable Map<String, String> dynamicOptions;
 
     public SourceQueryOperation(ContextResolvedTable contextResolvedTable) {
-        this(contextResolvedTable, null);
-    }
-
-    public SourceQueryOperation(
-            ContextResolvedTable contextResolvedTable,
-            @Nullable Map<String, String> dynamicOptions) {
         this.contextResolvedTable = contextResolvedTable;
-        this.dynamicOptions = dynamicOptions;
     }
 
     public ContextResolvedTable getContextResolvedTable() {
@@ -71,9 +59,6 @@ public class SourceQueryOperation implements QueryOperation {
         Map<String, Object> args = new LinkedHashMap<>();
         args.put("identifier", getContextResolvedTable().getIdentifier().asSummaryString());
         args.put("fields", getResolvedSchema().getColumnNames());
-        if (dynamicOptions != null) {
-            args.put("options", dynamicOptions);
-        }
 
         return OperationUtils.formatWithChildren(
                 "CatalogTable", args, getChildren(), Operation::asSummaryString);
@@ -81,19 +66,11 @@ public class SourceQueryOperation implements QueryOperation {
 
     @Override
     public String asSerializableString() {
-        String s =
-                String.format(
-                        "SELECT %s FROM %s",
-                        getResolvedSchema().getColumnNames().stream()
-                                .map(EncodingUtils::escapeIdentifier)
-                                .collect(Collectors.joining(", ")),
-                        getContextResolvedTable().getIdentifier().asSerializableString());
-
-        if (dynamicOptions != null && !dynamicOptions.isEmpty()) {
-            throw new TableException("Dynamic source options are not SQL serializable yet.");
-        }
-
-        return s;
+        return String.format(
+                "SELECT %s FROM %s %s",
+                OperationUtils.formatSelectColumns(getResolvedSchema(), INPUT_ALIAS),
+                getContextResolvedTable().getIdentifier().asSerializableString(),
+                INPUT_ALIAS);
     }
 
     @Override
@@ -105,8 +82,4 @@ public class SourceQueryOperation implements QueryOperation {
     public <T> T accept(QueryOperationVisitor<T> visitor) {
         return visitor.visit(this);
     }
-
-    public @Nullable Map<String, String> getDynamicOptions() {
-        return dynamicOptions;
-    }
 }
