@@ -18,10 +18,11 @@
 
 package org.apache.flink.table.operations.ddl;
 
+import org.apache.flink.annotation.Internal;
 import org.apache.flink.table.api.internal.TableResultImpl;
 import org.apache.flink.table.api.internal.TableResultInternal;
-import org.apache.flink.table.catalog.CatalogTable;
 import org.apache.flink.table.catalog.ObjectIdentifier;
+import org.apache.flink.table.catalog.ResolvedCatalogTable;
 import org.apache.flink.table.operations.Operation;
 import org.apache.flink.table.operations.OperationUtils;
 
@@ -30,15 +31,16 @@ import java.util.LinkedHashMap;
 import java.util.Map;
 
 /** Operation to describe a CREATE TABLE statement. */
+@Internal
 public class CreateTableOperation implements CreateOperation {
     private final ObjectIdentifier tableIdentifier;
-    private final CatalogTable catalogTable;
+    private final ResolvedCatalogTable catalogTable;
     private final boolean ignoreIfExists;
     private final boolean isTemporary;
 
     public CreateTableOperation(
             ObjectIdentifier tableIdentifier,
-            CatalogTable catalogTable,
+            ResolvedCatalogTable catalogTable,
             boolean ignoreIfExists,
             boolean isTemporary) {
         this.tableIdentifier = tableIdentifier;
@@ -47,7 +49,7 @@ public class CreateTableOperation implements CreateOperation {
         this.isTemporary = isTemporary;
     }
 
-    public CatalogTable getCatalogTable() {
+    public ResolvedCatalogTable getCatalogTable() {
         return catalogTable;
     }
 
