@@ -18,6 +18,10 @@
 
 package org.apache.flink.table.operations.ddl;
 
+import org.apache.flink.annotation.Internal;
+import org.apache.flink.table.api.TableException;
+import org.apache.flink.table.api.internal.TableResultImpl;
+import org.apache.flink.table.api.internal.TableResultInternal;
 import org.apache.flink.table.catalog.CatalogFunction;
 import org.apache.flink.table.catalog.CatalogFunctionImpl;
 import org.apache.flink.table.catalog.FunctionCatalog;
@@ -33,6 +37,7 @@ import java.util.List;
 import java.util.Map;
 
 /** Operation to describe a CREATE FUNCTION statement for temporary system function. */
+@Internal
 public class CreateTempSystemFunctionOperation implements CreateOperation {
     private final String functionName;
     private final boolean ignoreIfExists;
@@ -83,4 +88,15 @@ public class CreateTempSystemFunctionOperation implements CreateOperation {
                 Collections.emptyList(),
                 Operation::asSummaryString);
     }
+
+    @Override
+    public TableResultInternal execute(Context ctx) {
+        try {
+            ctx.getFunctionCatalog()
+                    .registerTemporarySystemFunction(functionName, catalogFunction, ignoreIfExists);
+            return TableResultImpl.TABLE_RESULT_OK;
+        } catch (Exception e) {
+            throw new TableException(String.format("Could not execute %s", asSummaryString()), e);
+        }
+    }
 }
