@@ -23,12 +23,15 @@ import org.apache.flink.table.api.Schema;
 import org.apache.flink.table.api.ValidationException;
 import org.apache.flink.table.catalog.exceptions.CatalogException;
 import org.apache.flink.table.catalog.listener.AlterDatabaseEvent;
+import org.apache.flink.table.catalog.listener.AlterModelEvent;
 import org.apache.flink.table.catalog.listener.AlterTableEvent;
 import org.apache.flink.table.catalog.listener.CatalogModificationEvent;
 import org.apache.flink.table.catalog.listener.CatalogModificationListener;
 import org.apache.flink.table.catalog.listener.CreateDatabaseEvent;
+import org.apache.flink.table.catalog.listener.CreateModelEvent;
 import org.apache.flink.table.catalog.listener.CreateTableEvent;
 import org.apache.flink.table.catalog.listener.DropDatabaseEvent;
+import org.apache.flink.table.catalog.listener.DropModelEvent;
 import org.apache.flink.table.catalog.listener.DropTableEvent;
 import org.apache.flink.table.utils.CatalogManagerMocks;
 import org.apache.flink.table.utils.ExpressionResolverMocks;
@@ -42,6 +45,7 @@ import java.util.Arrays;
 import java.util.Collections;
 import java.util.HashMap;
 import java.util.HashSet;
+import java.util.Map;
 import java.util.concurrent.CompletableFuture;
 import java.util.concurrent.TimeUnit;
 
@@ -144,11 +148,7 @@ class CatalogManagerTest {
 
         // Create a table
         catalogManager.createTable(
-                CatalogTable.of(
-                        Schema.newBuilder().build(),
-                        null,
-                        Collections.emptyList(),
-                        Collections.emptyMap()),
+                CatalogTable.newBuilder().schema(Schema.newBuilder().build()).build(),
                 ObjectIdentifier.of(
                         catalogManager.getCurrentCatalog(),
                         catalogManager.getCurrentDatabase(),
@@ -161,11 +161,7 @@ class CatalogManagerTest {
 
         // Create a temporary table
         catalogManager.createTemporaryTable(
-                CatalogTable.of(
-                        Schema.newBuilder().build(),
-                        null,
-                        Collections.emptyList(),
-                        Collections.emptyMap()),
+                CatalogTable.newBuilder().schema(Schema.newBuilder().build()).build(),
                 ObjectIdentifier.of(
                         catalogManager.getCurrentCatalog(),
                         catalogManager.getCurrentDatabase(),
@@ -178,11 +174,10 @@ class CatalogManagerTest {
 
         // Alter a table
         catalogManager.alterTable(
-                CatalogTable.of(
-                        Schema.newBuilder().build(),
-                        "table1 comment",
-                        Collections.emptyList(),
-                        Collections.emptyMap()),
+                CatalogTable.newBuilder()
+                        .schema(Schema.newBuilder().build())
+                        .comment("table1 comment")
+                        .build(),
                 ObjectIdentifier.of(
                         catalogManager.getCurrentCatalog(),
                         catalogManager.getCurrentDatabase(),
@@ -258,6 +253,119 @@ class CatalogManagerTest {
                 .hasMessage("Cannot drop a database which is currently in use.");
     }
 
+    @Test
+    public void testModelModificationListener() throws Exception {
+        CompletableFuture<CreateModelEvent> createFuture = new CompletableFuture<>();
+        CompletableFuture<CreateModelEvent> createTemporaryFuture = new CompletableFuture<>();
+        CompletableFuture<AlterModelEvent> alterFuture = new CompletableFuture<>();
+        CompletableFuture<DropModelEvent> dropFuture = new CompletableFuture<>();
+        CompletableFuture<DropModelEvent> dropTemporaryFuture = new CompletableFuture<>();
+        CatalogManager catalogManager =
+                CatalogManagerMocks.preparedCatalogManager()
+                        .defaultCatalog("default", new GenericInMemoryCatalog("default"))
+                        .classLoader(CatalogManagerTest.class.getClassLoader())
+                        .config(new Configuration())
+                        .catalogModificationListeners(
+                                Collections.singletonList(
+                                        new TestingModelModificationListener(
+                                                createFuture,
+                                                createTemporaryFuture,
+                                                alterFuture,
+                                                dropFuture,
+                                                dropTemporaryFuture)))
+                        .catalogStoreHolder(
+                                CatalogStoreHolder.newBuilder()
+                                        .classloader(CatalogManagerTest.class.getClassLoader())
+                                        .catalogStore(new GenericInMemoryCatalogStore())
+                                        .config(new Configuration())
+                                        .build())
+                        .build();
+
+        catalogManager.initSchemaResolver(
+                true, ExpressionResolverMocks.dummyResolver(), new ParserMock());
+
+        HashMap<String, String> options =
+                new HashMap<String, String>() {
+                    {
+                        put("provider", "openai");
+                        put("task", "TEXT_GENERATION");
+                    }
+                };
+
+        // Create a model
+        catalogManager.createModel(
+                CatalogModel.of(Schema.derived(), Schema.derived(), options, null),
+                ObjectIdentifier.of(
+                        catalogManager.getCurrentCatalog(),
+                        catalogManager.getCurrentDatabase(),
+                        "model1"),
+                true);
+        CreateModelEvent createModelEvent = createFuture.get(10, TimeUnit.SECONDS);
+        assertThat(createModelEvent.identifier().getObjectName()).isEqualTo("model1");
+        assertThat(createModelEvent.ignoreIfExists()).isTrue();
+
+        // Create a temporary table
+        catalogManager.createTemporaryModel(
+                CatalogModel.of(
+                        Schema.newBuilder().build(), Schema.newBuilder().build(), options, null),
+                ObjectIdentifier.of(
+                        catalogManager.getCurrentCatalog(),
+                        catalogManager.getCurrentDatabase(),
+                        "model2"),
+                false);
+        CreateModelEvent createTemporaryEvent = createTemporaryFuture.get(10, TimeUnit.SECONDS);
+        assertThat(createTemporaryEvent.isTemporary()).isTrue();
+        assertThat(createTemporaryEvent.identifier().getObjectName()).isEqualTo("model2");
+        assertThat(createTemporaryEvent.ignoreIfExists()).isFalse();
+
+        HashMap<String, String> azureOptions =
+                new HashMap<String, String>() {
+                    {
+                        put("provider", "azure");
+                        put("endpoint", "some-endpoint");
+                    }
+                };
+        // Alter a model
+        catalogManager.alterModel(
+                CatalogModel.of(Schema.derived(), Schema.derived(), azureOptions, "model1 comment"),
+                ObjectIdentifier.of(
+                        catalogManager.getCurrentCatalog(),
+                        catalogManager.getCurrentDatabase(),
+                        "model1"),
+                false);
+        Map<String, String> expectedOptions = new HashMap<>();
+        expectedOptions.put("provider", "azure");
+        expectedOptions.put("endpoint", "some-endpoint");
+        AlterModelEvent alterEvent = alterFuture.get(10, TimeUnit.SECONDS);
+        assertThat(alterEvent.identifier().getObjectName()).isEqualTo("model1");
+        assertThat(alterEvent.newModel().getComment()).isEqualTo("model1 comment");
+        assertThat(alterEvent.newModel().getOptions()).isEqualTo(expectedOptions);
+        assertThat(alterEvent.ignoreIfNotExists()).isFalse();
+
+        // Drop a model
+        catalogManager.dropModel(
+                ObjectIdentifier.of(
+                        catalogManager.getCurrentCatalog(),
+                        catalogManager.getCurrentDatabase(),
+                        "model1"),
+                true);
+        DropModelEvent dropEvent = dropFuture.get(10, TimeUnit.SECONDS);
+        assertThat(dropEvent.ignoreIfNotExists()).isTrue();
+        assertThat(dropEvent.identifier().getObjectName()).isEqualTo("model1");
+
+        // Drop a temporary model
+        catalogManager.dropTemporaryModel(
+                ObjectIdentifier.of(
+                        catalogManager.getCurrentCatalog(),
+                        catalogManager.getCurrentDatabase(),
+                        "model2"),
+                false);
+        DropModelEvent dropTemporaryEvent = dropTemporaryFuture.get(10, TimeUnit.SECONDS);
+        assertThat(dropTemporaryEvent.isTemporary()).isTrue();
+        assertThat(dropTemporaryEvent.ignoreIfNotExists()).isFalse();
+        assertThat(dropTemporaryEvent.identifier().getObjectName()).isEqualTo("model2");
+    }
+
     private CatalogManager createCatalogManager(@Nullable CatalogModificationListener listener) {
         CatalogManager.Builder builder =
                 CatalogManager.newBuilder()
@@ -350,6 +458,49 @@ class CatalogManagerTest {
         }
     }
 
+    /** Testing model modification listener. */
+    static class TestingModelModificationListener implements CatalogModificationListener {
+        private final CompletableFuture<CreateModelEvent> createFuture;
+        private final CompletableFuture<CreateModelEvent> createTemporaryFuture;
+        private final CompletableFuture<AlterModelEvent> alterFuture;
+        private final CompletableFuture<DropModelEvent> dropFuture;
+        private final CompletableFuture<DropModelEvent> dropTemporaryFuture;
+
+        TestingModelModificationListener(
+                CompletableFuture<CreateModelEvent> createFuture,
+                CompletableFuture<CreateModelEvent> createTemporaryFuture,
+                CompletableFuture<AlterModelEvent> alterFuture,
+                CompletableFuture<DropModelEvent> dropFuture,
+                CompletableFuture<DropModelEvent> dropTemporaryFuture) {
+            this.createFuture = createFuture;
+            this.createTemporaryFuture = createTemporaryFuture;
+            this.alterFuture = alterFuture;
+            this.dropFuture = dropFuture;
+            this.dropTemporaryFuture = dropTemporaryFuture;
+        }
+
+        @Override
+        public void onEvent(CatalogModificationEvent event) {
+            if (event instanceof CreateModelEvent) {
+                if (((CreateModelEvent) event).isTemporary()) {
+                    createTemporaryFuture.complete((CreateModelEvent) event);
+                } else {
+                    createFuture.complete((CreateModelEvent) event);
+                }
+            } else if (event instanceof AlterModelEvent) {
+                alterFuture.complete((AlterModelEvent) event);
+            } else if (event instanceof DropModelEvent) {
+                if (((DropModelEvent) event).isTemporary()) {
+                    dropTemporaryFuture.complete((DropModelEvent) event);
+                } else {
+                    dropFuture.complete((DropModelEvent) event);
+                }
+            } else {
+                throw new UnsupportedOperationException();
+            }
+        }
+    }
+
     @Test
     void testCatalogStore() throws Exception {
         CatalogStore catalogStore = new GenericInMemoryCatalogStore();
@@ -467,17 +618,19 @@ class CatalogManagerTest {
                 new CatalogDatabaseImpl(Collections.emptyMap(), "database for exist_cat"),
                 false);
         catalogManager.createTable(
-                CatalogTable.of(
-                        Schema.newBuilder().build(),
-                        null,
-                        Collections.emptyList(),
-                        Collections.emptyMap()),
+                CatalogTable.newBuilder().schema(Schema.newBuilder().build()).build(),
                 ObjectIdentifier.of("exist_cat", "cat_db", "test_table"),
                 false);
+        catalogManager.createModel(
+                CatalogModel.of(Schema.derived(), Schema.derived(), Collections.emptyMap(), null),
+                ObjectIdentifier.of("exist_cat", "cat_db", "test_model"),
+                false);
         assertThat(catalogManager.listSchemas("exist_cat"))
                 .isEqualTo(new HashSet<>(Arrays.asList("default", "cat_db")));
         assertThat(catalogManager.listTables("exist_cat", "cat_db"))
                 .isEqualTo(Collections.singleton("test_table"));
+        assertThat(catalogManager.listModels("exist_cat", "cat_db"))
+                .isEqualTo(Collections.singleton("test_model"));
         catalogManager.setCurrentCatalog("exist_cat");
         assertThat(catalogManager.listSchemas())
                 .isEqualTo(
