@@ -37,6 +37,10 @@ public final class SinkTestStep extends TableTestStep {
     public final @Nullable List<Row> expectedAfterRestore;
     public final @Nullable List<String> expectedBeforeRestoreStrings;
     public final @Nullable List<String> expectedAfterRestoreStrings;
+    // These are added for situations where we need to specify the output in batch.
+    // In many cases, the "expectBeforeRestore*" variables are sufficient.
+    public final @Nullable List<Row> expectedMaterializedRows;
+    public final @Nullable List<String> expectedMaterializedStrings;
     public final boolean testChangelogData;
 
     SinkTestStep(
@@ -49,20 +53,28 @@ public final class SinkTestStep extends TableTestStep {
             @Nullable List<Row> expectedAfterRestore,
             @Nullable List<String> expectedBeforeRestoreStrings,
             @Nullable List<String> expectedAfterRestoreStrings,
+            @Nullable List<Row> expectedMaterializedRows,
+            @Nullable List<String> expectedMaterializedStrings,
             boolean testChangelogData) {
         super(name, schemaComponents, distribution, partitionKeys, options);
-        if (expectedBeforeRestore != null && expectedAfterRestoreStrings != null) {
+        boolean hasRowsSet =
+                expectedBeforeRestore != null
+                        || expectedAfterRestore != null
+                        || expectedMaterializedRows != null;
+        boolean hasStringsSet =
+                expectedBeforeRestoreStrings != null
+                        || expectedAfterRestoreStrings != null
+                        || expectedMaterializedStrings != null;
+        if (hasRowsSet && hasStringsSet) {
             throw new IllegalArgumentException(
-                    "You can not mix Row/String representation in before/after restore data.");
-        }
-        if (expectedBeforeRestoreStrings != null && expectedAfterRestore != null) {
-            throw new IllegalArgumentException(
-                    "You can not mix Row/String representation in before/after restore data.");
+                    "You can not mix Row/String representations in restore data.");
         }
         this.expectedBeforeRestore = expectedBeforeRestore;
         this.expectedAfterRestore = expectedAfterRestore;
         this.expectedBeforeRestoreStrings = expectedBeforeRestoreStrings;
         this.expectedAfterRestoreStrings = expectedAfterRestoreStrings;
+        this.expectedMaterializedRows = expectedMaterializedRows;
+        this.expectedMaterializedStrings = expectedMaterializedStrings;
         this.testChangelogData = testChangelogData;
     }
 
@@ -101,6 +113,18 @@ public final class SinkTestStep extends TableTestStep {
         return data;
     }
 
+    public List<String> getExpectedMaterializedResultsAsStrings() {
+        if (expectedMaterializedStrings != null) {
+            return expectedMaterializedStrings;
+        }
+        if (expectedMaterializedRows != null) {
+            return expectedMaterializedRows.stream()
+                    .map(Row::toString)
+                    .collect(Collectors.toList());
+        }
+        return getExpectedAsStrings();
+    }
+
     @Override
     public TestKind getKind() {
         return expectedBeforeRestore == null && expectedBeforeRestoreStrings == null
@@ -110,7 +134,7 @@ public final class SinkTestStep extends TableTestStep {
                         : TestKind.SINK_WITH_RESTORE_DATA;
     }
 
-    public boolean getTestChangelogData() {
+    public boolean shouldTestChangelogData() {
         return testChangelogData;
     }
 
@@ -119,6 +143,8 @@ public final class SinkTestStep extends TableTestStep {
 
         private List<Row> expectedBeforeRestore;
         private List<Row> expectedAfterRestore;
+        private List<Row> expectedMaterializedBeforeRows;
+        private List<String> expectedMaterializedBeforeStrings;
 
         private List<String> expectedBeforeRestoreStrings;
         private List<String> expectedAfterRestoreStrings;
@@ -157,6 +183,16 @@ public final class SinkTestStep extends TableTestStep {
             return this;
         }
 
+        public Builder expectedMaterializedRows(Row... expectedRows) {
+            this.expectedMaterializedBeforeRows = Arrays.asList(expectedRows);
+            return this;
+        }
+
+        public Builder expectedMaterializedStrings(String... expectedRows) {
+            this.expectedMaterializedBeforeStrings = Arrays.asList(expectedRows);
+            return this;
+        }
+
         public Builder testChangelogData() {
             this.testChangelogData = true;
             return this;
@@ -178,6 +214,8 @@ public final class SinkTestStep extends TableTestStep {
                     expectedAfterRestore,
                     expectedBeforeRestoreStrings,
                     expectedAfterRestoreStrings,
+                    expectedMaterializedBeforeRows,
+                    expectedMaterializedBeforeStrings,
                     testChangelogData);
         }
     }
