@@ -18,13 +18,11 @@
 package org.apache.flink.table.api
 
 import org.apache.flink.table.expressions.ApiExpressionUtils._
-import org.apache.flink.table.expressions.Expression
 import org.apache.flink.table.functions.BuiltInFunctionDefinitions.{EQUALS, PLUS, TRIM}
 
-import org.hamcrest.CoreMatchers
+import org.assertj.core.api.AssertionsForClassTypes.assertThat
 import org.hamcrest.collection.IsEmptyIterable
-import org.junit.Assert._
-import org.junit.Test
+import org.junit.jupiter.api.Test
 
 import java.lang.reflect.Modifier
 
@@ -248,26 +246,23 @@ class ExpressionsConsistencyCheckTest {
     // It should be discouraged though as it might have unforeseen side effects
     val expr = lit("ABC") === $"f0".plus(Expressions.$("f1")).plus($("f2")).trim()
 
-    assertThat(
-      expr,
-      CoreMatchers.equalTo[Expression](
+    assertThat(expr).isEqualTo(
+      unresolvedCall(
+        EQUALS,
+        valueLiteral("ABC"),
         unresolvedCall(
-          EQUALS,
-          valueLiteral("ABC"),
+          TRIM,
+          valueLiteral(true),
+          valueLiteral(true),
+          valueLiteral(" "),
           unresolvedCall(
-            TRIM,
-            valueLiteral(true),
-            valueLiteral(true),
-            valueLiteral(" "),
+            PLUS,
             unresolvedCall(
               PLUS,
-              unresolvedCall(
-                PLUS,
-                unresolvedRef("f0"),
-                unresolvedRef("f1")
-              ),
-              unresolvedRef("f2")
-            )
+              unresolvedRef("f0"),
+              unresolvedRef("f1")
+            ),
+            unresolvedRef("f2")
           )
         )
       )
