@@ -28,6 +28,7 @@ import org.apache.flink.table.catalog.exceptions.CatalogException;
 import org.apache.flink.table.expressions.ResolvedExpression;
 import org.apache.flink.table.types.DataType;
 import org.apache.flink.table.types.logical.LogicalType;
+import org.apache.flink.util.StringUtils;
 
 import javax.annotation.Nullable;
 
@@ -46,6 +47,8 @@ import java.util.stream.Collectors;
 import java.util.stream.IntStream;
 import java.util.stream.Stream;
 
+import static org.apache.flink.table.utils.EncodingUtils.decodeBase64ToBytes;
+import static org.apache.flink.table.utils.EncodingUtils.encodeBytesToBase64;
 import static org.apache.flink.util.Preconditions.checkNotNull;
 
 /** Utilities for de/serializing {@link Catalog} objects into a map of string properties. */
@@ -76,7 +79,7 @@ public final class CatalogPropertiesUtil {
             serializeResolvedSchema(properties, resolvedTable.getResolvedSchema());
 
             final String comment = resolvedTable.getComment();
-            if (comment != null && comment.length() > 0) {
+            if (comment != null && !comment.isEmpty()) {
                 properties.put(COMMENT, comment);
             }
 
@@ -103,7 +106,7 @@ public final class CatalogPropertiesUtil {
             serializeResolvedSchema(properties, resolvedView.getResolvedSchema());
 
             final String comment = resolvedView.getComment();
-            if (comment != null && comment.length() > 0) {
+            if (comment != null && !comment.isEmpty()) {
                 properties.put(COMMENT, comment);
             }
 
@@ -117,6 +120,83 @@ public final class CatalogPropertiesUtil {
         }
     }
 
+    /**
+     * Serializes the given {@link ResolvedCatalogMaterializedTable} into a map of string
+     * properties.
+     */
+    public static Map<String, String> serializeCatalogMaterializedTable(
+            ResolvedCatalogMaterializedTable resolvedMaterializedTable) {
+        try {
+            final Map<String, String> properties = new HashMap<>();
+
+            serializeResolvedSchema(properties, resolvedMaterializedTable.getResolvedSchema());
+
+            final String comment = resolvedMaterializedTable.getComment();
+            if (comment != null && comment.length() > 0) {
+                properties.put(COMMENT, comment);
+            }
+
+            final Optional<Long> snapshot = resolvedMaterializedTable.getSnapshot();
+            snapshot.ifPresent(snapshotId -> properties.put(SNAPSHOT, Long.toString(snapshotId)));
+
+            serializePartitionKeys(properties, resolvedMaterializedTable.getPartitionKeys());
+
+            properties.putAll(resolvedMaterializedTable.getOptions());
+
+            properties.put(DEFINITION_QUERY, resolvedMaterializedTable.getDefinitionQuery());
+
+            IntervalFreshness intervalFreshness =
+                    resolvedMaterializedTable.getDefinitionFreshness();
+            properties.put(FRESHNESS_INTERVAL, intervalFreshness.getInterval());
+            properties.put(FRESHNESS_UNIT, intervalFreshness.getTimeUnit().name());
+
+            properties.put(
+                    LOGICAL_REFRESH_MODE, resolvedMaterializedTable.getLogicalRefreshMode().name());
+            properties.put(REFRESH_MODE, resolvedMaterializedTable.getRefreshMode().name());
+            properties.put(REFRESH_STATUS, resolvedMaterializedTable.getRefreshStatus().name());
+
+            resolvedMaterializedTable
+                    .getRefreshHandlerDescription()
+                    .ifPresent(
+                            refreshHandlerDesc ->
+                                    properties.put(REFRESH_HANDLER_DESC, refreshHandlerDesc));
+            if (resolvedMaterializedTable.getSerializedRefreshHandler() != null) {
+                properties.put(
+                        REFRESH_HANDLER_BYTES,
+                        encodeBytesToBase64(
+                                resolvedMaterializedTable.getSerializedRefreshHandler()));
+            }
+
+            return properties;
+        } catch (Exception e) {
+            throw new CatalogException("Error in serializing catalog materialized table.", e);
+        }
+    }
+
+    /** Serializes the given {@link ResolvedCatalogModel} into a map of string properties. */
+    public static Map<String, String> serializeResolvedCatalogModel(
+            ResolvedCatalogModel resolvedModel) {
+        try {
+            final Map<String, String> properties = new HashMap<>();
+
+            serializeResolvedModelSchema(
+                    properties,
+                    resolvedModel.getResolvedInputSchema(),
+                    resolvedModel.getResolvedOutputSchema());
+
+            final String comment = resolvedModel.getComment();
+            if (comment != null && !comment.isEmpty()) {
+                properties.put(COMMENT, comment);
+            }
+
+            properties.putAll(resolvedModel.getOptions());
+
+            return properties;
+        } catch (Exception e) {
+            throw new CatalogException("Error in serializing catalog model.", e);
+        }
+    }
+
     /** Deserializes the given map of string properties into an unresolved {@link CatalogTable}. */
     public static CatalogTable deserializeCatalogTable(Map<String, String> properties) {
         return deserializeCatalogTable(properties, null);
@@ -128,7 +208,7 @@ public final class CatalogPropertiesUtil {
      * @param properties The properties to deserialize from
      * @param fallbackKey The fallback key to get the schema properties. This is meant to support
      *     the old table (1.10) deserialization
-     * @return
+     * @return a catalog table instance.
      */
     public static CatalogTable deserializeCatalogTable(
             Map<String, String> properties, @Nullable String fallbackKey) {
@@ -152,12 +232,108 @@ public final class CatalogPropertiesUtil {
 
             final Map<String, String> options = deserializeOptions(properties, schemaKey);
 
-            return CatalogTable.of(schema, comment, partitionKeys, options, snapshot);
+            return CatalogTable.newBuilder()
+                    .schema(schema)
+                    .comment(comment)
+                    .partitionKeys(partitionKeys)
+                    .options(options)
+                    .snapshot(snapshot)
+                    .build();
         } catch (Exception e) {
             throw new CatalogException("Error in deserializing catalog table.", e);
         }
     }
 
+    /**
+     * Deserializes the given map of string properties into an unresolved {@link
+     * CatalogMaterializedTable}.
+     */
+    public static CatalogMaterializedTable deserializeCatalogMaterializedTable(
+            Map<String, String> properties) {
+        try {
+            final Schema schema = deserializeSchema(properties, SCHEMA);
+
+            final @Nullable String comment = properties.get(COMMENT);
+
+            final @Nullable Long snapshot =
+                    properties.containsKey(SNAPSHOT)
+                            ? getValue(properties, SNAPSHOT, Long::parseLong)
+                            : null;
+
+            final List<String> partitionKeys = deserializePartitionKeys(properties);
+
+            final Map<String, String> options = deserializeOptions(properties, SCHEMA);
+
+            final String definitionQuery = properties.get(DEFINITION_QUERY);
+
+            final String freshnessInterval = properties.get(FRESHNESS_INTERVAL);
+            final IntervalFreshness.TimeUnit timeUnit =
+                    IntervalFreshness.TimeUnit.valueOf(properties.get(FRESHNESS_UNIT));
+            final IntervalFreshness freshness = IntervalFreshness.of(freshnessInterval, timeUnit);
+
+            final CatalogMaterializedTable.LogicalRefreshMode logicalRefreshMode =
+                    CatalogMaterializedTable.LogicalRefreshMode.valueOf(
+                            properties.get(LOGICAL_REFRESH_MODE));
+            final CatalogMaterializedTable.RefreshMode refreshMode =
+                    CatalogMaterializedTable.RefreshMode.valueOf(properties.get(REFRESH_MODE));
+            final CatalogMaterializedTable.RefreshStatus refreshStatus =
+                    CatalogMaterializedTable.RefreshStatus.valueOf(properties.get(REFRESH_STATUS));
+
+            final @Nullable String refreshHandlerDesc = properties.get(REFRESH_HANDLER_DESC);
+            final @Nullable String refreshHandlerStringBytes =
+                    properties.get(REFRESH_HANDLER_BYTES);
+            final @Nullable byte[] refreshHandlerBytes =
+                    StringUtils.isNullOrWhitespaceOnly(refreshHandlerStringBytes)
+                            ? null
+                            : decodeBase64ToBytes(refreshHandlerStringBytes);
+
+            CatalogMaterializedTable.Builder builder = CatalogMaterializedTable.newBuilder();
+            builder.schema(schema)
+                    .comment(comment)
+                    .partitionKeys(partitionKeys)
+                    .options(options)
+                    .snapshot(snapshot)
+                    .definitionQuery(definitionQuery)
+                    .freshness(freshness)
+                    .logicalRefreshMode(logicalRefreshMode)
+                    .refreshMode(refreshMode)
+                    .refreshStatus(refreshStatus)
+                    .refreshHandlerDescription(refreshHandlerDesc)
+                    .serializedRefreshHandler(refreshHandlerBytes);
+            return builder.build();
+        } catch (Exception e) {
+            throw new CatalogException("Error in deserializing catalog materialized table.", e);
+        }
+    }
+
+    /*
+     * Deserializes the given map of string properties into an unresolved {@link CatalogModel}.
+     *
+     * @param properties The properties to deserialize from
+     * @return {@link CatalogModel}
+     */
+    public static CatalogModel deserializeCatalogModel(Map<String, String> properties) {
+        try {
+            final Builder inputSchemaBuilder = Schema.newBuilder();
+            deserializeColumns(properties, MODEL_INPUT_SCHEMA, inputSchemaBuilder);
+            final Schema inputSchema = inputSchemaBuilder.build();
+
+            final Builder outputSchemaBuilder = Schema.newBuilder();
+            deserializeColumns(properties, MODEL_OUTPUT_SCHEMA, outputSchemaBuilder);
+            final Schema outputSchema = outputSchemaBuilder.build();
+
+            final Map<String, String> modelOptions =
+                    deserializeOptions(
+                            properties, Arrays.asList(MODEL_INPUT_SCHEMA, MODEL_OUTPUT_SCHEMA));
+
+            final @Nullable String comment = properties.get(COMMENT);
+
+            return CatalogModel.of(inputSchema, outputSchema, modelOptions, comment);
+        } catch (Exception e) {
+            throw new CatalogException("Error in deserializing catalog model.", e);
+        }
+    }
+
     // --------------------------------------------------------------------------------------------
     // Helper methods and constants
     // --------------------------------------------------------------------------------------------
@@ -205,20 +381,60 @@ public final class CatalogPropertiesUtil {
 
     private static final String SNAPSHOT = "snapshot";
 
+    private static final String DEFINITION_QUERY = "definition-query";
+
+    private static final String FRESHNESS_INTERVAL = "freshness-interval";
+
+    private static final String FRESHNESS_UNIT = "freshness-unit";
+
+    private static final String LOGICAL_REFRESH_MODE = "logical-refresh-mode";
+
+    private static final String REFRESH_MODE = "refresh-mode";
+
+    private static final String REFRESH_STATUS = "refresh-status";
+
+    private static final String REFRESH_HANDLER_DESC = "refresh-handler-desc";
+
+    private static final String REFRESH_HANDLER_BYTES = "refresh-handler-bytes";
+
+    private static final String MODEL_INPUT_SCHEMA = "input-schema";
+
+    private static final String MODEL_OUTPUT_SCHEMA = "output-schema";
+
     private static Map<String, String> deserializeOptions(
             Map<String, String> map, String schemaKey) {
+        return deserializeOptions(map, Collections.singletonList(schemaKey));
+    }
+
+    private static Map<String, String> deserializeOptions(
+            Map<String, String> map, List<String> schemaKeys) {
         return map.entrySet().stream()
                 .filter(
                         e -> {
                             final String key = e.getKey();
-                            return !key.startsWith(schemaKey + SEPARATOR)
+                            return schemaKeys.stream()
+                                            .noneMatch(
+                                                    schemaKey ->
+                                                            key.startsWith(schemaKey + SEPARATOR))
                                     && !key.startsWith(PARTITION_KEYS + SEPARATOR)
                                     && !key.equals(COMMENT)
-                                    && !key.equals(SNAPSHOT);
+                                    && !key.equals(SNAPSHOT)
+                                    && !isMaterializedTableAttribute(key);
                         })
                 .collect(Collectors.toMap(Map.Entry::getKey, Map.Entry::getValue));
     }
 
+    private static boolean isMaterializedTableAttribute(String key) {
+        return key.equals(DEFINITION_QUERY)
+                || key.equals(FRESHNESS_INTERVAL)
+                || key.equals(FRESHNESS_UNIT)
+                || key.equals(LOGICAL_REFRESH_MODE)
+                || key.equals(REFRESH_MODE)
+                || key.equals(REFRESH_STATUS)
+                || key.equals(REFRESH_HANDLER_DESC)
+                || key.equals(REFRESH_HANDLER_BYTES);
+    }
+
     private static List<String> deserializePartitionKeys(Map<String, String> map) {
         final int partitionCount = getCount(map, PARTITION_KEYS, NAME);
         final List<String> partitionKeys = new ArrayList<>();
@@ -321,6 +537,14 @@ public final class CatalogPropertiesUtil {
                 keys.stream().map(Collections::singletonList).collect(Collectors.toList()));
     }
 
+    private static void serializeResolvedModelSchema(
+            Map<String, String> map, ResolvedSchema inputSchema, ResolvedSchema outputSchema) {
+        checkNotNull(inputSchema);
+        checkNotNull(outputSchema);
+        serializeColumnsWithKey(map, inputSchema.getColumns(), MODEL_INPUT_SCHEMA);
+        serializeColumnsWithKey(map, outputSchema.getColumns(), MODEL_OUTPUT_SCHEMA);
+    }
+
     private static void serializeResolvedSchema(Map<String, String> map, ResolvedSchema schema) {
         checkNotNull(schema);
 
@@ -362,6 +586,11 @@ public final class CatalogPropertiesUtil {
     }
 
     private static void serializeColumns(Map<String, String> map, List<Column> columns) {
+        serializeColumnsWithKey(map, columns, SCHEMA);
+    }
+
+    private static void serializeColumnsWithKey(
+            Map<String, String> map, List<Column> columns, String schemaKey) {
         final String[] names = serializeColumnNames(columns);
         final String[] dataTypes = serializeColumnDataTypes(columns);
         final String[] expressions = serializeColumnComputations(columns);
@@ -383,7 +612,7 @@ public final class CatalogPropertiesUtil {
 
         putIndexedProperties(
                 map,
-                SCHEMA,
+                schemaKey,
                 Arrays.asList(NAME, DATA_TYPE, EXPR, METADATA, VIRTUAL, COMMENT),
                 values);
     }
