@@ -24,6 +24,7 @@ import org.apache.flink.table.expressions.CallExpression;
 import org.apache.flink.table.expressions.ResolvedExpression;
 import org.apache.flink.table.expressions.TimeIntervalUnit;
 import org.apache.flink.table.expressions.ValueLiteralExpression;
+import org.apache.flink.table.types.logical.LogicalTypeFamily;
 import org.apache.flink.table.utils.EncodingUtils;
 
 import java.util.List;
@@ -106,7 +107,7 @@ public interface SqlCallSyntax {
                                     .map(ResolvedExpression::asSerializableString)
                                     .collect(Collectors.joining(", ")));
 
-    /** Binary operator syntax, as in "x + y". */
+    /** Binary operator syntax, as in "x - y". */
     SqlCallSyntax BINARY_OP =
             (sqlName, operands) ->
                     String.format(
@@ -115,6 +116,24 @@ public interface SqlCallSyntax {
                             sqlName,
                             CallSyntaxUtils.asSerializableOperand(operands.get(1)));
 
+    /** Syntax for unparsing '+', Special handling for a plus on string arguments. */
+    SqlCallSyntax PLUS_OP =
+            (sqlName, operands) -> {
+                boolean isString =
+                        operands.stream()
+                                .anyMatch(
+                                        op ->
+                                                op.getOutputDataType()
+                                                        .getLogicalType()
+                                                        .is(LogicalTypeFamily.CHARACTER_STRING));
+                if (isString) {
+                    return FUNCTION.unparse(
+                            BuiltInFunctionDefinitions.CONCAT.getSqlName(), operands);
+                } else {
+                    return BINARY_OP.unparse(sqlName, operands);
+                }
+            };
+
     /**
      * Binary operator syntax that in Table API can accept multiple operands, as in "x AND y AND t
      * AND w".
@@ -202,7 +221,7 @@ public interface SqlCallSyntax {
     /**
      * Special sql syntax for TRIM.
      *
-     * <p>Example: TRIM BOTH ' ' FROM 0;
+     * <p>Example: TRIM(BOTH ' ' FROM ' 0 ');
      */
     SqlCallSyntax TRIM =
             (sqlName, operands) -> {
@@ -214,13 +233,13 @@ public interface SqlCallSyntax {
 
                 // leading & trailing is translated to BOTH
                 if (trimLeading && trimTrailing) {
-                    format = "TRIM BOTH %s FROM %s";
+                    format = "TRIM(BOTH %s FROM %s)";
                 } else if (trimLeading) {
-                    format = "TRIM LEADING %s FROM %s";
+                    format = "TRIM(LEADING %s FROM %s)";
                 } else if (trimTrailing) {
-                    format = "TRIM TRAILING %s FROM %s";
+                    format = "TRIM(TRAILING %s FROM %s)";
                 } else {
-                    format = "TRIM %s FROM %s";
+                    format = "TRIM(%s FROM %s)";
                 }
 
                 return String.format(
@@ -281,6 +300,29 @@ public interface SqlCallSyntax {
 
     SqlCallSyntax WINDOW_START_END = (sqlName, operands) -> String.format("%s", sqlName);
 
+    /**
+     * Special sql syntax for LIKE.
+     *
+     * <p>Example: 'TE_ST' LIKE '%E&_S%' ESCAPE '&';
+     */
+    SqlCallSyntax LIKE =
+            (sqlName, operands) -> {
+                if (operands.size() == 2) {
+                    return String.format(
+                            "%s %s %s",
+                            CallSyntaxUtils.asSerializableOperand(operands.get(0)),
+                            sqlName,
+                            CallSyntaxUtils.asSerializableOperand(operands.get(1)));
+                } else {
+                    return String.format(
+                            "%s %s %s ESCAPE %s",
+                            CallSyntaxUtils.asSerializableOperand(operands.get(0)),
+                            sqlName,
+                            CallSyntaxUtils.asSerializableOperand(operands.get(1)),
+                            CallSyntaxUtils.asSerializableOperand(operands.get(2)));
+                }
+            };
+
     SqlCallSyntax OVER =
             ((sqlName, operands) -> {
                 String projection = operands.get(0).asSerializableString();
@@ -289,10 +331,10 @@ public interface SqlCallSyntax {
                         CallSyntaxUtils.overRangeToSerializableString(
                                 operands.get(2), operands.get(3));
                 if (operands.size() == 4) {
-                    return String.format("%s OVER(ORDER BY %s %s)", projection, order, rangeBounds);
+                    return String.format("%s OVER(ORDER BY %s%s)", projection, order, rangeBounds);
                 } else {
                     return String.format(
-                            "%s OVER(PARTITION BY %s ORDER BY %s %s)",
+                            "%s OVER(PARTITION BY %s ORDER BY %s%s)",
                             projection,
                             CallSyntaxUtils.asSerializableOperand(operands.get(4)),
                             order,
