@@ -19,8 +19,10 @@
 package org.apache.flink.table.types.extraction;
 
 import org.apache.flink.annotation.Internal;
+import org.apache.flink.api.java.typeutils.AvroUtils;
 import org.apache.flink.table.annotation.ArgumentHint;
 import org.apache.flink.table.annotation.DataTypeHint;
+import org.apache.flink.table.annotation.StateHint;
 import org.apache.flink.table.api.DataTypes;
 import org.apache.flink.table.api.dataview.DataView;
 import org.apache.flink.table.api.dataview.ListView;
@@ -39,6 +41,7 @@ import org.apache.flink.table.types.KeyValueDataType;
 import org.apache.flink.table.types.logical.LogicalType;
 import org.apache.flink.table.types.logical.LogicalTypeRoot;
 import org.apache.flink.table.types.utils.ClassDataTypeConverter;
+import org.apache.flink.table.types.utils.TypeInfoDataTypeConverter;
 import org.apache.flink.types.Row;
 
 import javax.annotation.Nullable;
@@ -142,8 +145,11 @@ public final class DataTypeExtractor {
         final Parameter parameter = method.getParameters()[paramPos];
         final DataTypeHint hint = parameter.getAnnotation(DataTypeHint.class);
         final ArgumentHint argumentHint = parameter.getAnnotation(ArgumentHint.class);
+        final StateHint stateHint = parameter.getAnnotation(StateHint.class);
         final DataTypeTemplate template;
-        if (argumentHint != null) {
+        if (stateHint != null) {
+            template = DataTypeTemplate.fromAnnotation(typeFactory, stateHint.type());
+        } else if (argumentHint != null) {
             template = DataTypeTemplate.fromAnnotation(typeFactory, argumentHint.type());
         } else if (hint != null) {
             template = DataTypeTemplate.fromAnnotation(typeFactory, hint);
@@ -204,9 +210,9 @@ public final class DataTypeExtractor {
      * Extracts a data type from a method return type by considering surrounding classes and method
      * annotation.
      */
-    public static DataType extractFromMethodOutput(
+    public static DataType extractFromMethodReturnType(
             DataTypeFactory typeFactory, Class<?> baseClass, Method method) {
-        return extractFromMethodOutput(
+        return extractFromMethodReturnType(
                 typeFactory, baseClass, method, method.getGenericReturnType());
     }
 
@@ -214,7 +220,7 @@ public final class DataTypeExtractor {
      * Extracts a data type from a method return type with specifying the method's type explicitly
      * by considering surrounding classes and method annotation.
      */
-    public static DataType extractFromMethodOutput(
+    public static DataType extractFromMethodReturnType(
             DataTypeFactory typeFactory, Class<?> baseClass, Method method, Type methodReturnType) {
         final DataTypeHint hint = method.getAnnotation(DataTypeHint.class);
         final DataTypeTemplate template;
@@ -341,6 +347,12 @@ public final class DataTypeExtractor {
             return resultDataType;
         }
 
+        // AVRO
+        resultDataType = extractAvroType(type);
+        if (resultDataType != null) {
+            return resultDataType;
+        }
+
         // try interpret the type as a STRUCTURED type
         try {
             return extractStructuredType(template, typeHierarchy, type);
@@ -526,6 +538,16 @@ public final class DataTypeExtractor {
         return DataTypes.MAP(key, value);
     }
 
+    private @Nullable DataType extractAvroType(Type type) {
+        final Class<?> clazz = toClass(type);
+        if (AvroUtils.isAvroSpecificRecord(clazz)) {
+            // refer to TypeExtractor#privateGetForClass to get the AvroTypeInfo
+            return TypeInfoDataTypeConverter.toDataType(
+                    typeFactory, AvroUtils.getAvroUtils().createAvroTypeInfo(clazz));
+        }
+        return null;
+    }
+
     private DataType extractStructuredType(
             DataTypeTemplate template, List<Type> typeHierarchy, Type type) {
         final Class<?> clazz = toClass(type);
