@@ -22,6 +22,7 @@ import org.apache.flink.annotation.PublicEvolving;
 import org.apache.flink.api.common.typeinfo.TypeInformation;
 import org.apache.flink.table.api.ValidationException;
 import org.apache.flink.table.catalog.UnresolvedIdentifier;
+import org.apache.flink.table.legacy.utils.TypeStringUtils;
 import org.apache.flink.table.types.logical.ArrayType;
 import org.apache.flink.table.types.logical.BigIntType;
 import org.apache.flink.table.types.logical.BinaryType;
@@ -53,7 +54,6 @@ import org.apache.flink.table.types.logical.VarCharType;
 import org.apache.flink.table.types.logical.YearMonthIntervalType;
 import org.apache.flink.table.types.logical.YearMonthIntervalType.YearMonthResolution;
 import org.apache.flink.table.types.logical.ZonedTimestampType;
-import org.apache.flink.table.utils.TypeStringUtils;
 
 import javax.annotation.Nullable;
 
@@ -106,19 +106,6 @@ public final class LogicalTypeParser {
         return converter.parseTokens();
     }
 
-    /**
-     * Parses a type string. All types will be fully resolved except for {@link
-     * UnresolvedUserDefinedType}s.
-     *
-     * @param typeString a string like "ROW(field1 INT, field2 BOOLEAN)"
-     * @throws ValidationException in case of parsing errors.
-     * @deprecated You should use {@link #parse(String, ClassLoader)} to correctly load user types
-     */
-    @Deprecated
-    public static LogicalType parse(String typeString) {
-        return parse(typeString, Thread.currentThread().getContextClassLoader());
-    }
-
     // --------------------------------------------------------------------------------------------
     // Tokenizer
     // --------------------------------------------------------------------------------------------
