@@ -19,7 +19,6 @@
 package org.apache.flink.table.typeutils;
 
 import org.apache.flink.annotation.Internal;
-import org.apache.flink.api.common.ExecutionConfig;
 import org.apache.flink.api.common.serialization.SerializerConfig;
 import org.apache.flink.api.common.typeinfo.SqlTimeTypeInfo;
 import org.apache.flink.api.common.typeutils.TypeSerializer;
@@ -72,11 +71,6 @@ public class TimeIndicatorTypeInfo extends SqlTimeTypeInfo<Timestamp> {
         return (TypeSerializer) LongSerializer.INSTANCE;
     }
 
-    @Override
-    public TypeSerializer<Timestamp> createSerializer(ExecutionConfig config) {
-        return createSerializer(config.getSerializerConfig());
-    }
-
     public boolean isEventTime() {
         return isEventTime;
     }
