@@ -250,11 +250,6 @@ class UserDefinedFunctionHelperTest {
             return Optional.empty();
         }
 
-        @Override
-        public boolean isGeneric() {
-            return false;
-        }
-
         @Override
         public FunctionLanguage getFunctionLanguage() {
             return FunctionLanguage.JAVA;
