@@ -21,7 +21,6 @@ package org.apache.flink.table.planner.functions.inference;
 import org.apache.flink.annotation.Internal;
 import org.apache.flink.table.catalog.DataTypeFactory;
 import org.apache.flink.table.functions.FunctionDefinition;
-import org.apache.flink.table.planner.calcite.FlinkOperatorBinding;
 import org.apache.flink.table.planner.calcite.FlinkTypeFactory;
 import org.apache.flink.table.types.DataType;
 import org.apache.flink.table.types.inference.CallContext;
@@ -44,25 +43,23 @@ import static org.apache.flink.table.types.utils.TypeConversions.fromLogicalToDa
 public final class OperatorBindingCallContext extends AbstractSqlCallContext {
 
     private final SqlOperatorBinding binding;
-
     private final List<DataType> argumentDataTypes;
-
     private final @Nullable DataType outputDataType;
 
     public OperatorBindingCallContext(
             DataTypeFactory dataTypeFactory,
             FunctionDefinition definition,
-            SqlOperatorBinding sqlOperatorBinding,
+            SqlOperatorBinding binding,
             RelDataType returnRelDataType) {
         super(
                 dataTypeFactory,
                 definition,
-                sqlOperatorBinding.getOperator().getNameAsId().toString(),
-                sqlOperatorBinding.getGroupCount() > 0);
+                binding.getOperator().getNameAsId().toString(),
+                binding.getGroupCount() > 0);
 
-        this.binding = new FlinkOperatorBinding(sqlOperatorBinding);
+        this.binding = binding;
         this.argumentDataTypes =
-                new AbstractList<DataType>() {
+                new AbstractList<>() {
                     @Override
                     public DataType get(int pos) {
                         LogicalType logicalType =
