@@ -22,7 +22,6 @@ import org.apache.flink.sql.parser.ddl.SqlAddJar;
 import org.apache.flink.sql.parser.ddl.SqlAlterDatabase;
 import org.apache.flink.sql.parser.ddl.SqlAlterFunction;
 import org.apache.flink.sql.parser.ddl.SqlAlterTable;
-import org.apache.flink.sql.parser.ddl.SqlAlterTableCompact;
 import org.apache.flink.sql.parser.ddl.SqlAlterTableDropColumn;
 import org.apache.flink.sql.parser.ddl.SqlAlterTableDropConstraint;
 import org.apache.flink.sql.parser.ddl.SqlAlterTableDropDistribution;
@@ -45,6 +44,7 @@ import org.apache.flink.sql.parser.ddl.SqlDropFunction;
 import org.apache.flink.sql.parser.ddl.SqlDropTable;
 import org.apache.flink.sql.parser.ddl.SqlDropView;
 import org.apache.flink.sql.parser.ddl.SqlRemoveJar;
+import org.apache.flink.sql.parser.ddl.SqlReplaceTableAs;
 import org.apache.flink.sql.parser.ddl.SqlReset;
 import org.apache.flink.sql.parser.ddl.SqlSet;
 import org.apache.flink.sql.parser.ddl.SqlStopJob;
@@ -64,7 +64,6 @@ import org.apache.flink.sql.parser.dml.SqlStatementSet;
 import org.apache.flink.sql.parser.dql.SqlLoadModule;
 import org.apache.flink.sql.parser.dql.SqlRichDescribeTable;
 import org.apache.flink.sql.parser.dql.SqlRichExplain;
-import org.apache.flink.sql.parser.dql.SqlShowCatalogs;
 import org.apache.flink.sql.parser.dql.SqlShowColumns;
 import org.apache.flink.sql.parser.dql.SqlShowCreateTable;
 import org.apache.flink.sql.parser.dql.SqlShowCreateView;
@@ -73,8 +72,6 @@ import org.apache.flink.sql.parser.dql.SqlShowCurrentDatabase;
 import org.apache.flink.sql.parser.dql.SqlShowJars;
 import org.apache.flink.sql.parser.dql.SqlShowJobs;
 import org.apache.flink.sql.parser.dql.SqlShowModules;
-import org.apache.flink.sql.parser.dql.SqlShowTables;
-import org.apache.flink.sql.parser.dql.SqlShowViews;
 import org.apache.flink.sql.parser.dql.SqlUnloadModule;
 import org.apache.flink.table.api.DataTypes;
 import org.apache.flink.table.api.TableException;
@@ -94,7 +91,6 @@ import org.apache.flink.table.catalog.CatalogView;
 import org.apache.flink.table.catalog.Column;
 import org.apache.flink.table.catalog.ContextResolvedTable;
 import org.apache.flink.table.catalog.FunctionLanguage;
-import org.apache.flink.table.catalog.ManagedTableListener;
 import org.apache.flink.table.catalog.ObjectIdentifier;
 import org.apache.flink.table.catalog.ResolvedCatalogTable;
 import org.apache.flink.table.catalog.ResolvedSchema;
@@ -122,20 +118,16 @@ import org.apache.flink.table.operations.EndStatementSetOperation;
 import org.apache.flink.table.operations.ExplainOperation;
 import org.apache.flink.table.operations.LoadModuleOperation;
 import org.apache.flink.table.operations.ModifyOperation;
+import org.apache.flink.table.operations.ModifyType;
 import org.apache.flink.table.operations.NopOperation;
 import org.apache.flink.table.operations.Operation;
-import org.apache.flink.table.operations.QueryOperation;
-import org.apache.flink.table.operations.ShowCatalogsOperation;
 import org.apache.flink.table.operations.ShowColumnsOperation;
 import org.apache.flink.table.operations.ShowCreateTableOperation;
 import org.apache.flink.table.operations.ShowCreateViewOperation;
 import org.apache.flink.table.operations.ShowCurrentCatalogOperation;
 import org.apache.flink.table.operations.ShowCurrentDatabaseOperation;
 import org.apache.flink.table.operations.ShowModulesOperation;
-import org.apache.flink.table.operations.ShowTablesOperation;
-import org.apache.flink.table.operations.ShowViewsOperation;
 import org.apache.flink.table.operations.SinkModifyOperation;
-import org.apache.flink.table.operations.SourceQueryOperation;
 import org.apache.flink.table.operations.StatementSetOperation;
 import org.apache.flink.table.operations.UnloadModuleOperation;
 import org.apache.flink.table.operations.UseCatalogOperation;
@@ -165,6 +157,8 @@ import org.apache.flink.table.operations.ddl.DropDatabaseOperation;
 import org.apache.flink.table.operations.ddl.DropTableOperation;
 import org.apache.flink.table.operations.ddl.DropTempSystemFunctionOperation;
 import org.apache.flink.table.operations.ddl.DropViewOperation;
+import org.apache.flink.table.operations.utils.LikeType;
+import org.apache.flink.table.operations.utils.ShowLikeOperator;
 import org.apache.flink.table.planner.calcite.FlinkPlannerImpl;
 import org.apache.flink.table.planner.hint.FlinkHints;
 import org.apache.flink.table.planner.operations.converters.SqlNodeConverters;
@@ -280,8 +274,6 @@ public class SqlNodeToOperationConversion {
             return Optional.of(converter.convertDropCatalog((SqlDropCatalog) validated));
         } else if (validated instanceof SqlLoadModule) {
             return Optional.of(converter.convertLoadModule((SqlLoadModule) validated));
-        } else if (validated instanceof SqlShowCatalogs) {
-            return Optional.of(converter.convertShowCatalogs((SqlShowCatalogs) validated));
         } else if (validated instanceof SqlShowCurrentCatalog) {
             return Optional.of(
                     converter.convertShowCurrentCatalog((SqlShowCurrentCatalog) validated));
@@ -316,14 +308,10 @@ public class SqlNodeToOperationConversion {
             return Optional.of(converter.convertDropTable((SqlDropTable) validated));
         } else if (validated instanceof SqlAlterTable) {
             return Optional.of(converter.convertAlterTable((SqlAlterTable) validated));
-        } else if (validated instanceof SqlShowTables) {
-            return Optional.of(converter.convertShowTables((SqlShowTables) validated));
         } else if (validated instanceof SqlShowColumns) {
             return Optional.of(converter.convertShowColumns((SqlShowColumns) validated));
         } else if (validated instanceof SqlDropView) {
             return Optional.of(converter.convertDropView((SqlDropView) validated));
-        } else if (validated instanceof SqlShowViews) {
-            return Optional.of(converter.convertShowViews((SqlShowViews) validated));
         } else if (validated instanceof SqlCreateFunction) {
             return Optional.of(converter.convertCreateFunction((SqlCreateFunction) validated));
         } else if (validated instanceof SqlDropFunction) {
@@ -463,11 +451,6 @@ public class SqlNodeToOperationConversion {
         } else if (sqlAlterTable instanceof SqlAlterTableRenameColumn) {
             return alterSchemaConverter.convertAlterSchema(
                     (SqlAlterTableRenameColumn) sqlAlterTable, resolvedCatalogTable);
-        } else if (sqlAlterTable instanceof SqlAlterTableCompact) {
-            return convertAlterTableCompact(
-                    tableIdentifier,
-                    optionalCatalogTable.get(),
-                    (SqlAlterTableCompact) sqlAlterTable);
         } else if (sqlAlterTable instanceof SqlAlterTableSchema) {
             return alterSchemaConverter.convertAlterSchema(
                     (SqlAlterTableSchema) sqlAlterTable, resolvedCatalogTable);
@@ -543,59 +526,6 @@ public class SqlNodeToOperationConversion {
                 alterTableReset.ifTableExists());
     }
 
-    /**
-     * Convert `ALTER TABLE ... COMPACT` operation to {@link ModifyOperation} for Flink's managed
-     * table to trigger a compaction batch job.
-     */
-    private ModifyOperation convertAlterTableCompact(
-            ObjectIdentifier tableIdentifier,
-            ContextResolvedTable contextResolvedTable,
-            SqlAlterTableCompact alterTableCompact) {
-        Catalog catalog = catalogManager.getCatalog(tableIdentifier.getCatalogName()).orElse(null);
-        ResolvedCatalogTable resolvedCatalogTable = contextResolvedTable.getResolvedTable();
-
-        if (ManagedTableListener.isManagedTable(catalog, resolvedCatalogTable)) {
-            Map<String, String> partitionKVs = alterTableCompact.getPartitionKVs();
-            CatalogPartitionSpec partitionSpec = new CatalogPartitionSpec(Collections.emptyMap());
-            if (partitionKVs != null) {
-                List<String> partitionKeys = resolvedCatalogTable.getPartitionKeys();
-                Set<String> validPartitionKeySet = new HashSet<>(partitionKeys);
-                String exMsg =
-                        partitionKeys.isEmpty()
-                                ? String.format("Table %s is not partitioned.", tableIdentifier)
-                                : String.format(
-                                        "Available ordered partition columns: [%s]",
-                                        partitionKeys.stream()
-                                                .collect(Collectors.joining("', '", "'", "'")));
-                partitionKVs.forEach(
-                        (partitionKey, partitionValue) -> {
-                            if (!validPartitionKeySet.contains(partitionKey)) {
-                                throw new ValidationException(
-                                        String.format(
-                                                "Partition column '%s' not defined in the table schema. %s",
-                                                partitionKey, exMsg));
-                            }
-                        });
-                partitionSpec = new CatalogPartitionSpec(partitionKVs);
-            }
-            Map<String, String> compactOptions =
-                    catalogManager.resolveCompactManagedTableOptions(
-                            resolvedCatalogTable, tableIdentifier, partitionSpec);
-            QueryOperation child = new SourceQueryOperation(contextResolvedTable, compactOptions);
-            return new SinkModifyOperation(
-                    contextResolvedTable,
-                    child,
-                    partitionSpec.getPartitionSpec(),
-                    null, // targetColumns
-                    false,
-                    compactOptions);
-        }
-        throw new ValidationException(
-                String.format(
-                        "ALTER TABLE COMPACT operation is not supported for non-managed table %s",
-                        tableIdentifier));
-    }
-
     /** Convert ALTER TABLE DROP DISTRIBUTION statement. */
     private static AlterTableChangeOperation convertAlterTableDropDistribution(
             SqlAlterTable sqlAlterTable,
@@ -915,11 +845,6 @@ public class SqlNodeToOperationConversion {
         return new AlterDatabaseOperation(catalogName, databaseName, catalogDatabase);
     }
 
-    /** Convert SHOW CATALOGS statement. */
-    private Operation convertShowCatalogs(SqlShowCatalogs sqlShowCatalogs) {
-        return new ShowCatalogsOperation();
-    }
-
     /** Convert SHOW CURRENT CATALOG statement. */
     private Operation convertShowCurrentCatalog(SqlShowCurrentCatalog sqlShowCurrentCatalog) {
         return new ShowCurrentCatalogOperation();
@@ -930,47 +855,16 @@ public class SqlNodeToOperationConversion {
         return new ShowCurrentDatabaseOperation();
     }
 
-    /** Convert SHOW TABLES statement. */
-    private Operation convertShowTables(SqlShowTables sqlShowTables) {
-        if (sqlShowTables.getPreposition() == null) {
-            return new ShowTablesOperation(
-                    sqlShowTables.getLikeSqlPattern(),
-                    sqlShowTables.isWithLike(),
-                    sqlShowTables.isNotLike());
-        }
-        String[] fullDatabaseName = sqlShowTables.fullDatabaseName();
-        if (fullDatabaseName.length > 2) {
-            throw new ValidationException(
-                    String.format(
-                            "show tables from/in identifier [ %s ] format error",
-                            String.join(".", fullDatabaseName)));
-        }
-        String catalogName =
-                (fullDatabaseName.length == 1)
-                        ? catalogManager.getCurrentCatalog()
-                        : fullDatabaseName[0];
-        String databaseName =
-                (fullDatabaseName.length == 1) ? fullDatabaseName[0] : fullDatabaseName[1];
-        return new ShowTablesOperation(
-                catalogName,
-                databaseName,
-                sqlShowTables.getLikeSqlPattern(),
-                sqlShowTables.isWithLike(),
-                sqlShowTables.isNotLike(),
-                sqlShowTables.getPreposition());
-    }
-
     /** Convert SHOW COLUMNS statement. */
     private Operation convertShowColumns(SqlShowColumns sqlShowColumns) {
         UnresolvedIdentifier unresolvedIdentifier =
-                UnresolvedIdentifier.of(sqlShowColumns.fullTableName());
+                UnresolvedIdentifier.of(sqlShowColumns.getSqlIdentifierNameList());
         ObjectIdentifier identifier = catalogManager.qualifyIdentifier(unresolvedIdentifier);
-        return new ShowColumnsOperation(
-                identifier,
-                sqlShowColumns.getLikeSqlPattern(),
-                sqlShowColumns.isWithLike(),
-                sqlShowColumns.isNotLike(),
-                sqlShowColumns.getPreposition());
+        ShowLikeOperator likeOp =
+                ShowLikeOperator.of(
+                        LikeType.of(sqlShowColumns.getLikeType(), sqlShowColumns.isNotLike()),
+                        sqlShowColumns.getLikeSqlPattern());
+        return new ShowColumnsOperation(identifier, sqlShowColumns.getLikeSqlPattern(), likeOp);
     }
 
     /** Convert SHOW CREATE TABLE statement. */
@@ -999,11 +893,6 @@ public class SqlNodeToOperationConversion {
                 identifier, sqlDropView.getIfExists(), sqlDropView.isTemporary());
     }
 
-    /** Convert SHOW VIEWS statement. */
-    private Operation convertShowViews(SqlShowViews sqlShowViews) {
-        return new ShowViewsOperation();
-    }
-
     /** Convert RICH EXPLAIN statement. */
     private Operation convertRichExplain(SqlRichExplain sqlExplain) {
         SqlNode sqlNode = sqlExplain.getStatement();
@@ -1014,6 +903,16 @@ public class SqlNodeToOperationConversion {
             operation = convertSqlStatementSet((SqlStatementSet) sqlNode);
         } else if (sqlNode.getKind().belongsTo(SqlKind.QUERY)) {
             operation = convertSqlQuery(sqlExplain.getStatement());
+        } else if ((sqlNode instanceof SqlCreateTableAs)
+                || (sqlNode instanceof SqlReplaceTableAs)) {
+            operation =
+                    convert(flinkPlanner, catalogManager, sqlNode)
+                            .orElseThrow(
+                                    () ->
+                                            new ValidationException(
+                                                    String.format(
+                                                            "EXPLAIN statement doesn't support %s",
+                                                            sqlNode.getKind())));
         } else {
             throw new ValidationException(
                     String.format("EXPLAIN statement doesn't support %s", sqlNode.getKind()));
@@ -1324,8 +1223,7 @@ public class SqlNodeToOperationConversion {
                         catalogManager.qualifyIdentifier(unresolvedTableIdentifier));
         // try push down delete
         Optional<DynamicTableSink> optionalDynamicTableSink =
-                DeletePushDownUtils.getDynamicTableSink(
-                        contextResolvedTable, tableModify, catalogManager);
+                DeletePushDownUtils.getDynamicTableSink(contextResolvedTable, tableModify);
         if (optionalDynamicTableSink.isPresent()) {
             DynamicTableSink dynamicTableSink = optionalDynamicTableSink.get();
             // if the table sink supports delete push down
@@ -1353,7 +1251,7 @@ public class SqlNodeToOperationConversion {
                 contextResolvedTable,
                 queryOperation,
                 null, // targetColumns
-                SinkModifyOperation.ModifyType.DELETE);
+                ModifyType.DELETE);
     }
 
     private Operation convertUpdate(SqlUpdate sqlUpdate) {
@@ -1382,10 +1280,7 @@ public class SqlNodeToOperationConversion {
                 getTargetColumnIndices(contextResolvedTable, sqlUpdate.getTargetColumnList());
 
         return new SinkModifyOperation(
-                contextResolvedTable,
-                queryOperation,
-                columnIndices,
-                SinkModifyOperation.ModifyType.UPDATE);
+                contextResolvedTable, queryOperation, columnIndices, ModifyType.UPDATE);
     }
 
     private int[][] getTargetColumnIndices(
