@@ -63,7 +63,12 @@ public class SqlNodeConverters {
         register(new SqlAlterMaterializedTableRefreshConverter());
         register(new SqlAlterMaterializedTableSuspendConverter());
         register(new SqlAlterMaterializedTableResumeConverter());
+        register(new SqlAlterMaterializedTableAsQueryConverter());
         register(new SqlDropMaterializedTableConverter());
+        register(new SqlShowTablesConverter());
+        register(new SqlShowViewsConverter());
+        register(new SqlShowCatalogsConverter());
+        register(new SqlDescribeFunctionConverter());
     }
 
     /**
