@@ -23,9 +23,12 @@ import org.apache.flink.api.common.typeinfo.TypeInformation;
 import org.apache.flink.api.dag.Transformation;
 import org.apache.flink.configuration.ReadableConfig;
 import org.apache.flink.core.io.InputSplit;
+import org.apache.flink.legacy.table.sources.StreamTableSource;
 import org.apache.flink.streaming.api.datastream.DataStream;
 import org.apache.flink.streaming.api.environment.StreamExecutionEnvironment;
 import org.apache.flink.table.data.RowData;
+import org.apache.flink.table.legacy.sources.RowtimeAttributeDescriptor;
+import org.apache.flink.table.legacy.sources.TableSource;
 import org.apache.flink.table.planner.codegen.CodeGeneratorContext;
 import org.apache.flink.table.planner.codegen.OperatorCodeGenerator;
 import org.apache.flink.table.planner.plan.nodes.exec.ExecNode;
@@ -37,10 +40,7 @@ import org.apache.flink.table.planner.sources.TableSourceUtil;
 import org.apache.flink.table.planner.utils.JavaScalaConversionUtil;
 import org.apache.flink.table.runtime.operators.TableStreamOperator;
 import org.apache.flink.table.runtime.operators.wmassigners.PeriodicWatermarkAssignerWrapper;
-import org.apache.flink.table.runtime.operators.wmassigners.PunctuatedWatermarkAssignerWrapper;
-import org.apache.flink.table.sources.RowtimeAttributeDescriptor;
-import org.apache.flink.table.sources.StreamTableSource;
-import org.apache.flink.table.sources.TableSource;
+import org.apache.flink.table.runtime.operators.wmassigners.PunctuatedWatermarkStrategyWrapper;
 import org.apache.flink.table.sources.wmstrategies.PeriodicWatermarkAssigner;
 import org.apache.flink.table.sources.wmstrategies.PunctuatedWatermarkAssigner;
 import org.apache.flink.table.sources.wmstrategies.WatermarkStrategy;
@@ -151,8 +151,8 @@ public class StreamExecLegacyTableSourceScan extends CommonExecLegacyTableSource
                                         return ingestedTable.assignTimestampsAndWatermarks(
                                                 watermarkGenerator);
                                     } else if (strategy instanceof PunctuatedWatermarkAssigner) {
-                                        PunctuatedWatermarkAssignerWrapper watermarkGenerator =
-                                                new PunctuatedWatermarkAssignerWrapper(
+                                        PunctuatedWatermarkStrategyWrapper watermarkGenerator =
+                                                new PunctuatedWatermarkStrategyWrapper(
                                                         (PunctuatedWatermarkAssigner) strategy,
                                                         rowtimeFieldIdx,
                                                         tableSource.getProducedDataType());
