@@ -19,7 +19,6 @@
 package org.apache.flink.table.planner.plan.rules.logical;
 
 import org.apache.flink.table.planner.calcite.FlinkRelBuilder;
-import org.apache.flink.table.planner.plan.utils.FlinkRelOptUtil;
 import org.apache.flink.table.planner.plan.utils.FlinkRexUtil;
 import org.apache.flink.util.Preconditions;
 
@@ -123,9 +122,7 @@ public class SubQueryDecorrelator extends RelShuttleImpl {
      * @return Decorrelate result.
      */
     public static Result decorrelateQuery(RelNode rootRel) {
-        int maxCnfNodeCount = FlinkRelOptUtil.getMaxCnfNodeCount(rootRel);
-
-        final CorelMapBuilder builder = new CorelMapBuilder(maxCnfNodeCount);
+        final CorelMapBuilder builder = new CorelMapBuilder();
         final CorelMap corelMap = builder.build(rootRel);
         if (builder.hasNestedCorScope || builder.hasUnsupportedCorCondition) {
             return null;
@@ -141,9 +138,7 @@ public class SubQueryDecorrelator extends RelShuttleImpl {
 
         final SubQueryDecorrelator decorrelator =
                 new SubQueryDecorrelator(
-                        new SubQueryRelDecorrelator(
-                                corelMap, relBuilder, rexBuilder, maxCnfNodeCount),
-                        relBuilder);
+                        new SubQueryRelDecorrelator(corelMap, relBuilder, rexBuilder), relBuilder);
         rootRel.accept(decorrelator);
 
         return new Result(decorrelator.subQueryMap);
@@ -264,13 +259,12 @@ public class SubQueryDecorrelator extends RelShuttleImpl {
             final Set<CorrelationId> variableSet,
             final RexNode condition,
             final RexBuilder rexBuilder,
-            final int maxCnfNodeCount,
             final List<RexNode> corConditions,
             final List<RexNode> nonCorConditions,
             final List<RexNode> unsupportedCorConditions) {
         // converts the expanded expression to conjunctive normal form,
         // like "(a AND b) OR c" will be converted to "(a OR c) AND (b OR c)"
-        final RexNode cnf = FlinkRexUtil.toCnf(rexBuilder, maxCnfNodeCount, condition);
+        final RexNode cnf = FlinkRexUtil.toCnf(rexBuilder, condition);
         // converts the cnf condition to a list of AND conditions
         final List<RexNode> conjunctions = RelOptUtil.conjunctions(cnf);
         // `true` for RexNode is supported correlation condition,
@@ -418,14 +412,11 @@ public class SubQueryDecorrelator extends RelShuttleImpl {
         private final ReflectUtil.MethodDispatcher<Frame> dispatcher =
                 ReflectUtil.createMethodDispatcher(
                         Frame.class, this, "decorrelateRel", RelNode.class);
-        private final int maxCnfNodeCount;
 
-        SubQueryRelDecorrelator(
-                CorelMap cm, RelBuilder relBuilder, RexBuilder rexBuilder, int maxCnfNodeCount) {
+        SubQueryRelDecorrelator(CorelMap cm, RelBuilder relBuilder, RexBuilder rexBuilder) {
             this.cm = cm;
             this.relBuilder = relBuilder;
             this.rexBuilder = rexBuilder;
-            this.maxCnfNodeCount = maxCnfNodeCount;
         }
 
         Frame getInvoke(RelNode r) {
@@ -536,7 +527,6 @@ public class SubQueryDecorrelator extends RelShuttleImpl {
                     cm.mapSubQueryNodeToCorSet.get(rel),
                     rel.getCondition(),
                     rexBuilder,
-                    maxCnfNodeCount,
                     corConditions,
                     nonCorConditions,
                     unsupportedCorConditions);
@@ -958,7 +948,7 @@ public class SubQueryDecorrelator extends RelShuttleImpl {
 
     /** Builds a {@link CorelMap}. */
     private static class CorelMapBuilder extends RelShuttleImpl {
-        private final int maxCnfNodeCount;
+
         // nested correlation variables in SubQuery, such as:
         // SELECT * FROM t1 WHERE EXISTS (SELECT * FROM t2 WHERE t1.a = t2.c AND
         // t2.d IN (SELECT t3.d FROM t3 WHERE t1.b = t3.e)
@@ -977,10 +967,6 @@ public class SubQueryDecorrelator extends RelShuttleImpl {
         // true if SubQuery rel tree has Over node, else false.
         boolean hasOverNode = false;
 
-        public CorelMapBuilder(int maxCnfNodeCount) {
-            this.maxCnfNodeCount = maxCnfNodeCount;
-        }
-
         final SortedMap<CorrelationId, RelNode> mapCorToCorRel = new TreeMap<>();
         final com.google.common.collect.SortedSetMultimap<RelNode, CorRef> mapRefRelToCorRef =
                 com.google.common.collect.Multimaps.newSortedSetMultimap(
@@ -1154,7 +1140,6 @@ public class SubQueryDecorrelator extends RelShuttleImpl {
                         mapSubQueryNodeToCorSet.get(filter),
                         filter.getCondition(),
                         filter.getCluster().getRexBuilder(),
-                        maxCnfNodeCount,
                         corConditions,
                         new ArrayList<>(),
                         unsupportedCorConditions);
