@@ -69,7 +69,7 @@ public class StreamPhysicalPythonGroupWindowAggregateRule extends ConverterRule
         List<AggregateCall> aggCalls = agg.getAggCallList();
 
         // check if we have grouping sets
-        if (agg.getGroupType() != Aggregate.Group.SIMPLE || agg.indicator) {
+        if (agg.getGroupType() != Aggregate.Group.SIMPLE) {
             throw new TableException("GROUPING SETS are currently not supported.");
         }
 
