@@ -36,7 +36,7 @@ object FlinkStreamRuleSets {
     FlinkRewriteSubQueryRule.FILTER,
     FlinkSubQueryRemoveRule.FILTER,
     JoinConditionTypeCoerceRule.INSTANCE,
-    FlinkJoinPushExpressionsRule.INSTANCE
+    CoreRules.JOIN_PUSH_EXPRESSIONS
   )
 
   /** Convert sub-queries before query decorrelation. */
@@ -121,7 +121,7 @@ object FlinkStreamRuleSets {
           new CoerceInputsRule(classOf[LogicalMinus], false),
           ConvertToNotInOrInRule.INSTANCE,
           // optimize limit 0
-          FlinkLimit0RemoveRule.INSTANCE,
+          PruneEmptyRules.SORT_FETCH_ZERO_INSTANCE,
           // fix: FLINK-28986 nested filter pattern causes unnest rule mismatch
           CoreRules.FILTER_MERGE,
           // unnest rule
@@ -183,7 +183,7 @@ object FlinkStreamRuleSets {
     PruneEmptyRules.AGGREGATE_INSTANCE,
     PruneEmptyRules.FILTER_INSTANCE,
     PruneEmptyRules.JOIN_LEFT_INSTANCE,
-    FlinkPruneEmptyRules.JOIN_RIGHT_INSTANCE,
+    PruneEmptyRules.JOIN_RIGHT_INSTANCE,
     PruneEmptyRules.PROJECT_INSTANCE,
     PruneEmptyRules.SORT_INSTANCE,
     PruneEmptyRules.UNION_INSTANCE
@@ -249,7 +249,7 @@ object FlinkStreamRuleSets {
     CoreRules.SORT_REMOVE,
 
     // join rules
-    FlinkJoinPushExpressionsRule.INSTANCE,
+    CoreRules.JOIN_PUSH_EXPRESSIONS,
     SimplifyJoinConditionRule.INSTANCE,
 
     // remove union with only a single child
@@ -401,6 +401,8 @@ object FlinkStreamRuleSets {
     AsyncCalcSplitRule.SPLIT_CONDITION_REX_FIELD,
     // Avoids accessing a field from an asynchronous result (projection).
     AsyncCalcSplitRule.SPLIT_PROJECTION_REX_FIELD,
+    // Avoid having async calls in join conditions if they aren't already pushed down
+    AsyncCalcSplitRule.NO_ASYNC_JOIN_CONDITIONS,
     // Avoids dealing with an async call in the condition.
     AsyncCalcSplitRule.SPLIT_CONDITION,
     // Avoids dealing with Java calls in the same Calc as Async calls.
@@ -442,7 +444,6 @@ object FlinkStreamRuleSets {
     StreamPhysicalTemporalSortRule.INSTANCE,
     // rank
     StreamPhysicalRankRule.INSTANCE,
-    StreamPhysicalDeduplicateRule.INSTANCE,
     // expand
     StreamPhysicalExpandRule.INSTANCE,
     // group agg
