@@ -17,9 +17,7 @@
  */
 package org.apache.flink.table.planner.plan.utils
 
-import org.apache.flink.annotation.Experimental
-import org.apache.flink.configuration.ConfigOption
-import org.apache.flink.configuration.ConfigOptions.key
+import org.apache.flink.table.planner.{JInt, JMap}
 import org.apache.flink.table.planner.functions.sql.SqlTryCastFunction
 import org.apache.flink.table.planner.plan.nodes.calcite.{LegacySink, Sink}
 import org.apache.flink.table.planner.plan.optimize.RelNodeBlock
@@ -33,7 +31,7 @@ import org.apache.calcite.avatica.util.ByteString
 import org.apache.calcite.plan.{RelOptPredicateList, RelOptUtil}
 import org.apache.calcite.rel.`type`.RelDataType
 import org.apache.calcite.rel.RelNode
-import org.apache.calcite.rel.core.{Calc, Filter, Project, TableScan, Values}
+import org.apache.calcite.rel.core._
 import org.apache.calcite.rel.logical.LogicalUnion
 import org.apache.calcite.rex._
 import org.apache.calcite.sql.`type`.SqlTypeName
@@ -54,31 +52,9 @@ import scala.collection.mutable
 /** Utility methods concerning [[RexNode]]. */
 object FlinkRexUtil {
 
-  /** This configuration will be removed in Flink 2.0. */
-  @Deprecated
-  @Experimental
-  val TABLE_OPTIMIZER_CNF_NODES_LIMIT: ConfigOption[Integer] =
-    key("table.optimizer.cnf-nodes-limit")
-      .intType()
-      .defaultValue(Integer.valueOf(-1))
-      .withDescription(
-        "When converting to conjunctive normal form (CNF, like '(a AND b) OR" +
-          " c' will be converted to '(a OR c) AND (b OR c)'), fail if the expression  exceeds " +
-          "this threshold; (e.g. predicate in TPC-DS q41.sql will be converted to hundreds of " +
-          "thousands of CNF nodes.) the threshold is expressed in terms of number of nodes " +
-          "(only count RexCall node, including leaves and interior nodes). " +
-          "Negative number to use the default threshold: double of number of nodes.")
-
   /**
-   * Similar to [[RexUtil#toCnf(RexBuilder, Int, RexNode)]]; it lets you specify a threshold in the
-   * number of nodes that can be created out of the conversion. however, if the threshold is a
-   * negative number, this method will give a default threshold value that is double of the number
-   * of RexCall in the given node.
-   *
-   * <p>If the number of resulting RexCalls exceeds that threshold, stops conversion and returns the
-   * original expression.
-   *
-   * <p>Leaf nodes(e.g. RexInputRef) in the expression do not count towards the threshold.
+   * Converts an expression to conjunctive normal form (CNF). See more at
+   * [[RexUtil#toCnf(RexBuilder, RexNode)]].
    *
    * <p>We strongly discourage use the [[RexUtil#toCnf(RexBuilder, RexNode)]] and
    * [[RexUtil#toCnf(RexBuilder, Int, RexNode)]], because there are many bad case when using
@@ -86,12 +62,8 @@ object FlinkRexUtil {
    * to extremely complex expression (including 736450 RexCalls); and we can not give an appropriate
    * value for `maxCnfNodeCount` when using [[RexUtil#toCnf(RexBuilder, Int, RexNode)]].
    */
-  def toCnf(rexBuilder: RexBuilder, maxCnfNodeCount: Int, rex: RexNode): RexNode = {
-    val maxCnfNodeCnt = if (maxCnfNodeCount < 0) {
-      getNumberOfRexCall(rex) * 2
-    } else {
-      maxCnfNodeCount
-    }
+  def toCnf(rexBuilder: RexBuilder, rex: RexNode): RexNode = {
+    val maxCnfNodeCnt = getNumberOfRexCall(rex) * 2
     new CnfHelper(rexBuilder, maxCnfNodeCnt).toCnf(rex)
   }
 
@@ -428,28 +400,26 @@ object FlinkRexUtil {
    * @return
    *   Return new expression with new field indices.
    */
-  private[flink] def adjustInputRef(
-      expr: RexNode,
-      fieldsOldToNewIndexMapping: Map[Int, Int]): RexNode = expr.accept(new RexShuttle() {
-    override def visitInputRef(inputRef: RexInputRef): RexNode = {
-      require(fieldsOldToNewIndexMapping.containsKey(inputRef.getIndex))
-      val newIndex = fieldsOldToNewIndexMapping(inputRef.getIndex)
-      new RexInputRef(newIndex, inputRef.getType)
-    }
-  })
+  def adjustInputRef(expr: RexNode, fieldsOldToNewIndexMapping: JMap[JInt, JInt]): RexNode =
+    expr.accept(new RexShuttle() {
+      override def visitInputRef(inputRef: RexInputRef): RexNode = {
+        require(fieldsOldToNewIndexMapping.containsKey(inputRef.getIndex))
+        val newIndex = fieldsOldToNewIndexMapping(inputRef.getIndex)
+        new RexInputRef(newIndex, inputRef.getType)
+      }
+    })
 
   private class EquivalentExprShuttle(rexBuilder: RexBuilder) extends RexShuttle {
-    private val equiExprMap = mutable.HashMap[String, RexNode]()
+    private val equiExprSet = mutable.HashSet[RexNode]()
 
     override def visitCall(call: RexCall): RexNode = {
       call.getOperator match {
         case EQUALS | NOT_EQUALS | GREATER_THAN | LESS_THAN | GREATER_THAN_OR_EQUAL |
             LESS_THAN_OR_EQUAL =>
-          val swapped = swapOperands(call)
-          if (equiExprMap.contains(swapped.toString)) {
-            swapped
+          if (equiExprSet.contains(call)) {
+            swapOperands(call)
           } else {
-            equiExprMap.put(call.toString, call)
+            equiExprSet.add(call)
             call
           }
         case _ => super.visitCall(call)
@@ -668,7 +638,6 @@ object FlinkRexUtil {
       rel: RelNode,
       rexBuilder: RexBuilder): (Array[RexNode], Array[RexNode]) = {
     val context = ShortcutUtils.unwrapContext(rel)
-    val maxCnfNodeCount = FlinkRelOptUtil.getMaxCnfNodeCount(rel);
     val converter =
       new RexNodeToExpressionConverter(
         rexBuilder,
@@ -677,11 +646,7 @@ object FlinkRexUtil {
         context.getCatalogManager,
         Some(rel.getRowType));
 
-    RexNodeExtractor.extractConjunctiveConditions(
-      filterExpression,
-      maxCnfNodeCount,
-      rexBuilder,
-      converter);
+    RexNodeExtractor.extractConjunctiveConditions(filterExpression, rexBuilder, converter);
   }
 }
 
