@@ -24,7 +24,6 @@ import org.apache.flink.table.api.Schema.UnresolvedPhysicalColumn;
 import org.apache.flink.table.api.Table;
 import org.apache.flink.table.api.TableConfig;
 import org.apache.flink.table.api.TableEnvironment;
-import org.apache.flink.table.api.TableSchema;
 import org.apache.flink.table.api.Tumble;
 import org.apache.flink.table.catalog.CatalogBaseTable;
 import org.apache.flink.table.catalog.CatalogTable;
@@ -32,6 +31,7 @@ import org.apache.flink.table.catalog.CatalogView;
 import org.apache.flink.table.catalog.GenericInMemoryCatalog;
 import org.apache.flink.table.catalog.ObjectPath;
 import org.apache.flink.table.catalog.exceptions.TableNotExistException;
+import org.apache.flink.table.legacy.api.TableSchema;
 import org.apache.flink.table.planner.utils.TableTestBase;
 import org.apache.flink.table.planner.utils.TableTestUtil;
 import org.apache.flink.table.types.DataType;
@@ -53,7 +53,6 @@ import java.util.stream.Collectors;
 
 import static org.apache.flink.table.api.Expressions.$;
 import static org.apache.flink.table.api.Expressions.lit;
-import static org.assertj.core.api.Assertions.assertThat;
 
 /**
  * Tests for resolving types of computed columns (including time attributes) of tables from catalog.
@@ -171,10 +170,10 @@ class JavaCatalogTableTest extends TableTestBase {
         tableEnvironment.executeSql("CREATE VIEW `cat`.`default`.v AS SELECT * FROM t");
         testUtil.verifyExecPlan(
                 "SELECT sum(i), window_start "
-                        + "FROM TABLE(TUMBLE(\n"
+                        + "FROM TUMBLE(\n"
                         + "     DATA => TABLE `cat`.`default`.v,\n"
                         + "     TIMECOL => DESCRIPTOR(ts),\n"
-                        + "     SIZE => INTERVAL '10' MINUTES))\n"
+                        + "     SIZE => INTERVAL '10' MINUTES)\n"
                         + "GROUP BY window_start, window_end");
     }
 
@@ -203,25 +202,6 @@ class JavaCatalogTableTest extends TableTestBase {
         testUtil.verifyExecPlan("SELECT * FROM `cat`.`default`.v");
     }
 
-    @TestTemplate
-    void testShowCreateViewUsesCorrectColumnNames() {
-        TableTestUtil testUtil = getTestUtil();
-        TableEnvironment tableEnvironment = testUtil.getTableEnv();
-        tableEnvironment.registerCatalog("cat", new CustomCatalog("cat"));
-        tableEnvironment.executeSql(
-                "CREATE VIEW `cat`.`default`.v (`customer_id`, `product_id`) AS " + "SELECT 1, 1");
-        String result =
-                tableEnvironment
-                        .executeSql("SHOW CREATE VIEW `cat`.`default`.v")
-                        .collect()
-                        .next()
-                        .getFieldAs(0);
-        assertThat(result)
-                .isEqualTo(
-                        "CREATE VIEW `cat`.`default`.`v`(`customer_id`, `product_id`) as\n"
-                                + "SELECT 1, 1");
-    }
-
     private static class CustomCatalog extends GenericInMemoryCatalog {
         public CustomCatalog(String name) {
             super(name);
@@ -330,11 +310,6 @@ class JavaCatalogTableTest extends TableTestBase {
             return this;
         }
 
-        @Override
-        public Map<String, String> toProperties() {
-            return Collections.emptyMap();
-        }
-
         @Override
         public Map<String, String> getOptions() {
             Map<String, String> map = new HashMap<>();
