@@ -22,7 +22,7 @@ import org.apache.flink.FlinkVersion;
 import org.apache.flink.api.common.JobStatus;
 import org.apache.flink.configuration.StateBackendOptions;
 import org.apache.flink.core.execution.JobClient;
-import org.apache.flink.core.execution.RestoreMode;
+import org.apache.flink.core.execution.RecoveryClaimMode;
 import org.apache.flink.core.execution.SavepointFormatType;
 import org.apache.flink.runtime.jobgraph.SavepointRestoreSettings;
 import org.apache.flink.runtime.testutils.CommonTestUtils;
@@ -318,7 +318,8 @@ public abstract class RestoreTestBase implements TableTestProgramRunner {
             restoreSettings = SavepointRestoreSettings.none();
         } else {
             restoreSettings =
-                    SavepointRestoreSettings.forPath(savepointPath, false, RestoreMode.NO_CLAIM);
+                    SavepointRestoreSettings.forPath(
+                            savepointPath, false, RecoveryClaimMode.NO_CLAIM);
         }
         SavepointRestoreSettings.toConfiguration(restoreSettings, settings.getConfiguration());
         settings.getConfiguration().set(StateBackendOptions.STATE_BACKEND, "rocksdb");
@@ -375,9 +376,11 @@ public abstract class RestoreTestBase implements TableTestProgramRunner {
                 assertThat(expectedResults)
                         .containsExactlyInAnyOrder(
                                 Stream.concat(
-                                                sinkTestStep.getExpectedBeforeRestoreAsStrings()
+                                                sinkTestStep
+                                                        .getExpectedBeforeRestoreAsStrings()
                                                         .stream(),
-                                                sinkTestStep.getExpectedAfterRestoreAsStrings()
+                                                sinkTestStep
+                                                        .getExpectedAfterRestoreAsStrings()
                                                         .stream())
                                         .toArray(String[]::new));
             }
@@ -396,7 +399,7 @@ public abstract class RestoreTestBase implements TableTestProgramRunner {
     }
 
     private static List<String> getExpectedResults(SinkTestStep sinkTestStep, String tableName) {
-        if (sinkTestStep.getTestChangelogData()) {
+        if (sinkTestStep.shouldTestChangelogData()) {
             return TestValuesTableFactory.getRawResultsAsStrings(tableName);
         } else {
             return TestValuesTableFactory.getResultsAsStrings(tableName);
