@@ -18,22 +18,24 @@
 package org.apache.flink.table.api
 
 import org.apache.flink.api.common.typeinfo.Types.STRING
-import org.apache.flink.api.scala._
 import org.apache.flink.streaming.api.environment.StreamExecutionEnvironment
-import org.apache.flink.streaming.api.scala.{StreamExecutionEnvironment => ScalaStreamExecutionEnvironment}
 import org.apache.flink.table.api.bridge.java.StreamTableEnvironment
-import org.apache.flink.table.api.bridge.scala.{StreamTableEnvironment => ScalaStreamTableEnvironment, _}
+import org.apache.flink.table.api.bridge.scala.{dataStreamConversions, StreamTableEnvironment => ScalaStreamTableEnvironment}
 import org.apache.flink.table.api.config.TableConfigOptions
-import org.apache.flink.table.api.internal.{TableEnvironmentImpl, TableEnvironmentInternal}
+import org.apache.flink.table.api.internal.TableEnvironmentImpl
 import org.apache.flink.table.catalog._
+import org.apache.flink.table.legacy.api.TableSchema
+import org.apache.flink.table.planner.factories.TestValuesTableFactory
 import org.apache.flink.table.planner.factories.utils.TestCollectionTableFactory
-import org.apache.flink.table.planner.runtime.utils.TestingAppendSink
-import org.apache.flink.table.planner.utils.{TableTestUtil, TestTableSourceSinks, TestTableSourceWithTime}
+import org.apache.flink.table.planner.runtime.utils.{StreamingEnvUtil, TestingAppendSink}
+import org.apache.flink.table.planner.runtime.utils.{TestingAppendSink, TestSinkUtil}
+import org.apache.flink.table.planner.runtime.utils.BatchTestBase.{row => buildRow}
+import org.apache.flink.table.planner.utils.{TableTestUtil, TestTableSourceSinks}
 import org.apache.flink.table.planner.utils.TableTestUtil.{readFromResource, replaceStageId}
 import org.apache.flink.testutils.junit.extensions.parameterized.{ParameterizedTestExtension, Parameters}
 import org.apache.flink.testutils.junit.utils.TempDirUtils
 import org.apache.flink.types.{Row, RowKind}
-import org.apache.flink.util.{CollectionUtil, FileUtils}
+import org.apache.flink.util.CollectionUtil
 
 import org.assertj.core.api.Assertions.assertThatThrownBy
 import org.junit.jupiter.api.{BeforeEach, TestTemplate}
@@ -41,7 +43,7 @@ import org.junit.jupiter.api.Assertions._
 import org.junit.jupiter.api.extension.ExtendWith
 import org.junit.jupiter.api.io.TempDir
 
-import java.io.{File, FileFilter}
+import java.io.File
 import java.lang.{Long => JLong}
 import java.nio.file.Path
 import java.util
@@ -88,22 +90,22 @@ class TableEnvironmentITCase(tableEnvName: String, isStreaming: Boolean) {
       new TableSchema(Array("first"), Array(STRING)),
       "MySink2")
 
-    checkEmptyFile(sink1Path)
-    checkEmptyFile(sink2Path)
+    checkEmptyDir(sink1Path)
+    checkEmptyDir(sink2Path)
 
     val table1 = tEnv.sqlQuery("select first from MyTable")
     table1.executeInsert("MySink1").await()
-    assertFirstValues(sink1Path)
-    checkEmptyFile(sink2Path)
+    assertFirstValues("MySink1")
+    checkEmptyDir(sink2Path)
 
     // delete first csv file
-    new File(sink1Path).delete()
+    deleteDir(sink1Path)
     assertFalse(new File(sink1Path).exists())
 
     val table2 = tEnv.sqlQuery("select last from MyTable")
     table2.executeInsert("MySink2").await()
     assertFalse(new File(sink1Path).exists())
-    assertLastValues(sink2Path)
+    assertLastValues("MySink2")
   }
 
   @TestTemplate
@@ -115,7 +117,7 @@ class TableEnvironmentITCase(tableEnvName: String, isStreaming: Boolean) {
 
     val table1 = tEnv.sqlQuery("select first from MyTable")
     table1.executeInsert("MySink1").await()
-    assertFirstValues(sinkPath)
+    assertFirstValues("MySink1")
   }
 
   @TestTemplate
@@ -124,10 +126,10 @@ class TableEnvironmentITCase(tableEnvName: String, isStreaming: Boolean) {
       tEnv,
       new TableSchema(Array("first"), Array(STRING)),
       "MySink1")
-    checkEmptyFile(sinkPath)
+    checkEmptyDir(sinkPath)
     val tableResult = tEnv.executeSql("insert into MySink1 select first from MyTable")
     checkInsertTableResult(tableResult, "default_catalog.default_database.MySink1")
-    assertFirstValues(sinkPath)
+    assertFirstValues("MySink1")
   }
 
   @TestTemplate
@@ -152,11 +154,11 @@ class TableEnvironmentITCase(tableEnvName: String, isStreaming: Boolean) {
 
     val tableResult1 = tEnv.executeSql("insert overwrite MySink select first from MyTable")
     checkInsertTableResult(tableResult1, "default_catalog.default_database.MySink")
-    assertFirstValues(sinkPath)
+    assertFirstValues("MySink")
 
     val tableResult2 = tEnv.executeSql("insert overwrite MySink select first from MyTable")
     checkInsertTableResult(tableResult2, "default_catalog.default_database.MySink")
-    assertFirstValues(sinkPath)
+    assertFirstValues("MySink")
   }
 
   @TestTemplate
@@ -169,22 +171,22 @@ class TableEnvironmentITCase(tableEnvName: String, isStreaming: Boolean) {
       tEnv,
       new TableSchema(Array("last"), Array(STRING)),
       "MySink2")
-    checkEmptyFile(sink1Path)
-    checkEmptyFile(sink2Path)
+    checkEmptyDir(sink1Path)
+    checkEmptyDir(sink2Path)
 
     val tableResult = tEnv.executeSql("insert into MySink1 select first from MyTable")
     checkInsertTableResult(tableResult, "default_catalog.default_database.MySink1")
 
-    assertFirstValues(sink1Path)
-    checkEmptyFile(sink2Path)
+    assertFirstValues("MySink1")
+    checkEmptyDir(sink2Path)
 
     // delete first csv file
-    new File(sink1Path).delete()
+    deleteDir(sink1Path)
     assertFalse(new File(sink1Path).exists())
 
     tEnv.sqlQuery("select last from MyTable").executeInsert("MySink2").await()
     assertFalse(new File(sink1Path).exists())
-    assertLastValues(sink2Path)
+    assertLastValues("MySink2")
   }
 
   @TestTemplate
@@ -199,7 +201,7 @@ class TableEnvironmentITCase(tableEnvName: String, isStreaming: Boolean) {
       streamTableEnv,
       new TableSchema(Array("first"), Array(STRING)),
       "MySink1")
-    checkEmptyFile(sink1Path)
+    checkEmptyDir(sink1Path)
 
     val table = streamTableEnv.sqlQuery("select last from MyTable where id > 0")
     val resultSet = streamTableEnv.toDataStream(table)
@@ -208,17 +210,17 @@ class TableEnvironmentITCase(tableEnvName: String, isStreaming: Boolean) {
 
     val tableResult = streamTableEnv.executeSql("insert into MySink1 select first from MyTable")
     checkInsertTableResult(tableResult, "default_catalog.default_database.MySink1")
-    assertFirstValues(sink1Path)
+    assertFirstValues(streamTableEnv, "MySink1")
 
     // the DataStream program is not executed
     assertFalse(sink.isInitialized)
 
-    deleteFile(sink1Path)
+    deleteDir(sink1Path)
 
     streamEnv.execute("test2")
     assertEquals(getExpectedLastValues.sorted, sink.getAppendResults.sorted)
     // the table program is not executed again
-    assertFileNotExist(sink1Path)
+    checkEmptyDir(sink1Path)
   }
 
   @TestTemplate
@@ -233,7 +235,7 @@ class TableEnvironmentITCase(tableEnvName: String, isStreaming: Boolean) {
       streamTableEnv,
       new TableSchema(Array("first"), Array(STRING)),
       "MySink1")
-    checkEmptyFile(sink1Path)
+    checkEmptyDir(sink1Path)
 
     val table = streamTableEnv.sqlQuery("select last from MyTable where id > 0")
     val resultSet = streamTableEnv.toDataStream(table)
@@ -254,11 +256,11 @@ class TableEnvironmentITCase(tableEnvName: String, isStreaming: Boolean) {
 
     streamEnv.execute("test2")
     // the table program is not executed
-    checkEmptyFile(sink1Path)
+    checkEmptyDir(sink1Path)
     assertEquals(getExpectedLastValues.sorted, sink.getAppendResults.sorted)
 
     streamTableEnv.executeSql(insertStmt).await()
-    assertFirstValues(sink1Path)
+    assertFirstValues(streamTableEnv, "MySink1")
     // the DataStream program is not executed again because the result in sink is not changed
     assertEquals(getExpectedLastValues.sorted, sink.getAppendResults.sorted)
   }
@@ -268,17 +270,17 @@ class TableEnvironmentITCase(tableEnvName: String, isStreaming: Boolean) {
     if (!tableEnvName.equals("StreamTableEnvironment")) {
       return
     }
-    val streamEnv = ScalaStreamExecutionEnvironment.getExecutionEnvironment
+    val streamEnv = StreamExecutionEnvironment.getExecutionEnvironment
     val streamTableEnv = ScalaStreamTableEnvironment.create(streamEnv, settings)
-    val t = streamEnv
-      .fromCollection(getPersonData)
+    val t = StreamingEnvUtil
+      .fromCollection(streamEnv, getPersonData)
       .toTable(streamTableEnv, 'first, 'id, 'score, 'last)
     streamTableEnv.createTemporaryView("MyTable", t)
     val sink1Path = TestTableSourceSinks.createCsvTemporarySinkTable(
       streamTableEnv,
       new TableSchema(Array("first"), Array(STRING)),
       "MySink1")
-    checkEmptyFile(sink1Path)
+    checkEmptyDir(sink1Path)
 
     val table = streamTableEnv.sqlQuery("select last from MyTable where id > 0")
     val resultSet = streamTableEnv.toDataStream(table)
@@ -300,11 +302,11 @@ class TableEnvironmentITCase(tableEnvName: String, isStreaming: Boolean) {
 
     streamEnv.execute("test2")
     // the table program is not executed
-    checkEmptyFile(sink1Path)
+    checkEmptyDir(sink1Path)
     assertEquals(getExpectedLastValues.sorted, sink.getAppendResults.sorted)
 
     streamTableEnv.executeSql(insertStmt).await()
-    assertFirstValues(sink1Path)
+    assertFirstValues(streamTableEnv, "MySink1")
     // the DataStream program is not executed again because the result in sink is not changed
     assertEquals(getExpectedLastValues.sorted, sink.getAppendResults.sorted)
   }
@@ -315,11 +317,11 @@ class TableEnvironmentITCase(tableEnvName: String, isStreaming: Boolean) {
       tEnv,
       new TableSchema(Array("first"), Array(STRING)),
       "MySink")
-    checkEmptyFile(sinkPath)
+    checkEmptyDir(sinkPath)
     val table = tEnv.sqlQuery("select first from MyTable")
     val tableResult = table.executeInsert("MySink")
     checkInsertTableResult(tableResult, "default_catalog.default_database.MySink")
-    assertFirstValues(sinkPath)
+    assertFirstValues("MySink")
   }
 
   @TestTemplate
@@ -328,10 +330,10 @@ class TableEnvironmentITCase(tableEnvName: String, isStreaming: Boolean) {
       tEnv,
       new TableSchema(Array("first"), Array(STRING)),
       "MySink")
-    checkEmptyFile(sinkPath)
+    checkEmptyDir(sinkPath)
     val tableResult = tEnv.executeSql("execute insert into MySink select first from MyTable")
     checkInsertTableResult(tableResult, "default_catalog.default_database.MySink")
-    assertFirstValues(sinkPath)
+    assertFirstValues("MySink")
   }
 
   @TestTemplate
@@ -354,11 +356,11 @@ class TableEnvironmentITCase(tableEnvName: String, isStreaming: Boolean) {
     )
     val tableResult1 = tEnv.sqlQuery("select first from MyTable").executeInsert("MySink", true)
     checkInsertTableResult(tableResult1, "default_catalog.default_database.MySink")
-    assertFirstValues(sinkPath)
+    assertFirstValues("MySink")
 
     val tableResult2 = tEnv.sqlQuery("select first from MyTable").executeInsert("MySink", true)
     checkInsertTableResult(tableResult2, "default_catalog.default_database.MySink")
-    assertFirstValues(sinkPath)
+    assertFirstValues("MySink")
   }
 
   @TestTemplate
@@ -414,8 +416,8 @@ class TableEnvironmentITCase(tableEnvName: String, isStreaming: Boolean) {
 
     // checkInsertTableResult will wait the job finished,
     // we should assert file values first to verify job has been finished
-    assertFirstValues(sink2Path)
-    assertLastValues(sink3Path)
+    assertFirstValues("MySink2")
+    assertLastValues("MySink3")
 
     // check TableResult after verifying file values
     checkInsertTableResult(
@@ -468,8 +470,8 @@ class TableEnvironmentITCase(tableEnvName: String, isStreaming: Boolean) {
       "default_catalog.default_database.MySink1",
       "default_catalog.default_database.MySink2")
 
-    assertFirstValues(sink1Path)
-    assertLastValues(sink2Path)
+    assertFirstValues("MySink1")
+    assertLastValues("MySink2")
   }
 
   @TestTemplate
@@ -493,8 +495,8 @@ class TableEnvironmentITCase(tableEnvName: String, isStreaming: Boolean) {
       "default_catalog.default_database.MySink1",
       "default_catalog.default_database.MySink2")
 
-    assertFirstValues(sink1Path)
-    assertLastValues(sink2Path)
+    assertFirstValues("MySink1")
+    assertLastValues("MySink2")
   }
 
   @TestTemplate
@@ -539,8 +541,8 @@ class TableEnvironmentITCase(tableEnvName: String, isStreaming: Boolean) {
       "default_catalog.default_database.MySink1",
       "default_catalog.default_database.MySink2")
 
-    assertFirstValues(sink1Path)
-    assertLastValues(sink2Path)
+    assertFirstValues("MySink1")
+    assertLastValues("MySink2")
 
     // execute again using same StatementSet instance
     stmtSet
@@ -553,8 +555,8 @@ class TableEnvironmentITCase(tableEnvName: String, isStreaming: Boolean) {
       "default_catalog.default_database.MySink1",
       "default_catalog.default_database.MySink2")
 
-    assertFirstValues(sink1Path)
-    assertLastValues(sink2Path)
+    assertFirstValues("MySink1")
+    assertLastValues("MySink2")
   }
 
   @TestTemplate
@@ -665,12 +667,17 @@ class TableEnvironmentITCase(tableEnvName: String, isStreaming: Boolean) {
 
   @TestTemplate
   def testExecuteSelectWithTimeAttribute(): Unit = {
-    val data = Seq("Mary")
-    val schema = new TableSchema(Array("name", "pt"), Array(Types.STRING, Types.LOCAL_DATE_TIME))
-    val sourceType = Types.STRING
-    val tableSource = new TestTableSourceWithTime(true, schema, sourceType, data, null, "pt")
-    // TODO refactor this after FLINK-16160 is finished
-    tEnv.asInstanceOf[TableEnvironmentInternal].registerTableSourceInternal("T", tableSource)
+    val dataId = TestValuesTableFactory.registerData(Seq(buildRow("Mary")))
+    tEnv.executeSql(s"""
+                       |create table T (
+                       |  name string,
+                       |  pt as proctime()
+                       |) with (
+                       |  'connector' = 'values',
+                       |  'bounded' = 'true',
+                       |  'data-id' = '$dataId'
+                       |)
+                       |""".stripMargin)
 
     val tableResult = tEnv.executeSql("select * from T")
     assertTrue(tableResult.getJobClient.isPresent)
@@ -678,8 +685,9 @@ class TableEnvironmentITCase(tableEnvName: String, isStreaming: Boolean) {
     assertEquals(
       ResolvedSchema.of(
         Column.physical("name", DataTypes.STRING()),
-        Column.physical("pt", DataTypes.TIMESTAMP_LTZ(3))),
-      tableResult.getResolvedSchema)
+        Column.physical("pt", DataTypes.TIMESTAMP_LTZ(3).notNull())),
+      tableResult.getResolvedSchema
+    )
     val it = tableResult.collect()
     assertTrue(it.hasNext)
     val row = it.next()
@@ -721,14 +729,18 @@ class TableEnvironmentITCase(tableEnvName: String, isStreaming: Boolean) {
     data.toList
   }
 
-  private def assertFirstValues(csvFilePath: String): Unit = {
+  private def assertFirstValues(tableName: String): Unit = {
+    assertFirstValues(tEnv, tableName)
+  }
+
+  private def assertFirstValues(tEnv: TableEnvironment, tableName: String): Unit = {
     val expected = List("Mike", "Bob", "Sam", "Peter", "Liz", "Sally", "Alice", "Kelly")
-    val actual = readFile(csvFilePath)
+    val actual = getTableData(tEnv, tableName)
     assertEquals(expected.sorted, actual.sorted)
   }
 
-  private def assertLastValues(csvFilePath: String): Unit = {
-    val actual = readFile(csvFilePath)
+  private def assertLastValues(tableName: String): Unit = {
+    val actual = getTableData(tEnv, tableName)
     assertEquals(getExpectedLastValues.sorted, actual.sorted)
   }
 
@@ -736,8 +748,36 @@ class TableEnvironmentITCase(tableEnvName: String, isStreaming: Boolean) {
     List("Smith", "Taylor", "Miller", "Smith", "Williams", "Miller", "Smith", "Williams")
   }
 
-  private def checkEmptyFile(csvFilePath: String): Unit = {
-    assertTrue(FileUtils.readFileUtf8(new File(csvFilePath)).isEmpty)
+  private def getTableData(tEnv: TableEnvironment, tableName: String): List[String] = {
+    val iterator = tEnv.executeSql(s"select * from $tableName").collect()
+    val result = new mutable.MutableList[String]
+    try {
+      while (iterator.hasNext) {
+        result.+=(TestSinkUtil.rowToString(iterator.next()))
+      }
+    } finally {
+      iterator.close()
+    }
+    result.toList
+  }
+
+  private def checkEmptyDir(dirPath: String): Unit = {
+    val dir = new File(dirPath)
+    assertTrue(!dir.exists() || dir.listFiles().isEmpty)
+  }
+
+  private def deleteDir(dirPath: String): Unit = {
+    val dir = new File(dirPath)
+    if (!dir.exists()) {
+      return
+    }
+    if (dir.isFile) {
+      deleteFile(dir.getAbsolutePath)
+      return
+    }
+    dir.listFiles().foreach(file => deleteDir(file.getAbsolutePath))
+    dir.delete()
+    assertFalse(new File(dirPath).exists())
   }
 
   private def deleteFile(path: String): Unit = {
@@ -745,10 +785,6 @@ class TableEnvironmentITCase(tableEnvName: String, isStreaming: Boolean) {
     assertFalse(new File(path).exists())
   }
 
-  private def assertFileNotExist(path: String): Unit = {
-    assertFalse(new File(path).exists())
-  }
-
   private def checkInsertTableResult(tableResult: TableResult, fieldNames: String*): Unit = {
     assertTrue(tableResult.getJobClient.isPresent)
     assertEquals(ResultKind.SUCCESS_WITH_CONTENT, tableResult.getResultKind)
@@ -761,21 +797,6 @@ class TableEnvironmentITCase(tableEnvName: String, isStreaming: Boolean) {
     assertFalse(it.hasNext)
   }
 
-  private def readFile(csvFilePath: String): List[String] = {
-    val file = new File(csvFilePath)
-    if (file.isDirectory) {
-      file
-        .listFiles(new FileFilter() {
-          override def accept(f: File): Boolean = f.isFile
-        })
-        .map(FileUtils.readFileUtf8)
-        .flatMap(_.split("\n"))
-        .toList
-    } else {
-      FileUtils.readFileUtf8(file).split("\n").toList
-    }
-  }
-
 }
 
 object TableEnvironmentITCase {
