@@ -55,13 +55,6 @@ class ShuffledHashJoinTest extends JoinTestBase {
       .isInstanceOf[TableException]
   }
 
-  @Test
-  override def testLeftOuterJoinOnFalse(): Unit = {
-    assertThatThrownBy(() => super.testLeftOuterJoinOnFalse())
-      .hasMessageContaining("Cannot generate a valid execution plan for the given query")
-      .isInstanceOf[TableException]
-  }
-
   @Test
   override def testRightOuterJoinOnTrue(): Unit = {
     assertThatThrownBy(() => super.testRightOuterJoinOnTrue())
@@ -69,13 +62,6 @@ class ShuffledHashJoinTest extends JoinTestBase {
       .isInstanceOf[TableException]
   }
 
-  @Test
-  override def testRightOuterJoinOnFalse(): Unit = {
-    assertThatThrownBy(() => super.testRightOuterJoinOnFalse())
-      .hasMessageContaining("Cannot generate a valid execution plan for the given query")
-      .isInstanceOf[TableException]
-  }
-
   @Test
   override def testRightOuterJoinWithNonEquiPred(): Unit = {
     assertThatThrownBy(() => super.testRightOuterJoinWithNonEquiPred())
