@@ -23,8 +23,8 @@ import org.apache.flink.table.types.logical._
 import org.apache.calcite.rel.RelNode
 import org.apache.calcite.rex.RexNode
 import org.apache.calcite.sql.fun.SqlStdOperatorTable.{DIVIDE, EQUALS, GREATER_THAN, IS_FALSE, IS_NOT_NULL, IS_TRUE, LESS_THAN, LESS_THAN_OR_EQUAL, NOT_EQUALS}
-import org.junit.{Before, Test}
-import org.junit.Assert.{assertEquals, assertNull}
+import org.junit.jupiter.api.{BeforeEach, Test}
+import org.junit.jupiter.api.Assertions.{assertEquals, assertNull}
 
 import scala.collection.JavaConversions._
 
@@ -34,7 +34,7 @@ class FlinkRelMdFilteredColumnIntervalTest extends FlinkRelMdHandlerTestBase {
       expr13: RexNode = _
   private var projects: List[RexNode] = _
 
-  @Before
+  @BeforeEach
   def before(): Unit = {
     ts = relBuilder.scan("MyTable3").build()
     relBuilder.push(ts)
