@@ -17,16 +17,19 @@
  */
 package org.apache.flink.table.planner.plan.rules.logical
 
-import org.apache.flink.api.scala._
 import org.apache.flink.table.api._
 import org.apache.flink.table.planner.plan.optimize.program.{BatchOptimizeContext, FlinkChainedProgram, FlinkHepRuleSetProgramBuilder, HEP_RULES_EXECUTION_TYPE}
 import org.apache.flink.table.planner.utils.TableTestBase
 
 import org.apache.calcite.plan.hep.HepMatchOrder
+import org.apache.calcite.rel.rules.PruneEmptyRules
 import org.apache.calcite.tools.RuleSets
 import org.junit.jupiter.api.{BeforeEach, Test}
 
-/** Test for [[FlinkLimit0RemoveRule]]. */
+/**
+ * Former test for [[FlinkLimit0RemoveRule]] which now replaced by Calcite's
+ * [[PruneEmptyRules.SORT_FETCH_ZERO_INSTANCE]].
+ */
 class FlinkLimit0RemoveRuleTest extends TableTestBase {
 
   private val util = batchTestUtil()
@@ -39,7 +42,8 @@ class FlinkLimit0RemoveRuleTest extends TableTestBase {
       FlinkHepRuleSetProgramBuilder.newBuilder
         .setHepRulesExecutionType(HEP_RULES_EXECUTION_TYPE.RULE_SEQUENCE)
         .setHepMatchOrder(HepMatchOrder.BOTTOM_UP)
-        .add(RuleSets.ofList(FlinkSubQueryRemoveRule.FILTER, FlinkLimit0RemoveRule.INSTANCE))
+        .add(
+          RuleSets.ofList(FlinkSubQueryRemoveRule.FILTER, PruneEmptyRules.SORT_FETCH_ZERO_INSTANCE))
         .build()
     )
     util.replaceBatchProgram(programs)
