@@ -17,41 +17,32 @@
  */
 package org.apache.flink.table.planner.plan.stream.sql.join
 
-import org.apache.flink.api.scala._
+import org.apache.flink.legacy.table.sources.StreamTableSource
 import org.apache.flink.streaming.api.datastream.DataStream
 import org.apache.flink.streaming.api.environment.StreamExecutionEnvironment
 import org.apache.flink.table.api._
 import org.apache.flink.table.api.config.{ExecutionConfigOptions, OptimizerConfigOptions}
-import org.apache.flink.table.api.internal.TableEnvironmentInternal
 import org.apache.flink.table.data.RowData
 import org.apache.flink.table.descriptors.ConnectorDescriptorValidator.CONNECTOR_TYPE
 import org.apache.flink.table.descriptors.DescriptorProperties
-import org.apache.flink.table.factories.TableSourceFactory
 import org.apache.flink.table.functions.{AsyncTableFunction, TableFunction, UserDefinedFunction}
+import org.apache.flink.table.legacy.api.TableSchema
+import org.apache.flink.table.legacy.factories.TableSourceFactory
+import org.apache.flink.table.legacy.sources.{LookupableTableSource, TableSource}
 import org.apache.flink.table.planner.plan.utils._
 import org.apache.flink.table.planner.utils.{TableTestBase, TestingTableEnvironment}
 import org.apache.flink.table.planner.utils.TableTestUtil.{readFromResource, replaceNodeIdInOperator, replaceStageId, replaceStreamNodeId}
-import org.apache.flink.table.sources._
 import org.apache.flink.table.types.DataType
 import org.apache.flink.table.utils.EncodingUtils
-import org.apache.flink.testutils.junit.extensions.parameterized.{ParameterizedTestExtension, Parameters}
 
-import _root_.java.lang.{Boolean => JBoolean}
 import _root_.java.sql.Timestamp
 import _root_.java.util
-import _root_.java.util.{ArrayList => JArrayList, Collection => JCollection, HashMap => JHashMap, List => JList, Map => JMap}
-import _root_.scala.collection.JavaConversions._
+import _root_.java.util.{ArrayList => JArrayList, HashMap => JHashMap, List => JList, Map => JMap}
 import org.assertj.core.api.Assertions.{assertThat, assertThatExceptionOfType, assertThatThrownBy}
-import org.assertj.core.api.Assumptions.assumeThat
-import org.junit.jupiter.api.{BeforeEach, TestTemplate}
-import org.junit.jupiter.api.extension.ExtendWith
+import org.junit.jupiter.api.{BeforeEach, Test}
 
-/**
- * The physical plans for legacy [[org.apache.flink.table.sources.LookupableTableSource]] and new
- * [[org.apache.flink.table.connector.source.LookupTableSource]] should be identical.
- */
-@ExtendWith(Array(classOf[ParameterizedTestExtension]))
-class LookupJoinTest(legacyTableSource: Boolean) extends TableTestBase with Serializable {
+/** Tests for lookup join. */
+class LookupJoinTest extends TableTestBase with Serializable {
 
   private val util = streamTestUtil()
 
@@ -67,42 +58,83 @@ class LookupJoinTest(legacyTableSource: Boolean) extends TableTestBase with Seri
     util.addDataStream[(Int, String, Long, Double)]("T1", 'a, 'b, 'c, 'd)
     util.addDataStream[(Int, String, Int)]("nonTemporal", 'id, 'name, 'age)
 
-    if (legacyTableSource) {
-      TestTemporalTable.createTemporaryTable(util.tableEnv, "LookupTable")
-      TestTemporalTable.createTemporaryTable(util.tableEnv, "AsyncLookupTable", async = true)
-    } else {
-      util.addTable("""
-                      |CREATE TABLE LookupTable (
-                      |  `id` INT,
-                      |  `name` STRING,
-                      |  `age` INT
-                      |) WITH (
-                      |  'connector' = 'values'
-                      |)
-                      |""".stripMargin)
-      util.addTable("""
-                      |CREATE TABLE AsyncLookupTable (
-                      |  `id` INT,
-                      |  `name` STRING,
-                      |  `age` INT
-                      |) WITH (
-                      |  'connector' = 'values',
-                      |  'async' = 'true'
-                      |)
-                      |""".stripMargin)
+    util.addTable("""
+                    |CREATE TABLE LookupTable (
+                    |  `id` INT,
+                    |  `name` STRING,
+                    |  `age` INT
+                    |) WITH (
+                    |  'connector' = 'values'
+                    |)
+                    |""".stripMargin)
+    util.addTable("""
+                    |CREATE TABLE AsyncLookupTable (
+                    |  `id` INT,
+                    |  `name` STRING,
+                    |  `age` INT
+                    |) WITH (
+                    |  'connector' = 'values',
+                    |  'async' = 'true'
+                    |)
+                    |""".stripMargin)
 
-      util.addTable("""
-                      |CREATE TABLE LookupTableWithComputedColumn (
-                      |  `id` INT,
-                      |  `name` STRING,
-                      |  `age` INT,
-                      |  `nominal_age` as age + 1
-                      |) WITH (
-                      |  'connector' = 'values',
-                      |  'bounded' = 'true'
-                      |)
-                      |""".stripMargin)
-    }
+    util.addTable("""
+                    |CREATE TABLE LookupTableWithComputedColumn (
+                    |  `id` INT,
+                    |  `name` STRING,
+                    |  `age` INT,
+                    |  `nominal_age` as age + 1
+                    |) WITH (
+                    |  'connector' = 'values',
+                    |  'bounded' = 'true'
+                    |)
+                    |""".stripMargin)
+    util.addTable("""
+                    |CREATE TABLE LookupTableWithCustomShuffle1 (
+                    |  `id` INT,
+                    |  `name` STRING,
+                    |  `age` INT,
+                    |  PRIMARY KEY(id) NOT ENFORCED
+                    |) WITH (
+                    |  'connector' = 'values',
+                    |  'enable-custom-shuffle' = 'true'
+                    |)
+                    |""".stripMargin)
+
+    util.addTable("""
+                    |CREATE TABLE LookupTableWithCustomShuffle2 (
+                    |  `id` INT,
+                    |  `name` STRING,
+                    |  `age` INT,
+                    |  PRIMARY KEY(id) NOT ENFORCED
+                    |) WITH (
+                    |  'connector' = 'values',
+                    |  'enable-custom-shuffle' = 'true',
+                    |  'custom-shuffle-deterministic' = 'false'
+                    |)
+                    |""".stripMargin)
+    util.addTable("""
+                    |CREATE TABLE LookupTableWithCustomShuffle3 (
+                    |  `id` INT,
+                    |  `name` STRING,
+                    |  `age` INT,
+                    |  PRIMARY KEY(id) NOT ENFORCED
+                    |) WITH (
+                    |  'connector' = 'values',
+                    |  'enable-custom-shuffle' = 'true',
+                    |  'custom-shuffle-empty-partitioner' = 'true'
+                    |)
+                    |""".stripMargin)
+    util.addTable("""
+                    |CREATE TABLE UpsertSource (
+                    |  `a` int,
+                    |  `b` varchar,
+                    |  `c` bigint,
+                    |  `proctime` AS PROCTIME()
+                    |) with (
+                    |  'connector' = 'values',
+                    |  'changelog-mode' = 'I,UA,UB,D'
+                    |)""".stripMargin)
     util.addTable("""
                     |CREATE TABLE Sink1 (
                     |  a int,
@@ -117,7 +149,7 @@ class LookupJoinTest(legacyTableSource: Boolean) extends TableTestBase with Seri
       .set(ExecutionConfigOptions.TABLE_EXEC_RESOURCE_DEFAULT_PARALLELISM, Int.box(4))
   }
 
-  @TestTemplate
+  @Test
   def testJoinInvalidJoinTemporalTable(): Unit = {
     // must follow a period specification
     expectExceptionThrown(
@@ -143,7 +175,7 @@ class LookupJoinTest(legacyTableSource: Boolean) extends TableTestBase with Seri
     )
   }
 
-  @TestTemplate
+  @Test
   def testNotDistinctFromInJoinCondition(): Unit = {
 
     // does not support join condition contains `IS NOT DISTINCT`
@@ -165,11 +197,8 @@ class LookupJoinTest(legacyTableSource: Boolean) extends TableTestBase with Seri
     )
   }
 
-  @TestTemplate
+  @Test
   def testInvalidLookupTableFunction(): Unit = {
-    if (legacyTableSource) {
-      return
-    }
     util.addDataStream[(Int, String, Long, Timestamp)]("T", 'a, 'b, 'c, 'ts, 'proctime.proctime)
     createLookupTable("LookupTable1", new InvalidTableFunctionResultType)
 
@@ -262,7 +291,7 @@ class LookupJoinTest(legacyTableSource: Boolean) extends TableTestBase with Seri
     )
   }
 
-  @TestTemplate
+  @Test
   def testJoinOnDifferentKeyTypes(): Unit = {
     // Will do implicit type coercion.
     assertThatThrownBy(
@@ -275,7 +304,7 @@ class LookupJoinTest(legacyTableSource: Boolean) extends TableTestBase with Seri
       .isInstanceOf[TableException]
   }
 
-  @TestTemplate
+  @Test
   def testJoinTemporalTable(): Unit = {
     val sql = "SELECT * FROM MyTable AS T JOIN LookupTable " +
       "FOR SYSTEM_TIME AS OF T.proctime AS D ON T.a = D.id"
@@ -283,7 +312,7 @@ class LookupJoinTest(legacyTableSource: Boolean) extends TableTestBase with Seri
     util.verifyExecPlan(sql)
   }
 
-  @TestTemplate
+  @Test
   def testLeftJoinTemporalTable(): Unit = {
     val sql = "SELECT * FROM MyTable AS T LEFT JOIN LookupTable " +
       "FOR SYSTEM_TIME AS OF T.proctime AS D ON T.a = D.id"
@@ -291,7 +320,7 @@ class LookupJoinTest(legacyTableSource: Boolean) extends TableTestBase with Seri
     util.verifyExecPlan(sql)
   }
 
-  @TestTemplate
+  @Test
   def testJoinTemporalTableWithNestedQuery(): Unit = {
     val sql = "SELECT * FROM " +
       "(SELECT a, b, proctime FROM MyTable WHERE c > 1000) AS T " +
@@ -301,7 +330,7 @@ class LookupJoinTest(legacyTableSource: Boolean) extends TableTestBase with Seri
     util.verifyExecPlan(sql)
   }
 
-  @TestTemplate
+  @Test
   def testJoinTemporalTableWithProjectionPushDown(): Unit = {
     val sql =
       """
@@ -314,7 +343,7 @@ class LookupJoinTest(legacyTableSource: Boolean) extends TableTestBase with Seri
     util.verifyExecPlan(sql)
   }
 
-  @TestTemplate
+  @Test
   def testJoinTemporalTableWithFilterPushDown(): Unit = {
     val sql =
       """
@@ -327,7 +356,7 @@ class LookupJoinTest(legacyTableSource: Boolean) extends TableTestBase with Seri
     util.verifyExecPlan(sql)
   }
 
-  @TestTemplate
+  @Test
   def testJoinTemporalTableWithCalcPushDown(): Unit = {
     val sql =
       """
@@ -340,7 +369,7 @@ class LookupJoinTest(legacyTableSource: Boolean) extends TableTestBase with Seri
     util.verifyExecPlan(sql)
   }
 
-  @TestTemplate
+  @Test
   def testJoinTemporalTableWithMultiIndexColumn(): Unit = {
     val sql =
       """
@@ -353,7 +382,7 @@ class LookupJoinTest(legacyTableSource: Boolean) extends TableTestBase with Seri
     util.verifyExecPlan(sql)
   }
 
-  @TestTemplate
+  @Test
   def testAvoidAggregatePushDown(): Unit = {
     val sql1 =
       """
@@ -380,7 +409,7 @@ class LookupJoinTest(legacyTableSource: Boolean) extends TableTestBase with Seri
     util.verifyExecPlan(sql)
   }
 
-  @TestTemplate
+  @Test
   def testJoinTemporalTableWithTrueCondition(): Unit = {
     val sql =
       """
@@ -396,7 +425,7 @@ class LookupJoinTest(legacyTableSource: Boolean) extends TableTestBase with Seri
       .isInstanceOf[TableException]
   }
 
-  @TestTemplate
+  @Test
   def testJoinTemporalTableWithFunctionAndConstantCondition(): Unit = {
 
     val sql =
@@ -409,7 +438,7 @@ class LookupJoinTest(legacyTableSource: Boolean) extends TableTestBase with Seri
     util.verifyExecPlan(sql)
   }
 
-  @TestTemplate
+  @Test
   def testJoinTemporalTableWithMultiFunctionAndConstantCondition(): Unit = {
 
     val sql =
@@ -422,7 +451,7 @@ class LookupJoinTest(legacyTableSource: Boolean) extends TableTestBase with Seri
     util.verifyExecPlan(sql)
   }
 
-  @TestTemplate
+  @Test
   def testJoinTemporalTableWithFunctionAndReferenceCondition(): Unit = {
     val sql =
       """
@@ -435,7 +464,7 @@ class LookupJoinTest(legacyTableSource: Boolean) extends TableTestBase with Seri
     util.verifyExecPlan(sql)
   }
 
-  @TestTemplate
+  @Test
   def testJoinTemporalTableWithUdfEqualFilter(): Unit = {
     val sql =
       """
@@ -449,10 +478,8 @@ class LookupJoinTest(legacyTableSource: Boolean) extends TableTestBase with Seri
     util.verifyExecPlan(sql)
   }
 
-  @TestTemplate
+  @Test
   def testJoinTemporalTableWithComputedColumn(): Unit = {
-    // Computed column do not support in legacyTableSource.
-    assumeThat(legacyTableSource).isFalse
     val sql =
       """
         |SELECT
@@ -464,10 +491,8 @@ class LookupJoinTest(legacyTableSource: Boolean) extends TableTestBase with Seri
     util.verifyExecPlan(sql)
   }
 
-  @TestTemplate
+  @Test
   def testJoinTemporalTableWithComputedColumnAndPushDown(): Unit = {
-    // Computed column do not support in legacyTableSource.
-    assumeThat(legacyTableSource).isFalse
     val sql =
       """
         |SELECT
@@ -479,7 +504,7 @@ class LookupJoinTest(legacyTableSource: Boolean) extends TableTestBase with Seri
     util.verifyExecPlan(sql)
   }
 
-  @TestTemplate
+  @Test
   def testJoinTemporalTableWithMultiConditionOnSameDimField(): Unit = {
     val sql = "SELECT * FROM MyTable AS T JOIN LookupTable " +
       "FOR SYSTEM_TIME AS OF T.proctime AS D ON T.a = D.id and CAST(T.c as INT) = D.id"
@@ -487,7 +512,7 @@ class LookupJoinTest(legacyTableSource: Boolean) extends TableTestBase with Seri
     util.verifyExecPlan(sql)
   }
 
-  @TestTemplate
+  @Test
   def testJoinTemporalTableWithCastOnLookupTable(): Unit = {
     util.addTable("""
                     |CREATE TABLE LookupTable2 (
@@ -512,7 +537,7 @@ class LookupJoinTest(legacyTableSource: Boolean) extends TableTestBase with Seri
       .isInstanceOf[TableException]
   }
 
-  @TestTemplate
+  @Test
   def testJoinTemporalTableWithInteroperableCastOnLookupTable(): Unit = {
     util.addTable("""
                     |CREATE TABLE LookupTable2 (
@@ -534,7 +559,7 @@ class LookupJoinTest(legacyTableSource: Boolean) extends TableTestBase with Seri
     verifyTranslationSuccess(sql)
   }
 
-  @TestTemplate
+  @Test
   def testJoinTemporalTableWithCTE(): Unit = {
     val sql =
       """
@@ -548,7 +573,7 @@ class LookupJoinTest(legacyTableSource: Boolean) extends TableTestBase with Seri
     util.verifyExecPlan(sql)
   }
 
-  @TestTemplate
+  @Test
   def testAggAndAllConstantLookupKeyWithTryResolveMode(): Unit = {
     // expect lookup join using single parallelism due to all constant lookup key
     util.tableEnv.getConfig.set(
@@ -564,18 +589,14 @@ class LookupJoinTest(legacyTableSource: Boolean) extends TableTestBase with Seri
         |  ON D.id = 100
       """.stripMargin
     val actual = util.tableEnv.explainSql(sql, ExplainDetail.JSON_EXECUTION_PLAN)
-    val expected = if (legacyTableSource) {
-      readFromResource(
-        "explain/stream/join/lookup/testAggAndAllConstantLookupKeyWithTryResolveMode.out")
-    } else {
+    val expected =
       readFromResource(
         "explain/stream/join/lookup/testAggAndAllConstantLookupKeyWithTryResolveMode_newSource.out")
-    }
     assertThat(replaceNodeIdInOperator(replaceStreamNodeId(replaceStageId(actual))))
       .isEqualTo(replaceNodeIdInOperator(replaceStreamNodeId(replaceStageId(expected))))
   }
 
-  @TestTemplate
+  @Test
   def testInvalidJoinHint(): Unit = {
     // lost required hint option 'table'
     expectExceptionThrown(
@@ -726,7 +747,7 @@ class LookupJoinTest(legacyTableSource: Boolean) extends TableTestBase with Seri
     )
   }
 
-  @TestTemplate
+  @Test
   def testJoinHintWithTableAlias(): Unit = {
     val sql =
       "SELECT /*+ LOOKUP('table'='D', 'retry-predicate'='lookup_miss', 'retry-strategy'='fixed_delay', 'fixed-delay'='10s', 'max-attempts'='3') */ * FROM MyTable AS T JOIN LookupTable " +
@@ -734,14 +755,14 @@ class LookupJoinTest(legacyTableSource: Boolean) extends TableTestBase with Seri
     util.verifyExecPlan(sql)
   }
 
-  @TestTemplate
+  @Test
   def testJoinHintWithTableNameOnly(): Unit = {
     val sql = "SELECT /*+ LOOKUP('table'='LookupTable') */ * FROM MyTable AS T JOIN LookupTable " +
       "FOR SYSTEM_TIME AS OF T.proctime ON T.a = LookupTable.id"
     util.verifyExecPlan(sql)
   }
 
-  @TestTemplate
+  @Test
   def testMultipleJoinHintsWithSameTableName(): Unit = {
     // only the first hint will take effect
     val sql =
@@ -755,7 +776,7 @@ class LookupJoinTest(legacyTableSource: Boolean) extends TableTestBase with Seri
     util.verifyExecPlan(sql)
   }
 
-  @TestTemplate
+  @Test
   def testMultipleJoinHintsWithSameTableAlias(): Unit = {
     // only the first hint will take effect
     val sql =
@@ -769,7 +790,7 @@ class LookupJoinTest(legacyTableSource: Boolean) extends TableTestBase with Seri
     util.verifyExecPlan(sql)
   }
 
-  @TestTemplate
+  @Test
   def testMultipleJoinHintsWithDifferentTableName(): Unit = {
     // both hints on corresponding tables will take effect
     val sql =
@@ -785,7 +806,7 @@ class LookupJoinTest(legacyTableSource: Boolean) extends TableTestBase with Seri
     util.verifyExecPlan(sql)
   }
 
-  @TestTemplate
+  @Test
   def testMultipleJoinHintsWithDifferentTableAlias(): Unit = {
     // both hints on corresponding tables will take effect
     val sql =
@@ -801,7 +822,7 @@ class LookupJoinTest(legacyTableSource: Boolean) extends TableTestBase with Seri
     util.verifyExecPlan(sql)
   }
 
-  @TestTemplate
+  @Test
   def testJoinSyncTableWithAsyncHint(): Unit = {
     val sql =
       "SELECT /*+ LOOKUP('table'='D', 'async'='true') */ * FROM MyTable AS T JOIN LookupTable " +
@@ -809,7 +830,7 @@ class LookupJoinTest(legacyTableSource: Boolean) extends TableTestBase with Seri
     util.verifyExecPlan(sql)
   }
 
-  @TestTemplate
+  @Test
   def testJoinAsyncTableWithAsyncHint(): Unit = {
     val sql =
       "SELECT /*+ LOOKUP('table'='D', 'async'='true') */ * " +
@@ -818,7 +839,7 @@ class LookupJoinTest(legacyTableSource: Boolean) extends TableTestBase with Seri
     util.verifyExecPlan(sql)
   }
 
-  @TestTemplate
+  @Test
   def testJoinAsyncTableWithSyncHint(): Unit = {
     val sql =
       "SELECT /*+ LOOKUP('table'='D', 'async'='false') */ * " +
@@ -827,7 +848,7 @@ class LookupJoinTest(legacyTableSource: Boolean) extends TableTestBase with Seri
     util.verifyExecPlan(sql)
   }
 
-  @TestTemplate
+  @Test
   def testAggAndLeftJoinAllowUnordered(): Unit = {
     util.tableEnv.getConfig.set(
       ExecutionConfigOptions.TABLE_EXEC_ASYNC_LOOKUP_OUTPUT_MODE,
@@ -846,6 +867,7 @@ class LookupJoinTest(legacyTableSource: Boolean) extends TableTestBase with Seri
     util.verifyExplain(stmt, ExplainDetail.JSON_EXECUTION_PLAN)
   }
 
+  @Test
   def testAggAndLeftJoinWithTryResolveMode(): Unit = {
     util.tableEnv.getConfig.set(
       OptimizerConfigOptions.TABLE_OPTIMIZER_NONDETERMINISTIC_UPDATE_STRATEGY,
@@ -866,7 +888,7 @@ class LookupJoinTest(legacyTableSource: Boolean) extends TableTestBase with Seri
       .isInstanceOf[TableException]
   }
 
-  @TestTemplate
+  @Test
   def testAsyncJoinWithDefaultParams(): Unit = {
     val stmt = util.tableEnv.asInstanceOf[TestingTableEnvironment].createStatementSet()
     stmt.addInsertSql("""
@@ -880,7 +902,7 @@ class LookupJoinTest(legacyTableSource: Boolean) extends TableTestBase with Seri
     util.verifyExplain(stmt, ExplainDetail.JSON_EXECUTION_PLAN)
   }
 
-  @TestTemplate
+  @Test
   def testJoinWithAsyncHint(): Unit = {
     val stmt = util.tableEnv.asInstanceOf[TestingTableEnvironment].createStatementSet()
     stmt.addInsertSql(
@@ -896,7 +918,7 @@ class LookupJoinTest(legacyTableSource: Boolean) extends TableTestBase with Seri
     util.verifyExplain(stmt, ExplainDetail.JSON_EXECUTION_PLAN)
   }
 
-  @TestTemplate
+  @Test
   def testJoinWithRetryHint(): Unit = {
     val stmt = util.tableEnv.asInstanceOf[TestingTableEnvironment].createStatementSet()
     stmt.addInsertSql(
@@ -912,7 +934,7 @@ class LookupJoinTest(legacyTableSource: Boolean) extends TableTestBase with Seri
     util.verifyExplain(stmt, ExplainDetail.JSON_EXECUTION_PLAN)
   }
 
-  @TestTemplate
+  @Test
   def testJoinWithAsyncAndRetryHint(): Unit = {
     val stmt = util.tableEnv.asInstanceOf[TestingTableEnvironment].createStatementSet()
     stmt.addInsertSql(
@@ -928,7 +950,7 @@ class LookupJoinTest(legacyTableSource: Boolean) extends TableTestBase with Seri
     util.verifyExplain(stmt, ExplainDetail.JSON_EXECUTION_PLAN)
   }
 
-  @TestTemplate
+  @Test
   def testJoinWithMixedCaseJoinHint(): Unit = {
     util.verifyExecPlan(
       """
@@ -944,7 +966,7 @@ class LookupJoinTest(legacyTableSource: Boolean) extends TableTestBase with Seri
     )
   }
 
-  @TestTemplate
+  @Test
   def testJoinHintWithNoPropagatingToSubQuery(): Unit = {
     util.verifyExecPlan(
       """
@@ -961,29 +983,60 @@ class LookupJoinTest(legacyTableSource: Boolean) extends TableTestBase with Seri
     )
   }
 
+  @Test
+  def testJoinTemporalTableWithShuffleLookupHint(): Unit = {
+    val sql =
+      "SELECT /*+ LOOKUP('table'='D', 'shuffle'='true') */ * FROM MyTable AS T JOIN LookupTableWithCustomShuffle1 " +
+        "FOR SYSTEM_TIME AS OF T.proctime AS D ON T.a = D.id"
+    util.verifyExplain(sql, ExplainDetail.JSON_EXECUTION_PLAN)
+  }
+
+  @Test
+  def testJoinTemporalTableWithNotShuffleLookupHint(): Unit = {
+    val sql =
+      "SELECT /*+ LOOKUP('table'='D', 'shuffle'='false') */ * FROM MyTable AS T JOIN LookupTableWithCustomShuffle1 " +
+        "FOR SYSTEM_TIME AS OF T.proctime AS D ON T.a = D.id"
+    util.verifyExplain(sql, ExplainDetail.JSON_EXECUTION_PLAN)
+  }
+
+  @Test
+  def testJoinTemporalTableWithShuffleLookupHintEmptyPartitioner(): Unit = {
+    val sql =
+      "SELECT /*+ LOOKUP('table'='D', 'shuffle'='true') */ * FROM MyTable AS T JOIN LookupTableWithCustomShuffle3 " +
+        "FOR SYSTEM_TIME AS OF T.proctime AS D ON T.a = D.id"
+    util.verifyExplain(sql, ExplainDetail.JSON_EXECUTION_PLAN)
+  }
+
+  @Test
+  def testJoinTemporalTableWithNonDeterministicInsertOnlyInputCustomShuffle(): Unit = {
+    val sql =
+      "SELECT /*+ LOOKUP('table'='D', 'shuffle'='true') */ * FROM MyTable AS T JOIN LookupTableWithCustomShuffle2 " +
+        "FOR SYSTEM_TIME AS OF T.proctime AS D ON T.a = D.id"
+    util.verifyExplain(sql, ExplainDetail.JSON_EXECUTION_PLAN)
+  }
+
+  @Test
+  def testJoinTemporalTableWithNonDeterministicUpsertInputCustomShuffle(): Unit = {
+    val sql =
+      "SELECT /*+ LOOKUP('table'='D', 'shuffle'='true') */ * FROM UpsertSource AS T JOIN LookupTableWithCustomShuffle2 " +
+        "FOR SYSTEM_TIME AS OF T.proctime AS D ON T.a = D.id"
+    util.verifyExplain(sql, ExplainDetail.JSON_EXECUTION_PLAN)
+  }
+
   // ==========================================================================================
 
   private def createLookupTable(tableName: String, lookupFunction: UserDefinedFunction): Unit = {
-    if (legacyTableSource) {
-      lookupFunction match {
-        case tf: TableFunction[_] =>
-          TestInvalidTemporalTable.createTemporaryTable(util.tableEnv, tableName, tf)
-        case atf: AsyncTableFunction[_] =>
-          TestInvalidTemporalTable.createTemporaryTable(util.tableEnv, tableName, atf)
-      }
-    } else {
-      util.addTable(s"""
-                       |CREATE TABLE $tableName (
-                       |  `id` INT,
-                       |  `name` STRING,
-                       |  `age` INT,
-                       |  `ts` TIMESTAMP(3)
-                       |) WITH (
-                       |  'connector' = 'values',
-                       |  'lookup-function-class' = '${lookupFunction.getClass.getName}'
-                       |)
-                       |""".stripMargin)
-    }
+    util.addTable(s"""
+                     |CREATE TABLE $tableName (
+                     |  `id` INT,
+                     |  `name` STRING,
+                     |  `age` INT,
+                     |  `ts` TIMESTAMP(3)
+                     |) WITH (
+                     |  'connector' = 'values',
+                     |  'lookup-function-class' = '${lookupFunction.getClass.getName}'
+                     |)
+                     |""".stripMargin)
   }
 
   private def expectExceptionThrown(
@@ -1000,13 +1053,6 @@ class LookupJoinTest(legacyTableSource: Boolean) extends TableTestBase with Seri
   }
 }
 
-object LookupJoinTest {
-  @Parameters(name = "LegacyTableSource={0}")
-  def parameters(): JCollection[Array[Object]] = {
-    Seq[Array[AnyRef]](Array(JBoolean.TRUE), Array(JBoolean.FALSE))
-  }
-}
-
 class TestTemporalTable(
     bounded: Boolean = false,
     val keys: Array[String] = Array.empty[String],
@@ -1059,18 +1105,6 @@ class TestTemporalTable(
   }
 }
 
-object TestTemporalTable {
-
-  def createTemporaryTable(
-      tEnv: TableEnvironment,
-      tableName: String,
-      isBounded: Boolean = false,
-      async: Boolean = false): Unit = {
-    val source = new TestTemporalTable(isBounded, async = async)
-    tEnv.asInstanceOf[TableEnvironmentInternal].registerTableSourceInternal(tableName, source)
-  }
-}
-
 class TestTemporalTableFactory extends TableSourceFactory[RowData] {
 
   override def createTableSource(properties: JMap[String, String]): TableSource[RowData] = {
