@@ -21,14 +21,18 @@ import org.apache.flink.api.common.typeinfo.TypeInformation
 import org.apache.flink.api.dag.Transformation
 import org.apache.flink.api.java.functions.KeySelector
 import org.apache.flink.configuration.Configuration
-import org.apache.flink.contrib.streaming.state.RocksDBStateBackend
-import org.apache.flink.runtime.state.StateBackend
-import org.apache.flink.runtime.state.memory.MemoryStateBackend
-import org.apache.flink.streaming.api.operators.OneInputStreamOperator
-import org.apache.flink.streaming.api.scala.DataStream
+import org.apache.flink.runtime.asyncprocessing.operators.AsyncKeyedProcessOperator
+import org.apache.flink.runtime.state.{CheckpointStorage, StateBackend}
+import org.apache.flink.runtime.state.hashmap.HashMapStateBackend
+import org.apache.flink.runtime.state.storage.{FileSystemCheckpointStorage, JobManagerCheckpointStorage}
+import org.apache.flink.state.rocksdb.EmbeddedRocksDBStateBackend
+import org.apache.flink.streaming.api.datastream.DataStream
+import org.apache.flink.streaming.api.operators.{OneInputStreamOperator, SimpleOperatorFactory}
 import org.apache.flink.streaming.api.transformations.{OneInputTransformation, PartitionTransformation}
 import org.apache.flink.streaming.api.watermark.Watermark
+import org.apache.flink.streaming.runtime.operators.asyncprocessing.AsyncStateProcessingOperator
 import org.apache.flink.streaming.util.{KeyedOneInputStreamOperatorTestHarness, OneInputStreamOperatorTestHarness}
+import org.apache.flink.streaming.util.asyncprocessing.AsyncKeyedOneInputStreamOperatorTestHarness
 import org.apache.flink.table.data.RowData
 import org.apache.flink.table.planner.JLong
 import org.apache.flink.table.planner.runtime.utils.StreamingTestBase
@@ -48,10 +52,21 @@ class HarnessTestBase(mode: StateBackendMode) extends StreamingTestBase {
     mode match {
       case HEAP_BACKEND =>
         val conf = new Configuration()
-        new MemoryStateBackend().configure(conf, classLoader)
+        new HashMapStateBackend().configure(conf, classLoader)
 
       case ROCKSDB_BACKEND =>
-        new RocksDBStateBackend("file://" + TempDirUtils.newFolder(tempFolder).getAbsoluteFile)
+        new EmbeddedRocksDBStateBackend()
+    }
+  }
+
+  protected def getCheckpointStorage: CheckpointStorage = {
+    mode match {
+      case HEAP_BACKEND =>
+        new JobManagerCheckpointStorage()
+
+      case ROCKSDB_BACKEND =>
+        new FileSystemCheckpointStorage(
+          "file://" + TempDirUtils.newFolder(tempFolder).getAbsoluteFile)
     }
   }
 
@@ -59,9 +74,13 @@ class HarnessTestBase(mode: StateBackendMode) extends StreamingTestBase {
       operator: OneInputStreamOperator[IN, OUT],
       keySelector: KeySelector[IN, KEY],
       keyType: TypeInformation[KEY]): KeyedOneInputStreamOperatorTestHarness[KEY, IN, OUT] = {
-    val harness =
+    val harness = if (operator.isInstanceOf[AsyncStateProcessingOperator]) {
+      AsyncKeyedOneInputStreamOperatorTestHarness.create(operator, keySelector, keyType)
+    } else {
       new KeyedOneInputStreamOperatorTestHarness[KEY, IN, OUT](operator, keySelector, keyType)
+    }
     harness.setStateBackend(getStateBackend)
+    harness.setCheckpointStorage(getCheckpointStorage)
     harness
   }
 
@@ -69,7 +88,7 @@ class HarnessTestBase(mode: StateBackendMode) extends StreamingTestBase {
       : KeyedOneInputStreamOperatorTestHarness[RowData, RowData, RowData] = {
 
     val transformation =
-      extractExpectedTransformation(ds.javaStream.getTransformation, operatorNameIdentifier)
+      extractExpectedTransformation(ds.getTransformation, operatorNameIdentifier)
     val processOperator = transformation.getOperator
       .asInstanceOf[OneInputStreamOperator[Any, Any]]
     val keySelector = transformation.getStateKeySelector.asInstanceOf[KeySelector[Any, Any]]
@@ -83,7 +102,7 @@ class HarnessTestBase(mode: StateBackendMode) extends StreamingTestBase {
       ds: DataStream[_],
       operatorNameIdentifier: String): OneInputStreamOperatorTestHarness[RowData, RowData] = {
     val transformation =
-      extractExpectedTransformation(ds.javaStream.getTransformation, operatorNameIdentifier)
+      extractExpectedTransformation(ds.getTransformation, operatorNameIdentifier)
     val processOperator = transformation.getOperator
       .asInstanceOf[OneInputStreamOperator[Any, Any]]
     new OneInputStreamOperatorTestHarness(processOperator)
@@ -112,6 +131,14 @@ class HarnessTestBase(mode: StateBackendMode) extends StreamingTestBase {
   def dropWatermarks(elements: Array[AnyRef]): util.Collection[AnyRef] = {
     elements.filter(e => !e.isInstanceOf[Watermark]).toList
   }
+
+  protected def isAsyncStateOperator(
+      testHarness: KeyedOneInputStreamOperatorTestHarness[RowData, RowData, RowData]): Boolean = {
+    testHarness.getOperatorFactory
+      .asInstanceOf[SimpleOperatorFactory[_]]
+      .getOperator
+      .isInstanceOf[AsyncKeyedProcessOperator[_, _, _]]
+  }
 }
 
 object HarnessTestBase {
