@@ -39,11 +39,8 @@ import org.apache.flink.table.runtime.keyselector.RowDataKeySelector;
 import org.apache.flink.table.runtime.typeutils.InternalTypeInfo;
 import org.apache.flink.util.Collector;
 
-import org.apache.flink.shaded.guava31.com.google.common.cache.Cache;
-import org.apache.flink.shaded.guava31.com.google.common.cache.CacheBuilder;
-import org.apache.flink.shaded.guava31.com.google.common.cache.RemovalCause;
-import org.apache.flink.shaded.guava31.com.google.common.cache.RemovalListener;
-import org.apache.flink.shaded.guava31.com.google.common.cache.RemovalNotification;
+import org.apache.flink.shaded.guava32.com.google.common.cache.Cache;
+import org.apache.flink.shaded.guava32.com.google.common.cache.CacheBuilder;
 
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
@@ -68,7 +65,8 @@ import static org.apache.flink.util.Preconditions.checkArgument;
  * input data has unique keys and unique key must contain partition key 3. input stream could not
  * contain DELETE record or UPDATE_BEFORE record
  */
-public class UpdatableTopNFunction extends AbstractTopNFunction implements CheckpointedFunction {
+public class UpdatableTopNFunction extends AbstractSyncStateTopNFunction
+        implements CheckpointedFunction {
 
     private static final long serialVersionUID = 6786508184355952781L;
 
@@ -134,12 +132,14 @@ public class UpdatableTopNFunction extends AbstractTopNFunction implements Check
         CacheBuilder<Object, Object> cacheBuilder = CacheBuilder.newBuilder();
         if (ttlConfig.isEnabled()) {
             cacheBuilder.expireAfterWrite(
-                    ttlConfig.getTtl().toMilliseconds(), TimeUnit.MILLISECONDS);
+                    ttlConfig.getTimeToLive().toMillis(), TimeUnit.MILLISECONDS);
         }
         kvRowKeyMap =
                 cacheBuilder
                         .maximumSize(lruCacheSize)
-                        .removalListener(new CacheRemovalListener())
+                        .removalListener(
+                                new TopNBufferCacheRemovalListener<>(
+                                        keyContext, this::flushBufferToState))
                         .build();
 
         LOG.info(
@@ -192,9 +192,7 @@ public class UpdatableTopNFunction extends AbstractTopNFunction implements Check
         for (Map.Entry<RowData, Tuple2<TopNBuffer, Map<RowData, RankRow>>> entry :
                 kvRowKeyMap.asMap().entrySet()) {
             RowData partitionKey = entry.getKey();
-            Map<RowData, RankRow> currentRowKeyMap = entry.getValue().f1;
-            keyContext.setCurrentKey(partitionKey);
-            flushBufferToState(currentRowKeyMap);
+            flushBufferToState(partitionKey, entry.getValue());
         }
     }
 
@@ -543,7 +541,11 @@ public class UpdatableTopNFunction extends AbstractTopNFunction implements Check
         }
     }
 
-    private void flushBufferToState(Map<RowData, RankRow> curRowKeyMap) throws Exception {
+    private void flushBufferToState(
+            RowData currentKey, Tuple2<TopNBuffer, Map<RowData, RankRow>> bufferEntry)
+            throws Exception {
+        keyContext.setCurrentKey(currentKey);
+        Map<RowData, RankRow> curRowKeyMap = bufferEntry.f1;
         for (Map.Entry<RowData, RankRow> entry : curRowKeyMap.entrySet()) {
             RowData key = entry.getKey();
             RankRow rankRow = entry.getValue();
@@ -572,37 +574,6 @@ public class UpdatableTopNFunction extends AbstractTopNFunction implements Check
         }
     }
 
-    private class CacheRemovalListener
-            implements RemovalListener<RowData, Tuple2<TopNBuffer, Map<RowData, RankRow>>> {
-
-        @Override
-        public void onRemoval(
-                RemovalNotification<RowData, Tuple2<TopNBuffer, Map<RowData, RankRow>>>
-                        notification) {
-            if (notification.getCause() != RemovalCause.SIZE) {
-                // Don't flush values to state if cause is ttl expired
-                return;
-            }
-
-            RowData partitionKey = notification.getKey();
-            Tuple2<TopNBuffer, Map<RowData, RankRow>> value = notification.getValue();
-            if (partitionKey == null || value == null) {
-                return;
-            }
-
-            RowData previousKey = (RowData) keyContext.getCurrentKey();
-            keyContext.setCurrentKey(partitionKey);
-            try {
-                flushBufferToState(value.f1);
-            } catch (Throwable e) {
-                LOG.error("Fail to synchronize state!", e);
-                throw new RuntimeException(e);
-            } finally {
-                keyContext.setCurrentKey(previousKey);
-            }
-        }
-    }
-
     private static class RankRow {
         private final RowData row;
         private int innerRank;
