@@ -33,7 +33,6 @@ import org.apache.flink.metrics.MetricGroup;
 import org.apache.flink.runtime.state.internal.InternalMergingState;
 import org.apache.flink.runtime.state.internal.InternalValueState;
 import org.apache.flink.streaming.api.operators.AbstractStreamOperator;
-import org.apache.flink.streaming.api.operators.ChainingStrategy;
 import org.apache.flink.streaming.api.operators.InternalTimer;
 import org.apache.flink.streaming.api.operators.InternalTimerService;
 import org.apache.flink.streaming.api.operators.OneInputStreamOperator;
@@ -207,8 +206,11 @@ public abstract class WindowOperator<K, W extends Window> extends AbstractStream
         this.rowtimeIndex = rowtimeIndex;
         this.shiftTimeZone = shiftTimeZone;
         this.recordCounter = RecordCounter.of(inputCountIndex);
+    }
 
-        setChainingStrategy(ChainingStrategy.ALWAYS);
+    @Override
+    public boolean useSplittableTimers() {
+        return true;
     }
 
     WindowOperator(
@@ -240,8 +242,6 @@ public abstract class WindowOperator<K, W extends Window> extends AbstractStream
         this.rowtimeIndex = rowtimeIndex;
         this.shiftTimeZone = shiftTimeZone;
         this.recordCounter = RecordCounter.of(inputCountIndex);
-
-        setChainingStrategy(ChainingStrategy.ALWAYS);
     }
 
     protected abstract void compileGeneratedCode();
