@@ -27,9 +27,9 @@ import org.apache.flink.table.data.GenericRowData;
 import org.apache.flink.table.data.RowData;
 import org.apache.flink.util.Collector;
 
-import org.junit.After;
-import org.junit.Before;
-import org.junit.Test;
+import org.junit.jupiter.api.AfterEach;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Test;
 
 import java.util.HashMap;
 import java.util.Map;
@@ -37,7 +37,7 @@ import java.util.Map;
 import static org.assertj.core.api.Assertions.assertThat;
 
 /** Test hash agg. */
-public class HashAggTest {
+class HashAggTest {
 
     private static final int MEMORY_SIZE = 1024 * 1024 * 32;
 
@@ -47,8 +47,8 @@ public class HashAggTest {
     private IOManager ioManager;
     private SumHashAggTestOperator operator;
 
-    @Before
-    public void before() throws Exception {
+    @BeforeEach
+    void before() throws Exception {
         ioManager = new IOManagerAsync();
         operator =
                 new SumHashAggTestOperator(40 * 32 * 1024) {
@@ -88,8 +88,8 @@ public class HashAggTest {
         operator.open();
     }
 
-    @After
-    public void afterTest() throws Exception {
+    @AfterEach
+    void afterTest() throws Exception {
         this.ioManager.close();
 
         if (this.memoryManager != null) {
@@ -106,7 +106,7 @@ public class HashAggTest {
     }
 
     @Test
-    public void testNormal() throws Exception {
+    void testNormal() throws Exception {
         addRow(GenericRowData.of(1, 1L));
         addRow(GenericRowData.of(5, 2L));
         addRow(GenericRowData.of(2, 3L));
@@ -134,7 +134,7 @@ public class HashAggTest {
     }
 
     @Test
-    public void testSpill() throws Exception {
+    void testSpill() throws Exception {
         for (int i = 0; i < 30000; i++) {
             addRow(GenericRowData.of(i, (long) i));
             addRow(GenericRowData.of(i + 1, (long) i));
