@@ -21,7 +21,7 @@ package org.apache.flink.table.runtime.operators.rank;
 import org.apache.flink.streaming.util.OneInputStreamOperatorTestHarness;
 import org.apache.flink.table.data.RowData;
 
-import org.junit.Test;
+import org.junit.jupiter.api.TestTemplate;
 
 import java.util.ArrayList;
 import java.util.List;
@@ -29,13 +29,15 @@ import java.util.List;
 import static org.apache.flink.table.runtime.util.StreamRecordUtils.insertRecord;
 
 /** Tests for {@link AppendOnlyFirstNFunction}. */
-public class AppendOnlyFirstNFunctionTest extends TopNFunctionTestBase {
+class AppendOnlyFirstNFunctionTest extends TopNFunctionTestBase {
+
     @Override
     AbstractTopNFunction createFunction(
             RankType rankType,
             RankRange rankRange,
             boolean generateUpdateBefore,
-            boolean outputRankNumber) {
+            boolean outputRankNumber,
+            boolean enableAsyncState) {
         return new AppendOnlyFirstNFunction(
                 ttlConfig,
                 inputRowType,
@@ -48,8 +50,13 @@ public class AppendOnlyFirstNFunctionTest extends TopNFunctionTestBase {
     }
 
     @Override
-    @Test
-    public void testDisableGenerateUpdateBefore() throws Exception {
+    boolean supportedAsyncState() {
+        return false;
+    }
+
+    @Override
+    @TestTemplate
+    void testDisableGenerateUpdateBefore() throws Exception {
         AbstractTopNFunction func =
                 createFunction(RankType.ROW_NUMBER, new ConstantRankRange(1, 2), false, false);
         OneInputStreamOperatorTestHarness<RowData, RowData> testHarness = createTestHarness(func);
@@ -72,8 +79,8 @@ public class AppendOnlyFirstNFunctionTest extends TopNFunctionTestBase {
     }
 
     @Override
-    @Test
-    public void testDisableGenerateUpdateBeforeAndOutputRankNumber() throws Exception {
+    @TestTemplate
+    void testDisableGenerateUpdateBeforeAndOutputRankNumber() throws Exception {
         AbstractTopNFunction func =
                 createFunction(RankType.ROW_NUMBER, new ConstantRankRange(1, 2), false, true);
         OneInputStreamOperatorTestHarness<RowData, RowData> testHarness = createTestHarness(func);
@@ -96,8 +103,8 @@ public class AppendOnlyFirstNFunctionTest extends TopNFunctionTestBase {
     }
 
     @Override
-    @Test
-    public void testOutputRankNumberWithConstantRankRange() throws Exception {
+    @TestTemplate
+    void testOutputRankNumberWithConstantRankRange() throws Exception {
         AbstractTopNFunction func =
                 createFunction(RankType.ROW_NUMBER, new ConstantRankRange(1, 2), true, true);
         OneInputStreamOperatorTestHarness<RowData, RowData> testHarness = createTestHarness(func);
@@ -120,8 +127,8 @@ public class AppendOnlyFirstNFunctionTest extends TopNFunctionTestBase {
     }
 
     @Override
-    @Test
-    public void testConstantRankRangeWithOffset() throws Exception {
+    @TestTemplate
+    void testConstantRankRangeWithOffset() throws Exception {
         AbstractTopNFunction func =
                 createFunction(RankType.ROW_NUMBER, new ConstantRankRange(2, 2), true, false);
         OneInputStreamOperatorTestHarness<RowData, RowData> testHarness = createTestHarness(func);
@@ -142,8 +149,8 @@ public class AppendOnlyFirstNFunctionTest extends TopNFunctionTestBase {
     }
 
     @Override
-    @Test
-    public void testConstantRankRangeWithoutOffset() throws Exception {
+    @TestTemplate
+    void testConstantRankRangeWithoutOffset() throws Exception {
         AbstractTopNFunction func =
                 createFunction(RankType.ROW_NUMBER, new ConstantRankRange(1, 2), true, false);
         OneInputStreamOperatorTestHarness<RowData, RowData> testHarness = createTestHarness(func);
@@ -166,8 +173,8 @@ public class AppendOnlyFirstNFunctionTest extends TopNFunctionTestBase {
     }
 
     @Override
-    @Test
-    public void testOutputRankNumberWithVariableRankRange() throws Exception {
+    @TestTemplate
+    void testOutputRankNumberWithVariableRankRange() throws Exception {
         AbstractTopNFunction func =
                 createFunction(RankType.ROW_NUMBER, new VariableRankRange(1), false, true);
         OneInputStreamOperatorTestHarness<RowData, RowData> testHarness = createTestHarness(func);
