@@ -22,7 +22,6 @@ import org.apache.flink.annotation.Experimental;
 import org.apache.flink.api.common.JobID;
 import org.apache.flink.api.common.JobStatus;
 import org.apache.flink.api.common.eventtime.WatermarkStrategy;
-import org.apache.flink.api.common.restartstrategy.RestartStrategies;
 import org.apache.flink.api.common.typeutils.TypeSerializer;
 import org.apache.flink.api.connector.source.Boundedness;
 import org.apache.flink.api.connector.source.Source;
@@ -49,9 +48,9 @@ import org.apache.flink.streaming.api.environment.CheckpointConfig;
 import org.apache.flink.streaming.api.environment.StreamExecutionEnvironment;
 import org.apache.flink.streaming.api.functions.sink.v2.DiscardingSink;
 import org.apache.flink.streaming.api.operators.collect.CollectResultIterator;
-import org.apache.flink.streaming.api.operators.collect.CollectSinkOperator;
 import org.apache.flink.streaming.api.operators.collect.CollectSinkOperatorFactory;
 import org.apache.flink.streaming.api.operators.collect.CollectStreamSink;
+import org.apache.flink.streaming.util.RestartStrategyUtils;
 import org.apache.flink.util.CloseableIterator;
 import org.apache.flink.util.TestLoggerExtension;
 
@@ -312,7 +311,7 @@ public abstract class SourceTestSuiteBase<T> {
         execEnv.getCheckpointConfig()
                 .setCheckpointingConsistencyMode(CheckpointingMode.EXACTLY_ONCE);
         execEnv.enableCheckpointing(50);
-        execEnv.setRestartStrategy(RestartStrategies.noRestart());
+        RestartStrategyUtils.configureNoRestartStrategy(execEnv);
         DataStreamSource<T> source =
                 execEnv.fromSource(
                                 tryCreateSource(externalContext, sourceSettings),
@@ -674,12 +673,14 @@ public abstract class SourceTestSuiteBase<T> {
         String accumulatorName = "dataStreamCollect_" + UUID.randomUUID();
         CollectSinkOperatorFactory<T> factory =
                 new CollectSinkOperatorFactory<>(serializer, accumulatorName);
-        CollectSinkOperator<T> operator = (CollectSinkOperator<T>) factory.getOperator();
+
         CollectStreamSink<T> sink = new CollectStreamSink<>(stream, factory);
+        String operatorUid = "dataStreamCollect";
         sink.name("Data stream collect sink");
+        sink.uid(operatorUid);
         stream.getExecutionEnvironment().addOperator(sink.getTransformation());
         return new CollectIteratorBuilder<>(
-                operator,
+                operatorUid,
                 serializer,
                 accumulatorName,
                 stream.getExecutionEnvironment().getCheckpointConfig());
@@ -775,17 +776,17 @@ public abstract class SourceTestSuiteBase<T> {
     /** Builder class for constructing {@link CollectResultIterator} of collect sink. */
     protected static class CollectIteratorBuilder<T> {
 
-        private final CollectSinkOperator<T> operator;
+        private final String operatorUid;
         private final TypeSerializer<T> serializer;
         private final String accumulatorName;
         private final CheckpointConfig checkpointConfig;
 
         protected CollectIteratorBuilder(
-                CollectSinkOperator<T> operator,
+                String operatorUid,
                 TypeSerializer<T> serializer,
                 String accumulatorName,
                 CheckpointConfig checkpointConfig) {
-            this.operator = operator;
+            this.operatorUid = operatorUid;
             this.serializer = serializer;
             this.accumulatorName = accumulatorName;
             this.checkpointConfig = checkpointConfig;
@@ -794,7 +795,7 @@ public abstract class SourceTestSuiteBase<T> {
         protected CollectResultIterator<T> build(JobClient jobClient) {
             CollectResultIterator<T> iterator =
                     new CollectResultIterator<>(
-                            operator.getOperatorIdFuture(),
+                            operatorUid,
                             serializer,
                             accumulatorName,
                             checkpointConfig,
