@@ -35,16 +35,16 @@ public class ChangelogRecoveryRescaleITCase extends ChangelogRecoverySwitchEnvTe
 
     @Test
     public void testRescaleOut() throws Exception {
-        testSwitchEnv(getEnv(NUM_SLOTS / 2), getEnv(NUM_SLOTS));
+        testSwitchEnv(delegatedStateBackend, getEnv(NUM_SLOTS / 2), getEnv(NUM_SLOTS));
     }
 
     @Test
     public void testRescaleIn() throws Exception {
-        testSwitchEnv(getEnv(NUM_SLOTS), getEnv(NUM_SLOTS / 2));
+        testSwitchEnv(delegatedStateBackend, getEnv(NUM_SLOTS), getEnv(NUM_SLOTS / 2));
     }
 
     private StreamExecutionEnvironment getEnv(int parallelism) {
-        StreamExecutionEnvironment env = getEnv(delegatedStateBackend, 50, 0, 20, 0);
+        StreamExecutionEnvironment env = getEnv(50, 0, 20, 0);
         env.getCheckpointConfig()
                 .setExternalizedCheckpointRetention(
                         ExternalizedCheckpointRetention.RETAIN_ON_CANCELLATION);
