@@ -19,42 +19,47 @@ package org.apache.flink.test.streaming.runtime;
 
 import org.apache.flink.api.java.functions.KeySelector;
 import org.apache.flink.api.java.tuple.Tuple2;
+import org.apache.flink.configuration.Configuration;
+import org.apache.flink.configuration.StateBackendOptions;
 import org.apache.flink.streaming.api.datastream.DataStream;
 import org.apache.flink.streaming.api.datastream.KeyedStream;
 import org.apache.flink.streaming.api.datastream.UnsupportedTimeCharacteristicException;
 import org.apache.flink.streaming.api.environment.StreamExecutionEnvironment;
 import org.apache.flink.streaming.api.functions.co.ProcessJoinFunction;
-import org.apache.flink.streaming.api.functions.sink.SinkFunction;
-import org.apache.flink.streaming.api.functions.source.SourceFunction;
-import org.apache.flink.streaming.api.functions.timestamps.AscendingTimestampExtractor;
+import org.apache.flink.streaming.api.functions.sink.legacy.SinkFunction;
+import org.apache.flink.streaming.api.functions.source.legacy.SourceFunction;
 import org.apache.flink.streaming.api.watermark.Watermark;
-import org.apache.flink.streaming.api.windowing.time.Time;
+import org.apache.flink.test.streaming.runtime.TimestampITCase.AscendingRecordTimestampsWatermarkStrategy;
 import org.apache.flink.util.Collector;
 
-import org.apache.flink.shaded.guava31.com.google.common.collect.Lists;
-
-import org.junit.Assert;
-import org.junit.Before;
-import org.junit.Test;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Test;
+import org.junit.jupiter.params.ParameterizedTest;
+import org.junit.jupiter.params.provider.ValueSource;
 
 import java.io.Serializable;
+import java.time.Duration;
 import java.util.ArrayList;
-import java.util.Collections;
 import java.util.List;
 import java.util.function.Consumer;
 
+import static org.apache.flink.runtime.state.StateBackendLoader.FORST_STATE_BACKEND_NAME;
+import static org.assertj.core.api.Assertions.assertThat;
+import static org.junit.jupiter.api.Assertions.assertThrows;
+
 /** Integration tests for interval joins. */
 public class IntervalJoinITCase {
 
     private static List<String> testResults;
 
-    @Before
+    @BeforeEach
     public void setup() {
         testResults = new ArrayList<>();
     }
 
-    @Test
-    public void testCanJoinOverSameKey() throws Exception {
+    @ParameterizedTest(name = "Enable async state = {0}")
+    @ValueSource(booleans = {false, true})
+    public void testCanJoinOverSameKey(boolean enableAsyncState) throws Exception {
 
         final StreamExecutionEnvironment env = StreamExecutionEnvironment.getExecutionEnvironment();
         env.setParallelism(1);
@@ -81,9 +86,15 @@ public class IntervalJoinITCase {
                         .assignTimestampsAndWatermarks(new AscendingTuple2TimestampExtractor())
                         .keyBy(new Tuple2KeyExtractor());
 
+        if (enableAsyncState) {
+            streamOne.enableAsyncState();
+            streamTwo.enableAsyncState();
+            configAsyncState(env);
+        }
+
         streamOne
                 .intervalJoin(streamTwo)
-                .between(Time.milliseconds(0), Time.milliseconds(0))
+                .between(Duration.ofMillis(0), Duration.ofMillis(0))
                 .process(
                         new ProcessJoinFunction<
                                 Tuple2<String, Integer>, Tuple2<String, Integer>, String>() {
@@ -110,8 +121,9 @@ public class IntervalJoinITCase {
                 "(key,5):(key,5)");
     }
 
-    @Test
-    public void testJoinsCorrectlyWithMultipleKeys() throws Exception {
+    @ParameterizedTest(name = "Enable async state = {0}")
+    @ValueSource(booleans = {false, true})
+    public void testJoinsCorrectlyWithMultipleKeys(boolean enableAsyncState) throws Exception {
         final StreamExecutionEnvironment env = StreamExecutionEnvironment.getExecutionEnvironment();
         env.setParallelism(1);
 
@@ -137,12 +149,18 @@ public class IntervalJoinITCase {
                         .assignTimestampsAndWatermarks(new AscendingTuple2TimestampExtractor())
                         .keyBy(new Tuple2KeyExtractor());
 
+        if (enableAsyncState) {
+            streamOne.enableAsyncState();
+            streamTwo.enableAsyncState();
+            configAsyncState(env);
+        }
+
         streamOne
                 .intervalJoin(streamTwo)
                 // if it were not keyed then the boundaries [0; 1] would lead to the pairs (1, 1),
                 // (1, 2), (2, 2), (2, 3)..., so that this is not happening is what we are testing
                 // here
-                .between(Time.milliseconds(0), Time.milliseconds(1))
+                .between(Duration.ofMillis(0), Duration.ofMillis(1))
                 .process(new CombineToStringJoinFunction())
                 .addSink(new ResultSink());
 
@@ -179,62 +197,71 @@ public class IntervalJoinITCase {
         long serialVersionUID = 1L;
     }
 
-    @Test
-    public void testBoundedUnorderedStreamsStillJoinCorrectly() throws Exception {
+    @ParameterizedTest(name = "Enable async state = {0}")
+    @ValueSource(booleans = {false, true})
+    public void testBoundedUnorderedStreamsStillJoinCorrectly(boolean enableAsyncState)
+            throws Exception {
 
         final StreamExecutionEnvironment env = StreamExecutionEnvironment.getExecutionEnvironment();
         env.setParallelism(1);
 
-        DataStream<Tuple2<String, Integer>> streamOne =
+        KeyedStream<Tuple2<String, Integer>, String> streamOne =
                 env.addSource(
-                        new SourceFunction<Tuple2<String, Integer>>() {
-                            @Override
-                            public void run(SourceContext<Tuple2<String, Integer>> ctx) {
-                                ctx.collectWithTimestamp(Tuple2.of("key", 5), 5L);
-                                ctx.collectWithTimestamp(Tuple2.of("key", 1), 1L);
-                                ctx.collectWithTimestamp(Tuple2.of("key", 4), 4L);
-                                ctx.collectWithTimestamp(Tuple2.of("key", 3), 3L);
-                                ctx.collectWithTimestamp(Tuple2.of("key", 2), 2L);
-                                ctx.emitWatermark(new Watermark(5));
-                                ctx.collectWithTimestamp(Tuple2.of("key", 9), 9L);
-                                ctx.collectWithTimestamp(Tuple2.of("key", 8), 8L);
-                                ctx.collectWithTimestamp(Tuple2.of("key", 7), 7L);
-                                ctx.collectWithTimestamp(Tuple2.of("key", 6), 6L);
-                            }
+                                new SourceFunction<Tuple2<String, Integer>>() {
+                                    @Override
+                                    public void run(SourceContext<Tuple2<String, Integer>> ctx) {
+                                        ctx.collectWithTimestamp(Tuple2.of("key", 5), 5L);
+                                        ctx.collectWithTimestamp(Tuple2.of("key", 1), 1L);
+                                        ctx.collectWithTimestamp(Tuple2.of("key", 4), 4L);
+                                        ctx.collectWithTimestamp(Tuple2.of("key", 3), 3L);
+                                        ctx.collectWithTimestamp(Tuple2.of("key", 2), 2L);
+                                        ctx.emitWatermark(new Watermark(5));
+                                        ctx.collectWithTimestamp(Tuple2.of("key", 9), 9L);
+                                        ctx.collectWithTimestamp(Tuple2.of("key", 8), 8L);
+                                        ctx.collectWithTimestamp(Tuple2.of("key", 7), 7L);
+                                        ctx.collectWithTimestamp(Tuple2.of("key", 6), 6L);
+                                    }
 
-                            @Override
-                            public void cancel() {
-                                // do nothing
-                            }
-                        });
+                                    @Override
+                                    public void cancel() {
+                                        // do nothing
+                                    }
+                                })
+                        .keyBy(new Tuple2KeyExtractor());
 
-        DataStream<Tuple2<String, Integer>> streamTwo =
+        KeyedStream<Tuple2<String, Integer>, String> streamTwo =
                 env.addSource(
-                        new SourceFunction<Tuple2<String, Integer>>() {
-                            @Override
-                            public void run(SourceContext<Tuple2<String, Integer>> ctx) {
-                                ctx.collectWithTimestamp(Tuple2.of("key", 2), 2L);
-                                ctx.collectWithTimestamp(Tuple2.of("key", 1), 1L);
-                                ctx.collectWithTimestamp(Tuple2.of("key", 3), 3L);
-                                ctx.collectWithTimestamp(Tuple2.of("key", 4), 4L);
-                                ctx.collectWithTimestamp(Tuple2.of("key", 5), 5L);
-                                ctx.emitWatermark(new Watermark(5));
-                                ctx.collectWithTimestamp(Tuple2.of("key", 8), 8L);
-                                ctx.collectWithTimestamp(Tuple2.of("key", 7), 7L);
-                                ctx.collectWithTimestamp(Tuple2.of("key", 9), 9L);
-                                ctx.collectWithTimestamp(Tuple2.of("key", 6), 6L);
-                            }
+                                new SourceFunction<Tuple2<String, Integer>>() {
+                                    @Override
+                                    public void run(SourceContext<Tuple2<String, Integer>> ctx) {
+                                        ctx.collectWithTimestamp(Tuple2.of("key", 2), 2L);
+                                        ctx.collectWithTimestamp(Tuple2.of("key", 1), 1L);
+                                        ctx.collectWithTimestamp(Tuple2.of("key", 3), 3L);
+                                        ctx.collectWithTimestamp(Tuple2.of("key", 4), 4L);
+                                        ctx.collectWithTimestamp(Tuple2.of("key", 5), 5L);
+                                        ctx.emitWatermark(new Watermark(5));
+                                        ctx.collectWithTimestamp(Tuple2.of("key", 8), 8L);
+                                        ctx.collectWithTimestamp(Tuple2.of("key", 7), 7L);
+                                        ctx.collectWithTimestamp(Tuple2.of("key", 9), 9L);
+                                        ctx.collectWithTimestamp(Tuple2.of("key", 6), 6L);
+                                    }
 
-                            @Override
-                            public void cancel() {
-                                // do nothing
-                            }
-                        });
+                                    @Override
+                                    public void cancel() {
+                                        // do nothing
+                                    }
+                                })
+                        .keyBy(new Tuple2KeyExtractor());
+
+        if (enableAsyncState) {
+            streamOne.enableAsyncState();
+            streamTwo.enableAsyncState();
+            configAsyncState(env);
+        }
 
         streamOne
-                .keyBy(new Tuple2KeyExtractor())
-                .intervalJoin(streamTwo.keyBy(new Tuple2KeyExtractor()))
-                .between(Time.milliseconds(-1), Time.milliseconds(1))
+                .intervalJoin(streamTwo)
+                .between(Duration.ofMillis(-1), Duration.ofMillis(1))
                 .process(new CombineToStringJoinFunction())
                 .addSink(new ResultSink());
 
@@ -268,51 +295,68 @@ public class IntervalJoinITCase {
                 "(key,9):(key,9)");
     }
 
-    @Test(expected = NullPointerException.class)
+    @Test
     public void testFailsWithoutUpperBound() {
-        final StreamExecutionEnvironment env = StreamExecutionEnvironment.getExecutionEnvironment();
-        env.setParallelism(1);
+        assertThrows(
+                NullPointerException.class,
+                () -> {
+                    final StreamExecutionEnvironment env =
+                            StreamExecutionEnvironment.getExecutionEnvironment();
+                    env.setParallelism(1);
 
-        DataStream<Tuple2<String, Integer>> streamOne = env.fromData(Tuple2.of("1", 1));
-        DataStream<Tuple2<String, Integer>> streamTwo = env.fromData(Tuple2.of("1", 1));
+                    DataStream<Tuple2<String, Integer>> streamOne = env.fromData(Tuple2.of("1", 1));
+                    DataStream<Tuple2<String, Integer>> streamTwo = env.fromData(Tuple2.of("1", 1));
 
-        streamOne
-                .keyBy(new Tuple2KeyExtractor())
-                .intervalJoin(streamTwo.keyBy(new Tuple2KeyExtractor()))
-                .between(Time.milliseconds(0), null);
-    }
-
-    @Test(expected = NullPointerException.class)
-    public void testFailsWithoutLowerBound() {
-        final StreamExecutionEnvironment env = StreamExecutionEnvironment.getExecutionEnvironment();
-        env.setParallelism(1);
-
-        DataStream<Tuple2<String, Integer>> streamOne = env.fromData(Tuple2.of("1", 1));
-        DataStream<Tuple2<String, Integer>> streamTwo = env.fromData(Tuple2.of("1", 1));
-
-        streamOne
-                .keyBy(new Tuple2KeyExtractor())
-                .intervalJoin(streamTwo.keyBy(new Tuple2KeyExtractor()))
-                .between(null, Time.milliseconds(1));
+                    streamOne
+                            .keyBy(new Tuple2KeyExtractor())
+                            .intervalJoin(streamTwo.keyBy(new Tuple2KeyExtractor()))
+                            .between(Duration.ofMillis(0), null);
+                });
     }
 
     @Test
-    public void testBoundsCanBeExclusive() throws Exception {
+    public void testFailsWithoutLowerBound() {
+        assertThrows(
+                NullPointerException.class,
+                () -> {
+                    final StreamExecutionEnvironment env =
+                            StreamExecutionEnvironment.getExecutionEnvironment();
+                    env.setParallelism(1);
+
+                    DataStream<Tuple2<String, Integer>> streamOne = env.fromData(Tuple2.of("1", 1));
+                    DataStream<Tuple2<String, Integer>> streamTwo = env.fromData(Tuple2.of("1", 1));
+
+                    streamOne
+                            .keyBy(new Tuple2KeyExtractor())
+                            .intervalJoin(streamTwo.keyBy(new Tuple2KeyExtractor()))
+                            .between(null, Duration.ofMillis(1));
+                });
+    }
+
+    @ParameterizedTest(name = "Enable async state = {0}")
+    @ValueSource(booleans = {false, true})
+    public void testBoundsCanBeExclusive(boolean enableAsyncState) throws Exception {
         final StreamExecutionEnvironment env = StreamExecutionEnvironment.getExecutionEnvironment();
         env.setParallelism(1);
 
-        DataStream<Tuple2<String, Integer>> streamOne =
+        KeyedStream<Tuple2<String, Integer>, String> streamOne =
                 env.fromData(Tuple2.of("key", 0), Tuple2.of("key", 1), Tuple2.of("key", 2))
-                        .assignTimestampsAndWatermarks(new AscendingTuple2TimestampExtractor());
+                        .assignTimestampsAndWatermarks(new AscendingTuple2TimestampExtractor())
+                        .keyBy(new Tuple2KeyExtractor());
 
-        DataStream<Tuple2<String, Integer>> streamTwo =
+        KeyedStream<Tuple2<String, Integer>, String> streamTwo =
                 env.fromData(Tuple2.of("key", 0), Tuple2.of("key", 1), Tuple2.of("key", 2))
-                        .assignTimestampsAndWatermarks(new AscendingTuple2TimestampExtractor());
+                        .assignTimestampsAndWatermarks(new AscendingTuple2TimestampExtractor())
+                        .keyBy(new Tuple2KeyExtractor());
 
+        if (enableAsyncState) {
+            streamOne.enableAsyncState();
+            streamTwo.enableAsyncState();
+            configAsyncState(env);
+        }
         streamOne
-                .keyBy(new Tuple2KeyExtractor())
-                .intervalJoin(streamTwo.keyBy(new Tuple2KeyExtractor()))
-                .between(Time.milliseconds(0), Time.milliseconds(2))
+                .intervalJoin(streamTwo)
+                .between(Duration.ofMillis(0), Duration.ofMillis(2))
                 .upperBoundExclusive()
                 .lowerBoundExclusive()
                 .process(new CombineToStringJoinFunction())
@@ -323,23 +367,68 @@ public class IntervalJoinITCase {
         expectInAnyOrder("(key,0):(key,1)", "(key,1):(key,2)");
     }
 
-    @Test
-    public void testBoundsCanBeInclusive() throws Exception {
+    @ParameterizedTest(name = "Enable async state = {0}")
+    @ValueSource(booleans = {false, true})
+    public void testBoundsCanBeInclusive(boolean enableAsyncState) throws Exception {
         final StreamExecutionEnvironment env = StreamExecutionEnvironment.getExecutionEnvironment();
         env.setParallelism(1);
 
-        DataStream<Tuple2<String, Integer>> streamOne =
+        KeyedStream<Tuple2<String, Integer>, String> streamOne =
                 env.fromData(Tuple2.of("key", 0), Tuple2.of("key", 1), Tuple2.of("key", 2))
-                        .assignTimestampsAndWatermarks(new AscendingTuple2TimestampExtractor());
+                        .assignTimestampsAndWatermarks(new AscendingTuple2TimestampExtractor())
+                        .keyBy(new Tuple2KeyExtractor());
 
-        DataStream<Tuple2<String, Integer>> streamTwo =
+        KeyedStream<Tuple2<String, Integer>, String> streamTwo =
                 env.fromData(Tuple2.of("key", 0), Tuple2.of("key", 1), Tuple2.of("key", 2))
-                        .assignTimestampsAndWatermarks(new AscendingTuple2TimestampExtractor());
+                        .assignTimestampsAndWatermarks(new AscendingTuple2TimestampExtractor())
+                        .keyBy(new Tuple2KeyExtractor());
 
+        if (enableAsyncState) {
+            streamOne.enableAsyncState();
+            streamTwo.enableAsyncState();
+            configAsyncState(env);
+        }
         streamOne
-                .keyBy(new Tuple2KeyExtractor())
-                .intervalJoin(streamTwo.keyBy(new Tuple2KeyExtractor()))
-                .between(Time.milliseconds(0), Time.milliseconds(2))
+                .intervalJoin(streamTwo)
+                .between(Duration.ofMillis(0), Duration.ofMillis(2))
+                .process(new CombineToStringJoinFunction())
+                .addSink(new ResultSink());
+
+        env.execute();
+
+        expectInAnyOrder(
+                "(key,0):(key,0)",
+                "(key,0):(key,1)",
+                "(key,0):(key,2)",
+                "(key,1):(key,1)",
+                "(key,1):(key,2)",
+                "(key,2):(key,2)");
+    }
+
+    @ParameterizedTest(name = "Enable async state = {0}")
+    @ValueSource(booleans = {false, true})
+    public void testBoundsAreInclusiveByDefault(boolean enableAsyncState) throws Exception {
+        final StreamExecutionEnvironment env = StreamExecutionEnvironment.getExecutionEnvironment();
+        env.setParallelism(1);
+
+        KeyedStream<Tuple2<String, Integer>, String> streamOne =
+                env.fromData(Tuple2.of("key", 0), Tuple2.of("key", 1), Tuple2.of("key", 2))
+                        .assignTimestampsAndWatermarks(new AscendingTuple2TimestampExtractor())
+                        .keyBy(new Tuple2KeyExtractor());
+
+        KeyedStream<Tuple2<String, Integer>, String> streamTwo =
+                env.fromData(Tuple2.of("key", 0), Tuple2.of("key", 1), Tuple2.of("key", 2))
+                        .assignTimestampsAndWatermarks(new AscendingTuple2TimestampExtractor())
+                        .keyBy(new Tuple2KeyExtractor());
+
+        if (enableAsyncState) {
+            streamOne.enableAsyncState();
+            streamTwo.enableAsyncState();
+            configAsyncState(env);
+        }
+        streamOne
+                .intervalJoin(streamTwo)
+                .between(Duration.ofMillis(0), Duration.ofMillis(2))
                 .process(new CombineToStringJoinFunction())
                 .addSink(new ResultSink());
 
@@ -355,76 +444,55 @@ public class IntervalJoinITCase {
     }
 
     @Test
-    public void testBoundsAreInclusiveByDefault() throws Exception {
-        final StreamExecutionEnvironment env = StreamExecutionEnvironment.getExecutionEnvironment();
-        env.setParallelism(1);
+    public void testExecutionFailsInProcessingTime() {
+        assertThrows(
+                UnsupportedTimeCharacteristicException.class,
+                () -> {
+                    final StreamExecutionEnvironment env =
+                            StreamExecutionEnvironment.getExecutionEnvironment();
+                    env.setParallelism(1);
 
-        DataStream<Tuple2<String, Integer>> streamOne =
-                env.fromData(Tuple2.of("key", 0), Tuple2.of("key", 1), Tuple2.of("key", 2))
-                        .assignTimestampsAndWatermarks(new AscendingTuple2TimestampExtractor());
+                    DataStream<Tuple2<String, Integer>> streamOne = env.fromData(Tuple2.of("1", 1));
+                    DataStream<Tuple2<String, Integer>> streamTwo = env.fromData(Tuple2.of("1", 1));
 
-        DataStream<Tuple2<String, Integer>> streamTwo =
-                env.fromData(Tuple2.of("key", 0), Tuple2.of("key", 1), Tuple2.of("key", 2))
-                        .assignTimestampsAndWatermarks(new AscendingTuple2TimestampExtractor());
-
-        streamOne
-                .keyBy(new Tuple2KeyExtractor())
-                .intervalJoin(streamTwo.keyBy(new Tuple2KeyExtractor()))
-                .between(Time.milliseconds(0), Time.milliseconds(2))
-                .process(new CombineToStringJoinFunction())
-                .addSink(new ResultSink());
-
-        env.execute();
-
-        expectInAnyOrder(
-                "(key,0):(key,0)",
-                "(key,0):(key,1)",
-                "(key,0):(key,2)",
-                "(key,1):(key,1)",
-                "(key,1):(key,2)",
-                "(key,2):(key,2)");
-    }
-
-    @Test(expected = UnsupportedTimeCharacteristicException.class)
-    public void testExecutionFailsInProcessingTime() throws Exception {
-        final StreamExecutionEnvironment env = StreamExecutionEnvironment.getExecutionEnvironment();
-        env.setParallelism(1);
-
-        DataStream<Tuple2<String, Integer>> streamOne = env.fromData(Tuple2.of("1", 1));
-        DataStream<Tuple2<String, Integer>> streamTwo = env.fromData(Tuple2.of("1", 1));
-
-        streamOne
-                .keyBy(new Tuple2KeyExtractor())
-                .intervalJoin(streamTwo.keyBy(new Tuple2KeyExtractor()))
-                .inProcessingTime()
-                .between(Time.milliseconds(0), Time.milliseconds(0))
-                .process(
-                        new ProcessJoinFunction<
-                                Tuple2<String, Integer>, Tuple2<String, Integer>, String>() {
-                            @Override
-                            public void processElement(
-                                    Tuple2<String, Integer> left,
-                                    Tuple2<String, Integer> right,
-                                    Context ctx,
-                                    Collector<String> out)
-                                    throws Exception {
-                                out.collect(left + ":" + right);
-                            }
-                        });
+                    streamOne
+                            .keyBy(new Tuple2KeyExtractor())
+                            .intervalJoin(streamTwo.keyBy(new Tuple2KeyExtractor()))
+                            .inProcessingTime()
+                            .between(Duration.ofMillis(0), Duration.ofMillis(0))
+                            .process(
+                                    new ProcessJoinFunction<
+                                            Tuple2<String, Integer>,
+                                            Tuple2<String, Integer>,
+                                            String>() {
+                                        @Override
+                                        public void processElement(
+                                                Tuple2<String, Integer> left,
+                                                Tuple2<String, Integer> right,
+                                                Context ctx,
+                                                Collector<String> out)
+                                                throws Exception {
+                                            out.collect(left + ":" + right);
+                                        }
+                                    });
+                });
     }
 
     private static void expectInAnyOrder(String... expected) {
-        List<String> listExpected = Lists.newArrayList(expected);
-        Collections.sort(listExpected);
-        Collections.sort(testResults);
-        Assert.assertEquals(listExpected, testResults);
+        assertThat(testResults).containsExactlyInAnyOrder(expected);
+    }
+
+    private static void configAsyncState(StreamExecutionEnvironment env) {
+        // For async state, by default we will use the forst state backend.
+        Configuration config = Configuration.fromMap(env.getConfiguration().toMap());
+        config.set(StateBackendOptions.STATE_BACKEND, FORST_STATE_BACKEND_NAME);
+        env.configure(config);
     }
 
     private static class AscendingTuple2TimestampExtractor
-            extends AscendingTimestampExtractor<Tuple2<String, Integer>> {
-        @Override
-        public long extractAscendingTimestamp(Tuple2<String, Integer> element) {
-            return element.f1;
+            extends AscendingRecordTimestampsWatermarkStrategy<Tuple2<String, Integer>> {
+        public AscendingTuple2TimestampExtractor() {
+            super((e) -> Long.valueOf(e.f1));
         }
     }
 
