@@ -29,7 +29,6 @@ import org.apache.flink.api.connector.source.util.ratelimit.GatedRateLimiter;
 import org.apache.flink.api.connector.source.util.ratelimit.RateLimiter;
 import org.apache.flink.api.connector.source.util.ratelimit.RateLimiterStrategy;
 import org.apache.flink.api.java.functions.KeySelector;
-import org.apache.flink.api.java.tuple.Tuple3;
 import org.apache.flink.client.program.ClusterClient;
 import org.apache.flink.configuration.CheckpointingOptions;
 import org.apache.flink.configuration.Configuration;
@@ -47,21 +46,26 @@ import org.apache.flink.streaming.api.graph.StreamEdge;
 import org.apache.flink.streaming.api.graph.StreamGraph;
 import org.apache.flink.streaming.api.graph.StreamNode;
 import org.apache.flink.streaming.runtime.operators.sink.TestSinkV2;
-import org.apache.flink.streaming.runtime.operators.sink.TestSinkV2.DefaultCommitter;
-import org.apache.flink.streaming.util.FiniteTestSource;
+import org.apache.flink.streaming.runtime.operators.sink.TestSinkV2.Record;
+import org.apache.flink.streaming.runtime.operators.sink.TestSinkV2.RecordSerializer;
 import org.apache.flink.test.junit5.InjectClusterClient;
 import org.apache.flink.test.junit5.InjectMiniCluster;
 import org.apache.flink.test.util.AbstractTestBase;
+import org.apache.flink.testutils.junit.SharedObjectsExtension;
+import org.apache.flink.testutils.junit.SharedReference;
 
-import org.junit.jupiter.api.BeforeEach;
 import org.junit.jupiter.api.Test;
+import org.junit.jupiter.api.extension.RegisterExtension;
 import org.junit.jupiter.api.io.TempDir;
 import org.junit.jupiter.params.ParameterizedTest;
 import org.junit.jupiter.params.provider.CsvSource;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
 
 import java.io.File;
 import java.io.Serializable;
 import java.util.Arrays;
+import java.util.Collection;
 import java.util.Collections;
 import java.util.List;
 import java.util.Optional;
@@ -70,156 +74,89 @@ import java.util.concurrent.CompletionStage;
 import java.util.concurrent.ConcurrentLinkedQueue;
 import java.util.concurrent.ExecutionException;
 import java.util.concurrent.atomic.AtomicBoolean;
-import java.util.function.BooleanSupplier;
-import java.util.function.Supplier;
 import java.util.stream.Collectors;
 import java.util.stream.IntStream;
 
-import static org.hamcrest.MatcherAssert.assertThat;
-import static org.hamcrest.Matchers.containsInAnyOrder;
-import static org.hamcrest.Matchers.is;
+import static org.assertj.core.api.Assertions.assertThat;
 
 /**
- * Integration test for {@link org.apache.flink.api.connector.sink.Sink} run time implementation.
+ * Integration test for {@link org.apache.flink.api.connector.sink2.Sink} run time implementation.
  */
 public class SinkV2ITCase extends AbstractTestBase {
+    private static final Logger LOG = LoggerFactory.getLogger(SinkV2ITCase.class);
+
     static final List<Integer> SOURCE_DATA =
             Arrays.asList(
                     895, 127, 148, 161, 148, 662, 822, 491, 275, 122, 850, 630, 682, 765, 434, 970,
                     714, 795, 288, 422);
 
-    // source send data two times
-    static final int STREAMING_SOURCE_SEND_ELEMENTS_NUM = SOURCE_DATA.size() * 2;
-
-    static final List<String> EXPECTED_COMMITTED_DATA_IN_STREAMING_MODE =
+    static final List<Record<Integer>> EXPECTED_COMMITTED_DATA_IN_STREAMING_MODE =
             SOURCE_DATA.stream()
                     // source send data two times
                     .flatMap(
                             x ->
-                                    Collections.nCopies(
-                                            2, Tuple3.of(x, null, Long.MIN_VALUE).toString())
+                                    Collections.nCopies(2, new Record<>(x, null, Long.MIN_VALUE))
                                             .stream())
                     .collect(Collectors.toList());
 
-    static final List<String> EXPECTED_COMMITTED_DATA_IN_BATCH_MODE =
+    static final List<Record<Integer>> EXPECTED_COMMITTED_DATA_IN_BATCH_MODE =
             SOURCE_DATA.stream()
-                    .map(x -> Tuple3.of(x, null, Long.MIN_VALUE).toString())
+                    .map(x -> new Record<>(x, null, Long.MIN_VALUE))
                     .collect(Collectors.toList());
 
-    static final Queue<Committer.CommitRequest<String>> COMMIT_QUEUE =
-            new ConcurrentLinkedQueue<>();
-
-    static final BooleanSupplier COMMIT_QUEUE_RECEIVE_ALL_DATA =
-            (BooleanSupplier & Serializable)
-                    () -> COMMIT_QUEUE.size() == STREAMING_SOURCE_SEND_ELEMENTS_NUM;
-
-    @BeforeEach
-    public void init() {
-        COMMIT_QUEUE.clear();
-    }
+    @RegisterExtension
+    static final SharedObjectsExtension SHARED_OBJECTS = SharedObjectsExtension.create();
 
     @Test
     public void writerAndCommitterExecuteInStreamingMode() throws Exception {
         final StreamExecutionEnvironment env = buildStreamEnv();
-        final FiniteTestSource<Integer> source =
-                new FiniteTestSource<>(COMMIT_QUEUE_RECEIVE_ALL_DATA, SOURCE_DATA);
+        SharedReference<Queue<Committer.CommitRequest<Record<Integer>>>> committed =
+                SHARED_OBJECTS.add(new ConcurrentLinkedQueue<>());
+        final Source<Integer, ?, ?> source = createStreamingSource();
 
-        env.addSource(source, IntegerTypeInfo.INT_TYPE_INFO)
+        env.fromSource(source, WatermarkStrategy.noWatermarks(), "source")
                 // Introduce the keyBy to assert unaligned checkpoint is enabled on the source ->
                 // sink writer edge
                 .keyBy((KeySelector<Integer, Integer>) value -> value)
                 .sinkTo(
                         TestSinkV2.<Integer>newBuilder()
-                                .setDefaultCommitter(
-                                        (Supplier<Queue<Committer.CommitRequest<String>>>
-                                                        & Serializable)
-                                                () -> COMMIT_QUEUE)
+                                .setCommitter(
+                                        new TrackingCommitter(committed), RecordSerializer::new)
                                 .build());
         executeAndVerifyStreamGraph(env);
-        assertThat(
-                COMMIT_QUEUE.stream()
-                        .map(Committer.CommitRequest::getCommittable)
-                        .collect(Collectors.toList()),
-                containsInAnyOrder(EXPECTED_COMMITTED_DATA_IN_STREAMING_MODE.toArray()));
+        assertThat(committed.get())
+                .extracting(Committer.CommitRequest::getCommittable)
+                .containsExactlyInAnyOrderElementsOf(EXPECTED_COMMITTED_DATA_IN_STREAMING_MODE);
     }
 
     @Test
     public void writerAndPrecommitToplogyAndCommitterExecuteInStreamingMode() throws Exception {
         final StreamExecutionEnvironment env = buildStreamEnv();
-        final FiniteTestSource<Integer> source =
-                new FiniteTestSource<>(COMMIT_QUEUE_RECEIVE_ALL_DATA, SOURCE_DATA);
+        SharedReference<Queue<Committer.CommitRequest<Record<Integer>>>> committed =
+                SHARED_OBJECTS.add(new ConcurrentLinkedQueue<>());
+        final Source<Integer, ?, ?> source = createStreamingSource();
 
-        env.addSource(source, IntegerTypeInfo.INT_TYPE_INFO)
+        env.fromSource(source, WatermarkStrategy.noWatermarks(), "source")
                 // Introduce the keyBy to assert unaligned checkpoint is enabled on the source ->
                 // sink writer edge
                 .keyBy((KeySelector<Integer, Integer>) value -> value)
                 .sinkTo(
                         TestSinkV2.<Integer>newBuilder()
-                                .setDefaultCommitter(
-                                        (Supplier<Queue<Committer.CommitRequest<String>>>
-                                                        & Serializable)
-                                                () -> COMMIT_QUEUE)
-                                .setWithPreCommitTopology(true)
+                                .setCommitter(
+                                        new TrackingCommitter(committed), RecordSerializer::new)
+                                .setWithPreCommitTopology(SinkV2ITCase::flipValue)
                                 .build());
         executeAndVerifyStreamGraph(env);
-        assertThat(
-                COMMIT_QUEUE.stream()
-                        .map(Committer.CommitRequest::getCommittable)
-                        .collect(Collectors.toList()),
-                containsInAnyOrder(
+        assertThat(committed.get())
+                .extracting(Committer.CommitRequest::getCommittable)
+                .containsExactlyInAnyOrderElementsOf(
                         EXPECTED_COMMITTED_DATA_IN_STREAMING_MODE.stream()
-                                .map(s -> s + "Transformed")
-                                .toArray()));
+                                .map(SinkV2ITCase::flipValue)
+                                .collect(Collectors.toList()));
     }
 
-    @Test
-    public void writerAndCommitterExecuteInBatchMode() throws Exception {
-        final StreamExecutionEnvironment env = buildBatchEnv();
-
-        env.fromData(SOURCE_DATA)
-                // Introduce the rebalance to assert unaligned checkpoint is enabled on the source
-                // -> sink writer edge
-                .rebalance()
-                .sinkTo(
-                        TestSinkV2.<Integer>newBuilder()
-                                .setDefaultCommitter(
-                                        (Supplier<Queue<Committer.CommitRequest<String>>>
-                                                        & Serializable)
-                                                () -> COMMIT_QUEUE)
-                                .build());
-        executeAndVerifyStreamGraph(env);
-        assertThat(
-                COMMIT_QUEUE.stream()
-                        .map(Committer.CommitRequest::getCommittable)
-                        .collect(Collectors.toList()),
-                containsInAnyOrder(EXPECTED_COMMITTED_DATA_IN_BATCH_MODE.toArray()));
-    }
-
-    @Test
-    public void writerAndPrecommitToplogyAndCommitterExecuteInBatchMode() throws Exception {
-        final StreamExecutionEnvironment env = buildBatchEnv();
-
-        env.fromData(SOURCE_DATA)
-                // Introduce the rebalance to assert unaligned checkpoint is enabled on the source
-                // -> sink writer edge
-                .rebalance()
-                .sinkTo(
-                        TestSinkV2.<Integer>newBuilder()
-                                .setDefaultCommitter(
-                                        (Supplier<Queue<Committer.CommitRequest<String>>>
-                                                        & Serializable)
-                                                () -> COMMIT_QUEUE)
-                                .setWithPreCommitTopology(true)
-                                .build());
-        executeAndVerifyStreamGraph(env);
-        assertThat(
-                COMMIT_QUEUE.stream()
-                        .map(Committer.CommitRequest::getCommittable)
-                        .collect(Collectors.toList()),
-                containsInAnyOrder(
-                        EXPECTED_COMMITTED_DATA_IN_BATCH_MODE.stream()
-                                .map(s -> s + "Transformed")
-                                .toArray()));
+    private static Record<Integer> flipValue(Record<Integer> r) {
+        return r.withValue(-r.getValue());
     }
 
     @ParameterizedTest
@@ -231,65 +168,96 @@ public class SinkV2ITCase extends AbstractTestBase {
             @InjectMiniCluster MiniCluster miniCluster,
             @InjectClusterClient ClusterClient<?> clusterClient)
             throws Exception {
-        final DefaultCommitter committer =
-                new DefaultCommitter(
-                        (Supplier<Queue<Committer.CommitRequest<String>>> & Serializable)
-                                () -> COMMIT_QUEUE);
+        SharedReference<Queue<Committer.CommitRequest<Record<Integer>>>> committed =
+                SHARED_OBJECTS.add(new ConcurrentLinkedQueue<>());
+        final TrackingCommitter trackingCommitter = new TrackingCommitter(committed);
         final Configuration config = createConfigForScalingTest(checkpointDir, initialParallelism);
 
         // first run
-        final JobID jobID = runStreamingWithScalingTest(config, true, committer, clusterClient);
+        final JobID jobID =
+                runStreamingWithScalingTest(
+                        config,
+                        initialParallelism,
+                        trackingCommitter,
+                        true,
+                        miniCluster,
+                        clusterClient);
 
         // second run
         config.set(StateRecoveryOptions.SAVEPOINT_PATH, getCheckpointPath(miniCluster, jobID));
         config.set(CoreOptions.DEFAULT_PARALLELISM, scaledParallelism);
-        runStreamingWithScalingTest(config, false, committer, clusterClient);
+        runStreamingWithScalingTest(
+                config, initialParallelism, trackingCommitter, false, miniCluster, clusterClient);
 
-        assertThat(
-                COMMIT_QUEUE.stream()
-                        .map(Committer.CommitRequest::getCommittable)
-                        .collect(Collectors.toList()),
-                containsInAnyOrder(duplicate(EXPECTED_COMMITTED_DATA_IN_STREAMING_MODE).toArray()));
+        assertThat(committed.get())
+                .extracting(Committer.CommitRequest::getCommittable)
+                .containsExactlyInAnyOrderElementsOf(
+                        duplicate(EXPECTED_COMMITTED_DATA_IN_STREAMING_MODE));
     }
 
-    private static List<String> duplicate(List<String> values) {
+    private static List<Record<Integer>> duplicate(List<Record<Integer>> values) {
         return IntStream.range(0, 2)
                 .boxed()
                 .flatMap(i -> values.stream())
                 .collect(Collectors.toList());
     }
 
-    private JobID runStreamingWithScalingTest(
-            Configuration config,
-            boolean shouldMapperFail,
-            DefaultCommitter committer,
-            ClusterClient<?> clusterClient)
-            throws Exception {
-        final StreamExecutionEnvironment env = buildStreamEnvWithCheckpointDir(config);
-        final Source<Integer, ?, ?> source = createStreamingSourceForScalingTest();
+    @Test
+    public void writerAndCommitterExecuteInBatchMode() throws Exception {
+        final StreamExecutionEnvironment env = buildBatchEnv();
+        SharedReference<Queue<Committer.CommitRequest<Record<Integer>>>> committed =
+                SHARED_OBJECTS.add(new ConcurrentLinkedQueue<>());
+
+        final DataGeneratorSource<Integer> source =
+                new DataGeneratorSource<>(
+                        l -> SOURCE_DATA.get(l.intValue()),
+                        SOURCE_DATA.size(),
+                        IntegerTypeInfo.INT_TYPE_INFO);
 
         env.fromSource(source, WatermarkStrategy.noWatermarks(), "source")
+                // Introduce the rebalance to assert unaligned checkpoint is enabled on the source
+                // -> sink writer edge
                 .rebalance()
-                .map(new FailingCheckpointMapper(!shouldMapperFail))
                 .sinkTo(
                         TestSinkV2.<Integer>newBuilder()
-                                .setCommitter(committer)
-                                .setWithPostCommitTopology(true)
+                                .setCommitter(
+                                        new TrackingCommitter(committed), RecordSerializer::new)
                                 .build());
-
-        final JobID jobId = clusterClient.submitJob(env.getStreamGraph().getJobGraph()).get();
-        clusterClient.requestJobResult(jobId).get();
-
-        return jobId;
+        executeAndVerifyStreamGraph(env);
+        assertThat(committed.get())
+                .extracting(Committer.CommitRequest::getCommittable)
+                .containsExactlyInAnyOrderElementsOf(EXPECTED_COMMITTED_DATA_IN_BATCH_MODE);
     }
 
-    private String getCheckpointPath(MiniCluster miniCluster, JobID secondJobId)
-            throws InterruptedException, ExecutionException, FlinkJobNotFoundException {
-        final Optional<String> completedCheckpoint =
-                CommonTestUtils.getLatestCompletedCheckpointPath(secondJobId, miniCluster);
+    @Test
+    public void writerAndPrecommitToplogyAndCommitterExecuteInBatchMode() throws Exception {
+        final StreamExecutionEnvironment env = buildBatchEnv();
+        SharedReference<Queue<Committer.CommitRequest<Record<Integer>>>> committed =
+                SHARED_OBJECTS.add(new ConcurrentLinkedQueue<>());
 
-        assertThat(completedCheckpoint.isPresent(), is(true));
-        return completedCheckpoint.get();
+        final DataGeneratorSource<Integer> source =
+                new DataGeneratorSource<>(
+                        l -> SOURCE_DATA.get(l.intValue()),
+                        SOURCE_DATA.size(),
+                        IntegerTypeInfo.INT_TYPE_INFO);
+
+        env.fromSource(source, WatermarkStrategy.noWatermarks(), "source")
+                // Introduce the rebalance to assert unaligned checkpoint is enabled on the source
+                // -> sink writer edge
+                .rebalance()
+                .sinkTo(
+                        TestSinkV2.<Integer>newBuilder()
+                                .setCommitter(
+                                        new TrackingCommitter(committed), RecordSerializer::new)
+                                .setWithPreCommitTopology(SinkV2ITCase::flipValue)
+                                .build());
+        executeAndVerifyStreamGraph(env);
+        assertThat(committed.get())
+                .extracting(Committer.CommitRequest::getCommittable)
+                .containsExactlyInAnyOrderElementsOf(
+                        EXPECTED_COMMITTED_DATA_IN_BATCH_MODE.stream()
+                                .map(SinkV2ITCase::flipValue)
+                                .collect(Collectors.toList()));
     }
 
     private StreamExecutionEnvironment buildStreamEnv() {
@@ -299,21 +267,6 @@ public class SinkV2ITCase extends AbstractTestBase {
         return env;
     }
 
-    private StreamExecutionEnvironment buildStreamEnvWithCheckpointDir(Configuration config) {
-        final StreamExecutionEnvironment env =
-                StreamExecutionEnvironment.getExecutionEnvironment(config);
-        env.setRuntimeMode(RuntimeExecutionMode.STREAMING);
-        env.enableCheckpointing(100);
-
-        return env;
-    }
-
-    private StreamExecutionEnvironment buildBatchEnv() {
-        final StreamExecutionEnvironment env = StreamExecutionEnvironment.getExecutionEnvironment();
-        env.setRuntimeMode(RuntimeExecutionMode.BATCH);
-        return env;
-    }
-
     private Configuration createConfigForScalingTest(File checkpointDir, int parallelism) {
         final Configuration config = new Configuration();
         config.set(CoreOptions.DEFAULT_PARALLELISM, parallelism);
@@ -328,6 +281,58 @@ public class SinkV2ITCase extends AbstractTestBase {
         return config;
     }
 
+    private StreamExecutionEnvironment buildStreamEnvWithCheckpointDir(Configuration config) {
+        final StreamExecutionEnvironment env =
+                StreamExecutionEnvironment.getExecutionEnvironment(config);
+        env.setRuntimeMode(RuntimeExecutionMode.STREAMING);
+        env.enableCheckpointing(100);
+
+        return env;
+    }
+
+    private JobID runStreamingWithScalingTest(
+            Configuration config,
+            int parallelism,
+            TrackingCommitter trackingCommitter,
+            boolean shouldMapperFail,
+            MiniCluster miniCluster,
+            ClusterClient<?> clusterClient)
+            throws Exception {
+        final StreamExecutionEnvironment env = buildStreamEnvWithCheckpointDir(config);
+        final Source<Integer, ?, ?> source = createStreamingSource();
+
+        env.fromSource(source, WatermarkStrategy.noWatermarks(), "source")
+                .rebalance()
+                .map(
+                        new FailingCheckpointMapper(
+                                SHARED_OBJECTS.add(new AtomicBoolean(!shouldMapperFail))))
+                .sinkTo(
+                        TestSinkV2.<Integer>newBuilder()
+                                .setCommitter(trackingCommitter, RecordSerializer::new)
+                                .setWithPostCommitTopology(true)
+                                .build());
+
+        final JobID jobId = clusterClient.submitJob(env.getStreamGraph().getJobGraph()).get();
+        clusterClient.requestJobResult(jobId).get();
+
+        return jobId;
+    }
+
+    private String getCheckpointPath(MiniCluster miniCluster, JobID secondJobId)
+            throws InterruptedException, ExecutionException, FlinkJobNotFoundException {
+        final Optional<String> completedCheckpoint =
+                CommonTestUtils.getLatestCompletedCheckpointPath(secondJobId, miniCluster);
+
+        assertThat(completedCheckpoint).isPresent();
+        return completedCheckpoint.get();
+    }
+
+    private StreamExecutionEnvironment buildBatchEnv() {
+        final StreamExecutionEnvironment env = StreamExecutionEnvironment.getExecutionEnvironment();
+        env.setRuntimeMode(RuntimeExecutionMode.BATCH);
+        return env;
+    }
+
     private void executeAndVerifyStreamGraph(StreamExecutionEnvironment env) throws Exception {
         StreamGraph streamGraph = env.getStreamGraph();
         assertNoUnalignedCheckpointInSink(streamGraph);
@@ -337,7 +342,7 @@ public class SinkV2ITCase extends AbstractTestBase {
 
     private void assertNoUnalignedCheckpointInSink(StreamGraph streamGraph) {
         // all the out edges between sink nodes should not support unaligned checkpoints
-        org.assertj.core.api.Assertions.assertThat(streamGraph.getStreamNodes())
+        assertThat(streamGraph.getStreamNodes())
                 .filteredOn(t -> t.getOperatorName().contains("Sink"))
                 .flatMap(StreamNode::getOutEdges)
                 .allMatch(e -> !e.supportsUnalignedCheckpoints())
@@ -347,7 +352,7 @@ public class SinkV2ITCase extends AbstractTestBase {
     private void assertUnalignedCheckpointInNonSink(StreamGraph streamGraph) {
         // All connections are rebalance between source and source, so all the out edges of nodes
         // upstream of the sink should support unaligned checkpoints
-        org.assertj.core.api.Assertions.assertThat(streamGraph.getStreamNodes())
+        assertThat(streamGraph.getStreamNodes())
                 .filteredOn(t -> !t.getOperatorName().contains("Sink"))
                 .flatMap(StreamNode::getOutEdges)
                 .allMatch(StreamEdge::supportsUnalignedCheckpoints)
@@ -359,7 +364,7 @@ public class SinkV2ITCase extends AbstractTestBase {
      * for two more checkpoints to complete, 3) then re-emits the same elements before 4) waiting
      * for another two checkpoints and 5) exiting.
      */
-    private Source<Integer, ?, ?> createStreamingSourceForScalingTest() {
+    private Source<Integer, ?, ?> createStreamingSource() {
         RateLimiterStrategy rateLimiterStrategy =
                 parallelism -> new BurstingRateLimiter(SOURCE_DATA.size() / 4, 2);
         return new DataGeneratorSource<>(
@@ -394,21 +399,37 @@ public class SinkV2ITCase extends AbstractTestBase {
         }
     }
 
+    private static class TrackingCommitter implements Committer<Record<Integer>>, Serializable {
+        private final SharedReference<Queue<CommitRequest<Record<Integer>>>> committed;
+
+        public TrackingCommitter(SharedReference<Queue<CommitRequest<Record<Integer>>>> committed) {
+            this.committed = committed;
+        }
+
+        @Override
+        public void commit(Collection<CommitRequest<Record<Integer>>> committables) {
+            committed.get().addAll(committables);
+        }
+
+        @Override
+        public void close() {}
+    }
+
     private static class FailingCheckpointMapper
             implements MapFunction<Integer, Integer>, CheckpointListener {
 
-        private static final AtomicBoolean failed = new AtomicBoolean(false);
+        private final SharedReference<AtomicBoolean> failed;
         private long lastCheckpointId = 0;
         private int emittedBetweenCheckpoint = 0;
 
-        FailingCheckpointMapper(boolean failed) {
-            FailingCheckpointMapper.failed.set(failed);
+        FailingCheckpointMapper(SharedReference<AtomicBoolean> failed) {
+            this.failed = failed;
         }
 
         @Override
         public Integer map(Integer value) {
-            if (lastCheckpointId >= 1 && emittedBetweenCheckpoint > 0 && !failed.get()) {
-                failed.set(true);
+            if (lastCheckpointId >= 1 && emittedBetweenCheckpoint > 0 && !failed.get().get()) {
+                failed.get().set(true);
                 throw new RuntimeException("Planned exception.");
             }
             emittedBetweenCheckpoint++;
