@@ -20,6 +20,7 @@ package org.apache.flink.test.streaming.runtime;
 import org.apache.flink.api.common.JobID;
 import org.apache.flink.api.common.typeinfo.BasicTypeInfo;
 import org.apache.flink.api.connector.sink2.Sink;
+import org.apache.flink.api.connector.sink2.WriterInitContext;
 import org.apache.flink.configuration.Configuration;
 import org.apache.flink.core.execution.JobClient;
 import org.apache.flink.metrics.Counter;
@@ -28,16 +29,18 @@ import org.apache.flink.metrics.Metric;
 import org.apache.flink.metrics.groups.OperatorMetricGroup;
 import org.apache.flink.metrics.groups.SinkWriterMetricGroup;
 import org.apache.flink.runtime.metrics.MetricNames;
+import org.apache.flink.runtime.metrics.groups.TaskMetricGroup;
 import org.apache.flink.runtime.testutils.InMemoryReporter;
 import org.apache.flink.runtime.testutils.MiniClusterResourceConfiguration;
 import org.apache.flink.streaming.api.environment.StreamExecutionEnvironment;
 import org.apache.flink.streaming.runtime.operators.sink.TestSinkV2;
+import org.apache.flink.streaming.runtime.operators.sink.TestSinkV2.Record;
 import org.apache.flink.test.util.MiniClusterWithClientResource;
 import org.apache.flink.testutils.junit.SharedObjects;
 import org.apache.flink.testutils.junit.SharedReference;
 import org.apache.flink.util.TestLogger;
 
-import org.apache.flink.shaded.guava31.com.google.common.collect.ImmutableMap;
+import org.apache.flink.shaded.guava32.com.google.common.collect.ImmutableMap;
 
 import org.junit.Rule;
 import org.junit.Test;
@@ -136,12 +139,15 @@ public class SinkV2MetricsITCase extends TestLogger {
                 sharedObjects.add(new CountDownLatch(numCommittables));
         SharedReference<CountDownLatch> afterLatch = sharedObjects.add(new CountDownLatch(1));
 
+        TestSinkV2<Long> sink =
+                TestSinkV2.<Long>newBuilder()
+                        .setCommitter(
+                                new MetricCommitter(beforeLatch, afterLatch),
+                                TestSinkV2.RecordSerializer::new)
+                        .build();
         env.fromSequence(0, numCommittables - 1)
                 .returns(BasicTypeInfo.LONG_TYPE_INFO)
-                .sinkTo(
-                        (TestSinkV2.<Long>newBuilder()
-                                        .setCommitter(new MetricCommitter(beforeLatch, afterLatch)))
-                                .build())
+                .sinkTo(sink)
                 .name(TEST_SINK_NAME);
         JobClient jobClient = env.executeAsync();
         final JobID jobId = jobClient.getJobID();
@@ -212,6 +218,25 @@ public class SinkV2MetricsITCase extends TestLogger {
                     .isEqualTo((processedRecordsPerSubtask - 1) * MetricWriter.BASE_SEND_TIME);
         }
         assertThat(subtaskWithMetrics, equalTo(numSplits));
+
+        // Test operator I/O metrics are reused by task metrics
+        List<TaskMetricGroup> taskMetricGroups =
+                reporter.findTaskMetricGroups(jobId, TEST_SINK_NAME);
+
+        int subtaskWithTaskMetrics = 0;
+        for (TaskMetricGroup taskMetricGroup : taskMetricGroups) {
+            // there are only 2 splits assigned; so two groups will not update metrics
+            if (taskMetricGroup.getIOMetricGroup().getNumRecordsOutCounter().getCount() == 0) {
+                continue;
+            }
+
+            subtaskWithTaskMetrics++;
+            assertThatCounter(taskMetricGroup.getIOMetricGroup().getNumRecordsOutCounter())
+                    .isEqualTo(processedRecordsPerSubtask);
+            assertThatCounter(taskMetricGroup.getIOMetricGroup().getNumBytesOutCounter())
+                    .isEqualTo(processedRecordsPerSubtask * MetricWriter.RECORD_SIZE_IN_BYTES);
+        }
+        assertThat(subtaskWithTaskMetrics, equalTo(numSplits));
     }
 
     private void assertSinkCommitterMetrics(JobID jobId, Map<String, Long> expected) {
@@ -257,7 +282,7 @@ public class SinkV2MetricsITCase extends TestLogger {
         private long sendTime;
 
         @Override
-        public void init(Sink.InitContext context) {
+        public void init(WriterInitContext context) {
             this.metricGroup = context.metricGroup();
             metricGroup.setCurrentSendTimeGauge(() -> sendTime);
         }
@@ -274,7 +299,7 @@ public class SinkV2MetricsITCase extends TestLogger {
         }
     }
 
-    private static class MetricCommitter extends TestSinkV2.DefaultCommitter {
+    private static class MetricCommitter extends TestSinkV2.DefaultCommitter<Record<Long>> {
         private int counter = 0;
         private SharedReference<CountDownLatch> beforeLatch;
         private SharedReference<CountDownLatch> afterLatch;
@@ -288,7 +313,7 @@ public class SinkV2MetricsITCase extends TestLogger {
         }
 
         @Override
-        public void commit(Collection<CommitRequest<String>> committables) {
+        public void commit(Collection<CommitRequest<Record<Long>>> committables) {
             if (counter == 0) {
                 System.err.println(
                         "Committables arrived "
@@ -312,26 +337,26 @@ public class SinkV2MetricsITCase extends TestLogger {
 
                 committables.forEach(
                         c -> {
-                            switch (c.getCommittable().charAt(1)) {
-                                case '0':
+                            switch (c.getCommittable().getValue().intValue()) {
+                                case 0:
                                     c.signalAlreadyCommitted();
                                     // 1 already committed
                                     break;
-                                case '1':
-                                case '2':
+                                case 1:
+                                case 2:
                                     // 2 failed
                                     c.signalFailedWithKnownReason(new RuntimeException());
                                     break;
-                                case '3':
+                                case 3:
                                     // Retry without change
                                     if (counter == 1) {
                                         c.retryLater();
                                     }
                                     break;
-                                case '4':
-                                case '5':
+                                case 4:
+                                case 5:
                                     // Retry with change
-                                    c.updateAndRetryLater("Retry-" + c.getCommittable());
+                                    c.updateAndRetryLater(c.getCommittable().withValue(6L));
                             }
                         });
             }
