@@ -19,7 +19,7 @@
 package org.apache.flink.test.streaming.runtime.util;
 
 import org.apache.flink.api.common.functions.OpenContext;
-import org.apache.flink.streaming.api.functions.sink.RichSinkFunction;
+import org.apache.flink.streaming.api.functions.sink.legacy.RichSinkFunction;
 
 import java.util.ArrayList;
 import java.util.List;
