@@ -18,7 +18,6 @@
 
 package org.apache.flink.yarn;
 
-import org.apache.flink.api.common.time.Time;
 import org.apache.flink.client.cli.CliFrontend;
 import org.apache.flink.configuration.Configuration;
 import org.apache.flink.configuration.GlobalConfiguration;
@@ -39,7 +38,7 @@ import org.apache.flink.yarn.cli.FlinkYarnSessionCli;
 import org.apache.flink.yarn.configuration.YarnConfigOptions;
 import org.apache.flink.yarn.util.TestUtils;
 
-import org.apache.flink.shaded.guava31.com.google.common.net.HostAndPort;
+import org.apache.flink.shaded.guava32.com.google.common.net.HostAndPort;
 
 import org.apache.commons.io.FileUtils;
 import org.apache.hadoop.yarn.api.records.ApplicationId;
@@ -54,7 +53,6 @@ import org.junit.jupiter.api.AfterEach;
 import org.junit.jupiter.api.BeforeAll;
 import org.junit.jupiter.api.Test;
 import org.junit.jupiter.api.extension.RegisterExtension;
-import org.junit.jupiter.api.io.TempDir;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 import org.slf4j.event.Level;
@@ -64,6 +62,7 @@ import java.io.IOException;
 import java.lang.reflect.InvocationTargetException;
 import java.lang.reflect.Method;
 import java.nio.charset.Charset;
+import java.time.Duration;
 import java.util.Arrays;
 import java.util.Collections;
 import java.util.EnumSet;
@@ -94,6 +93,9 @@ class YARNSessionCapacitySchedulerITCase extends YarnTestBase {
     private static final Logger LOG =
             LoggerFactory.getLogger(YARNSessionCapacitySchedulerITCase.class);
 
+    private static final ApplicationId TEST_YARN_APPLICATION_ID =
+            ApplicationId.newInstance(System.currentTimeMillis(), 42);
+
     /** RestClient to query Flink cluster. */
     private static RestClient restClient;
 
@@ -136,7 +138,7 @@ class YARNSessionCapacitySchedulerITCase extends YarnTestBase {
             YarnTestBase.teardown();
         } finally {
             if (restClient != null) {
-                restClient.shutdown(Time.seconds(5));
+                restClient.shutdown(Duration.ofSeconds(5));
             }
 
             if (restClientExecutor != null) {
@@ -172,98 +174,6 @@ class YARNSessionCapacitySchedulerITCase extends YarnTestBase {
                                 0));
     }
 
-    /**
-     * Test per-job yarn cluster
-     *
-     * <p>This also tests the prefixed CliFrontend options for the YARN case We also test if the
-     * requested parallelism of 2 is passed through. The parallelism is requested at the YARN client
-     * (-ys).
-     */
-    @Test
-    void perJobYarnCluster() throws Exception {
-        runTest(
-                () -> {
-                    LOG.info("Starting perJobYarnCluster()");
-                    File exampleJarLocation = getTestJarPath("BatchWordCount.jar");
-                    runWithArgs(
-                            new String[] {
-                                "run",
-                                "-m",
-                                "yarn-cluster",
-                                "-yj",
-                                flinkUberjar.getAbsolutePath(),
-                                "-yt",
-                                flinkLibFolder.getAbsolutePath(),
-                                "-ys",
-                                "2", // test that the job is executed with a DOP of 2
-                                "-yjm",
-                                "768m",
-                                "-ytm",
-                                "1024m",
-                                exampleJarLocation.getAbsolutePath()
-                            },
-                            /* test succeeded after this string */
-                            "Program execution finished",
-                            /* prohibited strings: (to verify the parallelism) */
-                            // (we should see "DataSink (...) (1/2)" and "DataSink (...) (2/2)"
-                            // instead)
-                            new String[] {"DataSink \\(.*\\) \\(1/1\\) switched to FINISHED"},
-                            RunTypes.CLI_FRONTEND,
-                            0,
-                            cliLoggerAuditingExtension::getMessages);
-                    LOG.info("Finished perJobYarnCluster()");
-                });
-    }
-
-    /**
-     * Test per-job yarn cluster and memory calculations for off-heap use (see FLINK-7400) with the
-     * same job as {@link #perJobYarnCluster()}.
-     *
-     * <p>This ensures that with (any) pre-allocated off-heap memory by us, there is some off-heap
-     * memory remaining for Flink's libraries. Creating task managers will thus fail if no off-heap
-     * memory remains.
-     */
-    @Test
-    void perJobYarnClusterOffHeap() throws Exception {
-        runTest(
-                () -> {
-                    LOG.info("Starting perJobYarnCluster()");
-                    File exampleJarLocation = getTestJarPath("BatchWordCount.jar");
-
-                    // set memory constraints (otherwise this is the same test as
-                    // perJobYarnCluster() above)
-                    final long taskManagerMemoryMB = 1024;
-
-                    runWithArgs(
-                            new String[] {
-                                "run",
-                                "-m",
-                                "yarn-cluster",
-                                "-yj",
-                                flinkUberjar.getAbsolutePath(),
-                                "-yt",
-                                flinkLibFolder.getAbsolutePath(),
-                                "-ys",
-                                "2", // test that the job is executed with a DOP of 2
-                                "-yjm",
-                                "768m",
-                                "-ytm",
-                                taskManagerMemoryMB + "m",
-                                exampleJarLocation.getAbsolutePath()
-                            },
-                            /* test succeeded after this string */
-                            "Program execution finished",
-                            /* prohibited strings: (to verify the parallelism) */
-                            // (we should see "DataSink (...) (1/2)" and "DataSink (...) (2/2)"
-                            // instead)
-                            new String[] {"DataSink \\(.*\\) \\(1/1\\) switched to FINISHED"},
-                            RunTypes.CLI_FRONTEND,
-                            0,
-                            cliLoggerAuditingExtension::getMessages);
-                    LOG.info("Finished perJobYarnCluster()");
-                });
-    }
-
     /**
      * Starts a session cluster on YARN, and submits a streaming job.
      *
@@ -477,78 +387,6 @@ class YARNSessionCapacitySchedulerITCase extends YarnTestBase {
                 });
     }
 
-    /**
-     * Test per-job yarn cluster with the parallelism set at the CliFrontend instead of the YARN
-     * client.
-     */
-    @Test
-    void perJobYarnClusterWithParallelism() throws Exception {
-        runTest(
-                () -> {
-                    LOG.info("Starting perJobYarnClusterWithParallelism()");
-                    File exampleJarLocation = getTestJarPath("BatchWordCount.jar");
-                    runWithArgs(
-                            new String[] {
-                                "run",
-                                "-p",
-                                "2", // test that the job is executed with a DOP of 2
-                                "-m",
-                                "yarn-cluster",
-                                "-yj",
-                                flinkUberjar.getAbsolutePath(),
-                                "-yt",
-                                flinkLibFolder.getAbsolutePath(),
-                                "-ys",
-                                "2",
-                                "-yjm",
-                                "768m",
-                                "-ytm",
-                                "1024m",
-                                exampleJarLocation.getAbsolutePath()
-                            },
-                            /* test succeeded after this string */
-                            "Program execution finished",
-                            /* prohibited strings: (we want to see "DataSink (...) (2/2) switched to FINISHED") */
-                            new String[] {"DataSink \\(.*\\) \\(1/1\\) switched to FINISHED"},
-                            RunTypes.CLI_FRONTEND,
-                            0,
-                            cliLoggerAuditingExtension::getMessages);
-                    LOG.info("Finished perJobYarnClusterWithParallelism()");
-                });
-    }
-
-    /** Test a fire-and-forget job submission to a YARN cluster. */
-    @Test
-    void testDetachedPerJobYarnCluster(@TempDir File tempDir) throws Exception {
-        runTest(
-                () -> {
-                    LOG.info("Starting testDetachedPerJobYarnCluster()");
-
-                    File exampleJarLocation = getTestJarPath("BatchWordCount.jar");
-
-                    testDetachedPerJobYarnClusterInternal(
-                            tempDir, exampleJarLocation.getAbsolutePath());
-
-                    LOG.info("Finished testDetachedPerJobYarnCluster()");
-                });
-    }
-
-    /** Test a fire-and-forget job submission to a YARN cluster. */
-    @Test
-    void testDetachedPerJobYarnClusterWithStreamingJob(@TempDir File tempDir) throws Exception {
-        runTest(
-                () -> {
-                    LOG.info("Starting testDetachedPerJobYarnClusterWithStreamingJob()");
-
-                    File exampleJarLocation = getTestJarPath("StreamingWordCount.jar");
-
-                    testDetachedPerJobYarnClusterInternal(
-                            tempDir, exampleJarLocation.getAbsolutePath());
-
-                    LOG.info("Finished testDetachedPerJobYarnClusterWithStreamingJob()");
-                });
-    }
-
     private void testDetachedPerJobYarnClusterInternal(File tempDir, String job) throws Exception {
         YarnClient yc = YarnClient.createYarnClient();
         yc.init(YARN_CONFIGURATION);
