@@ -48,7 +48,6 @@ import org.apache.flink.util.concurrent.ScheduledExecutorServiceAdapter;
 import org.apache.flink.yarn.YarnClusterDescriptor;
 import org.apache.flink.yarn.configuration.YarnConfigOptions;
 import org.apache.flink.yarn.configuration.YarnDeploymentTarget;
-import org.apache.flink.yarn.executors.YarnJobClusterExecutor;
 import org.apache.flink.yarn.executors.YarnSessionClusterExecutor;
 
 import org.apache.commons.cli.CommandLine;
@@ -85,7 +84,6 @@ import java.util.concurrent.TimeUnit;
 import java.util.stream.Stream;
 
 import static org.apache.flink.client.cli.CliFrontendParser.DETACHED_OPTION;
-import static org.apache.flink.client.cli.CliFrontendParser.YARN_DETACHED_OPTION;
 import static org.apache.flink.configuration.HighAvailabilityOptions.HA_CLUSTER_ID;
 import static org.apache.flink.util.Preconditions.checkNotNull;
 
@@ -275,7 +273,6 @@ public class FlinkYarnSessionCli extends AbstractYarnCli {
         allOptions.addOption(slots);
         allOptions.addOption(dynamicproperties);
         allOptions.addOption(DETACHED_OPTION);
-        allOptions.addOption(YARN_DETACHED_OPTION);
         allOptions.addOption(name);
         allOptions.addOption(applicationId);
         allOptions.addOption(applicationType);
@@ -406,10 +403,8 @@ public class FlinkYarnSessionCli extends AbstractYarnCli {
 
             effectiveConfiguration.set(HA_CLUSTER_ID, zooKeeperNamespace);
             effectiveConfiguration.set(YarnConfigOptions.APPLICATION_ID, applicationId.toString());
-            effectiveConfiguration.set(DeploymentOptions.TARGET, YarnSessionClusterExecutor.NAME);
-        } else {
-            effectiveConfiguration.set(DeploymentOptions.TARGET, YarnJobClusterExecutor.NAME);
         }
+        effectiveConfiguration.set(DeploymentOptions.TARGET, YarnSessionClusterExecutor.NAME);
 
         if (commandLine.hasOption(jmMemory.getOpt())) {
             String jmMemoryVal = commandLine.getOptionValue(jmMemory.getOpt());
@@ -479,9 +474,7 @@ public class FlinkYarnSessionCli extends AbstractYarnCli {
             configuration.set(YarnConfigOptions.APPLICATION_QUEUE, queueName);
         }
 
-        final boolean detached =
-                commandLine.hasOption(YARN_DETACHED_OPTION.getOpt())
-                        || commandLine.hasOption(DETACHED_OPTION.getOpt());
+        final boolean detached = commandLine.hasOption(DETACHED_OPTION.getOpt());
         configuration.set(DeploymentOptions.ATTACHED, !detached);
 
         if (commandLine.hasOption(name.getOpt())) {
@@ -531,8 +524,7 @@ public class FlinkYarnSessionCli extends AbstractYarnCli {
     }
 
     private boolean isDetachedOption(Option option) {
-        return option.getOpt().equals(YARN_DETACHED_OPTION.getOpt())
-                || option.getOpt().equals(DETACHED_OPTION.getOpt());
+        return option.getOpt().equals(DETACHED_OPTION.getOpt());
     }
 
     private Configuration applyYarnProperties(Configuration configuration) throws FlinkException {
