@@ -32,7 +32,7 @@ import org.apache.flink.runtime.util.HadoopUtils;
 import org.apache.flink.util.ExceptionUtils;
 import org.apache.flink.yarn.configuration.YarnResourceManagerDriverConfiguration;
 
-import org.apache.flink.shaded.guava31.com.google.common.collect.ImmutableList;
+import org.apache.flink.shaded.guava32.com.google.common.collect.ImmutableList;
 
 import org.apache.hadoop.fs.Path;
 import org.apache.hadoop.yarn.api.ApplicationConstants;
@@ -702,7 +702,7 @@ public class YarnResourceManagerDriverTest extends ResourceManagerDriverTestBase
     private static Container createTestingContainerWithResource(
             Resource resource, Priority priority, int containerIdx) {
         final ContainerId containerId =
-                ContainerId.newInstance(
+                ContainerId.newContainerId(
                         ApplicationAttemptId.newInstance(
                                 ApplicationId.newInstance(System.currentTimeMillis(), 1), 1),
                         containerIdx);
@@ -729,8 +729,8 @@ public class YarnResourceManagerDriverTest extends ResourceManagerDriverTestBase
         final CompletableFuture<Void> nodeManagerClientStartFuture = new CompletableFuture<>();
         final CompletableFuture<Void> nodeManagerClientStopFuture = new CompletableFuture<>();
 
-        AMRMClientAsync.CallbackHandler resourceManagerClientCallbackHandler;
-        NMClientAsync.CallbackHandler nodeManagerClientCallbackHandler;
+        AMRMClientAsync.AbstractCallbackHandler resourceManagerClientCallbackHandler;
+        NMClientAsync.AbstractCallbackHandler nodeManagerClientCallbackHandler;
         TestingYarnNMClientAsync testingYarnNMClientAsync;
         TestingYarnAMRMClientAsync testingYarnAMRMClientAsync;
         final TestingYarnNMClientAsync.Builder testingYarnNMClientAsyncBuilder =
